@@ -1126,8 +1126,8 @@ edv_archive_info_struct *EDVArchiveInfoNew(
 	gtk_widget_modify_style(w, rcstyle);
 	gdk_window_set_cursor(w->window, d->text_cur);
 	gtk_widget_show(w);
-	GTK_RC_STYLE_UNREF(rcstyle)
-	/* Vertical scroll bar */
+	GTK_RC_STYLE_UNREF(rcstyle);
+	/* Vertical GtkScrollBar */
 	sb = gtk_vscrollbar_new(GTK_TEXT(w)->vadj);
 	gtk_table_attach(
 	    GTK_TABLE(parent3), sb,
