@@ -630,7 +630,7 @@ gboolean EDVArchAddOptsGetResponse(
 "-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-1"
 #endif
 		);
-		w = gtk_label_new(EDVGetPathName(arch_obj));
+		w = gtk_label_new(g_basename(arch_obj));
 		gtk_label_set_justify(GTK_LABEL(w), GTK_JUSTIFY_LEFT);
 		gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 		gtk_widget_modify_style(w, rcstyle);
@@ -1207,7 +1207,7 @@ gboolean EDVArchExtractOptsGetResponse(
 "-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-1"
 #endif
 		);
-		w = gtk_label_new(EDVGetPathName(arch_obj));
+		w = gtk_label_new(g_basename(arch_obj));
 		gtk_label_set_justify(GTK_LABEL(w), GTK_JUSTIFY_LEFT);
 		gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 		gtk_widget_modify_style(w, rcstyle);
