@@ -121,7 +121,7 @@ void EDVArchiverUpdateContentsHeadings(
 	edv_archiver_struct *archiver,
 	const gint *contents_heading, gint total_contents_headings
 );
-void EDVArchiverSetBusy(edv_archiver_struct *archiver, gboolean is_busy);
+void EDVArchiverSetBusy(edv_archiver_struct *archiver, gboolean busy);
 gboolean EDVArchiverIsMapped(edv_archiver_struct *archiver);
 void EDVArchiverMap(edv_archiver_struct *archiver);
 void EDVArchiverUnmap(edv_archiver_struct *archiver);
@@ -691,8 +691,8 @@ void EDVArchiverToolBarRegenerate(edv_archiver_struct *archiver)
 	    return;
 
 	/* Delete existing Tool Bar if any */
-	ToolBarDelete(archiver->toolbar);
-	archiver->toolbar = NULL;
+	ToolBarDelete(archiver->tool_bar);
+	archiver->tool_bar = NULL;
 
 	/* Create Tool Bar items list */
 	glist = intlist->list;
@@ -744,7 +744,7 @@ void EDVArchiverToolBarRegenerate(edv_archiver_struct *archiver)
 	}
 
 	/* Create new Tool Bar */
-	archiver->toolbar = toolbar = ToolBarNew(
+	archiver->tool_bar = toolbar = ToolBarNew(
 	    item, total_items, parent,
 	    tb_display, tb_relief, FALSE
 	);
@@ -1317,7 +1317,7 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 #else
 	button_name = "Add";
 	menu_name = "Add...";
-	tooltip = "Add objects to archive";
+	tooltip = "Add objects to the archive";
 #endif
 	accel_key = GDK_Insert;
 	accel_mods = 0;
@@ -1343,7 +1343,7 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 #else
 	button_name = "Extract";
 	menu_name = "Extract...";
-	tooltip = "Extract selected object(s) from archive";
+	tooltip = "Extract the selected object(s) from the archive";
 #endif
 	accel_key = GDK_Return;
 	accel_mods = 0;
@@ -1369,7 +1369,7 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 #else
 	button_name = "ExtractAll";
 	menu_name = "Extract All...";
-	tooltip = "Extract all objects from archive";
+	tooltip = "Extract all objects from the archive";
 #endif
 	accel_key = GDK_Return;
 	accel_mods = GDK_SHIFT_MASK;
@@ -1395,7 +1395,7 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 #else
 	button_name = "Delete";
 	menu_name = "Delete";
-	tooltip = "Delete selected object(s) from archive";
+	tooltip = "Delete the selected object(s) from the archive";
 #endif
 	accel_key = GDK_Delete;
 	accel_mods = 0;
@@ -1421,7 +1421,7 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 #else
 	button_name = "Properties";
 	menu_name = "Properties...";
-	tooltip = "Modify selected object's properties";
+	tooltip = "Modify the archive's properties";
 #endif
 	accel_key = GDK_Return;
 	accel_mods = GDK_CONTROL_MASK;
@@ -1994,9 +1994,15 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 	flags = 0;
 	button_icon_data = (guint8 **)icon_help_20x20_xpm;
 	menu_icon_data = NULL;
+#if defined(PROG_LANGUAGE_FRENCH)
+	button_name = "Aide";
+	menu_name = "Corbeille";
+	tooltip = "Aide sur l'utilisation de la Corbeille";
+#else
 	button_name = "Help";
 	menu_name = "Recycle Bin";
 	tooltip = "Help on using the recycle bin";
+#endif
 	accel_key = 0;
 	accel_mods = 0;
 	DO_APPEND_OPID
@@ -2689,7 +2695,7 @@ edv_archiver_struct *EDVArchiverNew(gpointer core_ptr)
 	archiver->contents_clist_selected_row = -1;
 	archiver->last_recbin_items = -1;
 	archiver->last_write_protect_state = -1;
-	archiver->findbar = NULL;
+	archiver->find_bar = NULL;
 	archiver->status_bar = NULL;
 
 
@@ -2798,7 +2804,7 @@ edv_archiver_struct *EDVArchiverNew(gpointer core_ptr)
 	if(archiver->tool_bar_map_state)
 	    gtk_widget_show(w);
 	/* Build tool bar later */
-	archiver->toolbar = NULL;
+	archiver->tool_bar = NULL;
 
 
 	/* Location bar handle box */
@@ -2939,8 +2945,8 @@ edv_archiver_struct *EDVArchiverNew(gpointer core_ptr)
 		dnd_src_types,
 		sizeof(dnd_src_types) / sizeof(GtkTargetEntry),
 		GDK_ACTION_COPY | GDK_ACTION_MOVE |
-		GDK_ACTION_LINK,			/* Actions */
-		GDK_BUTTON1_MASK | GDK_BUTTON2_MASK,	/* Buttons */
+		GDK_ACTION_LINK,		/* Actions */
+		GDK_BUTTON1_MASK,		/* Buttons */
 		NULL,
 		EDVLocBarIconDragDataGet,
 		NULL,
@@ -3034,7 +3040,7 @@ edv_archiver_struct *EDVArchiverNew(gpointer core_ptr)
 	parent2 = w;
 
 	/* Create the Find Bar */
-	archiver->findbar = EDVFindBarNew(
+	archiver->find_bar = EDVFindBarNew(
 	    core_ptr, parent2,
 	    EDV_FINDBAR_ROLE_ARCHIVE_OBJECT,
 	    EDVArchiverFindBarLocationCB,
@@ -3045,7 +3051,7 @@ edv_archiver_struct *EDVArchiverNew(gpointer core_ptr)
             EDVArchiverStatusProgressCB,
 	    archiver
 	);
-	EDVFindBarMap(archiver->findbar);
+	EDVFindBarMap(archiver->find_bar);
 
 
 	/* Scrolled window for contents clist */
@@ -3091,11 +3097,11 @@ edv_archiver_struct *EDVArchiverNew(gpointer core_ptr)
 	    GTK_OBJECT(w), "motion_notify_event",
 	    GTK_SIGNAL_FUNC(EDVCListMotionEventCB), core_ptr
 	);
-	gtk_signal_connect(
+	gtk_signal_connect_after(
 	    GTK_OBJECT(w), "key_press_event",
 	    GTK_SIGNAL_FUNC(EDVArchiverKeyEventCB), archiver
 	);
-	gtk_signal_connect(
+	gtk_signal_connect_after(
 	    GTK_OBJECT(w), "key_release_event",
 	    GTK_SIGNAL_FUNC(EDVArchiverKeyEventCB), archiver
 	);
@@ -3132,7 +3138,7 @@ edv_archiver_struct *EDVArchiverNew(gpointer core_ptr)
 	    dnd_src_types,
 	    sizeof(dnd_src_types) / sizeof(GtkTargetEntry),
 	    GDK_ACTION_COPY,			/* Actions */
-	    GDK_BUTTON1_MASK | GDK_BUTTON2_MASK,/* Buttons */
+	    GDK_BUTTON1_MASK,			/* Buttons */
 	    NULL,
 	    EDVArchiverContentsDragDataGetCB,
 	    EDVArchiverContentsDragDataDeleteCB,
@@ -3244,7 +3250,7 @@ void EDVArchiverUpdateMenus(edv_archiver_struct *archiver)
 	    return;
 
 	cfg_list = core_ptr->cfg_list;
-	tb = archiver->toolbar;
+	tb = archiver->tool_bar;
 
 #define DO_SHOW			\
 { if(w != NULL) gtk_widget_show(w); }
@@ -3444,54 +3450,42 @@ void EDVArchiverUpdateMenus(edv_archiver_struct *archiver)
 /*
  *      Marks the archiver as busy or ready.
  */
-void EDVArchiverSetBusy(edv_archiver_struct *archiver, gboolean is_busy)
+void EDVArchiverSetBusy(edv_archiver_struct *archiver, gboolean busy)
 {
-	GdkCursor *cursor;
+	GdkCursor *cur;
 	GtkWidget *w;
 	edv_core_struct *core_ptr;
 
-
 	if(archiver == NULL)
 	    return;
 
+	w = archiver->toplevel;
 	core_ptr = EDV_CORE(archiver->core_ptr);
-	if(core_ptr == NULL)
+	if((w == NULL) || (core_ptr == NULL))
 	    return;
 
-	w = archiver->toplevel;
-	if(w != NULL)
+	if(busy)
 	{
-	    if(is_busy)
-	    {
-		/* Increase busy count */
-		archiver->busy_count++;
+	    archiver->busy_count++;
+	    if(archiver->busy_count > 1)
+		return;
 
-		/* If already busy then don't change anything */
-		if(archiver->busy_count > 1)
-		    return;
+	    cur = EDVGetCursor(core_ptr, EDV_CURSOR_CODE_BUSY);
+	}
+	else
+	{
+	    archiver->busy_count--;
+	    if(archiver->busy_count < 0)
+		archiver->busy_count = 0;
+	    if(archiver->busy_count > 0)
+		return;
+	    cur = NULL;
+	}
 
-		cursor = EDVGetCursor(core_ptr, EDV_CURSOR_CODE_BUSY);
-	    }
-	    else
-	    {
-		/* Reduce busy count */
-		archiver->busy_count--;
-		if(archiver->busy_count < 0)
-		    archiver->busy_count = 0;
-
-		/* If still busy do not change anything */
-		if(archiver->busy_count > 0)
-		    return;
-
-		cursor = NULL;  /* Use default cursor */
-	    }
-
-	    /* Update toplevel window's cursor */
-	    if(w->window != NULL)
-	    {
-		gdk_window_set_cursor(w->window, cursor);
-		gdk_flush();
-	    }
+	if(w->window != NULL)
+	{
+	    gdk_window_set_cursor(w->window, cur);
+	    gdk_flush();
 	}
 }
 
@@ -3551,14 +3545,14 @@ void EDVArchiverDelete(edv_archiver_struct *archiver)
 
 	EDVStatusBarDelete(archiver->status_bar);
 
-	EDVFindBarDelete(archiver->findbar);
+	EDVFindBarDelete(archiver->find_bar);
 
 	GTK_WIDGET_DESTROY(archiver->location_password_entry);
 	GTK_WIDGET_DESTROY(archiver->location_combo);
 	GTK_WIDGET_DESTROY(archiver->location_icon_pm);
 	GTK_WIDGET_DESTROY(archiver->location_icon_fixed);
 
-	ToolBarDelete(archiver->toolbar);
+	ToolBarDelete(archiver->tool_bar);
 
 	GTK_WIDGET_DESTROY(archiver->menu_bar);
 
