@@ -183,13 +183,13 @@ struct _edv_archiver_struct {
 
 			*contents_clist;	/* Contents GtkCList */
 
-	/* General tool bar */
-	toolbar_struct	*toolbar;
+	/* Tool Bar */
+	toolbar_struct		*tool_bar;
 
-	/* Find bar */
-	edv_findbar_struct	*findbar;
+	/* Find Bar */
+	edv_findbar_struct	*find_bar;
 
-	/* Important menu items */
+	/* Menus and Menu Items */
 	GtkWidget	*new_mi,
 			*open_mi,
 			*sync_disks_mi,
@@ -328,7 +328,7 @@ extern void EDVArchiverUpdateContentsHeadings(
 	edv_archiver_struct *archiver,
 	const gint *contents_heading, gint total_contents_headings
 );
-extern void EDVArchiverSetBusy(edv_archiver_struct *archiver, gboolean is_busy);
+extern void EDVArchiverSetBusy(edv_archiver_struct *archiver, gboolean busy);
 extern gboolean EDVArchiverIsMapped(edv_archiver_struct *archiver);
 extern void EDVArchiverMap(edv_archiver_struct *archiver);
 extern void EDVArchiverUnmap(edv_archiver_struct *archiver);
