@@ -120,27 +120,27 @@ void EDVArchiverReconfiguredNotifyCB(edv_archiver_struct *archiver);
 
 void EDVArchiverMimeTypeAddedCB(
 	edv_archiver_struct *archiver,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 );
 void EDVArchiverMimeTypeModifiedCB(
 	edv_archiver_struct *archiver,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 );
 void EDVArchiverMimeTypeRemovedCB(
 	edv_archiver_struct *archiver, gint mt_num
 );
 
 
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
@@ -302,7 +302,7 @@ gint EDVArchiverKeyEventCB(
 	    return(status);
 
 	w = archiver->toplevel;
-	focus_widget = (w != NULL) ? GTK_WINDOW(w)->focus_widget : NULL;        
+	focus_widget = (w != NULL) ? GTK_WINDOW(w)->focus_widget : NULL;
 	cfg_list = core_ptr->cfg_list;
 	etype = key->type;
 	is_press = (etype == GDK_KEY_PRESS) ? TRUE : FALSE;
@@ -392,8 +392,9 @@ gint EDVArchiverKeyEventCB(
 		 * item who's name starts with the letter of the key
 		 * that was pressed
 		 */
-		if(isalnum((char)keyval) && is_press &&
-		   ((state == 0x00000000) || (state == GDK_SHIFT_MASK))
+		if(isalnum((int)keyval) && is_press &&
+                   !(state & GDK_CONTROL_MASK) &&
+                   !(state & GDK_SHIFT_MASK)    
 		)
 		{
 		    /* Get the column that is displaying the object
@@ -796,9 +797,10 @@ void EDVArchiverSelectRowCB(
 	/* Check which clist this signal is for */
 	if(GTK_WIDGET(clist) == archiver->contents_clist)
 	{
+	    edv_core_struct *core_ptr = EDV_CORE(archiver->core_ptr);
+
 	    /* Get total number of objects selected */
-	    gint total_selected = (clist->selection != NULL) ?
-		g_list_length(clist->selection) : 0;
+	    const gint nselected = g_list_length(clist->selection);
 
 	    /* Get object */
 	    edv_archive_object_struct *obj = EDV_ARCHIVE_OBJECT(
@@ -862,10 +864,10 @@ void EDVArchiverSelectRowCB(
 		    }
 
 		    /* Set status bar message */
-		    if(total_selected > 1)
+		    if(nselected > 1)
 			buf = g_strdup_printf(
-			    "%i objects selected",
-			    total_selected
+			    "%s objects selected",
+			    EDVGetObjectSizeStr(core_ptr, nselected)
 			);
 		    else if(!strcmp(obj->name, ".."))
 			buf = g_strdup_printf(
@@ -927,7 +929,25 @@ void EDVArchiverUnselectRowCB(
 	/* Check which clist this signal is for */
 	if(GTK_WIDGET(clist) == archiver->contents_clist)
 	{
+	    gchar *buf;
+	    edv_core_struct *core_ptr = EDV_CORE(archiver->core_ptr);
 
+	    /* Get total number of objects selected */
+	    const gint nselected = g_list_length(clist->selection);
+
+	    /* Update status bar message */
+	    if(nselected > 0)
+		buf = g_strdup_printf(
+		    "%s object%s selected",
+		    EDVGetObjectSizeStr(core_ptr, nselected),
+		    (nselected == 1) ? "" : "s"
+		);
+	    else
+		buf = STRDUP("No objects selected");
+	    EDVStatusBarMessage(
+		archiver->status_bar, buf, FALSE
+	    );
+	    g_free(buf);
 
 	    EDVArchiverUpdateMenus(archiver);
 	}
@@ -1114,16 +1134,14 @@ void EDVArchiverObjectRemovedNotifyCB(
 
 
 /*
- *      Called whenever an archive object has been add to the
- *      specified archive arch_path.
+ *	Object added to archive callback.
  */
 void EDVArchiverArchiveObjectAddedNotifyCB(
 	edv_archiver_struct *archiver, const gchar *arch_path,
 	const gchar *path, edv_archive_object_struct *obj
 )
 {
-	const gchar *cur_path;
-
+	const gchar *cur_loc;
 
 	if(archiver == NULL)
 	    return;
@@ -1134,10 +1152,10 @@ void EDVArchiverArchiveObjectAddedNotifyCB(
 	/* Compare the archive path with the current archive selected
 	 * by this archiver
 	 */
-	cur_path = EDVArchiverCurrentLocation(archiver);
-	if((cur_path != NULL) && (arch_path != NULL))
+	cur_loc = EDVArchiverCurrentLocation(archiver);
+	if((cur_loc != NULL) && (arch_path != NULL))
 	{
-	    if(!strcmp(cur_path, arch_path))
+	    if(!strcmp(cur_loc, arch_path))
 	    {
 		/* Notify contents list */
 		EDVArchiverContentsArchiveObjectAddedNotify(
@@ -1150,8 +1168,7 @@ void EDVArchiverArchiveObjectAddedNotifyCB(
 }
 
 /*
- *	Called whenever an archive object has been modified in the
- *      specified archive arch_path.
+ *	Object modified in archive callback.
  */
 void EDVArchiverArchiveObjectModifiedNotifyCB(
 	edv_archiver_struct *archiver, const gchar *arch_path,
@@ -1159,8 +1176,7 @@ void EDVArchiverArchiveObjectModifiedNotifyCB(
 	edv_archive_object_struct *obj
 )
 {
-	const gchar *cur_path;
-
+	const gchar *cur_loc;
 
 	if(archiver == NULL)
 	    return;
@@ -1171,10 +1187,10 @@ void EDVArchiverArchiveObjectModifiedNotifyCB(
 	/* Compare the archive path with the current archive selected
 	 * by this archiver
 	 */
-	cur_path = EDVArchiverCurrentLocation(archiver);
-	if((cur_path != NULL) && (arch_path != NULL))
+	cur_loc = EDVArchiverCurrentLocation(archiver);
+	if((cur_loc != NULL) && (arch_path != NULL))
 	{
-	    if(!strcmp(cur_path, arch_path))
+	    if(!strcmp(cur_loc, arch_path))
 	    {
 		/* Notify contents list */
 		EDVArchiverContentsArchiveObjectModifiedNotify(
@@ -1187,16 +1203,14 @@ void EDVArchiverArchiveObjectModifiedNotifyCB(
 }
 
 /*
- *	Called whenever an archive object has been removed from the
- *	specified archive arch_path.
+ *	Object removed from archive callback.
  */
 void EDVArchiverArchiveObjectRemovedNotifyCB(
 	edv_archiver_struct *archiver, const gchar *arch_path,
 	const gchar *path
 )
 {
-	const gchar *cur_path;
-
+	const gchar *cur_loc;
 
 	if(archiver == NULL)
 	    return;
@@ -1207,10 +1221,10 @@ void EDVArchiverArchiveObjectRemovedNotifyCB(
 	/* Compare the archive path with the current archive selected
 	 * by this archiver
 	 */
-	cur_path = EDVArchiverCurrentLocation(archiver);
-	if((cur_path != NULL) && (arch_path != NULL))
+	cur_loc = EDVArchiverCurrentLocation(archiver);
+	if((cur_loc != NULL) && (arch_path != NULL))
 	{
-	    if(!strcmp(cur_path, arch_path))
+	    if(!strcmp(cur_loc, arch_path))
 	    {
 		/* Notify contents list */
 		EDVArchiverContentsArchiveObjectRemovedNotify(
@@ -1223,7 +1237,7 @@ void EDVArchiverArchiveObjectRemovedNotifyCB(
 }
 
 /*
- *      Called whenever an object has been added to the Archiver.
+ *	Recycled object added callback.
  */
 void EDVArchiverRecycledObjectAddedNotifyCB(
 	edv_archiver_struct *archiver, guint index
@@ -1231,7 +1245,6 @@ void EDVArchiverRecycledObjectAddedNotifyCB(
 {
 	edv_core_struct *core_ptr;
 
-
 	if(archiver == NULL)
 	    return;
 
@@ -1239,17 +1252,16 @@ void EDVArchiverRecycledObjectAddedNotifyCB(
 	if(core_ptr == NULL)
 	    return;
 
-
 	/* There is not much interest when a recycled object has been
 	 * added or removed. Only the menus need to be updated if there
-	 * is a change in the number of recycled objects.
+	 * is a change in the number of recycled objects
 	 */
 	if(core_ptr->last_recbin_items != archiver->last_recbin_items)
 	    EDVArchiverUpdateMenus(archiver);
 }
 
 /*
- *      Called whenever an object has been removed from the Archiver.
+ *	Recycled object removed callback.
  */
 void EDVArchiverRecycledObjectRemovedNotifyCB(
 	edv_archiver_struct *archiver, guint index
@@ -1257,7 +1269,6 @@ void EDVArchiverRecycledObjectRemovedNotifyCB(
 {
 	edv_core_struct *core_ptr;
 
-
 	if(archiver == NULL)
 	    return;
 
@@ -1267,7 +1278,7 @@ void EDVArchiverRecycledObjectRemovedNotifyCB(
 
 	/* There is not much interest when a recycled object has been
 	 * added or removed. Only the menus need to be updated if there
-	 * is a change in the number of recycled objects.
+	 * is a change in the number of recycled objects
 	 */
 	if(core_ptr->last_recbin_items != archiver->last_recbin_items)
 	    EDVArchiverUpdateMenus(archiver);
@@ -1275,11 +1286,11 @@ void EDVArchiverRecycledObjectRemovedNotifyCB(
 
 
 /*
- *      Reconfigured notify callback.
+ *	Reconfigured callback.
  */
 void EDVArchiverReconfiguredNotifyCB(edv_archiver_struct *archiver)
 {
-	gchar *cur_path;
+	gchar *cur_loc;
 	GtkRcStyle *standard_rcstyle, *lists_rcstyle;
 	GtkWidget *w;
 	const cfg_item_struct *cfg_list;
@@ -1308,12 +1319,12 @@ void EDVArchiverReconfiguredNotifyCB(edv_archiver_struct *archiver)
 	archiver->last_write_protect_state = -1;
 
 
-	/* Get copy of current location path */
-	cur_path = STRDUP(EDVArchiverCurrentLocation(archiver));
+	/* Get the current location */
+	cur_loc = STRDUP(EDVArchiverCurrentLocation(archiver));
 
 
 	/* Update title */
-	EDVArchiverSetTitle(archiver, cur_path);
+	EDVArchiverSetTitle(archiver, cur_loc);
 
 	/* Update Accelkey Labels */
 	EDVArchiverAccelkeysRegenerate(archiver);
@@ -1396,35 +1407,34 @@ void EDVArchiverReconfiguredNotifyCB(edv_archiver_struct *archiver)
 	if(w != NULL)
 	    gtk_widget_queue_resize(w);
 
-	g_free(cur_path);
+	g_free(cur_loc);
 }
 
 
 /*
- *      Called whenever a MIME Type has been added to the core
- *      structure's list of MIME Types.
+ *	MIME Type added callback.
  */
 void EDVArchiverMimeTypeAddedCB(
 	edv_archiver_struct *archiver,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 )
 {
-	/* Treat a MIME Type added the same as it would be for a MIME Type
-	 * modified, forward signal to the MIME Type modified callback.
+	/* Treat a MIME Type added the same as it would be for a MIME
+	 * Type modified, forward signal to the MIME Type modified
+	 * callback
 	 */
-	EDVArchiverMimeTypeModifiedCB(archiver, mt_num, mt_ptr);
+	EDVArchiverMimeTypeModifiedCB(archiver, mt_num, mt);
 }
 
 /*
- *      Called whenever a MIME Type has been modified on the core
- *      structure's list of MIME Types.
+ *	MIME Type modified callback.
  */
 void EDVArchiverMimeTypeModifiedCB(
 	edv_archiver_struct *archiver,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 )
 {
-	gchar *cur_path;
+	gchar *cur_loc;
 	edv_core_struct *core_ptr;
 
 	if(archiver == NULL)
@@ -1438,25 +1448,24 @@ void EDVArchiverMimeTypeModifiedCB(
 	    return;
 
 	/* Get the current location */
-	cur_path = STRDUP(EDVArchiverCurrentLocation(archiver));
+	cur_loc = STRDUP(EDVArchiverCurrentLocation(archiver));
 
 	/* Realize listings */
 	EDVArchiverContentsRealizeListing(archiver);
 
 /*	EDVArchiverUpdateMenus(archiver); */
 
-	g_free(cur_path);
+	g_free(cur_loc);
 }
 
 /*
- *      Called whenever a MIME Type has been removed from the core
- *      structure's list of MIME Types.
+ *	MIME Type removed callback.
  */
 void EDVArchiverMimeTypeRemovedCB(
 	edv_archiver_struct *archiver, gint mt_num
 )
 {
-	gchar *cur_path;
+	gchar *cur_loc;
 	edv_core_struct *core_ptr;
 
 	if(archiver == NULL)
@@ -1470,13 +1479,12 @@ void EDVArchiverMimeTypeRemovedCB(
 	    return;
 
 	/* Get the current location */
-	cur_path = STRDUP(EDVArchiverCurrentLocation(archiver));
+	cur_loc = STRDUP(EDVArchiverCurrentLocation(archiver));
 
 	/* Realize listings */
 	EDVArchiverContentsRealizeListing(archiver);
 
 /*	EDVArchiverUpdateMenus(archiver); */
 
-	g_free(cur_path);
+	g_free(cur_loc);
 }
-
