@@ -91,11 +91,11 @@ extern void EDVArchiverReconfiguredNotifyCB(edv_archiver_struct *archiver);
 
 extern void EDVArchiverMimeTypeAddedCB(
 	edv_archiver_struct *archiver,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 );
 extern void EDVArchiverMimeTypeModifiedCB(
 	edv_archiver_struct *archiver,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 );
 extern void EDVArchiverMimeTypeRemovedCB(
 	edv_archiver_struct *archiver, gint mt_num
