@@ -267,16 +267,14 @@ static void EDVArchiverDragDataReceivedNexus(
 	    url = URL(url_list->data);
 	    if((url != NULL) ? (url->path != NULL) : FALSE)
 	    {
-		if(EDVCheckEDVArchiverArchive(
-		    core_ptr, EDVGetPathName(url->path)
-		))
+		const gchar *name = g_basename(url->path);
+		if(EDVCheckEDVArchiverArchive(core_ptr, name))
 		{
 		    /* There is exactly one DND object reference and
 		     * if is an archive, so query user about opening
 		     * it instead of adding it to the current archive
 		     */
 		    gint status;
-		    const gchar *name = EDVGetPathName(url->path);
 		    gchar *buf = g_strdup_printf(
 #if defined(PROG_LANGUAGE_SPANISH)
 "El archivo abierto \"%s\" en vez de agregarlo al\n\
