@@ -155,6 +155,7 @@ void EDVArchiverOPCB(
 	toolbar_item_struct *item, gint id, gpointer data  
 )
 {
+	GtkWidget *toplevel;
 	edv_archiver_struct *archiver;
 	edv_core_struct *core_ptr;
 	edv_archiver_opid_struct *opid = EDV_ARCHIVER_OPID(data);
@@ -168,6 +169,7 @@ void EDVArchiverOPCB(
 	if(archiver->processing || (archiver->freeze_count > 0))
 	    return;
 
+	toplevel = archiver->toplevel;
 	core_ptr = EDV_CORE(archiver->core_ptr);
 	if(core_ptr == NULL)
 	    return;
@@ -237,7 +239,7 @@ void EDVArchiverOPCB(
 
 
 	  case EDV_ARCHIVER_OP_HISTORY:
-	    EDVMapHistoryListWin(core_ptr, archiver->toplevel);
+	    EDVMapHistoryListWin(core_ptr, toplevel);
 	    break;
 
 	  case EDV_ARCHIVER_OP_SYNC_DISKS:
@@ -253,12 +255,19 @@ void EDVArchiverOPCB(
 		core_ptr,
 		NULL,
 		NULL,
-		archiver->toplevel
+		toplevel
 	    );
 	    break;
 
 	  case EDV_ARCHIVER_OP_RUN_TERMINAL:
-	    EDVRunTerminal(core_ptr, NULL, archiver->toplevel);
+	    if(core_ptr != NULL)
+	    {
+		gchar	*location = STRDUP(EDVArchiverCurrentLocation(archiver)),
+			*wd = g_dirname(location);
+		EDVRunTerminal(core_ptr, NULL, wd, toplevel);
+		g_free(wd);
+		g_free(location);
+	    }
 	    break;
 
 
@@ -332,7 +341,7 @@ void EDVArchiverOPCB(
 
 
 	  case EDV_ARCHIVER_OP_MIME_TYPES:
-	    EDVMapMIMETypesListWin(core_ptr, archiver->toplevel);
+	    EDVMapMIMETypesListWin(core_ptr, toplevel);
 	    break;
 
 
@@ -354,37 +363,37 @@ void EDVArchiverOPCB(
 
 
 	  case EDV_ARCHIVER_OP_OPTIONS:
-	    EDVMapOptionsWin(core_ptr, archiver->toplevel);
+	    EDVMapOptionsWin(core_ptr, toplevel);
 	    break;
 
 	  case EDV_ARCHIVER_OP_CUSTOMIZE:
-	    EDVMapCustomizeWin(core_ptr, archiver->toplevel);
+	    EDVMapCustomizeWin(core_ptr, toplevel);
 	    break;
 
 
 	  case EDV_ARCHIVER_OP_HELP_ABOUT:
-	    EDVAbout(core_ptr, archiver->toplevel);
+	    EDVAbout(core_ptr, toplevel);
 	    break;
 	  case EDV_ARCHIVER_OP_HELP_CONTENTS:
-	    EDVHelp(core_ptr, "Contents", archiver->toplevel);
+	    EDVHelp(core_ptr, "Contents", toplevel);
 	    break;
 	  case EDV_ARCHIVER_OP_HELP_FILE_BROWSER:
-	    EDVHelp(core_ptr, "File Browser", archiver->toplevel);
+	    EDVHelp(core_ptr, "File Browser", toplevel);
 	    break;
 	  case EDV_ARCHIVER_OP_HELP_IMAGE_BROWSER:
-	    EDVHelp(core_ptr, "Image Browser", archiver->toplevel);
+	    EDVHelp(core_ptr, "Image Browser", toplevel);
 	    break;
 	  case EDV_ARCHIVER_OP_HELP_ARCHIVER:
-	    EDVHelp(core_ptr, "Archiver", archiver->toplevel);
+	    EDVHelp(core_ptr, "Archiver", toplevel);
 	    break;
 	  case EDV_ARCHIVER_OP_HELP_RECYCLE_BIN:
-	    EDVHelp(core_ptr, "Recycle Bin", archiver->toplevel);
+	    EDVHelp(core_ptr, "Recycle Bin", toplevel);
 	    break;
 	  case EDV_ARCHIVER_OP_HELP_KEYS_LIST:
-	    EDVHelp(core_ptr, "Keys List", archiver->toplevel);
+	    EDVHelp(core_ptr, "Keys List", toplevel);
 	    break;
 	  case EDV_ARCHIVER_OP_HELP_COMMON_OPERATIONS:
-	    EDVHelp(core_ptr, "Common Operations", archiver->toplevel);
+	    EDVHelp(core_ptr, "Common Operations", toplevel);
 	    break;
 	}
 
@@ -1764,14 +1773,12 @@ void EDVArchiverOPExtractAll(edv_archiver_struct *archiver)
 void EDVArchiverOPDelete(edv_archiver_struct *archiver)
 {
 	gboolean yes_to_all = FALSE;
-	gint objects_deleted = 0;
+	gint i, status, total = 0, objects_deleted = 0;
+	gchar *arch_obj = NULL;
+	const gchar *src_path, *error_mesg;
 	GtkWidget *toplevel;
 	edv_archive_object_struct **list = NULL, *obj;
 	edv_core_struct *core_ptr;
-	gchar *arch_obj = NULL;
-	const gchar *src_path, *error_mesg;
-	gint i, status, total = 0;
-
 
 	if(archiver == NULL)
 	    return;
@@ -1820,10 +1827,8 @@ void EDVArchiverOPDelete(edv_archiver_struct *archiver)
 	else
 	    src_path = NULL;
 
-
 	EDVArchiverSetBusy(archiver, TRUE);
 
-
 	/* Confirm delete */
 	status = EDVConfirmArchiveDelete(
 	    core_ptr, toplevel, src_path, total
@@ -1834,7 +1839,6 @@ void EDVArchiverOPDelete(edv_archiver_struct *archiver)
 	    yes_to_all = TRUE;
 	  case CDIALOG_RESPONSE_YES:
 	    break;
-
 	  default:
 	    EDVArchiverSetBusy(archiver, FALSE);
 	    DO_FREE_LOCALS
@@ -1842,8 +1846,7 @@ void EDVArchiverOPDelete(edv_archiver_struct *archiver)
 	    break;
 	}
 
-
-	/* Iterate through selected objects */
+	/* Iterate through selected objects in the archive */
 	status = 0;
 	for(i = 0; i < total; i++)
 	{
@@ -1851,7 +1854,7 @@ void EDVArchiverOPDelete(edv_archiver_struct *archiver)
 	    if(obj == NULL)
 		continue;
 
-	    /* Delete archieve object */
+	    /* Delete object in the archive */
 	    status = EDVArchOPDelete(
 		core_ptr, arch_obj, obj, toplevel,
 		TRUE, TRUE, &yes_to_all
@@ -1875,8 +1878,8 @@ void EDVArchiverOPDelete(edv_archiver_struct *archiver)
 	    /* Was the archive object successfully delected? */
 	    if(!status)
 	    {
-		/* Report archive object removed */
-		EDVArchiveObjectRemovedNotifyCB(
+		/* Report object in archive being removed */
+		EDVArchiveObjectRemovedEmit(
 		    core_ptr, arch_obj, obj->full_path
 		);
 
@@ -1960,7 +1963,6 @@ void EDVArchiverOPSelectAll(edv_archiver_struct *archiver)
 	edv_core_struct *core_ptr;
 	GtkCList *clist;
 
-
 	if(archiver == NULL)
 	    return;
 
