@@ -117,7 +117,7 @@ void EDVBrowserObjectRemovedNotifyCB(
 
 void EDVBrowserMountNotifyCB(
 	edv_browser_struct *browser,
-	gint dev_num, edv_device_struct *dev_ptr,
+	gint dev_num, edv_device_struct *dev,
 	gboolean is_mounted
 );
 
@@ -132,11 +132,11 @@ void EDVBrowserReconfiguredNotifyCB(edv_browser_struct *browser);
 
 void EDVBrowserMimeTypeAddedCB(
 	edv_browser_struct *browser,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 );
 void EDVBrowserMimeTypeModifiedCB(
 	edv_browser_struct *browser,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 );
 void EDVBrowserMimeTypeRemovedCB(
 	edv_browser_struct *browser, gint mt_num
@@ -144,27 +144,27 @@ void EDVBrowserMimeTypeRemovedCB(
 
 void EDVBrowserDeviceAddedCB(
 	edv_browser_struct *browser,
-	gint dev_num, edv_device_struct *dev_ptr
+	gint dev_num, edv_device_struct *dev
 );
 void EDVBrowserDeviceModifiedCB(
 	edv_browser_struct *browser,
-	gint dev_num, edv_device_struct *dev_ptr
+	gint dev_num, edv_device_struct *dev
 );
 void EDVBrowserDeviceRemovedCB(
 	edv_browser_struct *browser, gint dev_num
 );
 
 
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
@@ -296,7 +296,7 @@ gint EDVBrowserKeyEventCB(
 )
 {
 	gint status = FALSE;
-	gboolean is_press;  
+	gboolean is_press;
 	gint etype;
 	guint keyval, state;
 	GtkWidget *w, *focus_widget;
@@ -314,7 +314,7 @@ gint EDVBrowserKeyEventCB(
 	    return(status);
 
 	w = browser->toplevel;
-	focus_widget = (w != NULL) ? GTK_WINDOW(w)->focus_widget : NULL;        
+	focus_widget = (w != NULL) ? GTK_WINDOW(w)->focus_widget : NULL;
 	cfg_list = core_ptr->cfg_list;
 	etype = key->type;
 	is_press = (etype == GDK_KEY_PRESS) ? TRUE : FALSE;
@@ -443,8 +443,9 @@ gint EDVBrowserKeyEventCB(
 		 * item who's name starts with the letter of the key
 		 * that was pressed
 		 */
-		if(isalnum((char)keyval) && is_press &&
-		   ((state == 0x00000000) || (state == GDK_SHIFT_MASK))
+		if(isalnum((int)keyval) && is_press &&
+		   !(state & GDK_CONTROL_MASK) &&
+		   !(state & GDK_SHIFT_MASK)
 		)
 		{
 		    /* Get the column that is displaying the object
@@ -796,13 +797,14 @@ void EDVBrowserTreeSelectRowCB(
 	       (node != NULL)
 	    )
 	    {
+		GtkWidget *toplevel = browser->toplevel;
 		GtkCList *clist;
 		edv_object_struct *obj = EDV_OBJECT(
 		    gtk_ctree_node_get_row_data(ctree, node)
 		);
 
 		EDVBrowserSetBusy(browser, TRUE);
-		GUIBlockInput(browser->toplevel, TRUE);
+		GUIBlockInput(toplevel, TRUE);
 		browser->processing = TRUE;
 
 		/* If node is not fully visible then scroll to position
@@ -909,57 +911,60 @@ g_print("%i %i\n", x_max, (gint)(adj->value + adj->page_size));
 		if((obj != NULL) && (clist != NULL))
 		{
 		    gint objects_in_directory;
+		    const gchar *path = obj->full_path;
 
-		    /* Update value of title, location combo (do not
-		     * record history), and location icon
-		     */
-		    EDVBrowserSetTitle(browser, obj->full_path);
-		    EDVBrowserSetLocation(
-			browser, obj->full_path, FALSE
-		    );
-		    EDVBrowserUpdateLocationIcon(browser, obj->full_path);
+		    /* Update the title, location, and location icon */
+		    EDVBrowserSetTitle(browser, path);
+		    EDVBrowserSetLocation(browser, path, FALSE);
+		    EDVBrowserUpdateLocationIcon(browser, path);
 
-		    /* Get listing */
+		    /* Get listing of contents in the directory */
 		    EDVBrowserContentsGetListing(
 			browser,
-			obj->full_path,
+			path,
 			EDV_GET_B(EDV_CFG_PARM_LISTS_ANIMATE_UPDATES)
 		    );
 
-		    /* Get number of objects in the directory by the
-		     * number of rows in the just updated contents
-		     * clist minus one (to get rid of the parent
-		     * directory notation row)
+		    /* Get the number of objects in the directory by
+		     * calculating the number of rows in the Contents
+		     * List minus one (the parent directory notation
+		     * row)
 		     */
 		    objects_in_directory = MAX(clist->rows - 1, 0);
 
-
 		    /* Update status bar message */
 		    if(!STRISEMPTY(obj->name))
 		    {
-			gchar *buf = g_strdup_printf(
- "Directory \"%s\" selected (containing %i objects)",
-			    obj->name, objects_in_directory
-			);
-
+			gchar *buf;
+			if(objects_in_directory > 0)
+			    buf = g_strdup_printf(
+"Directory \"%s\" selected (containing %i object%s)",
+				obj->name,
+				objects_in_directory,
+				(objects_in_directory == 1) ? "" : "s"
+			    );
+			else
+			    buf = g_strdup_printf(
+"Directory \"%s\" selected (empty)",
+				obj->name
+			    );
 			EDVStatusBarMessage(
 			    browser->status_bar, buf, FALSE
 			);
-
 			g_free(buf);
 		    }
 		    else
 		    {
 			EDVStatusBarMessage(
 			    browser->status_bar,
-			    "Directory with NULL name selected",
+			    "Directory with no name selected",
 			    FALSE
 			);
 		    }
 		}
 
 		browser->processing = FALSE;
-		GUIBlockInput(browser->toplevel, FALSE);
+		GUIBlockInput(toplevel, FALSE);
 		EDVBrowserSetBusy(browser, FALSE);
 
 		EDVBrowserUpdateMenus(browser);
@@ -985,29 +990,37 @@ void EDVBrowserTreeUnselectRowCB(
 	/* Check which ctree this signal is for */
 	if(GTK_WIDGET(ctree) == browser->directory_ctree)
 	{
+	    gchar *buf;
+	    GtkCList *clist = GTK_CLIST(ctree);
+	    edv_core_struct *core_ptr = EDV_CORE(browser->core_ptr);
+
+	    /* Get total number of objects selected */
+	    const gint nselected = g_list_length(clist->selection);
+
 	    if(browser->directory_ctree_selected_node != NULL)
 	    {
-#if 0
-		EDVBrowserSetBusy(browser, TRUE);
-		GUIBlockInput(browser->toplevel, TRUE);
-		browser->processing = TRUE;
-#endif
-
-		/* Mark node as unselected */
+		/* Mark that no node or device is selected */
 		browser->directory_ctree_selected_node = NULL;
-
-		/* Mark that no device is selected */
 		browser->selected_dev_num = -1;
-
-#if 0
-		browser->processing = FALSE;
-		GUIBlockInput(browser->toplevel, FALSE);
-		EDVBrowserSetBusy(browser, FALSE);
-#endif
-
-		EDVBrowserSetTitle(browser, NULL);
-		EDVBrowserUpdateMenus(browser);
 	    }
+
+	    EDVBrowserSetTitle(browser, NULL);
+
+	    /* Update status bar message */
+	    if(nselected > 0)
+		buf = g_strdup_printf(
+		    "%s object%s selected",
+		    EDVGetObjectSizeStr(core_ptr, nselected),
+		    (nselected == 1) ? "" : "s"
+		);
+	    else
+		buf = STRDUP("No objects selected");
+	    EDVStatusBarMessage(
+		browser->status_bar, buf, FALSE
+	    );
+	    g_free(buf);
+
+	    EDVBrowserUpdateMenus(browser);
 	}
 }
 
@@ -1054,10 +1067,8 @@ void EDVBrowserTreeExpandCB(
 		cb_data[0] = browser;
 		cb_data[1] = ctree;
 		cb_data[2] = node;
-		browser->directory_ctree_expand_optimize_idleid = gtk_idle_add_priority(
-		    G_PRIORITY_LOW,
-		    EDVBrowserTreeExpandOptimizeIdleCB,
-		    cb_data
+		browser->directory_ctree_expand_optimize_idleid = gtk_idle_add(
+		    EDVBrowserTreeExpandOptimizeIdleCB, cb_data
 		);
 	    }
 
@@ -1212,7 +1223,7 @@ void EDVBrowserClickColumnCB(
 	    if(column_types_intlist != NULL)
 	    {
 		edv_browser_column_type column_type = (edv_browser_column_type)g_list_nth_data(
-		    column_types_intlist->list,  
+		    column_types_intlist->list,
 		    column
 		);
 		switch(column_type)
@@ -1316,13 +1327,11 @@ void EDVBrowserSelectRowCB(
 	/* Check which clist this signal is for */
 	if(GTK_WIDGET(clist) == browser->contents_clist)
 	{
-	    gint total_selected;
 	    edv_object_struct *obj;
-
+	    edv_core_struct *core_ptr = EDV_CORE(browser->core_ptr);
 
 	    /* Get total number of objects selected */
-	    total_selected = (clist->selection != NULL) ?
-		g_list_length(clist->selection) : 0;
+	    const gint nselected = g_list_length(clist->selection);
 
 	    /* Update selected row */
 	    browser->contents_clist_selected_row = row;
@@ -1359,8 +1368,7 @@ void EDVBrowserSelectRowCB(
 			size_str = g_strdup_printf(
 			    " (%s byte%s)",
 			    EDVGetObjectSizeStr(
-				EDV_CORE(browser->core_ptr),
-				obj->size
+				core_ptr, obj->size
 			    ),
 			    (obj->size == 1) ? "" : "s"
 			);
@@ -1392,10 +1400,10 @@ void EDVBrowserSelectRowCB(
 		    }
 
 		    /* Set status bar message */
-		    if(total_selected > 1)
+		    if(nselected > 1)
 			buf = g_strdup_printf(
-			    "%i objects selected",
-			    total_selected
+			    "%s objects selected",
+			    EDVGetObjectSizeStr(core_ptr, nselected)
 			);
 		    else if(!strcmp(obj->name, ".."))
 			buf = g_strdup_printf(
@@ -1457,6 +1465,26 @@ void EDVBrowserUnselectRowCB(
 	/* Check which clist this signal is for */
 	if(GTK_WIDGET(clist) == browser->contents_clist)
 	{
+	    gchar *buf;
+	    edv_core_struct *core_ptr = EDV_CORE(browser->core_ptr);
+
+	    /* Get total number of objects selected */
+	    const gint nselected = g_list_length(clist->selection);
+
+	    /* Update status bar message */
+	    if(nselected > 0)
+		buf = g_strdup_printf(
+		    "%s object%s selected",
+		    EDVGetObjectSizeStr(core_ptr, nselected),
+		    (nselected == 1) ? "" : "s"
+		);
+	    else
+		buf = STRDUP("No objects selected");
+	    EDVStatusBarMessage(
+		browser->status_bar, buf, FALSE
+	    );
+	    g_free(buf);
+
 	    EDVBrowserUpdateMenus(browser);
 	}
 }
@@ -1541,11 +1569,8 @@ void EDVBrowserComboActivateCB(GtkWidget *widget, gpointer data)
 }
 
 
-
 /*
- *	Called whenever the global write protect has changed.
- *
- *	The new state is given as state.
+ *	Write protect changed callback.
  */
 void EDVBrowserWriteProtectChangedCB(
 	edv_browser_struct *browser, gboolean state
@@ -1561,7 +1586,7 @@ void EDVBrowserWriteProtectChangedCB(
 }
 
 /*
- *	Called whenever a disk object has been added.
+ *	Object added callback.
  */
 void EDVBrowserObjectAddedNotifyCB(
 	edv_browser_struct *browser, const gchar *path,
@@ -1574,19 +1599,24 @@ void EDVBrowserObjectAddedNotifyCB(
 	if(browser->processing)
 	    return;
 
-	/* Notify contents clist and directory ctree about added object */
+	/* Contents Tree */
 	EDVBrowserContentsObjectAddedNotify(
 	    browser, path, lstat_buf
 	);
+
+	/* Directory List */
 	EDVBrowserDirTreeObjectAddedNotify(
 	    browser, path, lstat_buf
 	);
 
+	/* Mount Bar */
+	EDVMountBarUpdateMenus(browser->mount_bar);
+
 /*	EDVBrowserUpdateMenus(browser); */
 }
 
 /*
- *      Called whenever a disk object has had its properties modified.
+ *	Object modified callback.
  */
 void EDVBrowserObjectModifiedNotifyCB(
 	edv_browser_struct *browser, const gchar *path,
@@ -1630,19 +1660,24 @@ void EDVBrowserObjectModifiedNotifyCB(
 	    }
 	}
 
-	/* Notify contents clist and directory ctree about modified object */
+	/* Contents List */
 	EDVBrowserContentsObjectModifiedNotify(
 	    browser, path, new_path, lstat_buf
 	);
+
+	/* Directory Tree */
 	EDVBrowserDirTreeObjectModifiedNotify(
 	    browser, path, new_path, lstat_buf
 	);
 
+	/* Mount Bar */
+	EDVMountBarUpdateMenus(browser->mount_bar);
+
 /*	EDVBrowserUpdateMenus(browser); */
 }
 
 /*
- *	Called whenever a disk object has been removed.
+ *	Object removed callback.
  */
 void EDVBrowserObjectRemovedNotifyCB(
 	edv_browser_struct *browser, const gchar *path
@@ -1654,12 +1689,15 @@ void EDVBrowserObjectRemovedNotifyCB(
 	if(browser->processing)
 	    return;
 
-	/* Notify contents clist and directory ctree about the object
-	 * that was removed
-	 */
+	/* Contents List */
 	EDVBrowserContentsObjectRemovedNotify(browser, path);
+
+	/* Directory Tree */
 	EDVBrowserDirTreeObjectRemovedNotify(browser, path);
 
+	/* Mount Bar */
+	EDVMountBarUpdateMenus(browser->mount_bar);
+
 	/* Check if the path that was removed is the current location
 	 * (after letting contents clist and directory ctree check on it
 	 * first), if the path that was removed is the location then
@@ -1700,11 +1738,11 @@ void EDVBrowserObjectRemovedNotifyCB(
 
 
 /*
- *      Called whenever a device has been mounted or unmounted.
+ *	Device mount/unmount callback.
  */
 void EDVBrowserMountNotifyCB(
 	edv_browser_struct *browser,
-	gint dev_num, edv_device_struct *dev_ptr,
+	gint dev_num, edv_device_struct *dev,
 	gboolean is_mounted
 )
 {
@@ -1714,17 +1752,18 @@ void EDVBrowserMountNotifyCB(
 	if(browser->processing)
 	    return;
 
-	/* Notify contents clist and directory ctree about mount */
-	EDVBrowserContentsMountNotify(browser, dev_ptr, is_mounted);
-	EDVBrowserDirTreeMountNotify(browser, dev_ptr, is_mounted);
+	/* Contents List */
+	EDVBrowserContentsMountNotify(browser, dev, is_mounted);
 
+	/* Directory Tree */
+	EDVBrowserDirTreeMountNotify(browser, dev, is_mounted);
 
 	EDVBrowserUpdateMenus(browser);
 }
 
 
 /*
- *	Called whenever an object has been added to the recycle bin.
+ *	Recycled object added callback.
  */
 void EDVBrowserRecycledObjectAddedNotifyCB(
 	edv_browser_struct *browser, guint index
@@ -1732,7 +1771,6 @@ void EDVBrowserRecycledObjectAddedNotifyCB(
 {
 	edv_core_struct *core_ptr;
 
-
 	if(browser == NULL)
 	    return;
 
@@ -1740,7 +1778,6 @@ void EDVBrowserRecycledObjectAddedNotifyCB(
 	if(core_ptr == NULL)
 	    return;
 
-
 	/* There is not much interest when a recycled object has been
 	 * added or removed. Only the menus need to be updated if there
 	 * is a change in the number of recycled objects
@@ -1750,7 +1787,7 @@ void EDVBrowserRecycledObjectAddedNotifyCB(
 }
 
 /*
- *	Called whenever an object has been removed from the recycle bin.
+ *	Recycled object removed callback.
  */
 void EDVBrowserRecycledObjectRemovedNotifyCB(
 	edv_browser_struct *browser, guint index
@@ -1758,7 +1795,6 @@ void EDVBrowserRecycledObjectRemovedNotifyCB(
 {
 	edv_core_struct *core_ptr;
 
-
 	if(browser == NULL)
 	    return;
 
@@ -1766,7 +1802,6 @@ void EDVBrowserRecycledObjectRemovedNotifyCB(
 	if(core_ptr == NULL)
 	    return;
 
-
 	/* There is not much interest when a recycled object has been
 	 * added or removed. Only the menus need to be updated if there
 	 * is a change in the number of recycled objects
@@ -1777,11 +1812,11 @@ void EDVBrowserRecycledObjectRemovedNotifyCB(
 
 
 /*
- *	Reconfigured notify callback.
+ *	Reconfigured callback.
  */
 void EDVBrowserReconfiguredNotifyCB(edv_browser_struct *browser)
 {
-	gchar *cur_path;
+	gchar *cur_loc;
 	GtkRcStyle *standard_rcstyle, *lists_rcstyle;
 	GtkWidget *w;
 	const cfg_item_struct *cfg_list;
@@ -1811,11 +1846,11 @@ void EDVBrowserReconfiguredNotifyCB(edv_browser_struct *browser)
 
 
 	/* Get current location */
-	cur_path = STRDUP(EDVBrowserCurrentLocation(browser));
+	cur_loc = STRDUP(EDVBrowserCurrentLocation(browser));
 
 
 	/* Update Title */
-	EDVBrowserSetTitle(browser, cur_path);
+	EDVBrowserSetTitle(browser, cur_loc);
 
 	/* Recreate Accelkeys labels */
 	EDVBrowserAccelkeysRegenerate(browser);
@@ -1924,36 +1959,34 @@ void EDVBrowserReconfiguredNotifyCB(edv_browser_struct *browser)
 	if(w != NULL)
 	    gtk_widget_queue_resize(w);
 
-	g_free(cur_path);
+	g_free(cur_loc);
 }
 
 
 /*
- *      Called whenever a MIME Type has been added to the core
- *      structure's list of MIME Types.
+ *	MIME Type added callback.
  */
 void EDVBrowserMimeTypeAddedCB(
 	edv_browser_struct *browser,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 )
 {
 	/* Treat a MIME Type added the same as it would be for a
 	 * MIME Type modified, forward signal to the MIME Type modified
 	 * callback
 	 */
-	EDVBrowserMimeTypeModifiedCB(browser, mt_num, mt_ptr);
+	EDVBrowserMimeTypeModifiedCB(browser, mt_num, mt);
 }
 
 /*
- *      Called whenever a MIME Type has been modified on the core
- *      structure's list of MIME Types.
+ *	MIME Type modified callback.
  */
 void EDVBrowserMimeTypeModifiedCB(
 	edv_browser_struct *browser,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 )
 {
-	gchar *cur_path;
+	gchar *cur_loc;
 	edv_core_struct *core_ptr;
 
 	if(browser == NULL)
@@ -1967,7 +2000,7 @@ void EDVBrowserMimeTypeModifiedCB(
 	    return;
 
 	/* Get current location */
-	cur_path = STRDUP(EDVBrowserCurrentLocation(browser));
+	cur_loc = STRDUP(EDVBrowserCurrentLocation(browser));
 
 	/* Realize listings */
 	EDVBrowserDirTreeRealizeListing(browser, NULL);
@@ -1975,18 +2008,17 @@ void EDVBrowserMimeTypeModifiedCB(
 
 /*	EDVBrowserUpdateMenus(browser); */
 
-	g_free(cur_path);
+	g_free(cur_loc);
 }
 
 /*
- *      Called whenever a MIME Type has been removed from the core
- *      structure's list of MIME Types.
+ *	MIME Type removed callback.
  */
 void EDVBrowserMimeTypeRemovedCB(
 	edv_browser_struct *browser, gint mt_num
 )
 {
-	gchar *cur_path;
+	gchar *cur_loc;
 	edv_core_struct *core_ptr;
 
 	if(browser == NULL)
@@ -2000,7 +2032,7 @@ void EDVBrowserMimeTypeRemovedCB(
 	    return;
 
 	/* Get current location */
-	cur_path = STRDUP(EDVBrowserCurrentLocation(browser));
+	cur_loc = STRDUP(EDVBrowserCurrentLocation(browser));
 
 	/* Realize listings */
 	EDVBrowserDirTreeRealizeListing(browser, NULL);
@@ -2008,7 +2040,7 @@ void EDVBrowserMimeTypeRemovedCB(
 
 /*	EDVBrowserUpdateMenus(browser); */
 
-	g_free(cur_path);
+	g_free(cur_loc);
 }
 
 
@@ -2018,13 +2050,13 @@ void EDVBrowserMimeTypeRemovedCB(
  */
 void EDVBrowserDeviceAddedCB(
 	edv_browser_struct *browser,
-	gint dev_num, edv_device_struct *dev_ptr
+	gint dev_num, edv_device_struct *dev
 )
 {
 	/* Treat a device added the same as it would be for a device
 	 * modified, forward signal to the device modified callback.
 	 */
-	EDVBrowserDeviceModifiedCB(browser, dev_num, dev_ptr);
+	EDVBrowserDeviceModifiedCB(browser, dev_num, dev);
 }
 
 /*
@@ -2033,10 +2065,10 @@ void EDVBrowserDeviceAddedCB(
  */
 void EDVBrowserDeviceModifiedCB(
 	edv_browser_struct *browser,
-	gint dev_num, edv_device_struct *dev_ptr
+	gint dev_num, edv_device_struct *dev
 )
 {
-	gchar *cur_path;
+	gchar *cur_loc;
 	edv_core_struct *core_ptr;
 
 	if(browser == NULL)
@@ -2050,7 +2082,7 @@ void EDVBrowserDeviceModifiedCB(
 	    return;
 
 	/* Get current location */
-	cur_path = STRDUP(EDVBrowserCurrentLocation(browser));
+	cur_loc = STRDUP(EDVBrowserCurrentLocation(browser));
 
 	/* Realize listings */
 	EDVBrowserDirTreeRealizeListing(browser, NULL);
@@ -2058,7 +2090,7 @@ void EDVBrowserDeviceModifiedCB(
 
 	EDVBrowserUpdateMenus(browser);
 
-	g_free(cur_path);
+	g_free(cur_loc);
 }
 
 /*
@@ -2069,7 +2101,7 @@ void EDVBrowserDeviceRemovedCB(
 	edv_browser_struct *browser, gint dev_num
 )
 {
-	gchar *cur_path;
+	gchar *cur_loc;
 	edv_mountbar_struct *mb;
 	edv_core_struct *core_ptr;
 
@@ -2084,12 +2116,12 @@ void EDVBrowserDeviceRemovedCB(
 	    return;
 
 	/* Get current location */
-	cur_path = STRDUP(EDVBrowserCurrentLocation(browser));
+	cur_loc = STRDUP(EDVBrowserCurrentLocation(browser));
 
 	/* Check if mount bar is currently referencing this device, if it
 	 * is then its selected device needs to be set to -1
 	 */
-	mb = browser->mountbar;
+	mb = browser->mount_bar;
 	if(mb != NULL)
 	{
 	    if(mb->selected_dev_num == dev_num)
@@ -2106,5 +2138,5 @@ void EDVBrowserDeviceRemovedCB(
 
 	EDVBrowserUpdateMenus(browser);
 
-	g_free(cur_path);
+	g_free(cur_loc);
 }
