@@ -83,7 +83,7 @@ extern void EDVBrowserObjectRemovedNotifyCB(
 
 extern void EDVBrowserMountNotifyCB(
 	edv_browser_struct *browser,
-	gint dev_num, edv_device_struct *dev_ptr,
+	gint dev_num, edv_device_struct *dev,
 	gboolean is_mounted
 );
 
@@ -98,11 +98,11 @@ extern void EDVBrowserReconfiguredNotifyCB(edv_browser_struct *browser);
 
 extern void EDVBrowserMimeTypeAddedCB(
 	edv_browser_struct *browser,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 );
 extern void EDVBrowserMimeTypeModifiedCB(
 	edv_browser_struct *browser,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 );
 extern void EDVBrowserMimeTypeRemovedCB(
 	edv_browser_struct *browser, gint mt_num
@@ -110,11 +110,11 @@ extern void EDVBrowserMimeTypeRemovedCB(
 
 extern void EDVBrowserDeviceAddedCB(
 	edv_browser_struct *browser,
-	gint dev_num, edv_device_struct *dev_ptr
+	gint dev_num, edv_device_struct *dev
 );
 extern void EDVBrowserDeviceModifiedCB(
 	edv_browser_struct *browser,
-	gint dev_num, edv_device_struct *dev_ptr
+	gint dev_num, edv_device_struct *dev
 );
 extern void EDVBrowserDeviceRemovedCB(
 	edv_browser_struct *browser, gint dev_num
