@@ -33,11 +33,13 @@
 
 static void EDVBrowserContentsFPromptCancelCB(gpointer data);
 
+/* Column Setting */
 static void EDVBrowserContentsResetColumns(
 	edv_core_struct *core_ptr, edv_browser_struct *browser,
 	GtkCList *clist
 );
 
+/* Cell Setting */
 static void EDVBrowserContentsSetCellName(
 	edv_core_struct *core_ptr, edv_browser_struct *browser,
 	GtkCList *clist, edv_object_struct *obj,
@@ -582,6 +584,7 @@ static void EDVBrowserContentsSetCellSize(
 	gtk_clist_set_text(
 	    clist, row, column, s
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, -border_minor
 	);
@@ -610,6 +613,7 @@ static void EDVBrowserContentsSetCellType(
 	gtk_clist_set_text(
 	    clist, row, column, (type_str != NULL) ? type_str : ""
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, 0
 	);
@@ -655,6 +659,7 @@ static void EDVBrowserContentsSetCellPermissions(
 	gtk_clist_set_text(
 	    clist, row, column, s
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, 0
 	);
@@ -681,6 +686,7 @@ static void EDVBrowserContentsSetCellOwner(
 	gtk_clist_set_text(
 	    clist, row, column, owner_name
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, 0
 	);
@@ -707,6 +713,10 @@ static void EDVBrowserContentsSetCellGroup(
 	gtk_clist_set_text(
 	    clist, row, column, group_name
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
+	gtk_clist_set_shift(
+	    clist, row, column, 0, 0
+	);
 }
 
 /*
@@ -735,6 +745,7 @@ static void EDVBrowserContentsSetCellDateAccess(
 	gtk_clist_set_text(
 	    clist, row, column, s
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, 0
 	);
@@ -766,6 +777,7 @@ static void EDVBrowserContentsSetCellDateModified(
 	gtk_clist_set_text(
 	    clist, row, column, s
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, 0
 	);
@@ -797,6 +809,7 @@ static void EDVBrowserContentsSetCellDateChanged(
 	gtk_clist_set_text(
 	    clist, row, column, s
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, 0
 	);
@@ -826,6 +839,7 @@ static void EDVBrowserContentsSetCellHardLinks(
 	gtk_clist_set_text(
 	    clist, row, column, num_str
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, -border_minor
 	);
@@ -882,7 +896,7 @@ static void EDVBrowserContentsSetCellLinkedTo(
 			*dest_path = EDVEvaluatePath(parent, link_value);
 
 	    if((dest_path != NULL) ?
-		!lstat((char *)dest_path, &lstat_buf) : FALSE
+		!lstat((const char *)dest_path, &lstat_buf) : FALSE
 	    )
 	    {
 		edv_object_struct *dest_obj = EDVObjectNew();
@@ -1073,6 +1087,7 @@ static void EDVBrowserContentsSetCellDevice(
 	gtk_clist_set_text(
 	    clist, row, column, num_str
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, -border_minor
 	);
@@ -1101,6 +1116,7 @@ static void EDVBrowserContentsSetCellINode(
 	gtk_clist_set_text(
 	    clist, row, column, num_str
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, -border_minor
 	);
@@ -1144,6 +1160,7 @@ static void EDVBrowserContentsSetCellDeviceType(
 	gtk_clist_set_text(
 	    clist, row, column, num_str
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, -border_minor
 	);
@@ -1173,6 +1190,7 @@ static void EDVBrowserContentsSetCellBlockSize(
 	gtk_clist_set_text(
 	    clist, row, column, num_str
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, -border_minor
 	);
@@ -1201,6 +1219,7 @@ static void EDVBrowserContentsSetCellBlocks(
 	gtk_clist_set_text(
 	    clist, row, column, num_str
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, -border_minor
 	);
@@ -1457,7 +1476,7 @@ static void EDVBrowserContentsAppendListing(
 	    gint i, objects_loaded = 0;
 	    gint last_progress_percent, progress_percent;
 	    const gchar *name;
-	    gchar *obj_path;
+	    gchar *full_path;
 	    edv_object_struct *obj;
 	    gint stat_result;
 	    struct stat stat_buf, lstat_buf;
@@ -1471,12 +1490,12 @@ static void EDVBrowserContentsAppendListing(
 		 */
 		last_progress_percent = -1;	/* None/undefined */
 		progress_percent = 0;
-		obj_path = NULL;
+		full_path = NULL;
 		for(i = 0; i < strc; i++)
 		{
 #define FREE_AND_CONTINUE	{	\
- g_free(obj_path);			\
- obj_path = NULL;			\
+ g_free(full_path);			\
+ full_path = NULL;			\
 					\
  /* Do not delete strv[i] on this first iteration */ \
 					\
@@ -1491,24 +1510,46 @@ static void EDVBrowserContentsAppendListing(
 		    if(!strcmp(name, "."))
 			FREE_AND_CONTINUE
 
-		    /* Allocate full path to object as obj_path */
-		    obj_path = STRDUP(PrefixPaths(path, name));
-		    if(obj_path == NULL)
+		    /* Complete a full path to this object */
+		    full_path = STRDUP(PrefixPaths(path, name));
+		    if(full_path == NULL)
 			FREE_AND_CONTINUE
 
-		    /* Get destination object statistics */
-		    if(stat(obj_path, &stat_buf))
+		    /* Get the destination object's statistics */
+		    if(stat((const char *)full_path, &stat_buf))
+		    {
+#if 0
+/* Do not add anyways during the directory iteration */
+			/* Unable to get stats, add the object anyways
+			 * without stats
+			 */
+			obj = EDVObjectNew();
+			if(obj != NULL)
+			{
+			    EDVObjectSetPath(obj, full_path);
+			    EDVObjectUpdateLinkFlags(obj);
+			    EDVBrowserContentsAppendObject(
+				core_ptr, browser, clist, obj
+			    );
+			    obj = NULL;
+			    objects_loaded++;
+			}
+#endif
 			FREE_AND_CONTINUE
+		    }
+
 #ifdef S_ISDIR
-		    /* Skip if object's destination is not a directory */
+		    /* Skip if the object's destination is not a
+		     * directory
+		     */
 		    if(!S_ISDIR(stat_buf.st_mode))
 			FREE_AND_CONTINUE
 #endif
 
 		    /* Object's destination is a directory, now get
-		     * local stats.
+		     * local stats
 		     */
-		    lstat(obj_path, &lstat_buf);
+		    lstat((const char *)full_path, &lstat_buf);
 
 		    /* Create a new object, set its values from the
 		     * stats, and append it with a new row on the
@@ -1517,7 +1558,7 @@ static void EDVBrowserContentsAppendListing(
 		    obj = EDVObjectNew();
 		    if(obj != NULL)
 		    {
-			EDVObjectSetPath(obj, obj_path);
+			EDVObjectSetPath(obj, full_path);
 			EDVObjectSetStat(obj, &lstat_buf);
 			EDVObjectUpdateLinkFlags(obj);
 
@@ -1541,8 +1582,7 @@ static void EDVBrowserContentsAppendListing(
 				core_ptr, browser, clist, obj
 			    );
 			    obj = NULL;
-
-			    objects_loaded++;   /* Count this as an object loading */
+			    objects_loaded++;
 			}
 		    }
 
@@ -1573,12 +1613,12 @@ static void EDVBrowserContentsAppendListing(
 		 * Do not reset last_progress_percent, leave it as the
 		 * last value from the previous loop
 		 */
-		obj_path = NULL;
+		full_path = NULL;
 		for(i = 0; i < strc; i++)
 		{
 #define FREE_AND_CONTINUE	{	\
- g_free(obj_path);			\
- obj_path = NULL;			\
+ g_free(full_path);			\
+ full_path = NULL;			\
 					\
  g_free(strv[i]);			\
  strv[i] = NULL;			\
@@ -1593,17 +1633,34 @@ static void EDVBrowserContentsAppendListing(
 		    if(!strcmp(name, "."))
 			FREE_AND_CONTINUE
 
-		    /* Allocate full path to object as obj_path */
-		    obj_path = STRDUP(PrefixPaths(path, name));
-		    if(obj_path == NULL)
+		    /* Complete a full path to this object */
+		    full_path = STRDUP(PrefixPaths(path, name));
+		    if(full_path == NULL)
 			FREE_AND_CONTINUE
 
-		    /* Get local stats of the object */
-		    if(lstat(obj_path, &lstat_buf))
+		    /* Get the local object's stats */
+		    if(lstat((const char *)full_path, &lstat_buf))
+		    {
+			/* Unable to get stats, add the object anyways
+			 * without stats     
+			 */
+			memset(&lstat_buf, 0x00, sizeof(struct stat));
+			obj = EDVObjectNew();
+			if(obj != NULL)
+			{
+			    EDVObjectSetPath(obj, full_path);
+			    EDVObjectUpdateLinkFlags(obj);
+			    EDVBrowserContentsAppendObject(
+				core_ptr, browser, clist, obj
+			    );
+			    obj = NULL;
+			    objects_loaded++;
+			}
 			FREE_AND_CONTINUE
+		    }
 
 		    /* Get destination stats of the object */
-		    stat_result = stat(obj_path, &stat_buf);
+		    stat_result = stat((const char *)full_path, &stat_buf);
 		    if(!stat_result)
 		    {
 #ifdef S_ISDIR
@@ -1620,7 +1677,7 @@ static void EDVBrowserContentsAppendListing(
 		    obj = EDVObjectNew();
 		    if(obj != NULL)
 		    {
-			EDVObjectSetPath(obj, obj_path);
+			EDVObjectSetPath(obj, full_path);
 			EDVObjectSetStat(obj, &lstat_buf);
 			EDVObjectUpdateLinkFlags(obj);
 
@@ -1646,8 +1703,7 @@ static void EDVBrowserContentsAppendListing(
 				core_ptr, browser, clist, obj
 			    );
 			    obj = NULL;
-
-			    objects_loaded++;	/* Count this as an object loaded */
+			    objects_loaded++;
 			}
 		    }
 
@@ -2143,11 +2199,11 @@ static void EDVBrowserContentsFPromptRenameApplyCB(
 		if((new_obj != NULL) && (old_full_path != NULL))
 		{
 		    struct stat lstat_buf;
-		    const gchar	*new_child = EDVGetPathName(new_obj),
-				*old_child = EDVGetPathName(old_full_path); 
+		    const gchar	*new_child = g_basename(new_obj),
+				*old_child = g_basename(old_full_path); 
 
 		    /* Get new local statistics for the renamed object */
-		    if(!lstat(new_obj, &lstat_buf))
+		    if(!lstat((const char *)new_obj, &lstat_buf))
 		    {
 			gchar *buf = g_strdup_printf(
 			    "Object \"%s\" renamed to \"%s\"",
