@@ -459,7 +459,7 @@ static void EDVBrowserDirTreeDoGetChildrenListIterate(
 	/* Update status bar indicating which directory we're scanning? */
 	if(update_progress)
 	{
-	    const gchar *parent_name = EDVGetPathName(parent_path);
+	    const gchar *parent_name = g_basename(parent_path);
 	    gchar *buf = g_strdup_printf(
 		"Scanning directory: %s",
 		parent_name
@@ -1455,8 +1455,8 @@ static void EDVBrowserDirTreeFPromptRenameApplyCB(
 		if((new_obj != NULL) && (old_full_path != NULL))
 		{
 		    struct stat lstat_buf;
-		    const gchar	*new_child = EDVGetPathName(new_obj),
-				*old_child = EDVGetPathName(old_full_path);
+		    const gchar	*new_child = g_basename(new_obj),
+				*old_child = g_basename(old_full_path);
 
 		    /* Get new local statistics for the renamed object */
 		    if(!lstat(new_obj, &lstat_buf))
@@ -1982,28 +1982,22 @@ void EDVBrowserDirTreeMountNotify(
 	/* Unmounted? */
 	if(!is_mounted)
 	{
-	    /* Get current location */
-	    gchar *cur_path = STRDUP(EDVBrowserCurrentLocation(browser));
-	    if(cur_path != NULL)
+	    /* Is the current location within the mount path? */
+	    gchar *cur_loc = STRDUP(EDVBrowserCurrentLocation(browser));
+	    if((cur_loc != NULL) ? strpfx(cur_loc, mount_path) : FALSE)
 	    {
-		/* Is the current location an object that is within
-		 * this unmounted device?
-		 */
-		if(strpfx(cur_path, mount_path))
+		/* Select the unmounted device's node as needed */
+		GtkCTreeNode *cur_node = EDVBrowserDirTreeFindNodeByPath(
+		    browser, cur_loc
+		);
+		if((node != NULL) && (node != cur_node))
 		{
-		    /* Select the unmounted device's node as needed */
-		    GtkCTreeNode *cur_node = EDVBrowserDirTreeFindNodeByPath(
-			browser, cur_path    
-		    );
-		    if((node != NULL) && (node != cur_node))
-		    {
-			gtk_clist_freeze(clist);
-			gtk_ctree_select(ctree, node);
-			gtk_clist_thaw(clist);
-		    }
+		    gtk_clist_freeze(clist);
+		    gtk_ctree_select(ctree, node);
+		    gtk_clist_thaw(clist);
 		}
 	    }
-	    g_free(cur_path);
+	    g_free(cur_loc);
 	}
 
 	g_free(mount_path);
