@@ -45,10 +45,6 @@
 #include "config.h"
 
 
-static void EDVBrowserToolbarMenuPositionCB(
-	GtkMenu *menu, gint *x, gint *y, gpointer data
-);
-
 void EDVBrowserMenuItemCB(GtkWidget *widget, gpointer data);
 gint EDVBrowserMenuItemEnterCB(
 	GtkWidget *widget, GdkEventCrossing *crossing, gpointer data
@@ -166,34 +162,6 @@ void EDVBrowserOPDirectoryTreeOrigin(edv_browser_struct *browser);
 #define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
-/*
- *	Tool Bar Item GtkMenu position callback.
- */
-static void EDVBrowserToolbarMenuPositionCB( 
-	GtkMenu *menu, gint *x, gint *y, gpointer data  
-)
-{
-	gint width, height;
-	GdkWindow *window;
-	GtkWidget *w;
-	toolbar_item_struct *item = TOOLBAR_ITEM(data);
-	if((menu == NULL) || (x == NULL) || (y == NULL) || (item == NULL))
-	    return;
-
-	w = item->w;
-	if(w == NULL)
-	    return;
-
-	window = w->window;
-	if(window == NULL)
-	    return;
-
-	gdk_window_get_root_position(window, x, y);
-	gdk_window_get_size(window, &width, &height);
-	*y = (*y) + height;
-}
-
-
 /*
  *	Menu item activate callback.
  *
@@ -294,7 +262,12 @@ void EDVBrowserOPCB(
 	    EDVBrowserOPRun(browser);
 	    break;
 	  case EDV_BROWSER_OP_RUN_TERMINAL:
-	    EDVRunTerminal(core_ptr, NULL, toplevel);
+            if(core_ptr != NULL)
+            {
+                gchar *wd = STRDUP(EDVBrowserCurrentLocation(browser));
+                EDVRunTerminal(core_ptr, NULL, wd, toplevel);
+                g_free(wd);
+            }
 	    break;
 	  case EDV_BROWSER_OP_WRITE_PROTECT:
 	    EDVBrowserOPWriteProtect(browser);
@@ -1205,19 +1178,13 @@ void EDVBrowserOPNewObject(
 	edv_browser_struct *browser, toolbar_item_struct *item
 )
 {
-	GtkWidget *w;
-
 	if(browser == NULL)
 	    return;
 
-	w = browser->new_object_submenu;
-	if(w != NULL)
-	    gtk_menu_popup(
-		GTK_MENU(w), NULL, NULL,
-		(item != NULL) ? EDVBrowserToolbarMenuPositionCB : NULL,
-		item,
-		1, GDK_CURRENT_TIME
-	    );
+	EDVMenuButtonMapMenu(
+	    browser->new_object_submenu,
+	    (item != NULL) ? item->w : NULL
+	);
 }
 
 /*
@@ -2842,7 +2809,7 @@ void EDVBrowserOPDownload(edv_browser_struct *browser)
 void EDVBrowserOPRefresh(edv_browser_struct *browser)
 {
 	gchar *cur_path;
-	GtkWidget *w;
+	GtkWidget *w, *toplevel;
 	GtkCList *clist;
 	GtkCTree *ctree;
 	GtkCTreeNode *node;
@@ -2853,6 +2820,7 @@ void EDVBrowserOPRefresh(edv_browser_struct *browser)
 	if(browser == NULL)
 	    return;
 
+	toplevel = browser->toplevel;
 	core_ptr = EDV_CORE(browser->core_ptr);
 	if(core_ptr == NULL)
 	    return;
@@ -2860,16 +2828,16 @@ void EDVBrowserOPRefresh(edv_browser_struct *browser)
 	cfg_list = core_ptr->cfg_list;
 
 	EDVBrowserSetBusy(browser, TRUE);
-	GUIBlockInput(browser->toplevel, TRUE);
+	GUIBlockInput(toplevel, TRUE);
 
 	cur_path = STRDUP(EDVBrowserCurrentLocation(browser));
 
 	/* Refresh toplevel */
-	w = browser->toplevel;
+	w = toplevel;
 	if(w != NULL)
 	    gtk_widget_queue_resize(w);
 
-	/* Update directory ctree */
+	/* Update the Directory Tree */
 	clist = (GtkCList *)browser->directory_ctree;
 	ctree = (GtkCTree *)clist;
 
@@ -2922,7 +2890,7 @@ void EDVBrowserOPRefresh(edv_browser_struct *browser)
 	    browser->status_bar, "Refreshed contents listing", FALSE
 	);
 
-	GUIBlockInput(browser->toplevel, FALSE);
+	GUIBlockInput(toplevel, FALSE);
 	EDVBrowserSetBusy(browser, FALSE);
 
 	g_free(cur_path);
