@@ -27,11 +27,11 @@
  */
 #define PROG_NAME		"Endeavour"
 #define PROG_NAME_FULL		"Endeavour Mark II"
-#define PROG_VERSION		"2.5.2"
+#define PROG_VERSION		"2.5.7"
 
 #define PROG_VERSION_MAJOR	2
 #define PROG_VERSION_MINOR	5
-#define PROG_VERSION_RELEASE	2
+#define PROG_VERSION_RELEASE	7
 
 /*
  *      Copyright message:
@@ -110,20 +110,19 @@ to the fullest extent of the law.\n"
 #define PROG_CREDITS_LINES	{				\
  "                  http://wolfpack.twu.net/Endeavour2/",	\
  " ",								\
- "        Director: Capt Taura Milana",				\
+ " Project Captain: Tara Milana",				\
  " ",								\
- "     Programmers: Dan Stimitz",				\
- "                  Capt Taura Milana",				\
+ "     Programmers: Dan Stimits, Beta Testing",			\
+ "                  N Deepak, FreeBSD Porter",			\
+ "                  Tara Milana",				\
  " ",								\
- "    Beta Testing: Dan Stimits",				\
+ " Graphic Artists: Tara Milana",				\
  " ",								\
  "       Packagers: Thierry Vignaud",				\
  "                  Guillaume Rousse",				\
  " ",								\
  "    Contributors: Remi Broemeling",				\
  " ",								\
- "                  WolfPack Entertainment",			\
- " ",								\
  NULL								\
 }
 
@@ -236,7 +235,7 @@ to the fullest extent of the law.\n"
 	".rpm",         "RedHat Linux Package",			\
 	".tar",		"UNIX Tape Archive",			\
 	".tar.bz2",	"BZip2 Compressed UNIX Tape Archive",	\
-	".tar.gz .tgz",	"GZip Compressed UNIZ Tape Archive",	\
+	".tar.gz .tgz",	"GZip Compressed UNIX Tape Archive",	\
 	".tar.Z",	"Compressed UNIX Tape Archive",		\
 	".xpi",		"PKZip Archive With Java Script",	\
 	".zip",		"PKZip Archive",			\
