@@ -1473,7 +1473,7 @@ static void EDVDevicesListWinUpdateDisplay(
 	else
 	{
 	    const gchar	*dev_path = dev->device_path,
-			*dev_name = EDVGetPathName(dev_path);
+			*dev_name = g_basename(dev_path);
 	    if(dev_name == NULL)
 		dev_name = "(null)";
 	    lw->dev_name_label = w = gtk_label_new(dev_name);
@@ -2043,7 +2043,7 @@ void EDVDevicesListWinSetRow(
 	    {
 		const gchar *cell_text = dev->name;
 		if((cell_text == NULL) && (dev->device_path != NULL))
-		    cell_text = EDVGetPathName(dev->device_path);
+		    cell_text = g_basename(dev->device_path);
 		if(cell_text == NULL)
 		    cell_text = "(null)";
 
