@@ -116,10 +116,9 @@ static gchar *DownloadBrowseTargetPathCB(
 )
 {
 	gboolean status;
+	gint total_ftypes = 0, npaths = 0;
+	gchar **paths_list = NULL;       
 	fb_type_struct **ftype = NULL, *ftype_rtn = NULL;
-	gint total_ftypes = 0;
-	gchar **path_rtn = NULL;
-	gint total_path_rtns = 0;
 	GtkWidget *toplevel = NULL;
 
 	if(FileBrowserIsQuery())
@@ -139,7 +138,7 @@ static gchar *DownloadBrowseTargetPathCB(
 "Selecto",
 "Cancele",
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Choisir Le Sentier",
+"Choisir le rpertoire",
 "Choisir",
 "Annuler",
 #elif defined(PROG_LANGUAGE_GERMAN)
@@ -169,7 +168,7 @@ static gchar *DownloadBrowseTargetPathCB(
 #endif
 	    PDialogGetPromptValue(prompt_num),
 	    ftype, total_ftypes,
-	    &path_rtn, &total_path_rtns,
+	    &paths_list, &npaths,
 	    &ftype_rtn
 	);
 	FileBrowserSetTransientFor(NULL);
@@ -180,7 +179,7 @@ static gchar *DownloadBrowseTargetPathCB(
 	/* Reset due to possible file related change */
 	FileBrowserReset();
 
-	return((total_path_rtns > 0) ? path_rtn[0] : NULL);
+	return((npaths > 0) ? paths_list[0] : NULL);
 }
 
 /*
@@ -206,24 +205,23 @@ static gulong DownloadTryGetTotalLength(FILE *fp)
 	if(fstat(fileno(fp), &stat_buf))
 	    return((gulong)-1);
 
-	buf_len = stat_buf.st_size;
+	buf_len = (gint)stat_buf.st_size;
 	if(buf_len <= 0)
 	    return((gulong)-1);
 
-	/* Allocate read buffer */
+	/* Allocate the read buffer */
 	buf = (gchar *)g_malloc((buf_len + 1) * sizeof(gchar));
 	if(buf == NULL)
 	    return((gulong)-1);
 
 	/* Read the beginning of the file, searching for the content
-	 * length "\nLength:" string.
+	 * length "\nLength:" string
 	 */
 	rewind(fp);
 	bytes_read = fread(buf, sizeof(gchar), buf_len, fp);
 	if(bytes_read > 0)
 	{
-	    gchar *strptr, num_str[80];
-
+	    gchar *s, num_str[80];
 
 	    /* Null terminate buffer */
 	    if(bytes_read >= buf_len)
@@ -234,39 +232,40 @@ static gulong DownloadTryGetTotalLength(FILE *fp)
 	    /* Look for the content length string and that we got the
 	     * entire line.
 	     */
-	    strptr = strstr(buf, "\nLength:");
-	    if((strptr != NULL) ?
-		(strchr(strptr + 1, '\n') != NULL) : FALSE
+	    s = strstr(buf, "\nLength:");
+	    if((s != NULL) ?
+		(strchr(s + 1, '\n') != NULL) : FALSE
 	    )
 	    {
 		/* Found string, now seek past it to the next space
 		 * space separated string.
 		 */
-		while(!ISBLANK(*strptr) && (*strptr != '\0'))
-		    strptr++;
-		while(ISBLANK(*strptr))
-		    strptr++;
+		while(!ISBLANK(*s) && (*s != '\0'))
+		    s++;
+		while(ISBLANK(*s))
+		    s++;
 
-		/* Now strptr is positioned at the string we want,
-		 * it is assumed to be a number so copy it to num_str.
+		/* Now s is positioned at the string we want, it is
+		 * assumed to be a number so copy it to num_str
 		 */
-		strncpy(num_str, strptr, 80);
-		num_str[80 - 1] = '\0';
+		strncpy(num_str, s, sizeof(num_str));
+		num_str[sizeof(num_str) - 1] = '\0';
 		/* Null terminate number string */
-		strptr = num_str;
-		while(!ISBLANK(*strptr) && (*strptr != '\0'))
-		    strptr++;
-		*strptr = '\0';
+		s = num_str;
+		while(!ISBLANK(*s) && (*s != '\0'))
+		    s++;
+		*s = '\0';
 
 		/* Now we need to get rid of the ',' characters (if any)
 		 * in the number string.
 		 */
 		substr(num_str, ",", "");
-		total_length = atol(num_str);
+		total_length = ATOL(num_str);
 		/* Number string was 0 or contained no numbers?
+		 *
 		 * Then set total_length to 1, indicating that although
 		 * we got the total length, it was undeciperable
-		 * (which can happen if the total length is not given).
+		 * (which can happen if the total length is not given)
 		 */
 		if(total_length == 0)
 		    total_length = (gulong)-1;
@@ -274,7 +273,7 @@ static gulong DownloadTryGetTotalLength(FILE *fp)
 	    }	/* Look for the content length string */
 	}
 
-	/* Deallocate read buffer */
+	/* Delete the read buffer */
 	g_free(buf);
 
 	return(total_length);
@@ -552,7 +551,7 @@ To:\n\
 #if defined(PROG_LANGUAGE_SPANISH)
 "quedndose"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"rester"
+"restant"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "bleiben"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -577,7 +576,7 @@ To:\n\
 #if defined(PROG_LANGUAGE_SPANISH)
 "quedndose"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"rester"
+"restant"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "bleiben"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -600,7 +599,7 @@ To:\n\
 #if defined(PROG_LANGUAGE_SPANISH)
 "atascado"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"cal"
+"ralis"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "hingehalten"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -776,11 +775,11 @@ A:\n\
 #elif defined(PROG_LANGUAGE_FRENCH)
 "Tlcharger:\n\
 \n\
-    %s (??? bytes)\n\
+    %s (??? octets)\n\
 \n\
 A:\n\
 \n\
-    %s (%s bytes)\n"
+    %s (%s octets)\n"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Laden:\n\
 \n\
@@ -905,7 +904,7 @@ To:\n\
 	/* Close standard output file */
 	FClose(fp);
 
-	/* Deallocate progress message */
+	/* Delete progress message */
 	g_free(title);
 	g_free(message);
 	g_free(p1);
@@ -931,7 +930,7 @@ To:\n\
 \n\
 El objeto no existe ni el camarero remoto no responde.\n"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Incapable de tlcharger:\n\
+"Impossible de tlcharger:\n\
 \n\
     %s\n\
 \n\
@@ -988,11 +987,11 @@ puede querer tratar otra vez luego.\n",
 #elif defined(PROG_LANGUAGE_FRENCH)
 "Charger A Echou",
 		buf,
-"L'objet ne peut pas exister sur le serveur loign ou le serveur\n\
-loign ne rpond pas. S'il vous plat vrifier que le URL ce\n\
-reffers  l'objet est exact et que l'objet existe en fait sur\n\
-l'loign le serveur. Si le serveur loign ne rpond pas alors\n\
-vous pouvez vouloir essayer encore plus tard.\n",
+"L'objet peut ne pas exister sur le serveur distant ou le serveur\n\
+distant ne rpond pas. S'il vous plat vrifier que l'URL se\n\
+rfrant  l'objet est exact et que l'objet existe en fait sur\n\
+ le serveur distant. Si le serveur distant ne rpond pas alors\n\
+vous pouvez ressayer plus tard.\n",
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Laden Sie Versagt",
 		buf,
@@ -1087,8 +1086,8 @@ you may want to try again later.",
 "El objeto cargado tiene un tamao de byte de %s, pero el\n\
 el tamao esperado del objeto debe ser los byte de %s.\n"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"L'objet charg a une taille d'octets de %s, mais le\n\
-la taille prvue de l'objet doit tre les octets de %s.\n"
+"L'objet charg a une taille de %s octets, mais \n\
+la taille prvue de l'objet tait de %s octets.\n"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Das geladene objekt hat eine Gre von %s bytes, aber die\b\
 erwartete gre des objekts soll %s bytes sein.\n"
@@ -1121,10 +1120,10 @@ expected size of the object should be %s bytes.\n"
 "La descarga puede haber terminado prematuramente, se recomienda\n\
 que usted reasuma la descarga descargando el objeto otra vez.\n",
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Inconsistancy Tlcharg De Taille D'Objet",
+"Inconsistance de la taille de l'objet tlcharg",
 		    buf,
 "Le chargement a pu terminer prmaturment, il est recommand\n\
-que vous repreniez le chargement en tlchargeant l'objet encore.\n",
+que vous repreniez  nouveau le tlchargement de l'objet.\n",
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Geladene Objekt Gre Inconsistancy",
 		    buf,
@@ -1394,9 +1393,9 @@ int main(int argc, char *argv[])
 "No hay el registro de un previamente descargado se opone\n\
 para descargar.",
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Aucun Objet Pour Tlcharger",
-"Il n'y a pas de dossier de qu'un objet prcdemment\n\
-tlcharg pour tlcharger.",
+"Aucun Objet  Tlcharger",
+"Il n'y a pas de trace d'un objet prcdemment\n\
+tlcharg  tlcharger de nouveau.",
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Kein Objekt Zu Laden",
 "Es gibt keine aufzeichnung von einem vorher geladenen objekt\n\
@@ -1466,8 +1465,8 @@ to (re)download.",
 "Entre el URL (comenzar con http:// o el ftp://) del objeto eso\
  usted quiere cargar"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Entrer le URL (le commencer avec http:// ou ftp://) de l'objet\
- cela vous voulez charger"
+"Entrer l'URL (en commencant par http:// ou ftp://) de l'objet\
+ que vous voulez tlcharger"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Tragen sie die URL (der mit http:// oder ftp:// anfngt) vom objekt,\
  das sie laden wollen ein"
@@ -1517,9 +1516,9 @@ to (re)download.",
  descargar el objeto a o le sale blanco para descargar a la\
  gua actual"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Entrer le sentier plein de l'annuaire que vous voulez\
- tlcharger l'objet  ou le part le vide pour tlcharger \
- l'annuaire actuel"
+"Entrer le nom complet du rpertoire o vous voulez\
+ tlcharger l'objet ou ne rien indiquer pour tlcharger dans\
+ le rpertoire actuel"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Tragen sie den vollen pfad des verzeichnisses, das sie das\
  objekt zu oder laden wollen, verlassen es leerstelle ein, zum\
@@ -1551,9 +1550,9 @@ to (re)download.",
 quiere descargar. Si usted sale el blanco de campo de A: entonces\n\
 el objeto ser descargado a la gua actual."
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Entrer le URL (commenant avec http:// ou ftp://) de l'objet que\n\
-vous voulez tlcharger. Si vous partez le vide de champ de A: alors\n\
-l'objet sera tlcharg  l'annuaire actuel."
+"Entrer l'URL (en commenant par http:// ou ftp://) de l'objet que\n\
+vous voulez tlcharger. Si vous laissez le champ du destinataire vide A: alors\n\
+l'objet sera tlcharg dans le rpertoire actuel."
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Tragen sie die URL (der mit http:// oder ftp:// anfngt) vom objekt,\n\
 das sie laden wollen ein. Wenn sie die Zu: feld leerstelle dann das\n\
@@ -1777,7 +1776,7 @@ To:\n\
 #if defined(PROG_LANGUAGE_SPANISH)
 "Confirme La Descarga"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Confirmer Le Chargement"
+"Confirme le chargement"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Besttigen Sie Ldt"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1829,9 +1828,9 @@ El chasquido en el \"Cancela\" de para cancelar el carga.\n"
 \n\
     %s\n\
 \n\
-Le dclic sur \"Oui\" reprendre le chargement.\n\
-Le dclic sur \"Non\" superposer l'objet local avec l'objet loign.\n\
-Le dclic sur \"Annule\" pour annuler le chargement.\n"
+Clicquer sur \"Oui\" reprendre le chargement.\n\
+Clicquer sur \"Non\" remplace l'objet local par l'objet distant.\n\
+Clicquer sur \"Annule\" pour annuler le chargement.\n"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Lebenslauf ldt von existieren objekt:\n\
 \n\
@@ -1903,14 +1902,14 @@ chasquido en \"Cancela\".\n",
 #elif defined(PROG_LANGUAGE_FRENCH)
 "Confirmer Reprendre",
 		buf,
-"L'objet que vous essayez charger apparat \n\ existe dj\n\
-localement. Si l'existant local objet seulement a t charg\n\
-(e.g. grce  un interrompu transfert) vous doit cliqueter\n\
-sur \"Oui\" reprendre chargement il. Si vous souhaitez\n\
-superposer l'existant l'objet local avec l'objet que vous\n\
-chargez alors le dclic sur \"No\". Si vous n'tes pas sr ce\n\
-que de faire ou vous ne veut pas charger l'objet l'alors\n\
-dclic sur \"Annule\".\n",
+"L'objet que vous essayez de charger existe dj localement.\n\
+ Si l'objet local existe seulement en raison d'un tlchargement prcdent\n\
+(e.g. grce  un transfert interrompu) vous devez cliquer\n\
+sur \"Oui\" pour reprendre le chargement. Si vous souhaitez\n\
+superposer l'objet local existant avec l'objet que vous\n\
+tlchargez alors clicquer sur \"Non\". Si vous n'tes pas sr de\n\
+ ce que vous devez faire, alors clicquer sur \"Annule\".\n",
+
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Besttigen Sie Lebenslauf",
 		buf,
@@ -2014,13 +2013,13 @@ Verifique por favor que el programa es instalado en una\n\
 ubicacion especificada por el ambiente de %s y que\n\
 es ejecutable por este programa.",
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Incapable de trouver le programme de chargement:\n\
+"Impossible de trouver le programme de tlchargement:\n\
 \n\
     %s\n\
 \n\
-S'il vous plait verifier que le programme est installe\n\
-a un emplacement spe'cifie' par l'environnement de\n\
-%s et que c'est realisable par ce programme.",
+S'il vous plait verifier que le programme soit installe\n\
+a l'emplacement spcifi par l'environnement de\n\
+%s et que c'est xcutable par ce programme.",
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Unfahig, das downloadprogramm zu finden:\n\
 \n\
@@ -2082,7 +2081,7 @@ verdadera, se debe instalar en su sistema en la ubicacin\n\
 especificada encima de para permite este programa es capaz de\n\
 descargar objetos.\n",
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Le Programme de chargement n'A pas Trouv",
+"Le Programme de chargement n'a pas trouv",
 		buf,
 "Le programme de chargement est utilis pour excuter le\n\
 chargement vritable, il doit tre install sur votre systme\n\
@@ -2166,7 +2165,7 @@ objects.\n",
 \n\
     %s\n"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Incapable d'excuter l'ordre de chargement:\n\
+"Impossible d'excuter l'ordre de chargement:\n\
 \n\
     %s\n"
 #elif defined(PROG_LANGUAGE_GERMAN)
@@ -2205,12 +2204,12 @@ objects.\n",
 ejecutar, verifica por favor que el programa de la descarga\n\
 existe en la ubicacin especificada encima de y es ejecutable.\n",
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Tlcharger Echou",
+"ECHEC de tlchargement",
 		    buf,
-"L'ordre a utilis pour tlcharger l'objet ne pourrait pas\n\
+"La commande utilis pour tlcharger l'objet ne pourrait pas\n\
 tre excut, s'il vous plat vrifier que le programme de\n\
-chargement existe  l'emplacement spcifi au-dessus de et est\n\
-ralisable.\n",
+chargement existe  l'emplacement spcifi au-dessus  et est\n\
+xcutable.\n",
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Laden Sie Versagt",
 		    buf,
@@ -2271,7 +2270,15 @@ specified above and is executable.\n",
 		    if(beep_when_complete)
 			EDVPlaySoundCompleted(ctx);
 		    if(open_object)
-			EDVOpen(ctx, destination_file, NULL);
+		    {
+			GList *paths_list = NULL;
+			paths_list = g_list_append(
+			    paths_list, STRDUP(destination_file)
+			);
+			EDVOpen(ctx, paths_list, NULL);
+			g_list_foreach(paths_list, (GFunc)g_free, NULL);
+			g_list_free(paths_list);
+		    }
 		    break;
 
 		  case -2:	/* Process exited but object not completely downloaded */
