@@ -323,9 +323,9 @@ static void EDVArchFIOParseLineARJ(
 	    /* Strip tailing deliminators */
 	    StripPath((char *)obj->full_path);
 
-	    /* Get name from full path */
+	    /* Get name from path */
 	    g_free(obj->name);
-	    obj->name = STRDUP(EDVGetPathName(obj->full_path));
+	    obj->name = STRDUP(g_basename(obj->full_path));
 	}
 	while(ISSPACE(*buf_ptr))
 	    buf_ptr++;
@@ -881,9 +881,9 @@ static void EDVArchFIOParseLineLHA(
 	    /* Strip tailing deliminators */
 	    StripPath((char *)obj->full_path);
 
-	    /* Get name from full path */
+	    /* Get name from path */
 	    g_free(obj->name);
-	    obj->name = STRDUP(EDVGetPathName(obj->full_path));
+	    obj->name = STRDUP(g_basename(obj->full_path));
 	}
 	while(ISSPACE(*buf_ptr))
 	    buf_ptr++;
@@ -939,9 +939,9 @@ static void EDVArchFIOParseLineRAR(
 	    /* Strip tailing deliminators */
 	    StripPath((char *)obj->full_path);
 
-	    /* Get name from full path */
+	    /* Get name from path */
 	    g_free(obj->name);
-	    obj->name = STRDUP(EDVGetPathName(obj->full_path));
+	    obj->name = STRDUP(g_basename(obj->full_path));
 	}
 	while(ISSPACE(*buf_ptr))
 	    buf_ptr++;
@@ -1386,9 +1386,9 @@ static void EDVArchFIOParseLineRPM(
 	    /* Strip tailing deliminators */
 	    StripPath((char *)obj->full_path);
 
-	    /* Get name from full path */
+	    /* Get name from path */
 	    g_free(obj->name);
-	    obj->name = STRDUP(EDVGetPathName(obj->full_path));
+	    obj->name = STRDUP(g_basename(obj->full_path));
 	}
 	while(ISSPACE(*buf_ptr))
 	    buf_ptr++;
@@ -1684,9 +1684,9 @@ lrwxrwxrwx root/root   0 2001-11-19 02:57 file.ext -> link.dest
 	    /* Strip tailing deliminators */
 	    StripPath((char *)obj->full_path);
 
-	    /* Get name from full path */
+	    /* Get name from path */
 	    g_free(obj->name);
-	    obj->name = STRDUP(EDVGetPathName(obj->full_path));
+	    obj->name = STRDUP(g_basename(obj->full_path));
 	}
 	while(ISSPACE(*buf_ptr))
 	    buf_ptr++;
@@ -1911,9 +1911,9 @@ static void EDVArchFIOParseLineZip(
 	    /* Strip tailing deliminators */
 	    StripPath((char *)obj->full_path);
 
-	    /* Get name from full path */
+	    /* Get name from path */
 	    g_free(obj->name);
-	    obj->name = STRDUP(EDVGetPathName(obj->full_path));
+	    obj->name = STRDUP(g_basename(obj->full_path));
 	}
 	while(ISSPACE(*buf_ptr))
 	    buf_ptr++;
@@ -2596,11 +2596,10 @@ edv_archive_object_struct *EDVArchFIOStat(
 	edv_archive_object_struct *obj = NULL;
 	struct stat stat_buf;
 
-
 	if((core_ptr == NULL) || STRISEMPTY(arch_obj) || STRISEMPTY(path))
 	    return(obj);
 
-	arch_name = EDVGetPathName(arch_obj);
+	arch_name = g_basename(arch_obj);
 
 	/* Get archive stats and making sure it is a file */
 	if(stat((const char *)arch_obj, &stat_buf))
@@ -3628,7 +3627,7 @@ edv_archive_object_struct **EDVArchFIOGetListing(
 	if((core_ptr == NULL) || STRISEMPTY(arch_obj) || (total == NULL))
 	    return(list);
 
-        arch_name = EDVGetPathName(arch_obj);
+        arch_name = g_basename(arch_obj);
 
 	/* Get archive stats and make sure it is a file */
 	if(stat((const char *)arch_obj, &stat_buf))
@@ -4153,7 +4152,7 @@ gchar **EDVArchFIOGetComment(
 	if((core_ptr == NULL) || STRISEMPTY(arch_obj) || (total == NULL))
 	    return(strv);
 
-        arch_name = EDVGetPathName(arch_obj);
+        arch_name = g_basename(arch_obj);
 
 	/* Get archive stats and make sure it is a file */
 	if(stat(arch_obj, &stat_buf))
@@ -4404,7 +4403,7 @@ gint EDVArchFIOSetComment(
 	if((core_ptr == NULL) || STRISEMPTY(arch_obj))
 	    return(-1);
 
-        arch_name = EDVGetPathName(arch_obj);
+        arch_name = g_basename(arch_obj);
 
 	/* Get archive stats and make sure it is a file */
 	if(stat(arch_obj, &stat_buf))
