@@ -47,7 +47,7 @@
 #include "aboutdlg.h"
 #include "endeavour.h"
 #include "edvcb.h"
-#include "edvop.h"    
+#include "edvop.h"
 #include "edvinterpsop.h"
 #include "edvopen.h"
 #include "edvutils.h"
@@ -145,16 +145,16 @@ void EDVObjectMountEmit(
 );
 
 /* Archive Emitters */
-void EDVArchiveObjectAddedNotifyCB(
+void EDVArchiveObjectAddedEmit(
 	edv_core_struct *core_ptr, const gchar *arch_path,
 	const gchar *path, edv_archive_object_struct *obj
 );
-void EDVArchiveObjectModifiedNotifyCB(
+void EDVArchiveObjectModifiedEmit(
 	edv_core_struct *core_ptr, const gchar *arch_path,
 	const gchar *path, const gchar *new_path,
 	edv_archive_object_struct *obj
 );
-void EDVArchiveObjectRemovedNotifyCB(
+void EDVArchiveObjectRemovedEmit(
 	edv_core_struct *core_ptr, const gchar *arch_path,
 	const gchar *path
 );
@@ -173,11 +173,11 @@ void EDVReconfiguredEmit(edv_core_struct *core_ptr);
 /* MIME Type Emitters */
 void EDVMimeTypeAddedEmit(
 	edv_core_struct *core_ptr,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 );
 void EDVMimeTypeModifiedEmit(
 	edv_core_struct *core_ptr,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 );
 void EDVMimeTypeRemovedEmit(
 	edv_core_struct *core_ptr, gint mt_num
@@ -878,9 +878,9 @@ gint EDVCheckDevicesCB(gpointer data)
 	gboolean last_mount_state;
 	gint i;
 	edv_device_struct *d;
-        edv_core_struct *core_ptr = EDV_CORE(data);
-        if(core_ptr == NULL)                       
-            return(FALSE);
+	edv_core_struct *core_ptr = EDV_CORE(data);
+	if(core_ptr == NULL)                       
+	    return(FALSE);
 
 /* TODO */
 
@@ -906,7 +906,6 @@ gint EDVCheckDevicesCB(gpointer data)
 	}
 
 
-
 	return(TRUE);
 }
 
@@ -1343,12 +1342,12 @@ gint EDVEntryCompletePathCB(
 	    return(status);
 	}
 
-#define SIGNAL_EMIT_STOP        {               \
- gtk_signal_emit_stop_by_name(                  \
-  GTK_OBJECT(widget),                           \
-  press ?                                       \
-   "key_press_event" : "key_release_event"      \
- );                                             \
+#define SIGNAL_EMIT_STOP	{		\
+ gtk_signal_emit_stop_by_name(			\
+  GTK_OBJECT(widget),				\
+  press ?					\
+   "key_press_event" : "key_release_event"	\
+ );						\
 }
 
 	switch(key->keyval)
@@ -1452,8 +1451,12 @@ void EDVLocBarIconDragDataGet(
 
 
 /*
- *	Emits a write protect state change signal to all of endeavour's
- *	windows who are interested.
+ *	Write protect changed emit.
+ *
+ *	Notifies all relivant windows about the write protect state
+ *	being changed.
+ *
+ *	The state should be the new write protect state.
  */
 void EDVWriteProtectChangedEmit(
 	edv_core_struct *core_ptr, gboolean state
@@ -1506,7 +1509,7 @@ void EDVWriteProtectChangedEmit(
 }
 
 /*
- *	Emits an object added signal.
+ *	Emits an object added signal to all relivant windows.
  */
 void EDVObjectAddedEmit(
 	edv_core_struct *core_ptr, const gchar *path,
@@ -1516,13 +1519,17 @@ void EDVObjectAddedEmit(
 	gint i;
 	gchar *dpath;
 
-
 	if((core_ptr == NULL) || STRISEMPTY(path))
 	    return;
 
-	/* Create a local copy of the path */
+	/* Copy the specified path */
 	dpath = STRDUP(path);
 
+	/* Update device statistics */
+	EDVDevicesListUpdateStats(
+	    core_ptr->device, core_ptr->total_devices
+	);
+
 	/* Begin emitting signal */
 
 	/* File Browsers */
@@ -1537,16 +1544,21 @@ void EDVObjectAddedEmit(
 		core_ptr->imbr[i], dpath, lstat_buf
 	    );
 
-	/* Do not emit object added signal to Archivers */
-
+	/* Skip Archivers */
 
+	/* Skip the Recycle Bin */
 
+	/* Property Dialogs */
+	for(i = 0; i < core_ptr->total_propdlgs; i++)
+	    EDVPropDlgObjectAddedNotifyCB(
+		core_ptr->propdlg[i], dpath, lstat_buf
+	    );
 
 	g_free(dpath);
 }
 
 /*
- *	Emits an object modified signal.
+ *	Emits an object modified signal to all relivant windows.
  */
 void EDVObjectModifiedEmit(
 	edv_core_struct *core_ptr, const gchar *path,
@@ -1560,9 +1572,14 @@ void EDVObjectModifiedEmit(
 	if((core_ptr == NULL) || STRISEMPTY(path))
 	    return;
 
-	/* Create a local copy of the path */
+	/* Copy the specified path */
 	dpath = STRDUP(path);
 
+	/* Update device statistics */
+	EDVDevicesListUpdateStats(
+	    core_ptr->device, core_ptr->total_devices
+	);
+
 	/* Begin emitting signal */
 
 	/* File Browsers */
@@ -1583,32 +1600,36 @@ void EDVObjectModifiedEmit(
 		core_ptr->archiver[i], dpath, new_path, lstat_buf
 	    );
 
+	/* Skip the Recycle Bin */
+
 	/* Property Dialogs */
 	for(i = 0; i < core_ptr->total_propdlgs; i++)
 	    EDVPropDlgObjectModifiedNotifyCB(
 		core_ptr->propdlg[i], dpath, new_path, lstat_buf
 	    );
 
-
-
 	g_free(dpath);
 }
 
 /*
- *	Emits an object removed signal.
+ *	Emits an object removed signal to all relivant windows.
  */
 void EDVObjectRemovedEmit(edv_core_struct *core_ptr, const gchar *path)
 {
 	gint i;
 	gchar *dpath;
 
-
 	if((core_ptr == NULL) || STRISEMPTY(path))
 	    return;
 
-	/* Create a local copy of the path */
+	/* Copy the specified path */
 	dpath = STRDUP(path);
 
+	/* Update device statistics */
+	EDVDevicesListUpdateStats(
+	    core_ptr->device, core_ptr->total_devices
+	);
+
 	/* Begin emitting signal */
 
 	/* File Browsers */
@@ -1629,18 +1650,19 @@ void EDVObjectRemovedEmit(edv_core_struct *core_ptr, const gchar *path)
 		core_ptr->archiver[i], dpath
 	    );
 
+	/* Skip the Recycle Bin */
+
 	/* Property Dialogs */
 	for(i = 0; i < core_ptr->total_propdlgs; i++)
 	    EDVPropDlgObjectRemovedNotifyCB(
 		core_ptr->propdlg[i], dpath
 	    );
 
-
 	g_free(dpath);
 }
 
 /*
- *	Emits a mount/unmount signal.
+ *	Emits a device mount/unmount signal to all relivant windows.
  */
 void EDVObjectMountEmit(
 	edv_core_struct *core_ptr,
@@ -1655,7 +1677,7 @@ void EDVObjectMountEmit(
 
 	/* Begin emitting signal */
 
-	/* Devices list window */
+	/* Devices List */
 	EDVDevicesListWinMountNotifyCB(
 	    core_ptr->device_listwin, dev_num, dev, is_mounted
 	);
@@ -1672,6 +1694,10 @@ void EDVObjectMountEmit(
 		core_ptr->imbr[i], dev_num, dev, is_mounted
 	    );
 
+	/* Skip Archivers */
+
+	/* Skip the Recycle Bin */
+
 	/* Property Dialogs */
 	for(i = 0; i < core_ptr->total_propdlgs; i++)
 	    EDVPropDlgMountNotifyCB(
@@ -1681,14 +1707,14 @@ void EDVObjectMountEmit(
 
 
 /*
- *      Emits an archive object added signal to all of endeavour's
- *      windows who are interested.
+ *	Emits an object added to archive signal to all relivant windows.
  *
  *	The arch_path specifies the location of the archive that the
- *	archive object specified by path was added to. The obj contains
- *	the newly added archive object's statistics.
+ *	object specified by path was added to.
+ *
+ *	The obj contains the archive object's statistics.
  */
-void EDVArchiveObjectAddedNotifyCB(
+void EDVArchiveObjectAddedEmit(
 	edv_core_struct *core_ptr, const gchar *arch_path,
 	const gchar *path, edv_archive_object_struct *obj
 )
@@ -1698,6 +1724,11 @@ void EDVArchiveObjectAddedNotifyCB(
 	if(core_ptr == NULL)
 	    return;
 
+	/* Update device statistics */
+	EDVDevicesListUpdateStats(
+	    core_ptr->device, core_ptr->total_devices
+	);
+
 	/* Begin emitting signal */
 
 	/* Archivers */
@@ -1708,15 +1739,15 @@ void EDVArchiveObjectAddedNotifyCB(
 }
 
 /*
- *      Emits an archive object modified signal to all of endeavour's
- *      windows who are interested.
+ *	Emits an object modified in an archive signal to all relivant
+ *	windows.
  *
- *      The arch_path specifies the location of the archive that the
- *      archive object specified by path was modified. The obj contains
- *      the newly modified archive object's statistics and path reffers
- *	to the archive object's path.
+ *	The arch_path specifies the location of the archive that the
+ *	object specified by path was added to.
+ *
+ *	The obj contains the archive object's statistics.
  */
-void EDVArchiveObjectModifiedNotifyCB(
+void EDVArchiveObjectModifiedEmit(
 	edv_core_struct *core_ptr, const gchar *arch_path,
 	const gchar *path, const gchar *new_path,
 	edv_archive_object_struct *obj
@@ -1727,6 +1758,11 @@ void EDVArchiveObjectModifiedNotifyCB(
 	if(core_ptr == NULL)
 	    return;
 
+	/* Update device statistics */
+	EDVDevicesListUpdateStats(
+	    core_ptr->device, core_ptr->total_devices
+	);
+
 	/* Begin emitting signal */
 
 	/* Archivers */
@@ -1737,13 +1773,13 @@ void EDVArchiveObjectModifiedNotifyCB(
 }
 
 /*
- *      Emits an archive object removed signal to all of endeavour's
- *      windows who are interested.
+ *	Emits an object removed from archive signal to all relivant
+ *	windows.
  *
- *      The arch_path specifies the location of the archive that the
- *      archive object specified by path was removed.
+ *	The arch_path specifies the location of the archive that the
+ *	object specified by path was added to.
  */
-void EDVArchiveObjectRemovedNotifyCB(
+void EDVArchiveObjectRemovedEmit(
 	edv_core_struct *core_ptr, const gchar *arch_path,
 	const gchar *path
 )
@@ -1753,6 +1789,11 @@ void EDVArchiveObjectRemovedNotifyCB(
 	if(core_ptr == NULL)
 	    return;
 
+	/* Update device statistics */
+	EDVDevicesListUpdateStats(
+	    core_ptr->device, core_ptr->total_devices
+	);
+
 	/* Begin emitting signal */
 
 	/* Archivers */
@@ -1764,28 +1805,32 @@ void EDVArchiveObjectRemovedNotifyCB(
 
 
 /*
- *	Emits a recycled object added signal.
+ *	Emits a recycled object added signal to all relivant windows.
  */
 void EDVRecycledObjectAddedEmit(
 	edv_core_struct *core_ptr, guint index
 )
 {
 	gint i;
-	const gchar *recycled_index_file;
-
+	const gchar *recbin_index_file;
+	const cfg_item_struct *cfg_list;
 
 	if(core_ptr == NULL)
 	    return;
 
-	/* Get path of recycled object index file */
-	recycled_index_file = CFGItemListGetValueS(
-	    core_ptr->cfg_list, EDV_CFG_PARM_FILE_RECYCLED_INDEX
+	cfg_list = core_ptr->cfg_list;
+
+	recbin_index_file = EDV_GET_S(EDV_CFG_PARM_FILE_RECYCLED_INDEX);
+
+	/* Update device statistics */
+	EDVDevicesListUpdateStats(    
+	    core_ptr->device, core_ptr->total_devices
 	);
 
-	/* Update number of recycled objects on the core structure */
 #if 1
+	/* Update number of recycled objects */
 	core_ptr->last_recbin_items = EDVRecBinFIOTotalItems(
-	    recycled_index_file
+	    recbin_index_file
 	);
 #else
 	/* Use simplified method by just checking of the index file
@@ -1793,11 +1838,11 @@ void EDVRecycledObjectAddedEmit(
 	 *
 	 * This limits the result to be 0 or 1 items
 	 */
-	if(recycled_index_file != NULL)
+	if(recbin_index_file != NULL)
 	{
 
 	    struct stat stat_buf;
-	    if(stat(recycled_index_file, &stat_buf))
+	    if(stat(recbin_index_file, &stat_buf))
 		core_ptr->last_recbin_items = 0;
 	    else
 		core_ptr->last_recbin_items = (stat_buf.st_size > 0) ?
@@ -1839,27 +1884,32 @@ void EDVRecycledObjectAddedEmit(
 }
 
 /*
- *	Emits a recycled object removed signal.
+ *	Emits a recycled object removed signal to all relivant windows.
  */
 void EDVRecycledObjectRemovedEmit(
 	edv_core_struct *core_ptr, guint index
 )
 {
 	gint i;
-	const gchar *recycled_index_file;
+	const gchar *recbin_index_file;
+	const cfg_item_struct *cfg_list;
 
 	if(core_ptr == NULL)
 	    return;
 
-	/* Get path of recycled object index file */
-	recycled_index_file = CFGItemListGetValueS(
-	    core_ptr->cfg_list, EDV_CFG_PARM_FILE_RECYCLED_INDEX
+	cfg_list = core_ptr->cfg_list;
+
+	recbin_index_file = EDV_GET_S(EDV_CFG_PARM_FILE_RECYCLED_INDEX);
+
+	/* Update device statistics */
+	EDVDevicesListUpdateStats(    
+	    core_ptr->device, core_ptr->total_devices
 	);
 
-	/* Update number of recycled objects on the core structure */
 #if 1
+	/* Update number of recycled objects on the core structure */
 	core_ptr->last_recbin_items = EDVRecBinFIOTotalItems(
-	    recycled_index_file
+	    recbin_index_file
 	);
 #else
 	/* Use simplified method by just checking of the index file
@@ -1867,10 +1917,10 @@ void EDVRecycledObjectRemovedEmit(
 	 *
 	 * This limits the result to be 0 or 1 items
 	 */
-	if(recycled_index_file != NULL)
+	if(recbin_index_file != NULL)
 	{
 	    struct stat stat_buf;
-	    if(stat(recycled_index_file, &stat_buf))
+	    if(stat(recbin_index_file, &stat_buf))
 		core_ptr->last_recbin_items = 0;
 	    else
 		core_ptr->last_recbin_items = (stat_buf.st_size > 0) ?
@@ -2010,7 +2060,7 @@ void EDVReconfiguredEmit(edv_core_struct *core_ptr)
  */
 void EDVMimeTypeAddedEmit(
 	edv_core_struct *core_ptr,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 )
 {
 	gint i;
@@ -2033,30 +2083,30 @@ void EDVMimeTypeAddedEmit(
 
 	/* MIME Types Window */
 	EDVMimeTypesListWinMimeTypeAddedCB(
-	    core_ptr->mimetype_listwin, mt_num, mt_ptr
+	    core_ptr->mimetype_listwin, mt_num, mt
 	);
 
 	/* File Browsers */
 	for(i = 0; i < core_ptr->total_browsers; i++)
 	    EDVBrowserMimeTypeAddedCB(
-		core_ptr->browser[i], mt_num, mt_ptr
+		core_ptr->browser[i], mt_num, mt
 	    );
 
 	/* Image Browsers */
 	for(i = 0; i < core_ptr->total_imbrs; i++)
 	    EDVImbrMimeTypeAddedCB(
-		core_ptr->imbr[i], mt_num, mt_ptr
+		core_ptr->imbr[i], mt_num, mt
 	    );
 
 	/* Archivers */
 	for(i = 0; i < core_ptr->total_archivers; i++)
 	    EDVArchiverMimeTypeAddedCB(
-		core_ptr->archiver[i], mt_num, mt_ptr
+		core_ptr->archiver[i], mt_num, mt
 	    );
 
 	/* Recycle Bin */
 	EDVRecBinMimeTypeAddedCB(
-	    core_ptr->recbin, mt_num, mt_ptr
+	    core_ptr->recbin, mt_num, mt
 	);
 }
 
@@ -2065,7 +2115,7 @@ void EDVMimeTypeAddedEmit(
  */
 void EDVMimeTypeModifiedEmit(
 	edv_core_struct *core_ptr,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 )
 {
 	gint i;
@@ -2088,30 +2138,30 @@ void EDVMimeTypeModifiedEmit(
 
 	/* MIME Types Window */
 	EDVMimeTypesListWinMimeTypeModifiedCB(
-	    core_ptr->mimetype_listwin, mt_num, mt_ptr
+	    core_ptr->mimetype_listwin, mt_num, mt
 	);
 
 	/* File Browsers */
 	for(i = 0; i < core_ptr->total_browsers; i++)
 	    EDVBrowserMimeTypeModifiedCB(
-		core_ptr->browser[i], mt_num, mt_ptr
+		core_ptr->browser[i], mt_num, mt
 	    );
 
 	/* Image browsers */
 	for(i = 0; i < core_ptr->total_imbrs; i++)
 	    EDVImbrMimeTypeModifiedCB(
-		core_ptr->imbr[i], mt_num, mt_ptr
+		core_ptr->imbr[i], mt_num, mt
 	    );
 
 	/* Archivers */
 	for(i = 0; i < core_ptr->total_archivers; i++)
 	    EDVArchiverMimeTypeModifiedCB(
-		core_ptr->archiver[i], mt_num, mt_ptr
+		core_ptr->archiver[i], mt_num, mt
 	    );
 
 	/* Recycle Bin */
 	EDVRecBinMimeTypeModifiedCB(
-	    core_ptr->recbin, mt_num, mt_ptr
+	    core_ptr->recbin, mt_num, mt
 	);
 }
 
