@@ -683,7 +683,7 @@ gint EDVConfirmDelete(
 
 	if((total_objects == 1) && (src_path != NULL))
 	{
-	    const gchar *name = EDVGetPathName(src_path);
+	    const gchar *name = g_basename(src_path);
 	    if(ISLPATHDIR(src_path))
 		buf = g_strdup_printf(
 #if defined(PROG_LANGUAGE_SPANISH)
