@@ -190,10 +190,10 @@ static void EDVDoCreateStandardConfiguration(edv_core_struct *core_ptr)
 	);
 	/* MIME Types (Local) */
 #if defined(DEBIAN)
-        EDV_SET_S(              
-            EDV_CFG_PARM_FILE_MIME_TYPES,
-            PrefixPaths(global_config_dir, EDV_DEF_MIMETYPES_FILE)
-        );
+	EDV_SET_S(              
+	    EDV_CFG_PARM_FILE_MIME_TYPES,
+	    PrefixPaths(global_config_dir, EDV_DEF_MIMETYPES_FILE)
+	);
 #else
 	EDV_SET_S(
 	    EDV_CFG_PARM_FILE_MIME_TYPES,
@@ -891,7 +891,8 @@ static void EDVDoCreateStandardConfiguration(edv_core_struct *core_ptr)
 static void EDVDoCreateStandardCursors(edv_core_struct *core_ptr)
 {
 	GdkWindow *root = GDK_ROOT_PARENT();
-	GdkColor c_fg, c_bg;
+	GdkColor	c_fg = { 0, 0xffff, 0xffff, 0xffff },
+			c_bg = { 0, 0x0000, 0x0000, 0x0000 };
 
 #define APPEND_CURSOR(_cursor_)		{		\
  const gint i = MAX(core_ptr->total_cursors, 0);	\
@@ -923,14 +924,6 @@ static void EDVDoCreateStandardCursors(edv_core_struct *core_ptr)
  ));							\
 }
 
-	/* Set foreground and background colors */
-	c_fg.red	= 0xffff;
-	c_fg.green	= 0xffff;
-	c_fg.blue	= 0xffff;
-	c_bg.red	= 0x0000;
-	c_bg.green	= 0x0000;
-	c_bg.blue	= 0x0000;
-
 	/* Begin creating cursors */
 
 	if(FALSE)
@@ -2143,10 +2136,19 @@ by going to Settings->Options... and Settings->Customize...\n"
 	    EDVMapRecBinDeskIcon(core_ptr);
 
 
-	/* Begin creating initial window, check if no window was
-	 * specified from the command line
+	/* Create the initial window in accordance with the window
+	 * type specified from the command line, if no window type was
+	 * specified from the command line then refer to the window
+	 * type specified by the configuration
 	 */
-	if(STRISEMPTY(window_name))
+	if(!STRISEMPTY(window_name))
+	{
+	    /* Create a window specified by the command line */ 
+	    EDVNewWindowNexus(
+		core_ptr, window_name, startup_dir, arg_extra, NULL
+	    ); 
+	}
+	else
 	{
 	    /* No window name specified so startup with a window
 	     * specified by the configuration
@@ -2182,13 +2184,6 @@ by going to Settings->Options... and Settings->Customize...\n"
 		created_window = TRUE;
 	    }
 	}
-	else
-	{
-	    /* Create a window specified by the command line */
-	    EDVNewWindowNexus(
-		core_ptr, window_name, startup_dir, arg_extra, NULL
-	    );
-	}
 
 #if !defined(DEBIAN)
 	/* Display License/Copyright?
