@@ -11,12 +11,12 @@
 #include "config.h"
 
 
-gchar *EDVDateFormatString(
+const gchar *EDVDateFormatString(
 	gulong t,		/* In systime seconds */
 	const gchar *format,	/* Can be NULL to just use ctime() */
 	edv_date_relativity relativity
 );
-gchar *EDVDateStringDuration(gulong dt);
+const gchar *EDVDateStringDuration(gulong dt);
 
 void EDVDateParseDateDMY(
 	const gchar *s,
@@ -62,7 +62,7 @@ void EDVDateParseTime(
  *
  *	This function never returns NULL.
  */
-gchar *EDVDateFormatString(
+const gchar *EDVDateFormatString(
 	gulong t,               /* In systime seconds */
 	const gchar *format,    /* Can be NULL to just use ctime() */
 	edv_date_relativity relativity
@@ -77,13 +77,12 @@ gchar *EDVDateFormatString(
 		gulong ct, dt = (gulong)time(NULL) - t;
 		static gchar buf[80];
 
-
 		/* Less than one second? */
 		if(dt < 1)
 		{
 		    g_snprintf(
 			buf, sizeof(buf),
-			"less than 1 second ago"
+			"less than a second ago"
 		    );
 		}
 		/* Less than one minute? */
@@ -203,7 +202,7 @@ gchar *EDVDateFormatString(
  *	Returns a statically allocated string describing the time
  *	lapsed specified by dt.
  */
-gchar *EDVDateStringDuration(gulong dt)
+const gchar *EDVDateStringDuration(gulong dt)
 {
 	gulong ct, ct2;
 	static gchar buf[80];
@@ -213,7 +212,7 @@ gchar *EDVDateStringDuration(gulong dt)
 	{
 	    g_snprintf(
 		buf, sizeof(buf),
-		"less than 1 second"
+		"less than a second"
 	    );
 	}
 	/* Less than one minute? */
