@@ -9,6 +9,25 @@
 #include "edvtypes.h"
 
 
+typedef struct _edv_fs_type_struct		edv_fs_type_struct;
+typedef struct _edv_device_struct		edv_device_struct;
+
+
+/*
+ *	Device Flags:
+ */
+typedef enum {
+	EDV_DEVICE_MOUNTED		= (1 << 0),
+	EDV_DEVICE_READ_ONLY		= (1 << 1),
+	EDV_DEVICE_NO_UNMOUNT		= (1 << 2),
+	EDV_DEVICE_INTERNAL		= (1 << 3),	/* Internal, do not
+							 * save to devices
+							 * file */
+	EDV_DEVICE_UNLISTED		= (1 << 4),	/* Do not show on
+							 * "brief" listings */
+	EDV_DEVICE_REALIZED		= (1 << 5)
+} edv_device_flags;
+
 /*
  *	Device Icon States:
  */
@@ -21,7 +40,7 @@ typedef enum {
 
 
 /*
- *	Filesystem Types:
+ *	Filesystem Type Codes & Names:
  */
 #define EDV_FS_TYPE_EMPTY		0x0000
 
@@ -86,7 +105,6 @@ typedef enum {
 #define EDV_FS_TYPE_XIA_NAME		"xia"
 
 
-
 #define EDV_FS_TYPE_SWAP                0x0050  /* Universal swap */
 #define EDV_FS_TYPE_SWAP_NAME           "swap"
 
@@ -95,96 +113,67 @@ typedef enum {
 
 
 /*
- *	List of fs type names, each set comes with 3 char * pointers.
+ *	Filesystems List:
  *
- *	First pointer is casted to a guint which contains the fs type
- *	code.
- *
- *	Second pointer is casted to a char * which points to a string
- *	containing the fs type name.
- *
- *	Third pointer is reserved and is currently always NULL.
- *
- *	Last set of 3 pointers in this list are always NULL.
+ *	List of filesystem type codes with their corresponding
+ *	filesystem names.
  */
 #define EDV_FS_TYPE_LIST	{				\
-{ EDV_FS_TYPE_MSDOS,	EDV_FS_TYPE_MSDOS_NAME,		NULL },	\
-{ EDV_FS_TYPE_VFAT,	EDV_FS_TYPE_VFAT_NAME,		NULL },	\
+{ EDV_FS_TYPE_MSDOS,	EDV_FS_TYPE_MSDOS_NAME,		0 },	\
+{ EDV_FS_TYPE_VFAT,	EDV_FS_TYPE_VFAT_NAME,		0 },	\
 								\
-{ EDV_FS_TYPE_ISO9660,	EDV_FS_TYPE_ISO9660_NAME,	NULL },	\
+{ EDV_FS_TYPE_ISO9660,	EDV_FS_TYPE_ISO9660_NAME,	0 },	\
 								\
-{ EDV_FS_TYPE_HPFS,	EDV_FS_TYPE_HPFS_NAME,		NULL },	\
+{ EDV_FS_TYPE_HPFS,	EDV_FS_TYPE_HPFS_NAME,		0 },	\
 								\
-{ EDV_FS_TYPE_EXT,	EDV_FS_TYPE_EXT_NAME,		NULL },	\
-{ EDV_FS_TYPE_EXT2,	EDV_FS_TYPE_EXT2_NAME,		NULL },	\
-{ EDV_FS_TYPE_EXT3,	EDV_FS_TYPE_EXT3_NAME,		NULL },	\
+{ EDV_FS_TYPE_EXT,	EDV_FS_TYPE_EXT_NAME,		0 },	\
+{ EDV_FS_TYPE_EXT2,	EDV_FS_TYPE_EXT2_NAME,		0 },	\
+{ EDV_FS_TYPE_EXT3,	EDV_FS_TYPE_EXT3_NAME,		0 },	\
 								\
-{ EDV_FS_TYPE_MINIX,	EDV_FS_TYPE_MINIX_NAME,		NULL },	\
-{ EDV_FS_TYPE_MINIX2,	EDV_FS_TYPE_MINIX2_NAME,	NULL },	\
+{ EDV_FS_TYPE_MINIX,	EDV_FS_TYPE_MINIX_NAME,		0 },	\
+{ EDV_FS_TYPE_MINIX2,	EDV_FS_TYPE_MINIX2_NAME,	0 },	\
 								\
-{ EDV_FS_TYPE_NCP,	EDV_FS_TYPE_NCP_NAME,		NULL },	\
-{ EDV_FS_TYPE_NFS,	EDV_FS_TYPE_NFS_NAME,		NULL },	\
-{ EDV_FS_TYPE_SMB,	EDV_FS_TYPE_SMB_NAME,		NULL },	\
+{ EDV_FS_TYPE_NCP,	EDV_FS_TYPE_NCP_NAME,		0 },	\
+{ EDV_FS_TYPE_NFS,	EDV_FS_TYPE_NFS_NAME,		0 },	\
+{ EDV_FS_TYPE_SMB,	EDV_FS_TYPE_SMB_NAME,		0 },	\
 								\
-{ EDV_FS_TYPE_XENIX,	EDV_FS_TYPE_XENIX_NAME,		NULL },	\
-{ EDV_FS_TYPE_SYSV4,	EDV_FS_TYPE_SYSV4_NAME,		NULL },	\
-{ EDV_FS_TYPE_SYSV2,	EDV_FS_TYPE_SYSV2_NAME,		NULL },	\
+{ EDV_FS_TYPE_XENIX,	EDV_FS_TYPE_XENIX_NAME,		0 },	\
+{ EDV_FS_TYPE_SYSV4,	EDV_FS_TYPE_SYSV4_NAME,		0 },	\
+{ EDV_FS_TYPE_SYSV2,	EDV_FS_TYPE_SYSV2_NAME,		0 },	\
 								\
-{ EDV_FS_TYPE_COH,	EDV_FS_TYPE_COH_NAME,		NULL },	\
-{ EDV_FS_TYPE_UFS,	EDV_FS_TYPE_UFS_NAME,		NULL },	\
-{ EDV_FS_TYPE_XIA,	EDV_FS_TYPE_XIA_NAME,		NULL },	\
+{ EDV_FS_TYPE_COH,	EDV_FS_TYPE_COH_NAME,		0 },	\
+{ EDV_FS_TYPE_UFS,	EDV_FS_TYPE_UFS_NAME,		0 },	\
+{ EDV_FS_TYPE_XIA,	EDV_FS_TYPE_XIA_NAME,		0 },	\
 								\
-{ EDV_FS_TYPE_SWAP,	EDV_FS_TYPE_SWAP_NAME,		NULL },	\
-{ EDV_FS_TYPE_PROC,	EDV_FS_TYPE_PROC_NAME,		NULL },	\
+{ EDV_FS_TYPE_SWAP,	EDV_FS_TYPE_SWAP_NAME,		0 },	\
+{ EDV_FS_TYPE_PROC,	EDV_FS_TYPE_PROC_NAME,		0 },	\
 								\
-/* Last set of quantities must be 0, NULL, and NULL */		\
-{ 0,			NULL,				NULL }	\
+{ 0,			NULL,				0 }	\
 }
-
 /*
  *	Filesystem Type:
  */
-typedef struct _edv_fs_type_struct		edv_fs_type_struct;
 struct _edv_fs_type_struct {
-
 	guint32		fs_type;	/* One of EDV_FS_TYPE_* */
-	gchar		*name;
-	gpointer	reserved;
-
+	gchar		*name;		/* Filesystem's conical name */
+	guint32		flags;		/* Options (reserved) */
 };
-#define EDV_FS_TYPE(p)	((edv_fs_type_struct *)(p))
+#define EDV_FS_TYPE(p)		((edv_fs_type_struct *)(p))
+
 
 /*
- *	Device Reference:
+ *	Device:
  */
-typedef struct _edv_device_struct		edv_device_struct;
 struct _edv_device_struct {
 
+	edv_device_flags	flags;
+
 	guint32		fs_type;	/* One of EDV_FS_TYPE_* */
 
 	gchar		*name;		/* Descriptive name */
 	gchar		*device_path;	/* Path to device object */
 	gchar		*mount_path;	/* Path to mount point directory */
 
-	gboolean	is_mounted;	/* Is currently mounted */
-
-
-	/* Options */
-	gboolean	no_unmount;	/* Do not allow unmounting of device */
-	gboolean	read_only;	/* Always mount as read-only */
-	gboolean	unlisted;	/* Hide from general listings */
-
-	/* Indicates if this device structure has been realized,
-	 * realized meaning icons and related resources are all loaded
-	 */
-	gboolean	realized;
-
-	/* Indicates that this device is created internally by this
-	 * program and that it should not be saved to the device list
-	 * file
-	 */
-	gboolean	internal;
-
 	/* Small 20x20 icons */
 	GdkPixmap	*small_pixmap[EDV_DEVICE_TOTAL_ICON_STATES];
 	GdkBitmap	*small_mask[EDV_DEVICE_TOTAL_ICON_STATES];
@@ -213,11 +202,7 @@ struct _edv_device_struct {
 			*command_tools,
 			*command_format;
 
-	/* Statistics, units are in 1k blocks (or whatever statfs()
-	 * gives it in
-	 *
-	 * Note, statistics are only valid if member is_mounted is TRUE
-	 */
+	/* Statistics, units are in 1k blocks */
 	gulong		blocks_total,
 			blocks_available,	/* Available to effective user id */
 			blocks_free;
@@ -227,7 +212,20 @@ struct _edv_device_struct {
 			last_check_time;	/* Last time command_check aws runned */
 
 };
-#define EDV_DEVICE(p)	((edv_device_struct *)(p))
+#define EDV_DEVICE(p)		((edv_device_struct *)(p))
+
+#define EDV_DEVICE_IS_MOUNTED(p)	(((p) != NULL) ? \
+ ((p)->flags & EDV_DEVICE_MOUNTED) : FALSE)
+#define EDV_DEVICE_IS_READ_ONLY(p)	(((p) != NULL) ? \
+ ((p)->flags & EDV_DEVICE_READ_ONLY) : FALSE)
+#define EDV_DEVICE_IS_NO_UNMOUNT(p)	(((p) != NULL) ? \
+ ((p)->flags & EDV_DEVICE_NO_UNMOUNT) : FALSE)
+#define EDV_DEVICE_IS_INTERNAL(p)	(((p) != NULL) ? \
+ ((p)->flags & EDV_DEVICE_INTERNAL) : FALSE)
+#define EDV_DEVICE_IS_UNLISTED(p)	(((p) != NULL) ? \
+ ((p)->flags & EDV_DEVICE_UNLISTED) : FALSE)
+#define EDV_DEVICE_IS_REALIZED(p)	(((p) != NULL) ? \
+ ((p)->flags & EDV_DEVICE_REALIZED) : FALSE)
 
 
 /* Devices List Matching */
@@ -248,7 +246,8 @@ extern edv_device_struct *EDVDeviceListMatchObject(
 );
 
 
-/* Devices List Updating */
+/* Device Updating */
+extern void EDVDeviceUpdateMountState(edv_device_struct *d);
 extern void EDVDevicesListUpdateMountStates(
 	edv_device_struct **list, gint total
 );
@@ -257,8 +256,8 @@ extern void EDVDevicesListUpdateStats(
 );
 
 /* Filesystem */
-extern guint32 EDVDeviceGetFSFromString(const gchar *fs_type_str);
-extern const gchar *EDVDeviceGetFSStringFromNumber(guint32 fs_type);
+extern guint32 EDVDeviceGetFSTypeFromName(const gchar *name);
+extern const gchar *EDVDeviceGetFSNameFromType(guint32 type);
 
 /* Devices */
 extern edv_device_struct *EDVDeviceNew(
