@@ -1,7 +1,11 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#if defined(__SOLARIS__)
+#if defined(__FreeBSD__)
+# include <fstab.h>
+#include <sys/param.h>
+#include <sys/mount.h>
+#elif defined(__SOLARIS__)
 # include <sys/mnttab.h>
 # include <sys/vfstab.h>
 #else
@@ -73,23 +77,26 @@ void EDVDevicesListLoadFromSystem(
 {
 	FILE *fp;
 	gulong file_size;
-	gint dev_num = -1;
-	edv_device_struct *dev = NULL;
-#if defined(__SOLARIS__)
-	struct vfstab *vfs_ptr = NULL;
+	gint dev_num;
+	edv_device_struct *dev;
+#if defined(__FreeBSD__)
+	struct fstab *fs_ptr;
+#elif defined(__SOLARIS__)
+	struct vfstab *vfs_ptr;
 	int mtback;
 #else
 	struct mntent *mt_ptr;
 #endif
 	struct stat stat_buf;
 
-
 	if((list == NULL) || (total == NULL))
 	    return;
 
-
 	/* Open the system's devices list file */
-#if defined(__SOLARIS__)
+#if defined(__FreeBSD__)
+	setfsent();
+	fp = FOpen("/etc/fstab", "rb");
+#elif defined(__SOLARIS__)
 	fp = FOpen("/etc/vfstab", "rb");
 #else
 	fp = setmntent("/etc/fstab", "rb");
@@ -108,7 +115,10 @@ void EDVDevicesListLoadFromSystem(
 	    progress_cb(client_data, 0l, file_size);
 
 	/* Begin reading the system's devices list file */
-#if defined(__SOLARIS__)
+#if defined(__FreeBSD__)
+	fs_ptr = getfsent();
+	while(fs_ptr != NULL)
+#elif defined(__SOLARIS__)
 	vfs_ptr = (struct vfstab *)g_malloc(sizeof(struct vfstab));
 	mtback = getvfsent(fp, vfs_ptr);
 	while(mtback != 0)
@@ -131,7 +141,14 @@ void EDVDevicesListLoadFromSystem(
 	     */
 	    dev = EDVDeviceListMatchDevicePath(
 		*list, *total,
-		&dev_num, mt_ptr->mnt_fsname
+		&dev_num,
+#if defined(__FreeBSD__)
+		fs_ptr->fs_spec
+#elif defined(__SOLARIS__)
+		vfs_ptr->vfs_special
+#else
+		mt_ptr->mnt_fsname
+#endif
 	    );
 	    if(dev == NULL)
 	    {
@@ -153,7 +170,12 @@ void EDVDevicesListLoadFromSystem(
 		else
 		{
 		    (*list)[dev_num] = dev = EDVDeviceNew(
-#if defined(__SOLARIS__)
+#if defined(__FreeBSD__)
+			EDVDeviceGetFSTypeFromName(fs_ptr->fs_vfstype),
+			NULL,
+			fs_ptr->fs_spec,
+			fs_ptr->fs_file
+#elif defined(__SOLARIS__)
 			EDVDeviceGetFSTypeFromName(vfs_ptr->vfs_fstype),
 			NULL,
 			vfs_ptr->vfs_special,
@@ -204,7 +226,9 @@ void EDVDevicesListLoadFromSystem(
 		    dev->command_check = g_strdup_printf(
 			"%s %s",
 			EDV_DEF_FSCK_FRONT_PROG,
-#if defined(__SOLARIS__)
+#if defined(__FreeBSD__)
+			fs_ptr->fs_spec
+#elif defined(__SOLARIS__)
 			vfs_ptr->vfs_special
 #else
 			mt_ptr->mnt_fsname
@@ -216,7 +240,9 @@ void EDVDevicesListLoadFromSystem(
 		    dev->command_format = g_strdup_printf(
 			"%s %s",
 			EDV_DEF_FORMAT_FRONT_PROG,
-#if defined(__SOLARIS__)
+#if defined(__FreeBSD__)
+			fs_ptr->fs_spec
+#elif defined(__SOLARIS__)
 			vfs_ptr->vfs_special
 #else
 			mt_ptr->mnt_fsname
@@ -232,21 +258,29 @@ void EDVDevicesListLoadFromSystem(
 		 */
 
 		/* File system type */
-#if defined(__SOLARIS__)
-		dev->fs_type = EDVDeviceGetFSTypeFromName(vfs_ptr->vfs_fstype);
+		dev->fs_type = EDVDeviceGetFSTypeFromName(
+#if defined(__FreeBSD__)
+		    fs_ptr->fs_vfstype
+#elif defined(__SOLARIS__)
+		    vfs_ptr->vfs_fstype
 #else
-		dev->fs_type = EDVDeviceGetFSTypeFromName(mt_ptr->mnt_type);
+		    mt_ptr->mnt_type
 #endif
+		);
 
 		/* Mount path */
-#if defined(__SOLARIS__)
+#if defined(__FreeBSD__)
+		if(fs_ptr->fs_file != NULL)
+#elif defined(__SOLARIS__)
 		if(vfs_ptr->vfs_mountp != NULL)
 #else
 		if(mt_ptr->mnt_dir != NULL)
 #endif
 		{
 		    g_free(dev->mount_path);
-#if defined(__SOLARIS__)
+#if defined(__FreeBSD__)
+		    dev->mount_path = STRDUP(fs_ptr->fs_file);
+#elif defined(__SOLARIS__)
 		    dev->mount_path = STRDUP(vfs_ptr->vfs_mountp);
 #else
 		    dev->mount_path = STRDUP(mt_ptr->mnt_dir);
@@ -255,8 +289,10 @@ void EDVDevicesListLoadFromSystem(
 
 	    }
 
-	    /* Read next mount entry */
-#if defined(__SOLARIS__)
+	    /* Get the next mount entry */
+#if defined(__FreeBSD__)
+	    fs_ptr = getfsent();
+#elif defined(__SOLARIS__)
 	    mtback = getmntent(fp, vfs_ptr);
 #else
 	    mt_ptr = getmntent(fp);
@@ -265,8 +301,12 @@ void EDVDevicesListLoadFromSystem(
 
 
 	/* Close the system's devices list file */
-#if defined(__SOLARIS__)
+#if defined(__FreeBSD__)
+	endfsent();
 	FClose(fp);
+#elif defined(__SOLARIS__)
+	FClose(fp);
+	g_free(vfs_ptr);
 #else
 	endmntent(fp);
 #endif
@@ -285,11 +325,14 @@ void EDVDevicesListLoadFromSystem(
  */  
 void EDVDeviceUpdateMountStateFromSystem(edv_device_struct *dev)
 {
-	const gchar *device_path;
+	const gchar *device_path, *mount_path;
 	FILE *fp;
-#if defined(__SOLARIS__)
-	struct mnttab *mt_ptr = NULL;
-	int mtback;
+#if defined(__FreeBSD__)
+	gint i, mntsize;
+	struct statfs *mt_buf;
+#elif defined(__SOLARIS__)
+	gint mtback;
+	struct mnttab *mt_ptr;
 #else
 	struct mntent *mt_ptr;
 #endif
@@ -297,14 +340,16 @@ void EDVDeviceUpdateMountStateFromSystem(edv_device_struct *dev)
 	if(dev == NULL)
 	    return;
 
-	/* Reset mount state */
+	/* Reset the device's mount state */
 	dev->flags &= ~EDV_DEVICE_MOUNTED;
 
 	if(STRISEMPTY(dev->device_path)) 
 	    return;
 
 	/* Open the system's mounted devices list file */
-#if defined(__SOLARIS__)
+#if defined(__FreeBSD__)
+	fp = (FILE *)1;		/* Mark the mount info file as opened */
+#elif defined(__SOLARIS__)
 	fp = FOpen("/etc/mnttab", "rb");
 #else
 	fp = setmntent("/proc/mounts", "rb");
@@ -313,7 +358,12 @@ void EDVDeviceUpdateMountStateFromSystem(edv_device_struct *dev)
 	    return;
 
 	/* Begin reading the system's mounted devices list file */
-#if defined(__SOLARIS__)
+#if defined(__FreeBSD__)
+        if((mntsize = getmntinfo(&mt_buf, MNT_NOWAIT)) == 0)
+            return;
+        i = mntsize - 1;
+        while(i >= 0)
+#elif defined(__SOLARIS__)
 	mt_ptr = (struct mnttab *)g_malloc(sizeof(struct mnttab));
 	mtback = getmntent(fp, mt_ptr);
 	while(mtback != 0)
@@ -322,22 +372,54 @@ void EDVDeviceUpdateMountStateFromSystem(edv_device_struct *dev)
 	while(mt_ptr != NULL)
 #endif
 	{
-	    /* Check if this mount path matches this Device's path */
-#if defined(__SOLARIS__)
-	    device_path = (const gchar *)mt_ptr->mnt_special;
+	    /* Check if this mount path's device path matches this
+	     * Device's device path
+	     */
+	    device_path = (const gchar *)(
+#if defined(__FreeBSD__)
+                mt_buf[i].f_mntfromname
+#elif defined(__SOLARIS__)
+		mt_ptr->mnt_special
 #else
-	    device_path = (const gchar *)mt_ptr->mnt_fsname;
+		mt_ptr->mnt_fsname
 #endif
-	    if(!STRISEMPTY(device_path) ?
-		!strcmp(dev->device_path, device_path) : FALSE
-	    )
+	    );
+	    if(!STRISEMPTY(dev->device_path) && !STRISEMPTY(device_path))
 	    {
-		dev->flags |= EDV_DEVICE_MOUNTED;
-		break;
+		if(!strcmp(dev->device_path, device_path))
+		{
+		    /* Mark this device as mounted */
+		    dev->flags |= EDV_DEVICE_MOUNTED;
+		    break;
+		}
 	    }
 
-	    /* Read next mount entry */
-#if defined(__SOLARIS__)
+	    /* Also check if this mount path's mounted path matches
+	     * this Device's mounted path
+	     */
+	    mount_path = (const gchar *)(
+#if defined(__FreeBSD__)
+                mt_buf[i].f_mntonname
+#elif defined(__SOLARIS__)
+		mt_ptr->mnt_mountp
+#else
+		mt_ptr->mnt_dir
+#endif
+	    );
+	    if(!STRISEMPTY(dev->mount_path) && !STRISEMPTY(mount_path))
+	    {
+		if(!strcmp(dev->mount_path, mount_path))
+		{
+		    /* Mark this device as mounted */
+		    dev->flags |= EDV_DEVICE_MOUNTED;
+		    break;
+		}
+	    }
+
+	    /* Get the next mount entry */
+#if defined(__FreeBSD__)
+	    i--;
+#elif defined(__SOLARIS__)
 	    mtback = getmntent(fp, mt_ptr);
 #else
 	    mt_ptr = getmntent(fp);
@@ -345,8 +427,11 @@ void EDVDeviceUpdateMountStateFromSystem(edv_device_struct *dev)
 	}
 
 	/* Close the system's mounted devices list file */
-#if defined(__SOLARIS__)
+#if defined(__FreeBSD__)
+	fp = NULL;	/* Mark the mount info file as closed */
+#elif defined(__SOLARIS__)
 	FClose(fp);
+	g_free(mt_ptr);
 #else
 	endmntent(fp);
 #endif
