@@ -1,5 +1,5 @@
 /*
-		   Endeavour Disk Object Operations
+		       Endeavour Disk Object Operations
 
 	See edvrecbinfop.h for recycle bin recovery and delete operations.
  */
@@ -16,16 +16,16 @@ extern const gchar *EDVFOPGetError();
 extern gint EDVFOPCopy(
 	edv_core_struct *core_ptr,
 	const gchar *src_obj, const gchar *tar_obj,
-	gchar **new_obj_rtn,            /* Dynamically allocated. */
-	GtkWidget *toplevel,            /* Can be NULL. */
+	gchar **new_obj_rtn,            /* Dynamically allocated */
+	GtkWidget *toplevel,            /* Can be NULL */
 	gboolean show_progress, gboolean interactive,
 	gboolean *yes_to_all
 );
 extern gint EDVFOPMove(
 	edv_core_struct *core_ptr,
 	const gchar *src_obj, const gchar *tar_obj,
-	gchar **new_obj_rtn,            /* Dynamically allocated. */
-	GtkWidget *toplevel,            /* Can be NULL. */
+	gchar **new_obj_rtn,            /* Dynamically allocated */
+	GtkWidget *toplevel,            /* Can be NULL */
 	gboolean show_progress, gboolean interactive,
 	gboolean *yes_to_all
 );
