@@ -27,11 +27,11 @@ edv_uid_struct *EDVUIDMatchByGID(
 gint EDVUIDNameToUID(
 	edv_uid_struct **list, gint total, const gchar *user_name
 );
-gchar *EDVUIDGetNameFromUID(
+const gchar *EDVUIDGetNameFromUID(
 	edv_uid_struct **list, gint total,
 	gint user_id, gint *n
 );
-gchar *EDVUIDGetNameFromGID(
+const gchar *EDVUIDGetNameFromGID(
 	edv_uid_struct **list, gint total,
 	gint group_id, gint *n
 );
@@ -49,7 +49,7 @@ edv_gid_struct *EDVGIDMatchByGID(
 gint EDVGIDNameToGID(
 	edv_gid_struct **list, gint total, const gchar *group_name
 );
-gchar *EDVGIDGetNameFromGID(
+const gchar *EDVGIDGetNameFromGID(
 	edv_gid_struct **list, gint total,
 	gint group_id, gint *n
 );
@@ -267,19 +267,22 @@ gint EDVUIDNameToUID(
  *	On failed matched a number string describing the user ID is
  *	returned, so this function never returns NULL.
  */
-gchar *EDVUIDGetNameFromUID(
+const gchar *EDVUIDGetNameFromUID(
 	edv_uid_struct **list, gint total,
 	gint user_id, gint *n
 )
 {
 	static gchar num_str[40];
-	edv_uid_struct *uid;
-
-	uid = EDVUIDMatchByUID(list, total, user_id, n);
+	edv_uid_struct *uid = EDVUIDMatchByUID(list, total, user_id, n);
 	if((uid != NULL) ? (uid->name != NULL) : FALSE)
 	{
 	    return(uid->name);
 	}
+	else if(user_id < 0)
+	{
+	    *num_str = '\0';
+	    return(num_str);
+	}
 	else
 	{
 	    g_snprintf(
@@ -297,19 +300,22 @@ gchar *EDVUIDGetNameFromUID(
  *	On failed matched a number string describing the user ID is
  *	returned, so this function never returns NULL.
  */
-gchar *EDVUIDGetNameFromGID(
+const gchar *EDVUIDGetNameFromGID(
 	edv_uid_struct **list, gint total,
 	gint group_id, gint *n
 )
 {
 	static gchar num_str[40];
-	edv_uid_struct *uid;
-
-	uid = EDVUIDMatchByGID(list, total, group_id, n);
+	edv_uid_struct *uid = EDVUIDMatchByGID(list, total, group_id, n);
 	if((uid != NULL) ? (uid->name != NULL) : FALSE)
 	{
 	    return(uid->name);
 	}
+	else if(group_id < 0)
+	{
+	    *num_str = '\0';
+	    return(num_str);
+	}
 	else
 	{
 	    g_snprintf(
@@ -505,19 +511,22 @@ gint EDVGIDNameToGID(
  *	On failed matched, a number string containing the group ID is
  *      returned, so this function never returns NULL.
  */
-gchar *EDVGIDGetNameFromGID(
+const gchar *EDVGIDGetNameFromGID(
 	edv_gid_struct **list, gint total,
 	gint group_id, gint *n
 )
 {
 	static gchar num_str[40];
-	edv_gid_struct *gid;
-
-	gid = EDVGIDMatchByGID(list, total, group_id, n);
+	edv_gid_struct *gid = EDVGIDMatchByGID(list, total, group_id, n);
 	if((gid != NULL) ? (gid->name != NULL) : FALSE)
 	{
 	    return(gid->name);
 	}
+	else if(group_id < 0)
+	{
+	    *num_str = '\0';
+	    return(num_str);
+	}
 	else
 	{
 	    g_snprintf(
