@@ -7,10 +7,18 @@
 
 #include <glib.h>
 
+
+typedef struct _edv_uid_struct		edv_uid_struct;
+typedef struct _edv_gid_struct		edv_gid_struct;
+
+#define EDV_UID(p)		((edv_uid_struct *)(p))
+#define EDV_GID(p)		((edv_gid_struct *)(p))
+
+
 /*
  *	User ID:
  */
-typedef struct {
+struct _edv_uid_struct {
 
 	gchar		*name;
 	gchar		*password;	/* Crypted */
@@ -22,13 +30,12 @@ typedef struct {
 	gchar		*home_directory;
 	gchar		*shell_program;
 
-} edv_uid_struct;
-#define EDV_UID(p)	((edv_uid_struct *)(p))
+};
 
 /*
  *	Group ID:
  */
-typedef struct {
+struct _edv_gid_struct {
 
 	gchar		*name;
 	gchar		*password;        /* Crypted */
@@ -38,8 +45,7 @@ typedef struct {
 	gchar		**group_member;
 	gint		total_group_members;
 
-} edv_gid_struct;
-#define EDV_GID(p)	((edv_gid_struct *)(p))
+};
 
 
 /* User ID functions */
@@ -59,11 +65,11 @@ extern edv_uid_struct *EDVUIDMatchByGID(
 extern gint EDVUIDNameToUID(
 	edv_uid_struct **list, gint total, const gchar *user_name
 );
-extern gchar *EDVUIDGetNameFromUID(
+extern const gchar *EDVUIDGetNameFromUID(
 	edv_uid_struct **list, gint total,
 	gint user_id, gint *n
 );
-extern gchar *EDVUIDGetNameFromGID(
+extern const gchar *EDVUIDGetNameFromGID(
 	edv_uid_struct **list, gint total,
 	gint group_id, gint *n
 );
@@ -82,7 +88,7 @@ extern edv_gid_struct *EDVGIDMatchByGID(
 extern gint EDVGIDNameToGID(
 	edv_gid_struct **list, gint total, const gchar *group_name
 );
-extern gchar *EDVGIDGetNameFromGID(
+extern const gchar *EDVGIDGetNameFromGID(
 	edv_gid_struct **list, gint total,
 	gint group_id, gint *n
 );
