@@ -182,39 +182,6 @@ void EDVInterPSOPProcessCommand(
 		EDV_SET_S(parm, val);
 	    }
 	}
-	/* Open Object */
-	else if(!g_strcasecmp(op, "open_object"))
-	{
-	    if(argc >= 2)
-	    {
-		const gchar	*path = argv[1],
-				*command_name = (argc > 2) ? argv[2] : NULL;
-		gchar	*stdout_path_rtn = NULL,
-			*stderr_path_rtn = NULL;
-		GList *paths_list = NULL;
-
-		paths_list = g_list_append(
-		    paths_list,
-		    STRDUP(path)
-		);
-
-		EDVOpen(
-		    core_ptr,
-		    paths_list,			/* Paths List */
-		    command_name,		/* Command Name */
-		    NULL,			/* Toplevel */
-		    TRUE,			/* Verbose */
-		    &stdout_path_rtn,
-		    &stderr_path_rtn
-		);
-
-		g_list_foreach(paths_list, (GFunc)g_free, NULL);
-		g_list_free(paths_list);
-
-		g_free(stdout_path_rtn);
-		g_free(stderr_path_rtn);
-	    }
-	}
 	/* Write Protect Changed Notify */
 	else if(!g_strcasecmp(op, "write_protect_changed_notify"))
 	{
@@ -547,9 +514,8 @@ should regard this message as an internal programming error.\n",
 	strlistfree(argv, argc);
 }
 
-
 /*
- *      Processes the given InterPS commands.
+ *	Processes the specified InterPS commands.
  */
 void EDVInterPSOPProcessCommands(
 	edv_core_struct *core_ptr,
