@@ -162,6 +162,32 @@ void EDVDMimeTypesListLoadFromSystem(
  }						\
 }
 
+	icon_file_s[EDV_MIMETYPE_ICON_STATE_STANDARD] =
+	    "icon_object_misc_20x20.xpm";
+	icon_file_s[EDV_MIMETYPE_ICON_STATE_SELECTED] =
+	    "icon_object_misc_20x20.xpm";
+	icon_file_s[EDV_MIMETYPE_ICON_STATE_EXTENDED] = NULL;
+	icon_file_s[EDV_MIMETYPE_ICON_STATE_HIDDEN] =
+	    "icon_object_misc_20x20.xpm";
+	icon_file_m[EDV_MIMETYPE_ICON_STATE_STANDARD] =
+	    "icon_object_misc_32x32.xpm";
+	icon_file_m[EDV_MIMETYPE_ICON_STATE_SELECTED] =
+	    "icon_object_misc_32x32.xpm";
+	icon_file_m[EDV_MIMETYPE_ICON_STATE_EXTENDED] = NULL;
+	icon_file_m[EDV_MIMETYPE_ICON_STATE_HIDDEN] =
+	    "icon_object_misc_32x32.xpm";
+	icon_file_l[EDV_MIMETYPE_ICON_STATE_STANDARD] =
+	    "icon_object_misc_48x48.xpm";
+	icon_file_l[EDV_MIMETYPE_ICON_STATE_SELECTED] =
+	    "icon_object_misc_48x48.xpm";
+	icon_file_l[EDV_MIMETYPE_ICON_STATE_EXTENDED] = NULL;
+	icon_file_l[EDV_MIMETYPE_ICON_STATE_HIDDEN] =
+	    "icon_object_misc_48x48.xpm";
+	APPEND_MIMETYPE(
+	    NULL, EDV_MIMETYPE_STR_UNKNOWN, NULL,
+	    icon_file_s, icon_file_m, icon_file_l
+	);
+
 	icon_file_s[EDV_MIMETYPE_ICON_STATE_STANDARD] =
 	    "icon_file_20x20.xpm";
 	icon_file_s[EDV_MIMETYPE_ICON_STATE_SELECTED] = NULL;
