@@ -1,9 +1,8 @@
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
 #include <time.h>
-
 #include <gtk/gtk.h>
+#include <unistd.h>
 
 #include "../include/prochandle.h"
 
@@ -24,15 +23,15 @@ static gboolean FILE_EXISTS_NON_ZERO(const gchar *path);
 const gchar *EDVMountGetError(void);
 
 gint EDVMountDoMount(
-	edv_core_struct *core_ptr, edv_device_struct *dev_ptr,
+	edv_core_struct *core_ptr, edv_device_struct *dev,
 	GtkWidget *toplevel
 );
 gint EDVMountDoUnmount(
-	edv_core_struct *core_ptr, edv_device_struct *dev_ptr,
+	edv_core_struct *core_ptr, edv_device_struct *dev,
 	GtkWidget *toplevel
 );
 gint EDVMountDoEject(
-	edv_core_struct *core_ptr, edv_device_struct *dev_ptr,
+	edv_core_struct *core_ptr, edv_device_struct *dev,
 	GtkWidget *toplevel
 );
 
@@ -83,7 +82,7 @@ const gchar *EDVMountGetError(void)
  *	Any warnings and errors that occure will be printed.
  */
 gint EDVMountDoMount(
-	edv_core_struct *core_ptr, edv_device_struct *dev_ptr,
+	edv_core_struct *core_ptr, edv_device_struct *dev,
 	GtkWidget *toplevel
 )
 {
@@ -98,7 +97,7 @@ gint EDVMountDoMount(
 	/* Reset last error string */
 	last_error = NULL;
 
-	if(dev_ptr == NULL)
+	if(dev == NULL)
 	{
 	    last_error = "Bad input value";
 	    return(-1);
@@ -120,7 +119,7 @@ gint EDVMountDoMount(
 }
 
 	/* Get copy of mount path */
-	mount_path = STRDUP(dev_ptr->mount_path);
+	mount_path = STRDUP(dev->mount_path);
 	if(mount_path == NULL)
 	{
 	    DO_FREE_LOCALS
@@ -129,7 +128,7 @@ gint EDVMountDoMount(
 	}
 
 	/* Get copy of device path */
-	device_path = STRDUP(dev_ptr->device_path);
+	device_path = STRDUP(dev->device_path);
 	if(device_path == NULL)
 	{
 	    DO_FREE_LOCALS
@@ -138,7 +137,7 @@ gint EDVMountDoMount(
 	}
 
 	/* Get file system type as a string */
-	fs_type_str = EDVDeviceGetFSStringFromNumber(dev_ptr->fs_type);
+	fs_type_str = EDVDeviceGetFSNameFromType(dev->fs_type);
 	if(fs_type_str == NULL)
 	{
 	    DO_FREE_LOCALS
@@ -147,14 +146,14 @@ gint EDVMountDoMount(
 	}
 
 	/* Create mount command string */
-	if(!STRISEMPTY(dev_ptr->command_mount))
-	    cmd = STRDUP(dev_ptr->command_mount);
+	if(!STRISEMPTY(dev->command_mount))
+	    cmd = STRDUP(dev->command_mount);
 	else
 #if 1
 	    cmd = g_strdup_printf(
 		"/bin/mount \"%s\" %s",
 		mount_path,
-		dev_ptr->read_only ? "-r" : ""
+		EDV_DEVICE_IS_READ_ONLY(dev) ? "-r" : ""
 	    );
 #else
 /* Does not work for non-root users */
@@ -163,7 +162,7 @@ gint EDVMountDoMount(
 		fs_type_str,
 		device_path,
 		mount_path,
-		dev_ptr->read_only ? "-r" : ""
+		EDV_DEVICE_IS_READ_ONLY(dev) ? "-r" : ""
 	    );
 #endif
 
@@ -187,7 +186,7 @@ gint EDVMountDoMount(
 	}
 	else
 	{
-	    dev_ptr->last_mount_time = (gulong)time(NULL);
+	    dev->last_mount_time = (gulong)time(NULL);
 	    status = 0;
 	}
 
@@ -233,7 +232,7 @@ gint EDVMountDoMount(
  *	Any warnings and errors that occure will be printed.
  */
 gint EDVMountDoUnmount(
-	edv_core_struct *core_ptr, edv_device_struct *dev_ptr,
+	edv_core_struct *core_ptr, edv_device_struct *dev,
 	GtkWidget *toplevel
 )
 {
@@ -246,14 +245,14 @@ gint EDVMountDoUnmount(
 	/* Reset last error string */
 	last_error = NULL;
 
-	if(dev_ptr == NULL)
+	if(dev == NULL)
 	{
 	    last_error = "Bad input value";
 	    return(-1);
 	}
 
 	/* Device not allowed to be unmounted? */
-	if(dev_ptr->no_unmount)
+	if(EDV_DEVICE_IS_NO_UNMOUNT(dev))
 	{
 	    last_error = "Device is marked \"no unmount\"";
 	    return(-1);
@@ -272,7 +271,7 @@ gint EDVMountDoUnmount(
 }
 
 	/* Get copy of mount path */
-	mount_path = STRDUP(dev_ptr->mount_path);
+	mount_path = STRDUP(dev->mount_path);
 	if(mount_path == NULL)
 	{
 	    DO_FREE_LOCALS
@@ -285,8 +284,8 @@ gint EDVMountDoUnmount(
 	stderr_path = EDVTmpName(NULL);
 
 	/* Create unmount command string */
-	if(!STRISEMPTY(dev_ptr->command_unmount))
-	    cmd = STRDUP(dev_ptr->command_unmount);
+	if(!STRISEMPTY(dev->command_unmount))
+	    cmd = STRDUP(dev->command_unmount);
 	else
 	    cmd = g_strdup_printf(
 		"/bin/umount \"%s\"",
@@ -356,7 +355,7 @@ gint EDVMountDoUnmount(
  *	first.
  */
 gint EDVMountDoEject(
-	edv_core_struct *core_ptr, edv_device_struct *dev_ptr,
+	edv_core_struct *core_ptr, edv_device_struct *dev,
 	GtkWidget *toplevel
 )
 {
@@ -369,14 +368,14 @@ gint EDVMountDoEject(
 	/* Reset last error string */
 	last_error = NULL;
 
-	if(dev_ptr == NULL)
+	if(dev == NULL)
 	{
 	    last_error = "Bad input value";
 	    return(-1);
 	}
 
 	/* Media not allowed to be ejected from device? */
-	if(dev_ptr->no_unmount)
+	if(EDV_DEVICE_IS_NO_UNMOUNT(dev))
 	{
 	    last_error = "Unable to eject media, device is marked \"no unmount\"";
 	    return(-1);
@@ -395,7 +394,7 @@ gint EDVMountDoEject(
 }
 
 	/* Get copy of device path */
-	device_path = STRDUP(dev_ptr->device_path);
+	device_path = STRDUP(dev->device_path);
 	if(device_path == NULL)
 	{
 	    DO_FREE_LOCALS
@@ -408,8 +407,8 @@ gint EDVMountDoEject(
 	stderr_path = EDVTmpName(NULL);
 
 	/* Create eject command string */
-	if(!STRISEMPTY(dev_ptr->command_eject))
-	    cmd = STRDUP(dev_ptr->command_eject);
+	if(!STRISEMPTY(dev->command_eject))
+	    cmd = STRDUP(dev->command_eject);
 	else
 	    cmd = g_strdup_printf(
 		"/usr/bin/eject \"%s\"",
