@@ -59,8 +59,8 @@
 /* New/Map Window Nexus */
 gint EDVNewWindowNexus(
 	edv_core_struct *core_ptr,
-	const gchar *name,              /* Name of window */
-	const gchar *path,              /* Initial object path */
+	const gchar *name,		/* Name of window */
+	const gchar *path,		/* Initial object path */
 	const gchar *extra,
 	GtkWidget *toplevel
 );
@@ -98,7 +98,9 @@ void EDVRunDeviceFormat(
 );
 
 void EDVRunTerminal(
-	edv_core_struct *core_ptr, const gchar *cmd,
+	edv_core_struct *core_ptr,
+	const gchar *cmd,
+	const gchar *wd,
 	GtkWidget *toplevel
 );
 
@@ -210,16 +212,16 @@ void EDVRecycleBinSizeCheck(
 );
 
 
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
@@ -447,9 +449,18 @@ gint EDVNewBrowser(edv_core_struct *core_ptr)
 	{
 	    gchar *startup_dir = EDVEvaluatePath(
 		NULL, EDV_GET_S(EDV_CFG_PARM_DIR_START_UP)
-            );
+	    );
 	    GtkWidget *toplevel = browser->toplevel;
-	    GtkCList *clist;
+
+	    /* If the startup directory is not a directory then replace
+	     * it with its parent
+	     */
+	    if(!ISPATHDIR(startup_dir))
+	    {
+		gchar *s = g_dirname(startup_dir);
+		g_free(startup_dir);
+		startup_dir = s;
+	    }
 
 	    EDVBrowserSetBusy(browser, TRUE);
 	    GUIBlockInput(toplevel, TRUE);
@@ -459,23 +470,21 @@ gint EDVNewBrowser(edv_core_struct *core_ptr)
 	     */
 	    EDVBrowserMap(browser);
 
-	    /* Get directory tree and create initial toplevel nodes */
-	    clist = GTK_CLIST(browser->directory_ctree);
-	    if(clist != NULL)
+	    /* Set directory tree origin as needed */
+	    if(!EDVBrowserIsPathFromDirTreeOrigin(browser, startup_dir))
 	    {
-		/* Set directory tree origin as needed */
-		if(!EDVBrowserIsPathFromDirTreeOrigin(browser, startup_dir))
-		{
-		    EDVBrowserDirTreeSetOriginPath(browser, startup_dir);
-		}
-		else
-		{
-		    /* Create toplevels */
-		    EDVBrowserDirTreeCreateToplevels(browser);
+		/* Set directory tree origin, create the toplevels,
+		 * and select the startup directory
+		 */
+		EDVBrowserDirTreeSetOriginPath(browser, startup_dir);
+	    }
+	    else
+	    {
+		/* Create the toplevels */
+		EDVBrowserDirTreeCreateToplevels(browser);
 
-		    /* Select startup directory */
-		    EDVBrowserDirTreeSelectPath(browser, startup_dir);
-		}
+		/* Select startup directory */
+		EDVBrowserDirTreeSelectPath(browser, startup_dir);
 	    }
 
 	    g_free(startup_dir);
@@ -568,9 +577,19 @@ gint EDVNewImbr(edv_core_struct *core_ptr)
 	{
 	    gchar *startup_dir = EDVEvaluatePath(
 		NULL, EDV_GET_S(EDV_CFG_PARM_DIR_START_UP)
-            );
+	    );
 	    GtkWidget *toplevel = imbr->toplevel;
 
+	    /* If the startup directory is not a directory then replace
+	     * it with its parent
+	     */
+	    if(!ISPATHDIR(startup_dir))
+	    {
+		gchar *s = g_dirname(startup_dir);
+		g_free(startup_dir);
+		startup_dir = s;
+	    }
+
 	    EDVImbrSetBusy(imbr, TRUE);
 	    GUIBlockInput(toplevel, TRUE);
 
@@ -579,15 +598,15 @@ gint EDVNewImbr(edv_core_struct *core_ptr)
 	     */
 	    EDVImbrMap(imbr);
 
-	    /* Switch to startup directory */
+	    /* Get initial listing of the startup directory */
 	    EDVImbrSelectPath(imbr, startup_dir);
 
 	    EDVImbrUpdateMenus(imbr);
 
 	    g_free(startup_dir);
 
-            GUIBlockInput(toplevel, FALSE);
-            EDVImbrSetBusy(imbr, FALSE);
+	    GUIBlockInput(toplevel, FALSE);
+	    EDVImbrSetBusy(imbr, FALSE);
 
 	    return(i);
 	}
@@ -1087,16 +1106,22 @@ Appareil->Appareils... et dite la rfrence d'appareil.",
 }
 
 /*
- *	Runs the terminal defined on the configuration list on the
- *	given core structure. If cmd is not NULL, then the command
- *	specified by cmd will be appended to the terminal run command
- *	defined on the core structure.
+ *	Runs the terminal defined in the configuration list.
+ *
+ *	If cmd is not NULL then the command specified by cmd will be
+ *	appended to the terminal run command.
+ *
+ *	The wd specifies the working directory for the terminal. If this
+ *	is NULL then the current working directory will be used.
  */
 void EDVRunTerminal(
-	edv_core_struct *core_ptr, const gchar *cmd,
+	edv_core_struct *core_ptr,
+	const gchar *cmd,
+	const gchar *wd,
 	GtkWidget *toplevel
 )
 {
+	gchar *cwd;
 	const cfg_item_struct *cfg_list;
 
 	if(core_ptr == NULL)
@@ -1104,14 +1129,24 @@ void EDVRunTerminal(
 
 	cfg_list = core_ptr->cfg_list;
 
+	if(!STRISEMPTY(wd))
+	{
+	    cwd = STRDUP(g_get_current_dir());
+	    chdir(wd);
+	}
+	else
+	{
+	    cwd = NULL;
+	}
+
 	if(!STRISEMPTY(cmd))
 	{
 	    /* Get terminal command for running a program with a
-	     * terminal, format the command, then run the command
+	     * terminal, format the command, and then run the command
 	     */
-	    const gchar *cmd_src = EDV_GET_S(
+	    gchar *cmd_src = STRDUP(EDV_GET_S(
 		EDV_CFG_PARM_PROG_TERMINAL_RUN
-	    );
+	    ));
 	    if(!STRISEMPTY(cmd_src))
 	    {
 		gchar *cmd_tar = g_strdup_printf(
@@ -1122,16 +1157,25 @@ void EDVRunTerminal(
 		Exec(cmd_tar);
 		g_free(cmd_tar);
 	    }
+	    g_free(cmd_src);
 	}
 	else
 	{
-	    /* No command given, just run terminal */
-	    const gchar *cmd_src = EDV_GET_S(
+	    /* No command specified, just run the terminal */
+	    gchar *cmd_src = STRDUP(EDV_GET_S(
 		EDV_CFG_PARM_PROG_TERMINAL
-	    );
+	    ));
 	    if(!STRISEMPTY(cmd_src))
 		Exec(cmd_src);
+	    g_free(cmd_src);
 	}
+
+	if(cwd != NULL)
+	{
+	    chdir(cwd);
+	}
+
+	g_free(cwd);
 }
 
 
@@ -1186,7 +1230,7 @@ void EDVMapRecBin(edv_core_struct *core_ptr)
 	if(clist != NULL)
 	{
 	    gtk_clist_freeze(clist);
-	    EDVRecBinContentsDoUpdate(
+	    EDVRecBinContentsGetListing(
 		recbin,
 		EDV_GET_B(EDV_CFG_PARM_LISTS_ANIMATE_UPDATES)
 	    );
@@ -1905,7 +1949,7 @@ void EDVUpdateRCStyles(edv_core_struct *core_ptr)
 	    else
 	    {
 		GTK_RC_STYLE_UNREF(rcstyle)
-		core_ptr->lists_rcstyle = NULL;  
+		core_ptr->lists_rcstyle = NULL;
 	    }
 
 #undef SET_RCSTYLE
@@ -1979,10 +2023,10 @@ void EDVUpdateIDPULists(edv_core_struct *core_ptr)
 
 	/* Add Groups to the Popup List */
 	for(i = 0; i < core_ptr->total_gids; i++)
-	{                                        
+	{
 	    gid = core_ptr->gid[i];
 	    if((gid != NULL) ? STRISEMPTY(gid->name) : TRUE)
-		continue;   
+		continue;
 
 	    n = PUListAddItem(pulist, gid->name);
 	    if(n < 0)
@@ -2045,7 +2089,7 @@ void EDVUpdateDevicesPUList(edv_core_struct *core_ptr)
 	    /* Get device name */
 	    dev_name = dev->name;
 	    if((dev_name == NULL) && (dev->device_path != NULL))
-		dev_name = EDVGetPathName(dev->device_path);
+		dev_name = g_basename(dev->device_path);
 	    if(dev_name == NULL)
 		dev_name = "(null)";
 
@@ -2212,7 +2256,7 @@ void EDVRefresh(edv_core_struct *core_ptr)
 
 	/* Refresh File Browsers */
 	for(i = 0; i < core_ptr->total_browsers; i++)
-	{                                            
+	{
 	    browser = core_ptr->browser[i];
 	    if(browser == NULL)
 		continue;
@@ -2222,7 +2266,7 @@ void EDVRefresh(edv_core_struct *core_ptr)
 
 	/* Refresh Image Browsers */
 	for(i = 0; i < core_ptr->total_imbrs; i++)
-	{                                         
+	{
 	    imbr = core_ptr->imbr[i];
 	    if(imbr == NULL)
 		continue;
@@ -2234,7 +2278,7 @@ void EDVRefresh(edv_core_struct *core_ptr)
 	for(i = 0; i < core_ptr->total_archivers; i++)
 	{
 	    archiver = core_ptr->archiver[i];
-	    if(archiver == NULL)  
+	    if(archiver == NULL)
 		continue;
 
 	    EDVArchiverOPRefresh(archiver);
@@ -2366,7 +2410,7 @@ void EDVReset(edv_core_struct *core_ptr)
 	EDVMimeTypeListLoadFromFile(
 	    EDV_GET_S(EDV_CFG_PARM_FILE_MIME_TYPES),
 	    &core_ptr->mimetype, &core_ptr->total_mimetypes,
-	    -1,			/* Append */     
+	    -1,			/* Append */
 	    FALSE, FALSE,
 	    NULL, core_ptr,
 	    NULL, core_ptr,
@@ -2375,7 +2419,7 @@ void EDVReset(edv_core_struct *core_ptr)
 	EDVMimeTypeListLoadFromFile(
 	    EDV_GET_S(EDV_CFG_PARM_FILE_MIME_TYPES_GLOBAL),
 	    &core_ptr->mimetype, &core_ptr->total_mimetypes,
-	    -1,			/* Append */     
+	    -1,			/* Append */
 	    FALSE, FALSE,
 	    NULL, core_ptr,
 	    NULL, core_ptr,
