@@ -4,8 +4,6 @@
 #include <gtk/gtk.h>
 #include <unistd.h>
 
-#include "../include/string.h"
-
 #include "edvtypes.h"
 #include "edvmimetypes.h"
 #include "endeavour.h"
@@ -87,12 +85,11 @@ static gboolean EDVOpenIsFileExecutable(const gchar *path)
 }
 
 /*
- *	Substitutes the "%s" in the specified command with the specified
- *	path. Quotes '"' will be added as needed and '&' will be
- *	appended.
+ *	Performs substitutions to the command string specified by cmd 
+ *	with the values specified in the core and the paths list.
  *
- *	Returns a dynamically allocated string describing the formatted
- *	command, the calling function must delete ther returned string.
+ *	Returns a dynamically allocated string describing the command
+ *	with all the substitutions made.
  */
 static gchar *EDVOpenFormatCommand(
 	edv_core_struct *core_ptr, const gchar *cmd, GList *paths_list
@@ -136,7 +133,7 @@ static gchar *EDVOpenFormatCommand(
 
 	    s = g_strconcat(
 		names_quoted,
-		EDVGetPathName(path),
+		g_basename(path),
 		(glist->next != NULL) ? " " : "\"",
 		NULL
 	    );
@@ -167,7 +164,7 @@ static gchar *EDVOpenFormatCommand(
 	first_path = (glist != NULL) ? (gchar *)glist->data : NULL;   
 	if(first_path == NULL)                                        
 	    first_path = "";
-	first_name_quoted = g_strdup_printf("\"%s\"", EDVGetPathName(first_path));
+	first_name_quoted = g_strdup_printf("\"%s\"", g_basename(first_path));
 	first_path_quoted = g_strdup_printf("\"%s\"", first_path);
 
 	/* Last selected object name and path */
@@ -175,7 +172,7 @@ static gchar *EDVOpenFormatCommand(
 	last_path = (glist != NULL) ? (gchar *)glist->data : NULL;
 	if(last_path == NULL)
 	    last_path = "";
-	last_name_quoted = g_strdup_printf("\"%s\"", EDVGetPathName(last_path));
+	last_name_quoted = g_strdup_printf("\"%s\"", g_basename(last_path));
 	last_path_quoted = g_strdup_printf("\"%s\"", last_path);
 
 	/* Process ID */
@@ -189,7 +186,7 @@ static gchar *EDVOpenFormatCommand(
 	cmd_rtn = STRDUP(cmd);
 
 #define CMDSUB(_token_,_val_)	{			\
- gchar *s = strsub(cmd_rtn, (_token_), (_val_));	\
+ gchar *s = EDVStrSub(cmd_rtn, (_token_), (_val_));	\
  g_free(cmd_rtn);					\
  cmd_rtn = s;						\
 }
@@ -277,9 +274,8 @@ static gchar *EDVOpenFormatCommand(
  *
  *	0	Success.
  *	-1	General error.
- *	-2	Bad value, no MIME Type, or no application.
+ *	-2	Bad value or no MIME Type found.
  *	-3	System error.
- *	-6	Call is a re-enterent to an existing call to this function.
  */
 static gint EDVOpenIteration(
 	edv_core_struct *core_ptr, const gchar *path,
@@ -291,14 +287,14 @@ static gint EDVOpenIteration(
 	gboolean got_match;
 	gint i, status;
 	const gchar *name, *command_base;
-	const cfg_item_struct *cfg_list = core_ptr->cfg_list;
+	cfg_item_struct *cfg_list = core_ptr->cfg_list;
 	edv_mimetype_struct *mt;
 
 	if(STRISEMPTY(path))
 	    return(-2);
 
 	/* Get the object's name */
-	name = EDVGetPathName(path);
+	name = g_basename(path);
 
 	/* Iterate through MIME Types list and look for a MIME Type
 	 * appropriate for the specified object
@@ -340,7 +336,7 @@ static gint EDVOpenIteration(
 	/* Unable to find a MIME Type appropriate for this object? */
 	if(!got_match || (mt == NULL))
 	{
-	    const char *def_viewer_cmd = EDV_GET_S(EDV_CFG_PARM_PROG_DEF_VIEWER);
+	    const gchar *def_viewer_cmd = EDV_GET_S(EDV_CFG_PARM_PROG_DEF_VIEWER);
 
 	    /* If this object is a file and is set executable, then
 	     * attempt to run it
@@ -652,12 +648,13 @@ Help->MIME Types...",
 	    break;
 
 	  case EDV_MIMETYPE_HANDLER_EDV_IMAGE_BROWSER:
-/* TODO */
+	    EDV_SET_S(EDV_CFG_PARM_DIR_START_UP, path);
+	    EDVNewImbr(core_ptr);
 	    return(0);
 	    break;
 
 	  case EDV_MIMETYPE_HANDLER_EDV_RECYCLE_BIN:
-/* TODO */
+	    EDVMapRecBin(core_ptr);
 	    return(0);
 	    break;
 
