@@ -8,21 +8,21 @@
 #ifndef EDVOPEN_H
 #define EDVOPEN_H
 
-#include <glib.h>
-#include "edvtypes.h"
-#include "edvmimetypes.h"
+#include <gtk/gtk.h>
 #include "endeavour.h"
 
 
-extern gint EDVOpenObjectPath(
-	edv_core_struct *core_ptr, const gchar *path,
+extern gint EDVOpen(
+	edv_core_struct *core_ptr,
+	GList *paths_list,
 	const gchar *command_name,
 	GtkWidget *toplevel, gboolean verbose,
 	gchar **stdout_path_rtn, gchar **stderr_path_rtn
 );
 
-extern gint EDVOpenWithObjectPath(
-	edv_core_struct *core_ptr, const gchar *path,
+extern gint EDVOpenWith(
+	edv_core_struct *core_ptr,
+	GList *paths_list,
 	const gchar *command_name,
 	GtkWidget *toplevel, gboolean verbose,
 	gchar **stdout_path_rtn, gchar **stderr_path_rtn
