@@ -2142,9 +2142,9 @@ gint EDVRecBinDiskObjectRecover(
 		}
 	    }
 
-	    restore_permissions = FALSE;	/* Do not restore permissions for link */
+	    /* Do not restore permissions for links */
 	    restore_ownership = TRUE;
-	    restore_time = FALSE;
+	    /* Do not restore time for links */
 	}
 	/* FIFO pipe? */
 	else if(obj->type == EDV_OBJECT_TYPE_FIFO)
@@ -2270,6 +2270,7 @@ gint EDVRecBinDiskObjectRecover(
 
 	    restore_permissions = TRUE;
 	    restore_ownership = TRUE;
+	    restore_time = TRUE;
 	}
 	/* Character device? */
 	else if(obj->type == EDV_OBJECT_TYPE_DEVICE_CHARACTER)
@@ -2347,6 +2348,7 @@ gint EDVRecBinDiskObjectRecover(
 
 	    restore_permissions = TRUE;
 	    restore_ownership = TRUE;
+	    restore_time = TRUE;
 	}
 	/* Socket? */
 	else if(obj->type == EDV_OBJECT_TYPE_SOCKET)
@@ -2398,6 +2400,7 @@ gint EDVRecBinDiskObjectRecover(
 
 	    restore_permissions = TRUE;
 	    restore_ownership = TRUE;
+	    restore_time = TRUE;
 	}
 	/* Unsupported type? */
 	else
@@ -2423,7 +2426,6 @@ gint EDVRecBinDiskObjectRecover(
 	if(restore_permissions)
 	{
 	    mode_t m = 0;
-
 	    if(obj->permissions & EDV_PERMISSION_UEXECUTE)
 		m |= S_IXUSR;
 	    if(obj->permissions & EDV_PERMISSION_UREAD)
@@ -2448,7 +2450,6 @@ gint EDVRecBinDiskObjectRecover(
 		m |= S_ISGID;
 	    if(obj->permissions & EDV_PERMISSION_STICKY)
 		m |= S_ISVTX;
-
 	    chmod((const char *)out_path, m);
 	}
 
@@ -2456,14 +2457,13 @@ gint EDVRecBinDiskObjectRecover(
 	if(restore_time)
 	{
 	    struct utimbuf utime_buf;
-
 	    utime_buf.actime = (time_t)obj->access_time;
 	    utime_buf.modtime = (time_t)obj->modify_time;
-
 	    utime(out_path, &utime_buf);
 	}
 
 	DO_FREE_LOCALS
+
 	return(status);
 #undef DO_FREE_LOCALS
 }
