@@ -370,7 +370,7 @@ Are you sure you want to delete this object?"
 	 */
 
 	/* Special notations? */
-	s = EDVGetPathName(path);
+	s = g_basename(path);
 	if(!STRISEMPTY(s))
 	{
 	    /* Current or parent directory? */
@@ -1556,14 +1556,14 @@ static guint EDVRecBinFOPDeleteIterate(
 	    gulong cur_time = time(NULL);
 	    mode_t m = lstat_buf.st_mode;
 
-	    /* Create a new tempory recycled object structure */
+	    /* Create a new tempory recycled object */
 	    edv_recbin_object_struct *obj = EDVRecBinObjectNew();
 	    if(obj == NULL)
 		return(0);
 
-	    /* Set values from object to new recycled object structure */
+	    /* Set values from the object to new recycled object */
 	    g_free(obj->name);
-	    obj->name = STRDUP(EDVGetPathName(path));
+	    obj->name = STRDUP(g_basename(path));
 
 	    parent_path = g_dirname(path);
 	    if(parent_path == NULL)
