@@ -466,7 +466,7 @@ static void EDVRecBinSyncObjects(
 	gint i, strc;
 	gchar **strv;
 	const gchar	*obj_name,
-			*idx_file_name = EDVGetPathName(recbin_idx_file);
+			*idx_file_name = g_basename(recbin_idx_file);
 	GList *idx_list = NULL;
 	edv_recbin_index_struct *rbi_ptr = EDVRecBinIndexOpen(
 	    recbin_idx_file
@@ -1174,7 +1174,7 @@ gint EDVRecBinSync(
 	gchar *recbin_dir = NULL;
 	gulong time_start = (gulong)time(NULL);
 	struct stat stat_buf;
-
+	const cfg_item_struct *cfg_list;
 
 	if(reenterent)
 	{
@@ -1226,10 +1226,10 @@ gint EDVRecBinSync(
 	    POSTOP_AND_RETURN(status);
 	}
 
+	cfg_list = core_ptr->cfg_list;
+
 	/* Get path to the recycle bin index file */
-	recbin_idx_file = CFGItemListGetValueS(
-	    core_ptr->cfg_list, EDV_CFG_PARM_FILE_RECYCLED_INDEX
-	);
+	recbin_idx_file = EDV_GET_S(EDV_CFG_PARM_FILE_RECYCLED_INDEX);
 	if(STRISEMPTY(recbin_idx_file))
 	{
 	    MESSAGE_ERROR(
@@ -1256,9 +1256,9 @@ gint EDVRecBinSync(
 	/* Begin checking for errors */
 
 	/* Create recycled bin directory as needed */
-	if(stat(recbin_dir, &stat_buf))
+	if(stat((char *)recbin_dir, &stat_buf))
 	{
-	    if(rmkdir(recbin_dir, S_IRUSR | S_IWUSR | S_IXUSR))
+	    if(rmkdir((char *)recbin_dir, S_IRUSR | S_IWUSR | S_IXUSR))
 	    {
 		gchar *buf = g_strdup_printf(
 "Unable to create recycle bin directory:\n\
@@ -1310,7 +1310,7 @@ buf
 	}
 
 	/* Update permissions on recycle bin directory */
-	if(chmod(recbin_dir, S_IRUSR | S_IWUSR | S_IXUSR))
+	if(chmod((char *)recbin_dir, S_IRUSR | S_IWUSR | S_IXUSR))
 	{
 	    gchar *buf = g_strdup_printf(
 "Unable to set permissions on recycle bin directory:\n\
@@ -1383,10 +1383,10 @@ buf
 
 
 	/* Recycled objects index file exists? */
-	if(!access(recbin_idx_file, F_OK) && (status != -4))
+	if(!access((const char *)recbin_idx_file, F_OK) && (status != -4))
 	{
 	    /* Update permissions on the recycled objects index file */
-	    if(chmod(recbin_idx_file, S_IRUSR | S_IWUSR))
+	    if(chmod((const char *)recbin_idx_file, S_IRUSR | S_IWUSR))
 	    {
 		gchar *buf = g_strdup_printf(
 "Unable to set permissions on the index file:\n\
