@@ -1,8 +1,8 @@
 /*
                        Endeavour Recycle Bin Sync
 
-	Compacts objects and fixes errors in the recycle bin.
-
+	Compacts the recycled objects and fixes errors in the Recycle
+	Bin.
  */
 
 #ifndef EDVRECBINSYNC_H
@@ -21,16 +21,14 @@ extern gint EDVRecBinSync(
 	gboolean show_progress, gboolean interactive,
 	gboolean *yes_to_all,
 	void (*status_message_cb)(
-		gpointer,		/* NULL */
 		const gchar *,		/* Message */
 		gpointer		/* Data */
 	),
 	void (*status_progress_cb)(
-		gpointer,		/* NULL */
-		gfloat,			/* Progress [0.0 to 1.0] */
+		gfloat,			/* Progress */
 		gpointer		/* Data */
 	),
-	gpointer client_data
+	gpointer data
 );
 
 
