@@ -27,20 +27,18 @@
 
 extern char **environ;
 
-
-gchar *EDVSizeStrDelim(gulong i);
-
-const gchar *EDVGetPathName(const gchar *path);
+const gchar *EDVSizeStrDelim(gulong i);
+gchar *EDVStrSub(
+        const gchar *fmt, const gchar *token, const gchar *val  
+);
 
 void EDVSimplifyPath(gchar *path);
-
 gboolean EDVIsParentPath(const gchar *parent, const gchar *child);
 static gboolean EDVIsExtensionIterate(
 	const gchar *name, gint name_len,
 	const gchar *ext, gint ext_len
 );
 gboolean EDVIsExtension(const gchar *name, const gchar *ext);
-
 gchar *EDVShortenPath(const gchar *path, gint max);
 gchar *EDVEvaluatePath(const gchar *parent, const gchar *path);
 gint EDVCHDir(const gchar *path);
@@ -97,7 +95,7 @@ static gchar *G_STRCAT(gchar *s, const gchar *s2)
  *	Similar to EDVGetObjectSizeStr() except that the string is
  *	always deliminated.
  */
-gchar *EDVSizeStrDelim(gulong i)
+const gchar *EDVSizeStrDelim(gulong i)
 {
 	gint comma_countdown, slen;
 	gchar ss[80], *ss_ptr;
@@ -143,34 +141,20 @@ gchar *EDVSizeStrDelim(gulong i)
 
 
 /*
- *	Returns a pointer within the given path that points to the
- *	object's name in the path.
- *
- *	Example "/dir/file.ext" returns "file.ext".
- *
- *	If there are no path deliminators in the given path then the
- *	pointer to path is returned.
+ *	Returns a dynamically allocated string with all occurances of
+ *	the string token replaced with the string val in the string fmt.
  */
-const gchar *EDVGetPathName(const gchar *path)
+gchar *EDVStrSub(
+        const gchar *fmt, const gchar *token, const gchar *val  
+)
 {
-	const gchar *name;
-
-	if(path == NULL)
-	    return(NULL);
-
-	name = strrchr(path, G_DIR_SEPARATOR);
-	if(name != NULL)
-	    name++;
-	else
-	    name = path;
-
-	return((*name != '\0') ? name : path);
+	return(strsub(fmt, token, val));
 }
 
 
 /*
- *	Simplifies the path by removing any tailing deliminator characters
- *	and reducing any occurances of "/.." in the given path.
+ *	Simplifies the path by removing any tailing path deliminators
+ *	reducing any occurances of "/..".
  */
 void EDVSimplifyPath(gchar *path)
 {
@@ -194,13 +178,9 @@ void EDVSimplifyPath(gchar *path)
 	    strcpy(path, "/");
 }
 
-
 /*
- *	Returns TRUE if the given parent path is a parent or grand
- *	parent of the given child path.
- *
- *	Will also return TRUE if parent path and child paths are
- *	identical.
+ *	Checks if the specified parent path is a parent or grand parent
+ *	of the specified child path.
  *
  *	Both paths must be absolute and simplified.
  */
@@ -305,13 +285,16 @@ static gboolean EDVIsExtensionIterate(
 }
 
 /*
- *	Checks if at least one of the specified list of space separated
- *	extensions matches the extension of the specified name
+ *	Checks if at least one of the specified list of space-separated
+ *	extensions matches the extension of the specified name.
+ *
+ *	Wild cards such as '*' and '?' are accepted in the
+ *	space-separated extensions list.
  *
  *	The following example will return TRUE.
  *
- *	name="myfile.doc"
- *	ext=".txt .doc .nfo *rc Makefile*"
+ *	name	= "myfile.doc"
+ *	ext	= ".txt .doc *rc Makefile*"
  */
 gboolean EDVIsExtension(const gchar *name, const gchar *ext)
 {
@@ -365,14 +348,12 @@ gboolean EDVIsExtension(const gchar *name, const gchar *ext)
 	return(FALSE);
 }
 
-
 /*
- *	Returns a path no longer than the specified max characters.
+ *	Returns a dynamically allocated copy of the path that is no
+ *	longer than the specified max characters.
  *
  *	If the specified path is longer than max then the shortened
  *	return string will contain a "..." prefix.
- *
- *	The calling function must delete the returned string.
  */
 gchar *EDVShortenPath(const gchar *path, gint max)
 {
@@ -398,7 +379,8 @@ gchar *EDVShortenPath(const gchar *path, gint max)
 }
 
 /*
- *	Returns an evaluated path based on the specified path.
+ *	Returns a dynamically allocated evaluated path based on the
+ *	specified path.
  *
  *	The parent path should be an absolute path indicating the parent
  *	or current path. The parent path is only used if the specified
@@ -413,8 +395,6 @@ gchar *EDVShortenPath(const gchar *path, gint max)
  *	Simplified, all occurances of ".." evaluated.
  *
  *	Tailing directory deliminators removed.
- *
- *	The calling function must delete the returned string.
  */
 gchar *EDVEvaluatePath(const gchar *parent, const gchar *path)
 {
@@ -493,27 +473,17 @@ gint EDVCHDir(const gchar *path)
 }
 
 /*
- *	Returns a string describing the current working directory.
- *
- *	The calling function must delete the returned string.
+ *	Returns a dynamically allocated string describing the current
+ *	working directory.
  */
 gchar *EDVGetCWD(void)
 {
-	gchar path[PATH_MAX];
-
-	if(getcwd(path, sizeof(path)) == NULL)
-	    return(NULL);
-
-	path[sizeof(path) - 1] = '\0';
-
-	return(STRDUP(path));
+	return(STRDUP(g_get_current_dir()));
 }
 
 /*
- *	Generates a string describing a unique file name in the
- *	directory specified by dir that is gauranteed to not exist.
- *
- *	The calling function must delete the returned string.
+ *	Returns a dynamically allocated string describing a unique file
+ *	name in the specified dir that is gauranteed to not exist.
  */
 gchar *EDVTmpName(const gchar *dir)
 {
@@ -544,13 +514,11 @@ gchar *EDVTmpName(const gchar *dir)
 	return(path);
 }
 
-
 /*
- *	Returns an absolute path of the program found from the PATH
- *	environment variable for the specified name or NULL if there is
- *	no match.
- *
- *	The calling function must delete the returned pointer.
+ *	Returns a dynamically allocated string path describing the
+ *	completed absolute path to the program found from the PATH
+ *	environment variable for the program specified name or NULL if
+ *	there is no match.
  */
 gchar *EDVWhich(const gchar *name)
 {
@@ -600,10 +568,9 @@ gchar *EDVWhich(const gchar *name)
 	return(matched_path);
 }
 
-
 /*
- *	Checks if the specified link's destination can possibly be
- *	infinately recursive.
+ *	Checks if the link specified by path has a destination that
+ *	may possibly be infinately recursive.
  */
 gboolean EDVIsLinkInfinatelyRecursive(const gchar *path)
 {
@@ -670,6 +637,7 @@ gboolean EDVIsLinkInfinatelyRecursive(const gchar *path)
 	return(status);
 }
 
+
 /*
  *	Returns the device major and minor numbers parsed from the
  *	specified (dev_t)rdev value (obtained from stat()).
@@ -683,8 +651,8 @@ void EDVGetDeviceNumbers(gint rdev, gint *major, gint *minor)
 }
 
 /*
- *	Returns the (dev_t)rdev value (obtained from stat()) parsed from
- *	the specified device major and minor numbers.
+ *	Returns the (dev_t)rdev value (obtained from stat()) parsed
+ *	from the specified device major and minor numbers.
  */
 gint EDVFormatDeviceNumbers(gint major, gint minor)
 {
@@ -695,7 +663,7 @@ gint EDVFormatDeviceNumbers(gint major, gint minor)
 
 
 /*
- *	Checks if the specified process is still running.
+ *	Checks if the process speecified by pid is still running.
  */
 gboolean EDVProcessIsRunning(gint pid)
 {
@@ -845,8 +813,8 @@ gint EDVSystemBlock(const gchar *cmd, gint *status)
 
 
 /*
- *	Loads the contents of the file specified by path and returns
- *	them as a list of allocated strings in a GList.
+ *	Opens the file specified by path and returns its contents as
+ *	a list of dynamically allocated strings in a GList.
  *
  *	If max_lines is positive then no more than max_lines will be
  *	read from the file.
@@ -854,8 +822,8 @@ gint EDVSystemBlock(const gchar *cmd, gint *status)
 GList *EDVOpenFileGList(const gchar *path, gint max_lines)
 {
 	gint lines_read;
-	GList *glist;
 	gchar *s;
+	GList *glist;
 
 	/* Open file for reading */
 	FILE *fp = FOpen((const char *)path, "rb");
@@ -891,7 +859,8 @@ GList *EDVOpenFileGList(const gchar *path, gint max_lines)
 }
 
 /*
- *	Writes each string in the GList to the file specified by path.
+ *	Writes each string in the specified GList to the file
+ *	specified by path.
  */
 void EDVSaveFileGList(const gchar *path, const GList *glist)
 {
