@@ -37,8 +37,8 @@ gint EDVMatchAccelKeyOPID(
 	guint accel_key, guint accel_mods
 );
 cfg_accelkey_struct *EDVMatchAccelKey(
-        const cfg_item_struct *cfg_list, const gchar *parm,
-        gint opid 
+	const cfg_item_struct *cfg_list, const gchar *parm,
+	gint opid 
 );
 
 /* String Formatting */
@@ -187,6 +187,13 @@ void EDVPlaySoundWarning(edv_core_struct *core_ptr);
 void EDVPlaySoundError(edv_core_struct *core_ptr);
 void EDVPlaySoundCompleted(edv_core_struct *core_ptr);
 
+/* Menu & Button Interaction */
+static void EDVMenuButtonMenuHideCB(GtkWidget *widget, gpointer data);
+static void EDVMenuButtonMenuPositionCB(
+	GtkMenu *menu, gint *x, gint *y, gpointer data
+);
+void EDVMenuButtonMapMenu(GtkWidget *menu, GtkWidget *button);
+
 /* Window Centering */
 void EDVCenterWindowToWindow(GtkWidget *w1, GtkWidget *w2);
 void EDVCenterWindowToWindowOffset(
@@ -247,6 +254,8 @@ void EDVAppendHistory(
 #define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
 #define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
 
+#define EDV_MENU_BUTTON_MAP_DATA_KEY	\
+	"edv_menu_button_map_data"
 
 #define EDV_SCROLLED_WINDOW_DATA_TRANSLATE_CURSOR_KEY	\
 	"edv_scrolled_window_translate_cursor"
@@ -285,8 +294,19 @@ gint EDVMatchAccelKeyOPID(
 	if((cfg_list == NULL) || STRISEMPTY(parm))
 	    return(0);
 
+	/* Make sure that the specified accel key is upper case for
+	 * easy case insensitive matching
+	 */
 	accel_key = gdk_keyval_to_upper(accel_key);
 
+	/* Make sure that the specified modifier keys only contain
+	 * alt, ctrl, or shift
+	 */
+	accel_mods = (accel_mods & (GDK_SHIFT_MASK |
+				    GDK_CONTROL_MASK |
+				    GDK_MOD1_MASK)
+		     );
+
 	ak_list = CFGItemListGetValueAccelkeyList(
 	    cfg_list, parm
 	);
@@ -317,8 +337,8 @@ gint EDVMatchAccelKeyOPID(
  *	ID in the Cfg Item specified by parm.
  */
 cfg_accelkey_struct *EDVMatchAccelKey(
-        const cfg_item_struct *cfg_list, const gchar *parm,
-        gint opid 
+	const cfg_item_struct *cfg_list, const gchar *parm,
+	gint opid 
 )
 {
 	cfg_accelkey_list_struct *ak_list;
@@ -1618,10 +1638,14 @@ gint EDVMatchObjectIcon(
 	/* Check MIME Types */
 	if((mimetype != NULL) && !got_match)
 	{
-	    const gchar	*value,
-			*name = EDVGetPathName(path);
+	    const gchar	*value, *name;
 	    edv_mimetype_struct *m;
 
+	    if((path != NULL) ? g_path_is_absolute(path) : FALSE)
+		name = g_basename(path);
+	    else
+		name = path;
+
 	    /* Iterate through MIME Types list */
 	    for(i = 0; i < total_mimetypes; i++)
 	    {
@@ -1679,6 +1703,7 @@ gint EDVMatchObjectIcon(
 	    switch(type)
 	    {
 	      case EDV_OBJECT_TYPE_UNKNOWN:
+		mime_type_str = EDV_MIMETYPE_STR_UNKNOWN;
 		break;
 
 	      case EDV_OBJECT_TYPE_FILE:
@@ -1800,7 +1825,10 @@ gint EDVMatchObjectTypeString(
 	if(type_str != NULL)
 	    *type_str = NULL;
 
-	name = EDVGetPathName(path);
+	if((path != NULL) ? g_path_is_absolute(path) : FALSE)
+	    name = g_basename(path);
+	else
+	    name = path;
 
 	/* Parse extension from the specified name */
 	if(name != NULL)
@@ -2229,6 +2257,132 @@ void EDVPlaySoundCompleted(edv_core_struct *core_ptr)
 }
 
 
+/*
+ *	GtkMenu "hide" signal callback.
+ *
+ *	Used to release the GtkButton associated with the the GtkMenu
+ *	and disconnect this signal.
+ */
+static void EDVMenuButtonMenuHideCB(GtkWidget *widget, gpointer data)
+{ 
+	guint s;
+	GList *glist;
+	GtkWidget *w;
+	if(widget == NULL)
+	    return;
+
+	/* Get the meuu and button map data from the GtkMenu */
+	glist = (GList *)gtk_object_get_data(
+	    GTK_OBJECT(widget), EDV_MENU_BUTTON_MAP_DATA_KEY
+	);
+	w = (glist != NULL) ? (GtkWidget *)glist->data : NULL;
+	glist = g_list_next(glist);
+	s = (glist != NULL) ? (guint)glist->data : 0;
+
+	/* Release the GtkButton */
+	if((w != NULL) ? GTK_IS_BUTTON(w) : FALSE)
+	{
+	    GtkButton *button = GTK_BUTTON(w);
+	    button->in_button = 0;
+	    gtk_signal_emit_by_name(GTK_OBJECT(w), "released");
+	}
+
+	/* Disconnect this signal */
+	if(s > 0)
+	    gtk_signal_disconnect(GTK_OBJECT(widget), s);
+
+	/* Remove the menu and button and map data */
+	gtk_object_remove_data(
+	    GTK_OBJECT(widget), EDV_MENU_BUTTON_MAP_DATA_KEY
+	);
+}
+
+/*
+ *	GtkMenu position callback.
+ *
+ *	Moves the GtkMenu to the proper position based on the GtkButton
+ *	specified by data.
+ */
+static void EDVMenuButtonMenuPositionCB(
+	GtkMenu *menu, gint *x, gint *y, gpointer data
+)
+{
+	gint width, height;
+	GdkWindow *window;
+	GtkWidget *w = (GtkWidget *)data;
+	if((menu == NULL) || (x == NULL) || (y == NULL) || (w== NULL))
+	    return;
+
+	window = w->window;
+	if(window == NULL)
+	    return;
+
+	gdk_window_get_root_position(window, x, y);  
+	gdk_window_get_size(window, &width, &height);   
+	*y = (*y) + height;
+}
+
+/*
+ *	Maps the GtkMenu relative to the specified GtkButton.
+ */
+void EDVMenuButtonMapMenu(GtkWidget *menu, GtkWidget *button)
+{
+	if(menu == NULL)
+	    return;
+
+	/* Ungrab the GtkButton */
+	if(button != NULL)
+	{
+	    if(GTK_WIDGET_HAS_GRAB(button))
+		gtk_grab_remove(button);
+
+/*
+	    while(gtk_events_pending() > 0)
+		gtk_main_iteration();
+ */
+
+	    if(GTK_IS_BUTTON(button))
+	    {
+		/* Send a "pressed" signal to the GtkButton to keep
+		 * it pressed once the grab for the GtkButton has been
+		 * removed and the GtkMenu has been mapped
+		 */
+		GTK_BUTTON(button)->in_button = 1;
+		GTK_BUTTON(button)->button_down = 1;
+		gtk_signal_emit_by_name(GTK_OBJECT(button), "pressed");
+	    }
+	}
+
+	/* Map the menu */
+	if(GTK_IS_MENU(menu))
+	{
+	    /* Connect the hide signal */
+	    guint s = gtk_signal_connect(
+		GTK_OBJECT(menu), "hide",
+		GTK_SIGNAL_FUNC(EDVMenuButtonMenuHideCB), button
+	    );
+	    GList *data_list = NULL;
+
+	    /* Set object data on the menu */
+	    data_list = g_list_append(data_list, button);
+	    data_list = g_list_append(data_list, (gpointer)s);
+	    gtk_object_set_data_full(
+		GTK_OBJECT(menu), EDV_MENU_BUTTON_MAP_DATA_KEY,
+		data_list, (GtkDestroyNotify)g_list_free
+	    );
+
+	    /* Map the menu */
+	    gtk_menu_popup(
+		GTK_MENU(menu), NULL, NULL,
+		EDVMenuButtonMenuPositionCB,	/* Position Callback */
+		button,			/* Data */
+		1,			/* Button Number */
+		GDK_CURRENT_TIME	/* Time */
+	    );
+	}
+}
+
+
 /*
  *	Moves the GtkWindow w2 to be centered to GtkWindow w1.
  */
@@ -2333,9 +2487,7 @@ void EDVEntrySetCompletePath(edv_core_struct *core_ptr, GtkWidget *w)
 
 
 /*
- *	Creates a new GtkScrolledWindow.
- *
- *	It will be set up for scrolling.
+ *	Creates a new GtkScrolledWindow set up for improved scrolling.
  */
 GtkWidget *EDVScrolledWindowNew(
 	GtkPolicyType hscrollbar_policy,
@@ -2362,10 +2514,8 @@ GtkWidget *EDVScrolledWindowNew(
 	GTK_WIDGET_SET_FLAGS(w, GTK_CAN_FOCUS);
 	gtk_widget_add_events(
 	    w,
-	    GDK_EXPOSURE_MASK | GDK_VISIBILITY_NOTIFY_MASK |
-	    GDK_STRUCTURE_MASK | GDK_FOCUS_CHANGE_MASK |
+	    GDK_FOCUS_CHANGE_MASK |
 	    GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK |
-	    GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK |
 	    GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
 	    GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK
 	);
@@ -2403,7 +2553,7 @@ GtkWidget *EDVScrolledWindowNew(
 }
 
 /*
- *	GtkScrolledWindow event callback.
+ *	Scrolled window GtkEventBox event signal callback.
  */
 static gint EDVScrolledWindowEventCB(
 	GtkWidget *widget, GdkEvent *event, gpointer data
@@ -2437,11 +2587,20 @@ static gint EDVScrolledWindowEventCB(
 	{
 	  case GDK_FOCUS_CHANGE:
 	    focus = (GdkEventFocus *)event;
-	    if(focus->in && !GTK_WIDGET_HAS_FOCUS(widget))
-		GTK_WIDGET_SET_FLAGS(widget, GTK_HAS_FOCUS);
-	    else if(!focus->in && GTK_WIDGET_HAS_FOCUS(widget))
-		GTK_WIDGET_UNSET_FLAGS(widget, GTK_HAS_FOCUS);
-	    status = TRUE;
+	    if(focus->window == widget->window)
+	    {
+		if(focus->in && !GTK_WIDGET_HAS_FOCUS(widget))
+	        {
+		    GTK_WIDGET_SET_FLAGS(widget, GTK_HAS_FOCUS);
+		    gtk_widget_queue_draw(widget);
+		}
+		else if(!focus->in && GTK_WIDGET_HAS_FOCUS(widget))
+		{
+		    GTK_WIDGET_UNSET_FLAGS(widget, GTK_HAS_FOCUS);
+		    gtk_widget_queue_draw(widget);
+		}
+		status = TRUE;
+	    }
 	    break;
 
 	  case GDK_KEY_PRESS:
@@ -2524,25 +2683,21 @@ static gint EDVScrolledWindowEventCB(
 
 	  case GDK_BUTTON_PRESS:
 	    button = (GdkEventButton *)event;
-	    if(!GTK_WIDGET_HAS_FOCUS(widget))
-		gtk_widget_grab_focus(widget);
+	    if(button->window == widget->window)
+	    {
+		if(!GTK_WIDGET_HAS_FOCUS(widget))
+		    gtk_widget_grab_focus(widget);
+	    }
 	    switch(button->button)
 	    {
 	      case GDK_BUTTON1:
 	      case GDK_BUTTON2:
-		if(TRUE)
+		if(button->window == widget->window)
 		{
-		    gint x, y;
-		    GdkModifierType mask;
-		    GdkCursor *cursor = (GdkCursor *)GTK_OBJECT_GET_DATA(
+		    GdkCursor *cur = (GdkCursor *)GTK_OBJECT_GET_DATA(
 			sw,
 			EDV_SCROLLED_WINDOW_DATA_TRANSLATE_CURSOR_KEY
 		    );
-
-		    gdk_window_get_pointer(
-			button->window, &x, &y, &mask
-		    );
-
 		    gdk_pointer_grab(
 			button->window,
 			FALSE,
@@ -2551,13 +2706,12 @@ static gint EDVScrolledWindowEventCB(
 			    GDK_POINTER_MOTION_MASK |
 			    GDK_POINTER_MOTION_HINT_MASK,
 			NULL,
-			cursor,
+			cur,
 			button->time
 		    );
-
 		    do_scroll = TRUE;
-		    pointer_x_last = x;
-		    pointer_y_last = y;
+		    pointer_x_last = (gint)button->x;
+		    pointer_y_last = (gint)button->y;
 		    status = TRUE;
 		}
 		break;
@@ -2570,14 +2724,13 @@ static gint EDVScrolledWindowEventCB(
 	    {
 	      case GDK_BUTTON1:
 	      case GDK_BUTTON2:
-		if(TRUE)
+		if(do_scroll)
 		{
-		    gdk_pointer_ungrab(button->time);
-
+		    if(gdk_pointer_is_grabbed())
+			gdk_pointer_ungrab(button->time);
 		    do_scroll = FALSE;
 		    pointer_x_last = 0;
 		    pointer_y_last = 0;
-
 		    status = TRUE;
 		}
 		break;
@@ -2591,7 +2744,6 @@ static gint EDVScrolledWindowEventCB(
 		gint dx, dy;
 		GtkAdjustment *hadj = gtk_scrolled_window_get_hadjustment(sw),
 			      *vadj = gtk_scrolled_window_get_vadjustment(sw);
-
 		if(motion->is_hint)
 		{
 		    gint x, y;
@@ -2627,7 +2779,6 @@ static gint EDVScrolledWindowEventCB(
 		status = TRUE;
 	    }
 	    break;
-
 	}
 
 #undef ADJ_SET_DELTA_EMIT
