@@ -499,7 +499,7 @@ void EDVFindWinListAppend(
 		  case EDV_FINDWIN_ROLE_ARCHIVE_OBJECT:
 		    obj = EDVObjectNew();
 		    g_free(obj->name);
-		    obj->name = STRDUP(EDVGetPathName(path));
+		    obj->name = STRDUP(g_basename(path));
 		    g_free(obj->full_path);
 		    obj->full_path = STRDUP(path);
 		    break;
@@ -514,7 +514,8 @@ void EDVFindWinListAppend(
 		     * from the full path since the obj->name may
 		     * contain some other value depending on the role
 		     */
-		    const gchar *name = EDVGetPathName(obj->full_path);
+		    const gchar *name = (obj->full_path != NULL) ?
+			g_basename(obj->full_path) : NULL;
 
 		    /* Get pixmap and mask for the given object */
 		    EDVMatchObjectIcon(
