@@ -9,8 +9,8 @@
 #define FINDWIN_H
 
 #include <gtk/gtk.h>
+#include "statusbar.h"
 #include "edvtypes.h"
-#include "edvstatusbar.h"
 
 
 /*
@@ -72,8 +72,8 @@ typedef struct {
 			*results_clist_open_with_mi,
 			*results_clist_goto_mi;
 
-	/* Status bar */
-	edv_status_bar_struct *status_bar;
+	/* Status Bar */
+	edv_statusbar_struct *status_bar;
 
 	/* Reference browser index number (only one may be non-negative) */
 	gint		browser_num,
