@@ -579,12 +579,11 @@ void EDVFindWinSelectRowCB(
 				*type_str = "Object";
 		    gchar size_str[80];
 
-
 		    /* Get name from full path, since the name of the
 		     * object may be a string specifying a special
 		     * notation depending on the role
 		     */
-		    name = EDVGetPathName(obj->full_path);
+		    name = g_basename(obj->full_path);
 
 		    /* Get object type string and size string */
 		    *size_str = '\0';
