@@ -136,55 +136,39 @@ static void EDVFOPDlgProcessCB(GtkWidget *widget, gpointer data)
 	/* Get copy of parsed and simplified target path */
 	w = d->target_entry;
 	tar_path = (w != NULL) ?
-	    EDVCopyEvaluateInputPath(
-		d->src_dir,
-		gtk_entry_get_text(GTK_ENTRY(w))
-	    ) : NULL;
+	    EDVEvaluatePath(d->src_dir, gtk_entry_get_text(GTK_ENTRY(w))) : NULL;
 
 	/* Get permissions */
 	w = d->target_chmod_parent;
 	if(w != NULL)
 	{
-	    w = d->target_uread_check;
-	    if((w != NULL) ? GTK_TOGGLE_BUTTON(w)->active : FALSE)
+	    if(GTK_TOGGLE_BUTTON_GET_ACTIVE(d->target_uread_check))
 		permissions |= EDV_PERMISSION_UREAD;
-	    w = d->target_uwrite_check;
-	    if((w != NULL) ? GTK_TOGGLE_BUTTON(w)->active : FALSE)
+	    if(GTK_TOGGLE_BUTTON_GET_ACTIVE(d->target_uwrite_check))
 		permissions |= EDV_PERMISSION_UWRITE;
-	    w = d->target_uexecute_check;
-	    if((w != NULL) ? GTK_TOGGLE_BUTTON(w)->active : FALSE)
+	    if(GTK_TOGGLE_BUTTON_GET_ACTIVE(d->target_uexecute_check))
 		permissions |= EDV_PERMISSION_UEXECUTE;
 
-	    w = d->target_gread_check;
-	    if((w != NULL) ? GTK_TOGGLE_BUTTON(w)->active : FALSE)
+	    if(GTK_TOGGLE_BUTTON_GET_ACTIVE(d->target_gread_check))
 		permissions |= EDV_PERMISSION_GREAD;
-	    w = d->target_gwrite_check;
-	    if((w != NULL) ? GTK_TOGGLE_BUTTON(w)->active : FALSE)
+	    if(GTK_TOGGLE_BUTTON_GET_ACTIVE(d->target_gwrite_check))
 		permissions |= EDV_PERMISSION_GWRITE;
-	    w = d->target_gexecute_check;
-	    if((w != NULL) ? GTK_TOGGLE_BUTTON(w)->active : FALSE)
+	    if(GTK_TOGGLE_BUTTON_GET_ACTIVE(d->target_gexecute_check))
 		permissions |= EDV_PERMISSION_GEXECUTE;
 
-	    w = d->target_aread_check;
-	    if((w != NULL) ? GTK_TOGGLE_BUTTON(w)->active : FALSE)
+	    if(GTK_TOGGLE_BUTTON_GET_ACTIVE(d->target_aread_check))
 		permissions |= EDV_PERMISSION_AREAD;
-	    w = d->target_awrite_check;
-	    if((w != NULL) ? GTK_TOGGLE_BUTTON(w)->active : FALSE)
+	    if(GTK_TOGGLE_BUTTON_GET_ACTIVE(d->target_awrite_check))
 		permissions |= EDV_PERMISSION_AWRITE;
-	    w = d->target_aexecute_check;
-	    if((w != NULL) ? GTK_TOGGLE_BUTTON(w)->active : FALSE)
+	    if(GTK_TOGGLE_BUTTON_GET_ACTIVE(d->target_aexecute_check))
 		permissions |= EDV_PERMISSION_AEXECUTE;
 
-	    w = d->target_setuid_check;
-	    if((w != NULL) ? GTK_TOGGLE_BUTTON(w)->active : FALSE)
+	    if(GTK_TOGGLE_BUTTON_GET_ACTIVE(d->target_setuid_check))
 		permissions |= EDV_PERMISSION_SETUID;
-	    w = d->target_setgid_check;
-	    if((w != NULL) ? GTK_TOGGLE_BUTTON(w)->active : FALSE)
+	    if(GTK_TOGGLE_BUTTON_GET_ACTIVE(d->target_setgid_check))
 		permissions |= EDV_PERMISSION_SETGID;
-	    w = d->target_sticky_check;
-	    if((w != NULL) ? GTK_TOGGLE_BUTTON(w)->active : FALSE)
+	    if(GTK_TOGGLE_BUTTON_GET_ACTIVE(d->target_sticky_check))
 		permissions |= EDV_PERMISSION_STICKY;
-
 	}
 
 	/* Get owner and group */
@@ -279,7 +263,7 @@ static void EDVFOPDlgProcessCB(GtkWidget *widget, gpointer data)
 		    {
 			gfloat progress = (total_objects > 0) ?
 			    ((gfloat)i / (gfloat)total_objects) : 0.0f;
-			gchar *p1 = EDVCopyShortenPath(
+			gchar *p1 = EDVShortenPath(
 			    src_path, EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX
 			);
 			gchar *buf = g_strdup_printf(
@@ -330,7 +314,7 @@ static void EDVFOPDlgProcessCB(GtkWidget *widget, gpointer data)
 		    {
 			gfloat progress = (total_objects > 0) ?
 			    ((gfloat)i / (gfloat)total_objects) : 0.0f;
-			gchar *p1 = EDVCopyShortenPath(
+			gchar *p1 = EDVShortenPath(
 			    src_path, EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX
 			);
 			gchar *buf = g_strdup_printf(
@@ -468,14 +452,14 @@ static void EDVFOPDlgProcessCB(GtkWidget *widget, gpointer data)
 	tar_path = NULL;
 
 	/* From this point on these variables are invalid, and they
-	 * will be deallocated when EDVFOPDlgReset() is called
+	 * will be deleted when EDVFOPDlgReset() is called
 	 * further below
 	 */
 	total_objects = 0;
 	object = NULL;
 
-	/* Deallocate source disk objects structure list and current
-	 * source directory on the dialog
+	/* Delete source objects list and current source directory on
+	 * the dialog
 	 */
 	EDVFOPDlgReset(d);
 }
@@ -492,7 +476,7 @@ static void EDVFOPDlgCancelCB(GtkWidget *widget, gpointer data)
 	/* Unmap dialog */
 	EDVFOPDlgUnmap(d);
 
-	/* Deallocate source disk objects structure list and current
+	/* Delete source disk objects structure list and current
 	 * source directory on the dialog
 	 */
 	EDVFOPDlgReset(d);
@@ -949,10 +933,10 @@ edv_fopdlg_struct *EDVFOPDlgNew(gpointer core_ptr)
 	GTK_WIDGET_SET_FLAGS(w, GTK_CAN_DEFAULT);
 	gtk_widget_set_usize(w, 250, -1);
 	gtk_box_pack_start(GTK_BOX(parent6), w, TRUE, TRUE, 0);
-        gtk_signal_connect(
-            GTK_OBJECT(w), "activate",
-            GTK_SIGNAL_FUNC(EDVFOPDlgProcessCB), d
-        );
+	gtk_signal_connect(
+	    GTK_OBJECT(w), "activate",
+	    GTK_SIGNAL_FUNC(EDVFOPDlgProcessCB), d
+	);
 	gtk_widget_show(w);
 	/* Popup list map button */
 	d->target_owner_btn = w = PUListNewMapButton(
@@ -980,10 +964,10 @@ edv_fopdlg_struct *EDVFOPDlgNew(gpointer core_ptr)
 	GTK_WIDGET_SET_FLAGS(w, GTK_CAN_DEFAULT);
 	gtk_widget_set_usize(w, 250, -1);
 	gtk_box_pack_start(GTK_BOX(parent6), w, TRUE, TRUE, 0);
-        gtk_signal_connect(                                    
-            GTK_OBJECT(w), "activate",
-            GTK_SIGNAL_FUNC(EDVFOPDlgProcessCB), d
-        );
+	gtk_signal_connect(                                    
+	    GTK_OBJECT(w), "activate",
+	    GTK_SIGNAL_FUNC(EDVFOPDlgProcessCB), d
+	);
 	gtk_widget_show(w);
 	/* Popup list map button */
 	d->target_group_btn = w = PUListNewMapButton(
@@ -1230,7 +1214,7 @@ edv_fopdlg_struct *EDVFOPDlgNew(gpointer core_ptr)
 
 
 /*
- *	Deallocates source disk object structure list and current
+ *	Deletes source disk object structure list and current
  *	source directory on the given dialog.
  */
 void EDVFOPDlgReset(edv_fopdlg_struct *d)
@@ -1940,68 +1924,61 @@ void EDVFOPDlgMapValues(
 	    }
 
 	    /* Begin setting permission check widgets */
-#define SET_ACTIVE(_w_,_b_)	{		\
- if((_w_) != NULL)				\
-  gtk_toggle_button_set_active(			\
-   GTK_TOGGLE_BUTTON(_w_), (_b_) ? TRUE : FALSE	\
-  );						\
-}
-	    SET_ACTIVE(
+	    GTK_TOGGLE_BUTTON_SET_ACTIVE(
 		d->target_uread_check,
-		permissions & EDV_PERMISSION_UREAD
+		(permissions & EDV_PERMISSION_UREAD) ? TRUE : FALSE
 	    )
 	    if(GTK_WIDGET_CAN_FOCUS(d->target_uread_check))
 		gtk_widget_grab_focus(d->target_uread_check);
 	    if(GTK_WIDGET_CAN_DEFAULT(d->target_uread_check))
 		gtk_widget_grab_default(d->target_uread_check);
-	    SET_ACTIVE(
+	    GTK_TOGGLE_BUTTON_SET_ACTIVE(
 		d->target_uwrite_check,
-		permissions & EDV_PERMISSION_UWRITE
+		(permissions & EDV_PERMISSION_UWRITE) ? TRUE : FALSE
 	    )
-	    SET_ACTIVE(
+	    GTK_TOGGLE_BUTTON_SET_ACTIVE(
 		d->target_uexecute_check,
-		permissions & EDV_PERMISSION_UEXECUTE
+		(permissions & EDV_PERMISSION_UEXECUTE) ? TRUE : FALSE
 	    )
 
-	    SET_ACTIVE(
+	    GTK_TOGGLE_BUTTON_SET_ACTIVE(
 		d->target_gread_check,
-		permissions & EDV_PERMISSION_GREAD
+		(permissions & EDV_PERMISSION_GREAD) ? TRUE : FALSE
 	    )
-	    SET_ACTIVE(
+	    GTK_TOGGLE_BUTTON_SET_ACTIVE(
 		d->target_gwrite_check,
-		permissions & EDV_PERMISSION_GWRITE
+		(permissions & EDV_PERMISSION_GWRITE) ? TRUE : FALSE
 	    )
-	    SET_ACTIVE(
+	    GTK_TOGGLE_BUTTON_SET_ACTIVE(
 		d->target_gexecute_check,
-		permissions & EDV_PERMISSION_GEXECUTE
+		(permissions & EDV_PERMISSION_GEXECUTE) ? TRUE : FALSE
 	    )
 
-	    SET_ACTIVE(
+	    GTK_TOGGLE_BUTTON_SET_ACTIVE(
 		d->target_aread_check,
-		permissions & EDV_PERMISSION_AREAD
+		(permissions & EDV_PERMISSION_AREAD) ? TRUE : FALSE
 	    )
-	    SET_ACTIVE(
+	    GTK_TOGGLE_BUTTON_SET_ACTIVE(
 		d->target_awrite_check,
-		permissions & EDV_PERMISSION_AWRITE
+		(permissions & EDV_PERMISSION_AWRITE) ? TRUE : FALSE
 	    )
-	    SET_ACTIVE(
+	    GTK_TOGGLE_BUTTON_SET_ACTIVE(
 		d->target_aexecute_check,
-		permissions & EDV_PERMISSION_AEXECUTE
+		(permissions & EDV_PERMISSION_AEXECUTE) ? TRUE : FALSE
 	    )
 
-	    SET_ACTIVE(
+	    GTK_TOGGLE_BUTTON_SET_ACTIVE(
 		d->target_setuid_check,
-		permissions & EDV_PERMISSION_SETUID
+		(permissions & EDV_PERMISSION_SETUID) ? TRUE : FALSE
 	    )
-	    SET_ACTIVE(
+	    GTK_TOGGLE_BUTTON_SET_ACTIVE(
 		d->target_setgid_check,
-		permissions & EDV_PERMISSION_SETGID
+		(permissions & EDV_PERMISSION_SETGID) ? TRUE : FALSE
 	    )
-	    SET_ACTIVE(
+	    GTK_TOGGLE_BUTTON_SET_ACTIVE(
 		d->target_sticky_check,
-		permissions & EDV_PERMISSION_STICKY
+		(permissions & EDV_PERMISSION_STICKY) ? TRUE : FALSE
 	    )
-#undef SET_ACTIVE
 	}
 
 	/* Update owner and group? */
