@@ -65,16 +65,16 @@ El uso: format.front [device] [options] [GUI_options]\n\
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
 #define PROG_HELP_MESG  "\
-L'usage: format.front [device] [options] [GUI_options]\n\
+Usage: format.front [device] [options] [GUI_options]\n\
 \n\
     [device] spcifie l'appareil pour choisir au dmarrage.\n\
 \n\
-    [options] peut tre n'importe quel du suivre:\n\
+    [options] parmi les suivantes:\n\
 \n\
-        --start                 Le format de dbut de dbut au dmarrage.\n\
+        --start                 Lance le Formattage  l'ouverture.\n\
         -s                      Mme comme --start.\n\
-        --help                  Caractres (ceci) aide cran et sorties.\n\
-        --version               Caractres information de version et sorties.\n\
+        --help                  Affiche aide cran et sort.\n\
+        --version               Information de version et sort.\n\
 \n\
     [GUI_options] peut tre n'importe quelle norme d'options  votre\n\
     GUI, consulter le manuel de votre GUI pour les options disponibles.\n\
