@@ -574,7 +574,7 @@ Usted debe unmount el artefacto primero antes de format.",
 #ifdef PROG_LANGUAGE_FRENCH
 "`%s' d'appareil est actuellement mont.\n\
 \n\
-Vous devez unmount l'appareil premirement avant de format.",
+Vous devez dmont l'appareil avant de pouvoir le formatter.",
 #endif
 		dev->device_path
 	    );
@@ -589,12 +589,12 @@ esto deber prevenir los errores debido a lectura/escritura\n\
 que pueden occure durante el proceso que format. Use la\n\
 Endeavour otra aplicacin al unmount el artefacto primero.",
 #elif defined(PROG_LANGUAGE_FRENCH)
-		"Le Format A Echou",
+		"Le Format a Echou",
 		buf,
-"L'appareil doit tre unmounted avant d'il peut tre\n\
-format, ceci sera oblig  empcher des erreurs grce aux\n\
-lecture/criture qui peut occure pendant le procd qui\n\
-format. Utilise Endeavour ou un autre a la premierement.",
+"L'appareil doit tre dmont avant qu'il puisse tre\n\
+formatt, cela empchera les erreurs de lecture/criture\n\
+qui pourraient se produire pendant le procd de formattage.\n\
+Utilise Endeavour ou une autre commande pour dmonter.",
 #else
 		"Format Failed",
 		buf,
@@ -873,7 +873,7 @@ format stage.",
     %s",
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-"Incapable pour excuter l'ordre:\n\
+"Impossible d'excuter la commande:\n\
 \n\
     %s",
 #endif
@@ -893,7 +893,7 @@ format stage.",
 		NULL
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-		"Le Format A Echou",
+		"Le Formattage a Echou",
 		buf,
 		NULL,
 #endif
@@ -985,10 +985,10 @@ continuar formatear?",
 	    NULL,
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	    "Confirmer Le Format",
-"La mise en format le presse effacera toutes donnes\n\
-existantes sur le presse, tes vous sr que vous voulez\n\
-continuer la mise en format?",
+	    "Confirmer Le Formattage",
+"Le formattage dtruira toutes les donnes\n\
+existantes sur le disque, tes vous sr de vouloir continuer ?",
+
 	    NULL,
 #endif
 	    CDIALOG_ICON_WARNING,
