@@ -1,5 +1,5 @@
 /*
-                        Format Manager Window Callbacks
+			Format Manager Window Callbacks
  */
 
 #ifndef FORMATCB_H
@@ -11,7 +11,7 @@
 
 
 extern gint FormatManagerButtonPressEventCB(
-        GtkWidget *widget, GdkEventButton *button, gpointer data
+	GtkWidget *widget, GdkEventButton *button, gpointer data
 );
 extern gint FormatManagerDiskIconExposeCB(
 	GtkWidget *widget, GdkEventExpose *expose, gpointer data
@@ -19,10 +19,9 @@ extern gint FormatManagerDiskIconExposeCB(
 
 extern gint FormatManagerFormatTOCB(gpointer data);
 
-extern gint FormatManagerCloseCB(
-        GtkWidget *widget, GdkEvent *event, gpointer data
+extern gint FormatManagerDeleteEventCB(
+	GtkWidget *widget, GdkEvent *event, gpointer data
 );
-extern void FormatManagerDestroyCB(GtkObject *object, gpointer data);
 
 extern void FormatManagerStartCB(GtkWidget *widget, gpointer data);
 extern void FormatManagerStopCB(GtkWidget *widget, gpointer data);
@@ -30,12 +29,12 @@ extern void FormatManagerClearCB(GtkWidget *widget, gpointer data);
 extern void FormatManagerCloseBtnCB(GtkWidget *widget, gpointer data);
 
 extern void FormatManagerSelectRowCB(
-        GtkCList *clist, gint row, gint column, GdkEvent *event,
-        gpointer data
+	GtkCList *clist, gint row, gint column, GdkEvent *event,
+	gpointer data
 );
 extern void FormatManagerUnselectRowCB(
-        GtkCList *clist, gint row, gint column, GdkEvent *event,
-        gpointer data
+	GtkCList *clist, gint row, gint column, GdkEvent *event,
+	gpointer data
 );
 
 
