@@ -62,16 +62,16 @@ El uso: fsck.front [device] [options] [GUI_options]\n\
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
 #define PROG_HELP_MESG  "\
-L'usage: fsck.front [device] [options] [GUI_options]\n\
+Usage: fsck.front [device] [options] [GUI_options]\n\
 \n\
     [device] spcifie l'appareil pour choisir au dmarrage.\n\
 \n\
     [options] peut tre n'importe quel du suivre:\n\
 \n\
-        --start                 Le chque de Dbut de dbut au dmarrage.\n\
+        --start                 Le Controle est lanc au dmarrage.\n\
         -s                      Mme comme --start.\n\
-        --help                  Caractres (ceci) aide cran et sorties.\n\
-        --version               Caractres information de version et sorties.\n\
+        --help                  Affiche cran d'aide cran et sort.\n\
+        --version               Affiche information de version et sort.\n\
 \n\
     [GUI_options] peut tre n'importe quelle norme d'options  votre\n\
     GUI, consulter le manuel de votre GUI pour les options disponibles.\n\
