@@ -474,9 +474,9 @@ static void FSCKManagerDoStart(
 \n\
 Usted debe unmount el artefacto primero antes de verificar.",
 #elif defined(PROG_LANGUAGE_FRENCH)
-"\"%s\" d'appareil est actuellement mont.\n\
+"\"%s\" composant est actuellement mont.\n\
 \n\
-Vous devez unmount l'appareil premirement avant de vrifiant.",
+Vous devez dmont le composant pour pouvoir faire la vrification.",
 #else
 "Device \"%s\" is currently mounted.\n\
 \n\
@@ -495,12 +495,12 @@ esto deber prevenir los errores debido a lectura/escritura\n\
 que pueden occure durante el proceso que verifica. Use la\n\
 Endeavour otra aplicacin al unmount el artefacto primero.",
 #elif defined(PROG_LANGUAGE_FRENCH)
-		"Le Chque A Echou",
+		"La vrification a choue",
 		buf,
-"L'appareil doit tre unmounted avant d'il peut tre\n\
-vrifi, ceci sera oblig  empcher des erreurs grce aux\n\
-lecture/criture qui peut occure pendant le procd qui\n\
-vrifiant. Utilise Endeavour ou un autre a la premierement.",
+"L'appareil doit tre dmont avant de pouvoir tre vrifi, \n\
+c'est obligatoire, pour empcher des erreurs de lecture/criture \n\
+qui pourraient se drouler pendant le procd de vrification.\n\
+Utiliser Endeavour ou une autre commande pour faire le dmontage.",
 #else
 		"Check Failed",
 		buf,
@@ -571,8 +571,8 @@ filesystem:\n\
 \n\
     %s",
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Ce programme ne soutient pas actuellement\n\
-le filesystem:\n\
+"Ce programme ne supporte pas actuellement\n\
+ce Systme de fichier:\n\
 \n\
     %s",
 #else
@@ -589,7 +589,7 @@ the filesystem:\n\
 #if defined(PROG_LANGUAGE_SPANISH)
 		"Filesystem No Sostuvo",
 #elif defined(PROG_LANGUAGE_FRENCH)
-		"Filesystem n'A Pas Soutenu",
+		"Systme de fichier non support",
 #else
 		"Filesystem Not Supported",
 #endif
@@ -617,13 +617,13 @@ Verifique por favor ese programa es instalado en una\n\
 ubicacion especificada por el ambiente de %s y que es\n\
 ejecutable por este programa.",
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Incapable de trouver de programme de FSCK:\n\
+"Impossible de trouver le programme FSCK:\n\
 \n\
     %s\n\
 \n\
-S'il vous plait verifier ce programme est installe dans\n\
-un emplacement specifie par l'environnement de %s et\n\
-que c'est realisable par ce programme.",
+Verifier ce programme est install dans\n\
+un emplacement specifi par l'environnement de %s et\n\
+que c'est excutable par ce programme.",
 #else
 "Unable to find the FSCK program:\n\
 \n\
@@ -642,7 +642,7 @@ executable by this program.",
 #if defined(PROG_LANGUAGE_SPANISH)
 		"Incapaz De Encontrar El Programa De FSCK",
 #elif defined(PROG_LANGUAGE_FRENCH)
-		"Incapable De Trouver De Programme De FSCK",
+		"Impossible de Trouver le programme FSCK",
 #else
 		"Unable To Find FSCK Program",
 #endif
@@ -762,7 +762,7 @@ startup_message = NULL;
 \n\
     %s",
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Incapable d'executer l'ordre:\n\
+"Impossible d'executer la commande:\n\
 \n\
     %s",
 #else
@@ -778,7 +778,7 @@ startup_message = NULL;
 #if defined(PROG_LANGUAGE_SPANISH)
 		"Incapaz De Ejecutar La Prden",
 #elif defined(PROG_LANGUAGE_FRENCH)
-		"Incapable D'Executer L'Ordre",
+		"Impossible d'excuter la commande",
 #else
 		"Unable To Execute Command",
 #endif
