@@ -1,7 +1,7 @@
 #include <string.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkprivate.h>
-#if defined(_WIN32)
+#if defined(WIN32)
 # include <gdk/gdkwin32.h>
 # define HAVE_WIN32
 #else
@@ -82,16 +82,16 @@ guint8 *GUIGetRGBAImage(
 );
 
 
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
@@ -134,18 +134,20 @@ void GUIImageBufferCopyArea(
 	    src_line += src_bpl
 	)
 	{
+	    if(y < 0)
+		continue;
+	    if(y >= tar_height)
+		break;
+
 	    x = tar_x;
 	    src_ptr = src_line;
 	    src_end = src_ptr + (src_width * bpp);
-
 	    while(src_ptr < src_end)
 	    {
 		/* Current target coordinates fall in bounds on the
 		 * target image?
 		 */
-		if((x >= 0) && (x < tar_width) &&
-		   (y >= 0) && (y < tar_height)
-		)
+		if((x >= 0) && (x < tar_width))
 		{
 		    /* Current target coordinates are valid, get pointer
 		     * to target pixel
@@ -176,7 +178,7 @@ void GUIImageBufferCopyArea(
 			    );
 			    tar_ptr[2] = (guint8)(
 				((guint)(*src_ptr++) * src_alpha / 0xff) +
-				((guint)tar_ptr[2] * tar_alpha / 0xff)  
+				((guint)tar_ptr[2] * tar_alpha / 0xff)
 			    );
 			    tar_ptr[3] = MIN(
 				(guint)(*src_ptr++) + (guint)tar_ptr[3],
@@ -418,8 +420,8 @@ void GUIImageBufferResize(
 		    tar_y_row += 1;
 		    src_y_row += src_dh_y_row_inc;
 		}
-	    }    
-	}    
+	    }
+	}
 	/* 32 bits */
 	else if(bpp == 4)
 	{
@@ -550,7 +552,7 @@ void GUIImageBufferRotateCCW90(
 	/* Calculate bytes per line values as needed */
 	if(src_bpl <= 0)
 	    src_bpl = src_width * bpp;
-	if(tar_bpl <= 0)              
+	if(tar_bpl <= 0)
 	    tar_bpl = tar_width * bpp;
 
 	/* Copy/rotate counter-clockwise 90 degrees */
@@ -631,7 +633,7 @@ void GUIImageBufferMirrorH(
 	gint bpp,
 	const guint8 *src_data,
 	gint src_width, gint src_height, gint src_bpl,
-	guint8 *tar_data,      
+	guint8 *tar_data,
 	gint tar_width, gint tar_height, gint tar_bpl
 )
 {
@@ -643,7 +645,7 @@ void GUIImageBufferMirrorH(
 	   (src_data == NULL) || (tar_data == NULL) ||
 	   (bpp <= 0)
 	)
-	    return;        
+	    return;
 
 	/* Mirror geometry not correct? */
 	if((src_width != tar_width) || (src_height != tar_height))
@@ -703,7 +705,7 @@ void GUIImageBufferMirrorV(
 	/* Calculate bytes per line values as needed */
 	if(src_bpl <= 0)
 	    src_bpl = src_width * bpp;
-	if(tar_bpl <= 0)              
+	if(tar_bpl <= 0)
 	    tar_bpl = tar_width * bpp;
 
 	/* Copy/mirror horizontally */
@@ -732,7 +734,7 @@ void GUIImageBufferMirrorV(
  */
 void GUIImageBufferFlattenWithBG(
 	gint bpp,
-	guint8 *data,                             
+	guint8 *data,
 	gint width, gint height, gint bpl,
 	const guint8 *bg_color
 )
@@ -855,7 +857,7 @@ guint8 *GUIGetRGBImage(
 	if(width_rtn != NULL)
 	    *width_rtn = 0;
 	if(height_rtn != NULL)
-	    *height_rtn = 0;  
+	    *height_rtn = 0;
 	if(bpl_rtn != NULL)
 	    *bpl_rtn = 0;
 
@@ -863,12 +865,12 @@ guint8 *GUIGetRGBImage(
 	    return(NULL);
 
 	xdpy = private->xdisplay;
-	if(xdpy == NULL)         
+	if(xdpy == NULL)
 	    return(NULL);
 
 	/* If no rectangle is specified then set rectangle to cover the
 	 * entire drawable
-	 */  
+	 */
 	if(rect == NULL)
 	{
 	    rect = &lrect;
@@ -884,8 +886,8 @@ guint8 *GUIGetRGBImage(
 	/* Get an XImage from the GdkDrawable's Window */
 	ximg = XGetImage(
 	    xdpy, xwin,
-	    rect->x, rect->y,
-	    rect->width, rect->height,
+	    (int)rect->x, (int)rect->y,
+	    (unsigned int)rect->width, (unsigned int)rect->height,
 	    AllPlanes,
 	    ZPixmap
 	);
@@ -902,7 +904,7 @@ guint8 *GUIGetRGBImage(
 	src_bpl = ximg->bytes_per_line;
 	src_data = (const guint8 *)ximg->data;
 
-	/* Allocate target RGB image data */
+	/* Allocate the target RGB image data */
 	tar_bpp = 3;
 	tar_bpl = width * tar_bpp;
 	tar_data = (guint8 *)g_malloc(tar_bpl * height);
@@ -912,11 +914,13 @@ guint8 *GUIGetRGBImage(
 	    return(NULL);
 	}
 
-	/* Begin copying the XImage data to the return data */
+	/* Begin copying the XImage data to the return data by the
+	 * XImage's depth
+	 */
 	if(ximg->depth == 8)
 	{
 	    gint xoffset_bytes, x, y;
-	    const gint  r_div = 7,
+	    const gint	r_div = 7,
 			g_div = 7,
 			b_div = 3;
 	    guint src_v;
@@ -947,8 +951,8 @@ guint8 *GUIGetRGBImage(
 		((src_v & 0x03) >> 0) * 0xff / b_div
 		    );
 		}
-	    }    
-	}    
+	    }
+	}
 	else if(ximg->depth == 15)
 	{
 	    gint xoffset_bytes, x, y;
@@ -1046,7 +1050,7 @@ guint8 *GUIGetRGBImage(
 
 		    src_ptr += src_bpp;
 		}
-	    }    
+	    }
 	}
 	else if(ximg->depth == 32)
 	{
@@ -1073,7 +1077,7 @@ guint8 *GUIGetRGBImage(
 
 		    src_ptr += src_bpp;
 		}
-	    }    
+	    }
 	}
 
 	XDestroyImage(ximg);
@@ -1098,10 +1102,10 @@ guint8 *GUIGetRGBImage(
 }
 
 /*
- *      Gets a RGB image buffer from the specified drawable with the 
- *      specified rectangular area.
+ *	Gets a RGB image buffer from the specified drawable with the 
+ *	specified rectangular area.
  *
- *      If rect is NULL then the entire drawable is obtained.
+ *	If rect is NULL then the entire drawable is obtained.
  */
 guint8 *GUIGetRGBAImage(
 	GdkDrawable *drawable,
@@ -1151,8 +1155,8 @@ guint8 *GUIGetRGBAImage(
 	/* Get an XImage from the GdkDrawable's Window */
 	ximg = XGetImage(
 	    xdpy, xwin,
-	    rect->x, rect->y,
-	    rect->width, rect->height,
+	    (int)rect->x, (int)rect->y,
+	    (unsigned int)rect->width, (unsigned int)rect->height,
 	    AllPlanes,
 	    ZPixmap
 	);
@@ -1169,7 +1173,7 @@ guint8 *GUIGetRGBAImage(
 	src_bpl = ximg->bytes_per_line;
 	src_data = (const guint8 *)ximg->data;
 
-	/* Allocate target RGBA image data */
+	/* Allocate the target RGBA image data */
 	tar_bpp = 4;
 	tar_bpl = width * tar_bpp;
 	tar_data = (guint8 *)g_malloc(tar_bpl * height);
@@ -1198,7 +1202,7 @@ guint8 *GUIGetRGBAImage(
 		src_ptr = (const guint8 *)(
 		    src_data + (y * src_bpl) + xoffset_bytes
 		);
-		tar_ptr = tar_data + (y * tar_bpl);  
+		tar_ptr = tar_data + (y * tar_bpl);
 
 		for(x = 0; x < width; x++)
 		{
@@ -1248,6 +1252,10 @@ guint8 *GUIGetRGBAImage(
 		    *tar_ptr++ = (guint8)(
 		((((guint)*src_ptr) & 0x001F) >> 0) * 0xff / b_div
 		    );
+/* Alpha channel may not be defined
+		    *tar_ptr++ = (((guint)*src_ptr) & (1 << 15)) ?
+			0xff : 0x00;
+ */
 		    *tar_ptr++ = 0xff;
 
 		    src_ptr++;
@@ -1289,7 +1297,7 @@ guint8 *GUIGetRGBAImage(
 
 		    src_ptr++;
 		}
-	    }    
+	    }
 	}	    
 	else if(ximg->depth == 24)
 	{                         
@@ -1341,12 +1349,15 @@ guint8 *GUIGetRGBAImage(
 		    *tar_ptr++ = src_ptr[2];
 		    *tar_ptr++ = src_ptr[1];
 		    *tar_ptr++ = src_ptr[0];
+/* Alpha channel may not be defined
+		    *tar_ptr++ = src_ptr[3];
+ */
 		    *tar_ptr++ = 0xff;
 
 		    src_ptr += src_bpp;
 		}
-	    }    
-	}    
+	    }
+	}
 
 	XDestroyImage(ximg);
 
