@@ -60,15 +60,15 @@ El uso: hedit <file> [options] [GUI_options]\n\
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
 #define PROG_HELP_MESG  "\
-L'usage: hedit <file> [options] [GUI_options]\n\
+Usage: hedit <file> [options] [GUI_options]\n\
 \n\
     <file> specifies the file to edit.\n\
 \n\
     [options] peut tre n'importe quel du suivre:\n\
 \n\
-        --address <address>     La position d'adresse de srie au dmarrage.\n\
-        --help                  Caractres (ceci) aide cran et sorties.\n\
-        --version               Caractres information de version et sorties.\n\
+        --address <address>     L'adresse initiale au dmarrage.\n\
+        --help                  Affiche (ceci) cran d'aide et sort.\n\
+        --version               Affiche information de version et sort.\n\
 \n\
     [GUI_options] peut tre n'importe quelle norme d'options  votre\n\
     GUI, consulter le manuel de votre GUI pour les options disponibles.\n\
