@@ -1146,7 +1146,7 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Salve"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Epargner"
+"Enregister"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Sparen"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1171,7 +1171,7 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Salve Como..."
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Epargner Comme..."
+"Enregister sous..."
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Auer Als..."
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1198,7 +1198,7 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 #if defined(PROG_LANGUAGE_SPANISH)
 "La Salida"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Sortie"
+"Quitter"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Ausgang"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1250,7 +1250,7 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Corte"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Coupure"
+"Couper"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Schnitt"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1276,7 +1276,7 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 #if defined(PROG_LANGUAGE_SPANISH)
 "La Copia"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Copie"
+"Copier"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Kopie"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1302,7 +1302,7 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 #if defined(PROG_LANGUAGE_SPANISH)
 "La Pasta"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Pte"
+"Coller"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Paste"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1329,7 +1329,7 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 #if defined(PROG_LANGUAGE_SPANISH)
 "La Adicin"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Insertion"
+"Inserer"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Einsatz"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1354,7 +1354,7 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Borre"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Effacer"
+"Couper"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Lschen"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1382,7 +1382,7 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Cambio Redacta El Modo"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Le Changement Edite Le Mode"
+"Mode Edition"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "nderung Redigiert Modus"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1409,7 +1409,7 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Hallazgo..."
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Dcouverte..."
+"Rechercher..."
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Fund..."
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1434,7 +1434,7 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Encuentre Luego"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Trouver Prochain"
+"Rechercher suivant"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Finden Sie Nchst"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1540,7 +1540,7 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Acerca De"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"De"
+"A propos"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Ungefhr"
 #elif defined(PROG_LANGUAGE_ITALIAN)
