@@ -859,8 +859,8 @@ void EDVHistoryListWinClear(edv_history_listwin_struct *lw)
 "Usted est seguro que usted quiere borrar todos acontecimientos\n\
 de la historia?\n",
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Confirmer Clair",
-"Etes-vous sr que vous voulez effacer tous vnements d'histoire?\n",
+"Confirmer Effacer",
+"Etes-vous sr que vous voulez effacer tous vnements de l'historique?\n",
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Besttigen Sie Klar",
 "Sind sie sicher sie alles geschichte ereignisse wollen lschen?\n",
@@ -1004,7 +1004,7 @@ void EDVHistoryListWinSaveAs(edv_history_listwin_struct *lw)
 "Salve",
 "Cancele",
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Epargner L'Histoire Comme",
+"Enregister l'historique sous",
 "Epargner",
 "Annuler",
 #elif defined(PROG_LANGUAGE_GERMAN)
@@ -1064,7 +1064,7 @@ void EDVHistoryListWinSaveAs(edv_history_listwin_struct *lw)
 \n\
     %s\n"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Superposer le fichier existant:\n\
+"Ecraser le fichier existant:\n\
 \n\
     %s\n"
 #elif defined(PROG_LANGUAGE_GERMAN)
@@ -1101,7 +1101,7 @@ void EDVHistoryListWinSaveAs(edv_history_listwin_struct *lw)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Confirme Escriba Para Reemplazar"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Confirmer Superposer"
+"Confirmer craser"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Besttigen Sie berschreibt"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1154,7 +1154,7 @@ void EDVHistoryListWinSaveAs(edv_history_listwin_struct *lw)
 \n\
     %s\n"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"L'histoire d'conomie classer:\n\
+"Enregister l'historique sous:\n\
 \n\
     %s\n"
 #elif defined(PROG_LANGUAGE_GERMAN)
@@ -1558,13 +1558,12 @@ void EDVHistoryListWinUpdateDisplay(
 	/* Create source icon and label? */
 	if(!STRISEMPTY(h_ptr->src_path))
 	{
-	    const gchar *path = h_ptr->src_path;
-	    gchar *name = EDVShortenPath(
-		EDVGetPathName(path), 25
-	    );
+	    gchar	*path = STRDUP(h_ptr->src_path),
+			*name = EDVShortenPath(
+		    (path != NULL) ? g_basename(path) : NULL, 25
+			);
 	    GdkBitmap *mask = NULL;
 	    GdkPixmap *pixmap = NULL;
-
 	    if((path != NULL) ? g_path_is_absolute(path) : FALSE)
 	    {
 		struct stat lstat_buf;
@@ -1659,17 +1658,17 @@ void EDVHistoryListWinUpdateDisplay(
 	    GTK_RC_STYLE_UNREF(rcstyle)
 
 	    g_free(name);
+	    g_free(path);
 	}
 	/* Create target icon and label? */
 	if(!STRISEMPTY(h_ptr->tar_path))
 	{
-	    const gchar *path = h_ptr->tar_path;
-	    gchar *name = EDVShortenPath(
-		EDVGetPathName(path), 25
-	    );
+	    gchar	*path = STRDUP(h_ptr->tar_path),
+			*name = EDVShortenPath(
+		(path != NULL) ? g_basename(path) : NULL, 25
+			);
 	    GdkBitmap *mask = NULL;
 	    GdkPixmap *pixmap = NULL;
-
 	    if((path != NULL) ? g_path_is_absolute(path) : FALSE)
 	    {
 		struct stat lstat_buf;
@@ -1768,6 +1767,7 @@ void EDVHistoryListWinUpdateDisplay(
 	    GTK_RC_STYLE_UNREF(rcstyle)
 
 	    g_free(name);
+	    g_free(path);
 	}
 
 
@@ -2224,10 +2224,9 @@ static void EDVHistoryListWinSetRow(
 	    /* Set column 1 as the Source */
 	    if(clist->columns > 1)
 	    {
-		const gchar	*path = h_ptr->src_path,
-				*name = EDVGetPathName(path);
-		gchar *s;
-
+		gchar	*s,
+			*path = STRDUP(h_ptr->src_path),
+			*name = (path != NULL) ? g_basename(path) : NULL;
 		mask = NULL;
 		pixmap = NULL;
 		if((path != NULL) ? g_path_is_absolute(path) : FALSE)
@@ -2312,22 +2311,21 @@ static void EDVHistoryListWinSetRow(
 		    gtk_clist_set_text(
 		        clist, row, 1, s
 		    );
-
 		g_free(s);
+		g_free(path);
 	    }
 	    /* Set column 2 as the Target */
 	    if(clist->columns > 2)
 	    {
-		const gchar	*path = h_ptr->tar_path,
-				*name = EDVGetPathName(path);
-		gchar *s;
-
+		gchar	*s,
+			*path = STRDUP(h_ptr->tar_path),
+			*name = (path != NULL) ? g_basename(path) : NULL;
 		mask = NULL;
 		pixmap = NULL;
 		if((path != NULL) ? g_path_is_absolute(path) : FALSE)
 		{
 		    struct stat lstat_buf;
-		    if(!lstat(path, &lstat_buf))
+		    if(!lstat((char *)path, &lstat_buf))
 		    {
 			edv_object_struct *o = EDVObjectNew();
 			EDVObjectSetPath(o, path);
@@ -2402,6 +2400,7 @@ static void EDVHistoryListWinSetRow(
 			clist, row, 2, s
 		    );
 		g_free(s);
+		g_free(path);
 	    }
 	    /* Set column 3 as the Status */
 	    if(clist->columns > 3)
@@ -3026,7 +3025,7 @@ edv_history_listwin_struct *EDVHistoryListWinNew(gpointer core_ptr)
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Hallazgo"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Dcouverte"
+"Recherche"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Fund"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -3075,10 +3074,10 @@ edv_history_listwin_struct *EDVHistoryListWinNew(gpointer core_ptr)
 #elif defined(PROG_LANGUAGE_FRENCH)
 	heading[0] = "Type";
 	heading[1] = "Source";
-	heading[2] = "Cible";
-	heading[3] = "Statut";
-	heading[4] = "Dbut De Temps";
-	heading[5] = "Fin De Temps";
+	heading[2] = "Destination";
+	heading[3] = "Etat";
+	heading[4] = "Heure Dbut";
+	heading[5] = "Heure Fin";
 #elif defined(PROG_LANGUAGE_GERMAN)
 	heading[0] = "Typ";
 	heading[1] = "Quelle";
@@ -3240,7 +3239,7 @@ edv_history_listwin_struct *EDVHistoryListWinNew(gpointer core_ptr)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Salve Como"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Epargner Comme"
+"Enregister sous:"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Auer Als"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -3279,7 +3278,7 @@ edv_history_listwin_struct *EDVHistoryListWinNew(gpointer core_ptr)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Claro"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Clair"
+"Effacer"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Klar"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -3348,7 +3347,7 @@ edv_history_listwin_struct *EDVHistoryListWinNew(gpointer core_ptr)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Cierre"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Fin"
+"Quitter"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Nah"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -3444,7 +3443,7 @@ edv_history_listwin_struct *EDVHistoryListWinNew(gpointer core_ptr)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Salve Como"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Epargner Comme"
+"Enregister sous"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Auer Als"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -3472,7 +3471,7 @@ edv_history_listwin_struct *EDVHistoryListWinNew(gpointer core_ptr)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Claro"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Clair"
+"Effacer"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Klar"
 #elif defined(PROG_LANGUAGE_ITALIAN)
