@@ -313,7 +313,7 @@ gint HViewOpenFile(hview_struct *hv, const gchar *path)
 		((hv->buf_len % hv->cells_per_row) ? hv->cell_height : 0)
 	    );
 	    adj->page_size = (gfloat)height;
-	    adj->step_increment = hv->cell_height;
+	    adj->step_increment = (gfloat)hv->cell_height;
 	    adj->page_increment = adj->page_size / 2.0f;
 
 	    adj->value = adj->lower;
@@ -413,7 +413,7 @@ gint HViewOpenData(hview_struct *hv, const guint8 *data, gint data_len)
 		((hv->buf_len % hv->cells_per_row) ? hv->cell_height : 0)
 	    );
 	    adj->page_size = (gfloat)height;
-	    adj->step_increment = hv->cell_height;
+	    adj->step_increment = (gfloat)hv->cell_height;
 	    adj->page_increment = adj->page_size / 2.0f;
 
 	    adj->value = adj->lower;
@@ -470,7 +470,7 @@ void HViewClear(hview_struct *hv)
 		((hv->buf_len % hv->cells_per_row) ? hv->cell_height : 0)
 	    );
 	    adj->page_size = (gfloat)height;
-	    adj->step_increment = hv->cell_height;
+	    adj->step_increment = (gfloat)hv->cell_height;
 	    adj->page_increment = adj->page_size / 2.0f;
 
 	    gtk_signal_emit_by_name(GTK_OBJECT(adj), "value_changed");
@@ -783,7 +783,6 @@ hview_struct *HViewNew(GtkWidget *parent)
 	hv->dragging_selection = FALSE;
 	hv->dragging_scroll = FALSE;
 	hv->scroll_toid = 0;
-	hv->draw_idle_id = 0;
 	hv->buf = NULL;
 	hv->buf_pos = 0;
 	hv->buf_len = 0;
@@ -1054,7 +1053,7 @@ hview_struct *HViewNew(GtkWidget *parent)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Corte"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Coupure"
+"Couper"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Schnitt"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1080,7 +1079,7 @@ hview_struct *HViewNew(GtkWidget *parent)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Copia"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Copie"
+"Copier"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Kopie"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1106,7 +1105,7 @@ hview_struct *HViewNew(GtkWidget *parent)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Pasta"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Pte"
+"Coller"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Paste"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1134,7 +1133,7 @@ hview_struct *HViewNew(GtkWidget *parent)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Adicin"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Insertion"
+"Insrer"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Einsatz"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1160,7 +1159,7 @@ hview_struct *HViewNew(GtkWidget *parent)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Borre"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Effacer"
+"Supprimer"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Lschen"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1207,7 +1206,7 @@ hview_struct *HViewNew(GtkWidget *parent)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Hex Redacte El Modo"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Hex Editer Le Mode"
+"Mode hexadcimal"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Hex Redigieren Sie Modus"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1233,7 +1232,7 @@ hview_struct *HViewNew(GtkWidget *parent)
 #if defined(PROG_LANGUAGE_SPANISH)
 "ASCII Redacte El Modo"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"ASCII Editer Le Mode"
+"Mode ASCII"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "ASCII Redigieren Sie Modus"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1467,22 +1466,14 @@ void HViewDraw(hview_struct *hv)
  */
 void HViewQueueDraw(hview_struct *hv)
 {
+	GtkWidget *w;
+
 	if(hv == NULL)
 	    return;
 
-	/* Already queued? */
-	if(hv->draw_idle_id > 0)
-	    return;
-
-	/* Queue redraw by adding a idle callback to the draw idle
-	 * callback
-	 */
-	hv->draw_idle_id = gtk_idle_add_priority(
-	    GTK_PRIORITY_REDRAW,
-	    HViewDrawIdleCB,
-	    hv
-	);
-
+	w = hv->view_da;
+	if(w != NULL)
+	    gtk_widget_queue_draw(w);
 }
 
 
@@ -1642,16 +1633,8 @@ void HViewDelete(hview_struct *hv)
 	if(hv == NULL)
 	    return;
 
-	if(hv->scroll_toid > 0)
-	{
-	    gtk_timeout_remove(hv->scroll_toid);
-	    hv->scroll_toid = 0;
-	}
-	if(hv->draw_idle_id > 0)
-	{
-	    gtk_timeout_remove(hv->draw_idle_id);
-	    hv->draw_idle_id = 0;
-	}
+	GTK_TIMEOUT_REMOVE(hv->scroll_toid);
+	hv->scroll_toid = 0;
 
 	colormap = hv->colormap;
 
