@@ -31,7 +31,6 @@ gint HViewButtonCB(
 gint HViewMotionCB(
 	GtkWidget *widget, GdkEventMotion *motion, gpointer data
 );
-gint HViewDrawIdleCB(gpointer data);
 void HViewValueChangedCB(GtkAdjustment *adj, gpointer data);
 
 void HViewInsertCB(GtkWidget *w, gpointer data);
@@ -176,7 +175,7 @@ gint HViewConfigureCB(
 		((hv->buf_len % hv->cells_per_row) ? hv->cell_height : 0)
 	    );
 	    adj->page_size = (gfloat)height;
-	    adj->step_increment = hv->cell_height;
+	    adj->step_increment = (gfloat)hv->cell_height;
 	    adj->page_increment = adj->page_size / 2.0f;
 	    gtk_signal_emit_by_name(GTK_OBJECT(adj), "changed");
 
@@ -814,8 +813,8 @@ gint HViewKeyCB(
 		}
 		else if((adj != NULL) && (hv->cell_height > 0))
 		{
-		    gint last_pos = hv->buf_pos;
-		    gint rows_visible = adj->page_size / hv->cell_height;
+		    const gint	last_pos = hv->buf_pos,
+				rows_visible = (gint)(adj->page_size / hv->cell_height);
 
 		    hv->buf_pos -= (rows_visible / 2) * hv->cells_per_row;
 		    if(hv->buf_pos < 0)
@@ -860,8 +859,8 @@ gint HViewKeyCB(
 		}
 		else if((adj != NULL) && (hv->cell_height > 0))
 		{   
-		    gint last_pos = hv->buf_pos;
-		    gint rows_visible = adj->page_size / hv->cell_height;
+		    const gint	last_pos = hv->buf_pos,
+				rows_visible = (gint)(adj->page_size / hv->cell_height);
 		    hv->buf_pos += (rows_visible / 2) * hv->cells_per_row;
 		    if(hv->buf_pos >= hv->buf_len)
 			hv->buf_pos = hv->buf_len - 1;
@@ -1132,8 +1131,8 @@ gint HViewButtonCB(
 		GtkWidget *w = hv->view_da;
 
 		hv->dragging_scroll = TRUE;
-		hv->last_motion_x = button->x;
-		hv->last_motion_y = button->y;
+		hv->last_motion_x = (gint)button->x;
+		hv->last_motion_y = (gint)button->y;
 		if(w != NULL)
 		    gdk_window_set_cursor(w->window, hv->translate_cur);
 	    }
@@ -1156,7 +1155,7 @@ gint HViewButtonCB(
 
 		hv->buf_sel_start = hv->buf_pos =
 		    HViewPositionXYToBuffer(
-		    hv, button->x, button->y
+		    hv, (gint)button->x, (gint)button->y
 		);
 		hv->buf_sel_end = -1;
 
@@ -1176,7 +1175,7 @@ gint HViewButtonCB(
 		if(hv->buf_sel_end > -1)
 		{
 		    hv->buf_pos = HViewPositionXYToBuffer(
-			hv, button->x, button->y
+			hv, (gint)button->x, (gint)button->y
 		    );
 		}
 		else
@@ -1253,7 +1252,7 @@ gint HViewMotionCB(
 	    )
 		HViewScrollTo(
 		    hv, hv->buf_pos,
-		    (y < (height / 2)) ? 0.0 : 1.0
+		    (gfloat)((y < (height / 2)) ? 0.0 : 1.0)
 		);
 
 
@@ -1315,23 +1314,6 @@ gint HViewMotionCB(
 	return(TRUE);
 }
 
-/*
- *	Hex View draw idle callback.
- */
-gint HViewDrawIdleCB(gpointer data)
-{ 
-	hview_struct *hv = HVIEW(data);
-	if(hv == NULL)                 
-	    return(FALSE);
-
-	HViewDraw(hv);
-
-	/* Reset draw idle to indicate it has been handled */
-	hv->draw_idle_id = 0;
-
-	return(FALSE);
-}
-
 /*
  *	Hex View GtkAdjustment "value_changed" callback.
  */
@@ -1403,7 +1385,7 @@ void HViewInsertCB(GtkWidget *w, gpointer data)
 		((hv->buf_len % hv->cells_per_row) ? hv->cell_height : 0)
 	    );
 	    adj->page_size = (gfloat)height;
-	    adj->step_increment = hv->cell_height;
+	    adj->step_increment = (gfloat)hv->cell_height;
 	    adj->page_increment = adj->page_size / 2.0f;
 
 	    gtk_signal_emit_by_name(GTK_OBJECT(adj), "changed");
@@ -1524,7 +1506,7 @@ void HViewDeleteCB(GtkWidget *w, gpointer data)
 		((hv->buf_len % hv->cells_per_row) ? hv->cell_height : 0)
 	    );
 	    adj->page_size = (gfloat)height;
-	    adj->step_increment = hv->cell_height;
+	    adj->step_increment = (gfloat)hv->cell_height;
 	    adj->page_increment = adj->page_size / 2.0f;
 
 	    if((adj->value + adj->page_size) > adj->upper)
@@ -1681,7 +1663,7 @@ void HViewPasteCB(GtkWidget *w, gpointer data)
 		((hv->buf_len % hv->cells_per_row) ? hv->cell_height : 0)
 	    );
 	    adj->page_size = (gfloat)height;
-	    adj->step_increment = hv->cell_height;
+	    adj->step_increment = (gfloat)hv->cell_height;
 	    adj->page_increment = adj->page_size / 2.0f;
 
 	    gtk_signal_emit_by_name(GTK_OBJECT(adj), "changed");
