@@ -274,18 +274,18 @@ struct _edv_imbr_struct {
 			*help_about_mi;
 
         /* Tool Bar */
-        toolbar_struct	*toolbar;
+        toolbar_struct	*tool_bar;
 
         /* Mount Bar */
-        edv_mountbar_struct	*mountbar;
+        edv_mountbar_struct	*mount_bar;
 
         /* Find Bar */
-        edv_findbar_struct	*findbar;
+        edv_findbar_struct	*find_bar;
 
-	/* Thumbs list */
+	/* Thumbs List */
 	tlist_struct	*tlist;
 
-	/* Image viewer */
+	/* Image Viewer */
 	imgview_struct	*imgview;
 
 
@@ -393,8 +393,8 @@ extern cfg_accelkey_list_struct *EDVImbrAccelkeysListNewDefault(void);
 extern edv_imbr_struct *EDVImbrNew(gpointer core_ptr);
 extern void EDVImbrSyncData(edv_imbr_struct *imbr);
 extern void EDVImbrUpdateMenus(edv_imbr_struct *imbr);
-extern void EDVImbrSetBusy(edv_imbr_struct *imbr, gboolean is_busy);
-extern void EDVImbrSetPassiveBusy(edv_imbr_struct *imbr, gboolean is_busy);
+extern void EDVImbrSetBusy(edv_imbr_struct *imbr, gboolean busy);
+extern void EDVImbrSetPassiveBusy(edv_imbr_struct *imbr, gboolean busy);
 extern gboolean EDVImbrIsMapped(edv_imbr_struct *imbr);
 extern void EDVImbrMap(edv_imbr_struct *imbr);
 extern void EDVImbrUnmap(edv_imbr_struct *imbr);
