@@ -79,7 +79,7 @@ void EDVImbrObjectRemovedNotifyCB(
 
 void EDVImbrMountNotifyCB(
 	edv_imbr_struct *imbr,
-	gint dev_num, edv_device_struct *dev_ptr,
+	gint dev_num, edv_device_struct *dev,
 	gboolean is_mounted
 );
 
@@ -94,11 +94,11 @@ void EDVImbrReconfiguredNotifyCB(edv_imbr_struct *imbr);
 
 void EDVImbrMimeTypeAddedCB(
 	edv_imbr_struct *imbr,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 );
 void EDVImbrMimeTypeModifiedCB(
 	edv_imbr_struct *imbr,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 );
 void EDVImbrMimeTypeRemovedCB(
 	edv_imbr_struct *imbr, gint mt_num
@@ -106,11 +106,11 @@ void EDVImbrMimeTypeRemovedCB(
 
 void EDVImbrDeviceAddedCB(
 	edv_imbr_struct *imbr,
-	gint dev_num, edv_device_struct *dev_ptr
+	gint dev_num, edv_device_struct *dev
 );
 void EDVImbrDeviceModifiedCB(
 	edv_imbr_struct *imbr,
-	gint dev_num, edv_device_struct *dev_ptr
+	gint dev_num, edv_device_struct *dev
 );
 void EDVImbrDeviceRemovedCB(
 	edv_imbr_struct *imbr, gint dev_num
@@ -242,8 +242,9 @@ gint EDVImbrKeyEventCB(
 		 * item who's name starts with the letter of the key
 		 * that was pressed
 		 */
-		if(isalnum((char)keyval) && is_press &&
-		   ((state == 0x00000000) || (state == GDK_SHIFT_MASK))
+		if(isalnum((int)keyval) && is_press &&
+                   !(state & GDK_CONTROL_MASK) &&
+                   !(state & GDK_SHIFT_MASK)    
 		)
 		{
 		    TListFreeze(tlist);
@@ -494,15 +495,11 @@ void EDVImbrTListSelectCB(
 	    /* Change in selection? */
 	    if(imbr->tlist_selected_thumb != thumb_num)
 	    {
-		const gint total_selected = g_list_length(tlist->selection);
+		const gint nselected = g_list_length(tlist->selection);
 		edv_object_struct *obj = EDV_OBJECT(
 		    TListGetThumbData(tlist, thumb_num)
 		);
 
-		EDVImbrSetBusy(imbr, TRUE);
-		GUIBlockInput(imbr->toplevel, TRUE);
-		imbr->processing = TRUE;
-
 		/* Scroll if selected thumb is not visible */
 		if(TListIsThumbVisible(tlist, thumb_num) !=
 		    GTK_VISIBILITY_FULL
@@ -538,7 +535,7 @@ void EDVImbrTListSelectCB(
 		    /* If only one thumb is selected then display it
 		     * on the Image Browser's ImgView
 		     */
-		    if((total_selected == 1) &&
+		    if((nselected == 1) &&
 		       (thumb != NULL)
 		    )
 		    {
@@ -565,11 +562,20 @@ void EDVImbrTListSelectCB(
 				}
 			    }
 			}
+
+			EDVImbrSetBusy(imbr, TRUE);
+			GUIBlockInput(imbr->toplevel, TRUE);
+			imbr->processing = TRUE;  
+
 			EDVImbrImgViewLoad(
 			    imbr,
 			    full_path,
 			    need_reload_thumb ? thumb_num : -1
 			);
+
+			imbr->processing = FALSE;
+			GUIBlockInput(imbr->toplevel, FALSE);
+			EDVImbrSetBusy(imbr, FALSE);
 		    }
 
 		    /* Get object type string and size string */
@@ -615,10 +621,10 @@ void EDVImbrTListSelectCB(
 		    }
 
 		    /* Set status bar message */
-		    if(total_selected > 1)
+		    if(nselected > 1)
 			buf = g_strdup_printf(
-			    "%i objects selected",
-			    total_selected
+			    "%s objects selected",
+			    EDVGetObjectSizeStr(core_ptr, nselected)
 			);
 		    else if(!strcmp(obj->name, ".."))
 			buf = g_strdup_printf(
@@ -637,10 +643,6 @@ void EDVImbrTListSelectCB(
 		    g_free(size_str);
 		}
 
-		imbr->processing = FALSE;
-		GUIBlockInput(imbr->toplevel, FALSE);
-		EDVImbrSetBusy(imbr, FALSE);
-
 		EDVImbrUpdateMenus(imbr);
 	    }
 	}
@@ -668,8 +670,8 @@ void EDVImbrTListUnselectCB(
 
 	if(tlist == imbr->tlist)
 	{
-	    /* Get last selected thumb (if any) */
-	    const gint total_selected = g_list_length(tlist->selection);
+	    gchar *buf;
+	    const gint nselected = g_list_length(tlist->selection);
 	    GList *glist = tlist->selection_end;
 	    const gint thumb_num = (glist != NULL) ? (gint)glist->data : -1;
 	    if(thumb_num > -1)
@@ -677,7 +679,7 @@ void EDVImbrTListUnselectCB(
 		/* Last selected thumb changed? */
 		if(imbr->tlist_selected_thumb != thumb_num)
 		{
-		    const edv_object_struct *obj = EDV_OBJECT(
+		    edv_object_struct *obj = EDV_OBJECT(
 			TListGetThumbData(tlist, thumb_num)
 		    );
 		    if(obj != NULL)
@@ -692,11 +694,10 @@ void EDVImbrTListUnselectCB(
 		    }
 		}
 
-		if(total_selected == 1)
+		/* Only one thumb remained selected? */
+		if(nselected == 1)
 		{
-
 /* TODO */
-
 		}
 	    }
 	    else
@@ -706,6 +707,20 @@ void EDVImbrTListUnselectCB(
 		imbr->selected_dev_num = -1;
 	    }
 
+	    /* Update status bar message */
+	    if(nselected > 0)
+		buf = g_strdup_printf(
+		    "%s object%s selected",
+		    EDVGetObjectSizeStr(core_ptr, nselected),
+		    (nselected == 1) ? "" : "s"
+		);
+	    else
+		buf = STRDUP("No objects selected");
+	    EDVStatusBarMessage(
+		imbr->status_bar, buf, FALSE
+	    );
+	    g_free(buf);
+
 	    EDVImbrUpdateMenus(imbr);
 	}
 }
@@ -876,9 +891,7 @@ g_print(
 
 
 /*
- *	Called whenever the global write protect has changed.
- *
- *	The new state is given as state.
+ *	Write protect changed callback.
  */
 void EDVImbrWriteProtectChangedCB(
 	edv_imbr_struct *imbr, gboolean state
@@ -894,7 +907,7 @@ void EDVImbrWriteProtectChangedCB(
 }
 
 /*
- *	Called whenever a disk object has been added.
+ *	Object added callback.
  */
 void EDVImbrObjectAddedNotifyCB(
 	edv_imbr_struct *imbr, const gchar *path,
@@ -907,18 +920,22 @@ void EDVImbrObjectAddedNotifyCB(
 	if(imbr->processing)
 	    return;
 
+	/* Thumbs List */
 	EDVImbrTListObjectAddedNotify(
 	    imbr, path, lstat_buf
 	);
 
+	/* Mount Bar */
+	EDVMountBarUpdateMenus(imbr->mount_bar);
+
 	/* Need to update menus because a new loading process may be
-	 * queued.
+	 * queued
 	 */
 	EDVImbrUpdateMenus(imbr);
 }
 
 /*
- *      Called whenever a disk object has had its properties modified.
+ *	Object modified callback.
  */
 void EDVImbrObjectModifiedNotifyCB(
 	edv_imbr_struct *imbr, const gchar *path,
@@ -932,24 +949,23 @@ void EDVImbrObjectModifiedNotifyCB(
 	if(imbr->processing)
 	    return;
 
-	/* Check current location first, if the old path matches the
-	 * current location then the current location needs to be updated
-	 * to reflect the new path before notifying the contents clist.
+	/* Check current location first, if the old path matches
+	 * the current location then the current location needs to be
+	 * updated  to reflect the new path before notifying the
+	 * Thumbs List
 	 */
 	if(!STRISEMPTY(path))
 	{
-	    const gchar *cur_location = EDVImbrCurrentLocation(imbr);
+	    gchar *cur_loc = STRDUP(EDVImbrCurrentLocation(imbr));
 
 	    if(new_path == NULL)
 		new_path = path;
 
-	    /* Check if the old path matches the current location, if it
-	     * does then the current location needs to be updated to the
-	     * new path
+	    /* Check if the old path matches the current location, if
+	     * it does then the current location needs to be updated to
+	     * the new path
 	     */
-	    if((cur_location != NULL) ?
-		!strcmp(cur_location, path) : FALSE
-	    )
+	    if((cur_loc != NULL) ? !strcmp(cur_loc, path) : FALSE)
 	    {
 		/* Old path matches current location, change values
 		 * reflecting the current location to the value of
@@ -959,17 +975,23 @@ void EDVImbrObjectModifiedNotifyCB(
 		EDVImbrSetLocation(imbr, new_path, FALSE);
 		EDVImbrUpdateLocationIcon(imbr, new_path);
 	    }
+
+	    g_free(cur_loc);
 	}
 
+	/* Thumbs List */
 	EDVImbrTListObjectModifiedNotify(
 	    imbr, path, new_path, lstat_buf
 	);
 
+	/* Mount Bar */
+	EDVMountBarUpdateMenus(imbr->mount_bar);
+
 /*	EDVImbrUpdateMenus(imbr); */
 }
 
 /*
- *	Called whenever a disk object has been removed.
+ *	Object removed callback.
  */
 void EDVImbrObjectRemovedNotifyCB(
 	edv_imbr_struct *imbr, const gchar *path
@@ -981,31 +1003,25 @@ void EDVImbrObjectRemovedNotifyCB(
 	if(imbr->processing)
 	    return;
 
+	/* Thumbs List */
 	EDVImbrTListObjectRemovedNotify(imbr, path);
 
-	/* Check if the path that was removed is the current location
-	 * (after letting contents clist and directory ctree check on it
-	 * first), if the path that was removed is the location then
-	 * set the current location to be the parent of the path that
-	 * was removed
+	/* Mount Bar */
+	EDVMountBarUpdateMenus(imbr->mount_bar);
+
+	/* Check if the path that was removed is the current location,
+	 * if it is then set the current location to be the parent of
+	 * the path that was removed
 	 */
 	if(!STRISEMPTY(path))
 	{
-	    const gchar *cur_location = EDVImbrCurrentLocation(imbr);
+	    gchar *cur_loc = STRDUP(EDVImbrCurrentLocation(imbr));
 
-	    /* Check if the removed object path matches the current
-	     * location. If it matches then the current location needs to
-	     * be updated to reflect that
-	     */
-	    if((cur_location != NULL) ?
-		!strcmp(cur_location, path) : FALSE
-	    )
+	    /* Check if the removed object is the current location */
+	    if((cur_loc != NULL) ? !strcmp(cur_loc, path) : FALSE)
 	    {
-		/* Removed object path matches the current location, so
-		 * technically the current location needs to be cleared
-		 * however we'll instead just change the current location
-		 * value to reflect the value of the parent path of the
-		 * removed object path
+		/* Current location has been removed, change the
+		 * current location to the parent
 		 */
 		gchar *parent_path = g_dirname(path);
 		if(parent_path != NULL)
@@ -1016,6 +1032,8 @@ void EDVImbrObjectRemovedNotifyCB(
 		    g_free(parent_path);
 		}
 	    }
+
+	    g_free(cur_loc);
 	}
 
 /*	EDVImbrUpdateMenus(imbr); */
@@ -1023,28 +1041,53 @@ void EDVImbrObjectRemovedNotifyCB(
 
 
 /*
- *      Called whenever a device has been mounted or unmounted.
+ *	Device mount/unmount callback.
  */
 void EDVImbrMountNotifyCB(
 	edv_imbr_struct *imbr,
-	gint dev_num, edv_device_struct *dev_ptr,
+	gint dev_num, edv_device_struct *dev,
 	gboolean is_mounted
 )
 {
+	gchar *cur_loc, *mount_path;
+	GtkWidget *toplevel;
+
 	if(imbr == NULL)
 	    return;
 
 	if(imbr->processing)
 	    return;
 
-	EDVImbrTListMountNotify(imbr, dev_ptr, is_mounted);
+	toplevel = imbr->toplevel;
 
+	mount_path = STRDUP(dev->mount_path);
+
+	/* Thumbs List */
+	EDVImbrTListMountNotify(imbr, dev, is_mounted);
+
+	/* Check if the current location is within the mount path */ 
+	cur_loc = STRDUP(EDVImbrCurrentLocation(imbr));
+	if((cur_loc != NULL) ? strpfx(cur_loc, mount_path) : FALSE)
+	{
+	    /* Switch to the mount location, reget listing, and
+	     * restart the loading procedure
+	     */
+	    EDVImbrSetBusy(imbr, TRUE);
+	    GUIBlockInput(toplevel, TRUE);
+	    EDVImbrSelectPath(imbr, mount_path);
+	    GUIBlockInput(toplevel, FALSE);
+	    EDVImbrSetBusy(imbr, FALSE);
+	}
+  
 	EDVImbrUpdateMenus(imbr);
+
+	g_free(mount_path);
+	g_free(cur_loc);
 }
 
 
 /*
- *	Called whenever an object has been added to the recycle bin.
+ *	Recycled object added callback.
  */
 void EDVImbrRecycledObjectAddedNotifyCB(
 	edv_imbr_struct *imbr, guint index
@@ -1060,17 +1103,16 @@ void EDVImbrRecycledObjectAddedNotifyCB(
 	if(core_ptr == NULL)
 	    return;
 
-
 	/* There is not much interest when a recycled object has been
 	 * added or removed. Only the menus need to be updated if there
-	 * is a change in the number of recycled objects.
+	 * is a change in the number of recycled objects
 	 */
 	if(core_ptr->last_recbin_items != imbr->last_recbin_items)
 	    EDVImbrUpdateMenus(imbr);
 }
 
 /*
- *	Called whenever an object has been removed from the recycle bin.
+ *	Recycled object removed callback.
  */
 void EDVImbrRecycledObjectRemovedNotifyCB(
 	edv_imbr_struct *imbr, guint index
@@ -1078,7 +1120,6 @@ void EDVImbrRecycledObjectRemovedNotifyCB(
 {
 	edv_core_struct *core_ptr;
 
-
 	if(imbr == NULL)
 	    return;
 
@@ -1086,10 +1127,9 @@ void EDVImbrRecycledObjectRemovedNotifyCB(
 	if(core_ptr == NULL)
 	    return;
 
-
 	/* There is not much interest when a recycled object has been
 	 * added or removed. Only the menus need to be updated if there
-	 * is a change in the number of recycled objects.
+	 * is a change in the number of recycled objects
 	 */
 	if(core_ptr->last_recbin_items != imbr->last_recbin_items)
 	    EDVImbrUpdateMenus(imbr);
@@ -1097,11 +1137,11 @@ void EDVImbrRecycledObjectRemovedNotifyCB(
 
 
 /*
- *	Reconfigured notify callback.
+ *	Reconfigured callback.
  */
 void EDVImbrReconfiguredNotifyCB(edv_imbr_struct *imbr)
 {
-	gchar *cur_path;
+	gchar *cur_loc;
 	GtkRcStyle *standard_rcstyle, *lists_rcstyle;
 	GtkWidget *w;
 	const cfg_item_struct *cfg_list;
@@ -1134,13 +1174,13 @@ void EDVImbrReconfiguredNotifyCB(edv_imbr_struct *imbr)
 
 
 	/* Get copy of current location path */
-	cur_path = STRDUP(EDVImbrCurrentLocation(imbr));
+	cur_loc = STRDUP(EDVImbrCurrentLocation(imbr));
 
 
 	/* Begin updating */
 
 	/* Update Title */
-	EDVImbrSetTitle(imbr, cur_path);
+	EDVImbrSetTitle(imbr, cur_loc);
 
 	/* Recreate Accelkey Labels */
 	EDVImbrAccelkeysRegenerate(imbr);
@@ -1321,35 +1361,34 @@ void EDVImbrReconfiguredNotifyCB(edv_imbr_struct *imbr)
 
 
 	/* Delete copy of current location path */
-	g_free(cur_path);
+	g_free(cur_loc);
 }
 
 
 /*
- *      Called whenever a MIME Type has been added to the core
- *      structure's list of MIME Types.
+ *	MIME Type added callback.
  */
 void EDVImbrMimeTypeAddedCB(
 	edv_imbr_struct *imbr,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 )
 {
-	/* Treat a MIME Type added the same as it would be for a MIME Type
-	 * modified, forward signal to the MIME Type modified callback.
+	/* Treat a MIME Type added the same as it would be for a MIME
+	 * Type modified, forward signal to the MIME Type modified
+	 * callback
 	 */
-	EDVImbrMimeTypeModifiedCB(imbr, mt_num, mt_ptr);
+	EDVImbrMimeTypeModifiedCB(imbr, mt_num, mt);
 }
 
 /*
- *      Called whenever a MIME Type has been modified on the core
- *      structure's list of MIME Types.
+ *	MIME Type modified callback.
  */
 void EDVImbrMimeTypeModifiedCB(
 	edv_imbr_struct *imbr,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 )
 {
-	gchar *cur_path;
+	gchar *cur_loc;
 	tlist_struct *tlist;
 	edv_core_struct *core_ptr;
 
@@ -1365,25 +1404,24 @@ void EDVImbrMimeTypeModifiedCB(
 	    return;
 
 	/* Get current location */
-	cur_path = STRDUP(EDVImbrCurrentLocation(imbr));
+	cur_loc = STRDUP(EDVImbrCurrentLocation(imbr));
 
 	/* Realize listing */
 	TListFreeze(tlist);
 	EDVImbrTListRealizeListing(imbr);
 	TListThaw(tlist);
 
-	g_free(cur_path);
+	g_free(cur_loc);
 }
 
 /*
- *      Called whenever a MIME Type has been removed from the core
- *      structure's list of MIME Types.
+ *	MIME Type removed callback.
  */
 void EDVImbrMimeTypeRemovedCB(
 	edv_imbr_struct *imbr, gint mt_num
 )
 {
-	gchar *cur_path;
+	gchar *cur_loc;
 	tlist_struct *tlist;
 	edv_core_struct *core_ptr;
 
@@ -1399,42 +1437,40 @@ void EDVImbrMimeTypeRemovedCB(
 	    return;
 
 	/* Get current location */
-	cur_path = STRDUP(EDVImbrCurrentLocation(imbr));
+	cur_loc = STRDUP(EDVImbrCurrentLocation(imbr));
 
 	/* Realize listing */
 	TListFreeze(tlist);
 	EDVImbrTListRealizeListing(imbr);
 	TListThaw(tlist);
 
-	g_free(cur_path);
+	g_free(cur_loc);
 }
 
 
 /*
- *      Called whenever a device has been added to the core
- *      structure's list of devices.
+ *	Device added callback.
  */
 void EDVImbrDeviceAddedCB(
 	edv_imbr_struct *imbr,
-	gint dev_num, edv_device_struct *dev_ptr
+	gint dev_num, edv_device_struct *dev
 )
 {
 	/* Treat a device added the same as it would be for a device
-	 * modified, forward signal to the device modified callback.
+	 * modified, forward signal to the device modified callback
 	 */
-	EDVImbrDeviceModifiedCB(imbr, dev_num, dev_ptr);
+	EDVImbrDeviceModifiedCB(imbr, dev_num, dev);
 }
 
 /*
- *	Called whenever a device has been modified on the core
- *	structure's list of devices.
+ *	Device modified callback.
  */
 void EDVImbrDeviceModifiedCB(
 	edv_imbr_struct *imbr,
-	gint dev_num, edv_device_struct *dev_ptr
+	gint dev_num, edv_device_struct *dev
 )
 {
-	gchar *cur_path;
+	gchar *cur_loc;
 	tlist_struct *tlist;
 	edv_core_struct *core_ptr;
 
@@ -1450,7 +1486,7 @@ void EDVImbrDeviceModifiedCB(
 	    return;
 
 	/* Get current location */
-	cur_path = STRDUP(EDVImbrCurrentLocation(imbr));
+	cur_loc = STRDUP(EDVImbrCurrentLocation(imbr));
 
 	/* Realize listing */
 	TListFreeze(tlist);
@@ -1460,18 +1496,17 @@ void EDVImbrDeviceModifiedCB(
 	/* Update menus */
 	EDVImbrUpdateMenus(imbr);
 
-	g_free(cur_path);
+	g_free(cur_loc);
 }
 
 /*
- *      Called whenever a device has been removed from the core
- *      structure's list of devices.
+ *	Device removed callback.
  */
 void EDVImbrDeviceRemovedCB(
 	edv_imbr_struct *imbr, gint dev_num
 )
 {
-	gchar *cur_path;
+	gchar *cur_loc;
 	tlist_struct *tlist;
 	edv_mountbar_struct *mb;
 	edv_core_struct *core_ptr;
@@ -1488,12 +1523,12 @@ void EDVImbrDeviceRemovedCB(
 	    return;
 
 	/* Get current location */
-	cur_path = STRDUP(EDVImbrCurrentLocation(imbr));
+	cur_loc = STRDUP(EDVImbrCurrentLocation(imbr));
 
 	/* Check if the Mount Bar is currently referencing this device,
 	 * if it is then its selected device needs to be set to -1
 	 */
-	mb = imbr->mountbar;
+	mb = imbr->mount_bar;
 	if(mb != NULL)
 	{
 	    if(mb->selected_dev_num == dev_num)
@@ -1512,5 +1547,5 @@ void EDVImbrDeviceRemovedCB(
 	/* Update menus */
 	EDVImbrUpdateMenus(imbr);
 
-	g_free(cur_path);
+	g_free(cur_loc);
 }
