@@ -66,9 +66,9 @@ void EDVImbrImgViewLoad(
 {
 	gboolean need_zoom_to_fit = FALSE;
 	const gchar *name;
-	gint width, height, bpl;
-	guint8 *data_rgba;
-	GdkVisual *vis;
+	gint width, height, bpl, nframes;
+	const guint8 *first_rgba = NULL;
+	GList *rgba_list, *delay_list;
 	GdkWindow *window;
 	GtkWidget *w;
 	const cfg_item_struct *cfg_list;
@@ -85,7 +85,7 @@ void EDVImbrImgViewLoad(
 	if((core_ptr == NULL) || STRISEMPTY(path))
 	    return;
 
-	name = EDVGetPathName(path);
+	name = g_basename(path);
 	cfg_list = core_ptr->cfg_list;
 
 	/* Is the file's extension not supported by Imlib? */
@@ -98,23 +98,31 @@ void EDVImbrImgViewLoad(
 	/* Get the ImgView's view widget and window */
 	w = (GtkWidget *)ImgViewGetViewWidget(iv);
 	window = (w != NULL) ? w->window : NULL;
-	vis = gdk_window_get_visual(window);
 
 	/* Load the image data from the specified file */
-	data_rgba = EDVImbrTListLoadImageRGBA(
+	rgba_list = EDVImbrTListLoadImageRGBA(
 	    NULL, path,
-	    &width, &height, &bpl,
+	    &width, &height, &bpl, &nframes, &delay_list,
 	    FALSE,		/* Do not resize for thumbs list */
 	    FALSE,		/* Allow enlarge */
 	    window
 	);
-	if(data_rgba == NULL)
+	if(rgba_list == NULL)
 	{
 	    /* Failed to load image */
+	    g_list_free(delay_list);
 	    EDVImbrSetBusy(imbr, FALSE);
 	    return;
 	}
 
+	/* Record the first image data, the RGBA image datas in the
+	 * list will be transfered to the ImgView image, however
+	 * since the ImgView image will not be deleted, the RGBA image
+	 * datas will still be valid until the ImgView image is set
+	 * to the ImgView
+	 */
+	first_rgba = (guint8 *)rgba_list->data;
+
 	/* Check if the image size is larger in any one dimension than
 	 * the ImgView's view widget to determine if we need to zoom
 	 * to fit
@@ -122,49 +130,79 @@ void EDVImbrImgViewLoad(
 	if(w != NULL)
 	{
 	    if((width > w->allocation.width) ||
-               (height > w->allocation.height)
+	       (height > w->allocation.height)
 	    )
 		need_zoom_to_fit = TRUE;
 	}
 
-	/* Create an ImgView image "manually" */
-	img = IMGVIEW_IMAGE(g_malloc0(sizeof(imgview_image_struct)));
-	img->visual_depth = (vis != NULL) ? vis->depth : -1;
-	img->width = width;
-	img->height = height;
-	img->bpp = 4;
-	img->bpl = bpl;
-	img->mem = data_rgba;
+	/* Create a new ImgView image */
+	img = ImgViewImageNew(width, height, 4, bpl);
+	if(img != NULL)
+	{
+	    /* Transfer each RGBA image data to the new ImgView image
+	     * and set the RGBA image data as NULL on the RGBA image
+	     * list
+	     */
+	    guint8 *rgba;
+	    gulong delay;
+	    GList	*glist_rgba = rgba_list,
+			*glist_delay = delay_list;
+	    while(glist_rgba != NULL)
+	    {
+		rgba = (guint8 *)glist_rgba->data;
+		delay = (gulong)((glist_delay != NULL) ?
+		    (guint)glist_delay->data : 0
+		);
+		ImgViewImageAppendFrame(img, rgba, delay);
 
-        /* Update the Thumbs List thumb? */
-        if(thumb_num > -1)
-        {
+		glist_rgba->data = NULL;	/* Mark transfered */
+
+		glist_rgba = g_list_next(glist_rgba);
+		glist_delay = g_list_next(glist_delay);
+	    }
+	}
+
+	/* Update the Thumbs List thumb? */
+	if(thumb_num > -1)
+	{
 	    const gboolean no_enlarge = CFGItemListGetValueI(
-                cfg_list, EDV_CFG_PARM_IMBR_THUMB_NO_ENLARGE
-            );
+		cfg_list, EDV_CFG_PARM_IMBR_THUMB_NO_ENLARGE
+	    );
 	    tlist_struct *tlist = imbr->tlist;
 	    if(tlist != NULL)
 	    {
-                TListSetRGBA(
+		TListSetRGBA(
 		    tlist, thumb_num,
 		    width, height, bpl,
 		    GDK_RGB_DITHER_NORMAL,
-		    data_rgba,
+		    first_rgba,		/* First RGBA image data, is
+					 * still valid */
 		    no_enlarge
 		);
 		TListSetLoadState(
 		    tlist, thumb_num, TLIST_LOAD_STATE_LOADED
 		);
 	    }
-        }
+	}
 
-	/* Set the ImgView image to the ImgView */
+	/* Delete loaded images */
+	g_list_foreach(rgba_list, (GFunc)g_free, NULL);
+	g_list_free(rgba_list);
+	rgba_list = NULL;
+	first_rgba = NULL;
+	g_list_free(delay_list);
+	delay_list = NULL;
+
+	/* Set/transfer the ImgView image to the ImgView */
 	if(need_zoom_to_fit)
 	    ImgViewSetImageToFit(iv, img);
 	else
 	    ImgViewSetImage(iv, img);
 	img = NULL;	/* Do not reference again after the above call */
 
+	/* Set the ImgView to play if there are multiple frames */
+	if(nframes > 1)
+	    ImgViewPlay(iv);
 
 	EDVImbrSetBusy(imbr, FALSE);
 }
