@@ -1,5 +1,5 @@
 /*
-                  Endeavour Image Browser Image Viewer
+		  Endeavour Image Browser Image Viewer
  */
 
 #ifndef IMBRIMGVIEW_H
@@ -10,7 +10,9 @@
 
 
 extern void EDVImbrImgViewClear(edv_imbr_struct *imbr);
-extern void EDVImbrImgViewLoad(edv_imbr_struct *imbr, const gchar *path);
+extern void EDVImbrImgViewLoad(
+	edv_imbr_struct *imbr, const gchar *path, gint thumb_num
+);
 
 
 #endif	/* IMBRIMGVIEW_H */
