@@ -40,10 +40,6 @@
 #include "config.h"
 
 
-static void EDVImbrToolbarMenuPositionCB(
-	GtkMenu *menu, gint *x, gint *y, gpointer data
-);
-
 void EDVImbrMenuItemCB(GtkWidget *widget, gpointer data);
 gint EDVImbrMenuItemEnterCB(
 	GtkWidget *widget, GdkEventCrossing *crossing, gpointer data
@@ -161,34 +157,6 @@ void EDVImbrOPDownload(edv_imbr_struct *imbr);
 #define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
-/*
- *	Tool Bar Item GtkMenu position callback.
- */
-static void EDVImbrToolbarMenuPositionCB(
-	GtkMenu *menu, gint *x, gint *y, gpointer data
-)
-{
-	gint width, height;
-	GdkWindow *window;
-	GtkWidget *w;
-	toolbar_item_struct *item = TOOLBAR_ITEM(data);
-	if((menu == NULL) || (x == NULL) || (y == NULL) || (item == NULL))
-	    return;
-
-	w = item->w;
-	if(w == NULL)
-	    return;
-
-	window = w->window;
-	if(window == NULL)
-	    return;
-
-	gdk_window_get_root_position(window, x, y);
-	gdk_window_get_size(window, &width, &height);
-	*y = (*y) + height;
-}
-
-
 /*
  *	Menu item "activate" signal callback.
  *
@@ -291,7 +259,12 @@ void EDVImbrOPCB(
 	    EDVImbrOPRun(imbr);
 	    break;
 	  case EDV_IMBR_OP_RUN_TERMINAL:
-	    EDVRunTerminal(core_ptr, NULL, toplevel);
+            if(core_ptr != NULL)
+            {
+                gchar *wd = STRDUP(EDVImbrCurrentLocation(imbr));
+                EDVRunTerminal(core_ptr, NULL, wd, toplevel);
+                g_free(wd);
+            }
 	    break;
 	  case EDV_IMBR_OP_WRITE_PROTECT:
 	    EDVImbrOPWriteProtect(imbr);
@@ -667,7 +640,7 @@ void EDVImbrMountBarMountCB(
 			"Unmount Failed" : "Mount Failed",
 		    last_error,
 		    NULL,
-		    imbr->toplevel
+		    toplevel
 		);
 	    }
 	}
@@ -734,7 +707,7 @@ void EDVImbrMountBarEjectCB(
 		    "Eject Failed",
 		    last_error,
 		    NULL,
-		    imbr->toplevel
+		    toplevel
 		);
 	    }
 	}
@@ -908,14 +881,15 @@ void EDVImbrOPRun(edv_imbr_struct *imbr)
 {
 	gchar *cmd;
 	GList *glist;
+	GtkWidget *toplevel;
 	tlist_struct *tlist;
 	const edv_object_struct *obj;
 	edv_core_struct *core_ptr;
 
-
 	if(imbr == NULL)
 	    return;
 
+	toplevel = imbr->toplevel;
 	tlist = imbr->tlist;
 	core_ptr = EDV_CORE(imbr->core_ptr);
 	if((tlist == NULL) || (core_ptr == NULL))
@@ -947,7 +921,7 @@ void EDVImbrOPRun(edv_imbr_struct *imbr)
 	    core_ptr,
 	    cmd,
 	    EDVImbrCurrentLocation(imbr),
-	    imbr->toplevel
+	    toplevel
 	);
 
 	g_free(cmd);
@@ -1148,7 +1122,7 @@ static void EDVImbrOPNewObjectNexus(
 		    "Create Failed",
 		    error_mesg,
 		    NULL,
-		    imbr->toplevel
+		    toplevel
 		);
 	    }
 
@@ -1208,19 +1182,13 @@ void EDVImbrOPNewObject(
 	edv_imbr_struct *imbr, toolbar_item_struct *item
 )
 {
-	GtkWidget *w;
-
 	if(imbr == NULL)
 	    return;
 
-	w = imbr->new_object_submenu;
-	if(w != NULL)
-	    gtk_menu_popup(
-		GTK_MENU(w), NULL, NULL,
-		(item != NULL) ? EDVImbrToolbarMenuPositionCB : NULL,
-		item,
-		1, GDK_CURRENT_TIME
-	    );
+        EDVMenuButtonMapMenu(
+            imbr->new_object_submenu,
+            (item != NULL) ? item->w : NULL
+        );
 }
 
 /*
@@ -1428,9 +1396,9 @@ void EDVImbrOPGoToHome(edv_imbr_struct *imbr)
 ambiente HOME variable se pone.\n",            
 		NULL,
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Aller A L'Annuaire De Maison Echou",
-"Incapable de trouver l'annuaire de maison, s'assure que\n\
-l'environnement HOME variable est rgl.\n",
+"Aller au rpertoire d'accueil chou",
+"Impossible de trouver le rpertoire d'accueil, s'assurer que\n\
+la variable d''environnement HOME est dfinie.\n",
 		NULL,
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Gehen Sie Zu Heim Verzeichnis Hat Versagt",
@@ -1544,7 +1512,7 @@ void EDVImbrOPMount(edv_imbr_struct *imbr)
 			"Unmount Failed" : "Mount Failed",
 		    last_error,
 		    NULL,
-		    imbr->toplevel
+		    toplevel
 		);
 	    }
 	}
@@ -1615,7 +1583,7 @@ void EDVImbrOPEject(edv_imbr_struct *imbr)
 		    "Eject Failed",
 		    last_error,
 		    NULL,
-		    imbr->toplevel
+		    toplevel
 		);
 	    }
 	}
@@ -1700,19 +1668,20 @@ void EDVImbrOPMove(edv_imbr_struct *imbr)
 {
 	edv_object_struct **sel_object;
 	gint total_sel_objects;
+	GtkWidget *toplevel;
 	edv_core_struct *core_ptr;
 	edv_fopdlg_struct *d;
 
-
 	if(imbr == NULL)
 	    return;
 
+	toplevel = imbr->toplevel;
 	core_ptr = EDV_CORE(imbr->core_ptr);
 	if(core_ptr == NULL)
 	    return;
 
 	/* Check and warn if write protect is enabled */
-	if(EDVCheckWriteProtect(core_ptr, TRUE, imbr->toplevel))
+	if(EDVCheckWriteProtect(core_ptr, TRUE, toplevel))
 	    return;
 
 	/* Get pointer to file operation dialog and create it as needed */
@@ -1737,7 +1706,7 @@ void EDVImbrOPMove(edv_imbr_struct *imbr)
 	    d, EDV_FOPDLG_OP_MOVE,
 	    sel_object, total_sel_objects,
 	    EDVImbrCurrentLocation(imbr),
-	    imbr->toplevel
+	    toplevel
 	);
 
 	/* Delete selected objects pointer array but not each object
@@ -1753,19 +1722,20 @@ void EDVImbrOPCopy(edv_imbr_struct *imbr)
 {
 	edv_object_struct **sel_object;
 	gint total_sel_objects;
+	GtkWidget *toplevel;
 	edv_core_struct *core_ptr;
 	edv_fopdlg_struct *d;
 
-
 	if(imbr == NULL)
 	    return;
 
+	toplevel = imbr->toplevel;
 	core_ptr = EDV_CORE(imbr->core_ptr);
 	if(core_ptr == NULL)
 	    return;
 
 	/* Check and warn if write protect is enabled */
-	if(EDVCheckWriteProtect(core_ptr, TRUE, imbr->toplevel))
+	if(EDVCheckWriteProtect(core_ptr, TRUE, toplevel))
 	    return;
 
 	/* Get pointer to file operation dialog and create it as needed */
@@ -1790,7 +1760,7 @@ void EDVImbrOPCopy(edv_imbr_struct *imbr)
 	    d, EDV_FOPDLG_OP_COPY,
 	    sel_object, total_sel_objects,
 	    EDVImbrCurrentLocation(imbr),
-	    imbr->toplevel
+	    toplevel
 	);
 
 	/* Delete selected objects pointer array but not each object      
@@ -1806,19 +1776,20 @@ void EDVImbrOPLink(edv_imbr_struct *imbr)
 {
 	edv_object_struct **sel_object;
 	gint total_sel_objects;
+	GtkWidget *toplevel;
 	edv_core_struct *core_ptr;
 	edv_fopdlg_struct *d;
 
-
 	if(imbr == NULL)
 	    return;
 
+	toplevel = imbr->toplevel;
 	core_ptr = EDV_CORE(imbr->core_ptr);
 	if(core_ptr == NULL)
 	    return;
 
 	/* Check and warn if write protect is enabled */
-	if(EDVCheckWriteProtect(core_ptr, TRUE, imbr->toplevel))
+	if(EDVCheckWriteProtect(core_ptr, TRUE, toplevel))
 	    return;
 
 	/* Get pointer to file operation dialog and create it as needed */
@@ -1847,7 +1818,7 @@ void EDVImbrOPLink(edv_imbr_struct *imbr)
 	    d, EDV_FOPDLG_OP_LINK,
 	    sel_object, MIN(total_sel_objects, 1),
 	    EDVImbrCurrentLocation(imbr),
-	    imbr->toplevel
+	    toplevel
 	);
 
 	/* Delete selected objects pointer array but not each object      
@@ -1861,18 +1832,19 @@ void EDVImbrOPLink(edv_imbr_struct *imbr)
  */
 void EDVImbrOPRename(edv_imbr_struct *imbr)
 {
+	GtkWidget *toplevel;
 	edv_core_struct *core_ptr;
 
-
 	if(imbr == NULL)
 	    return;
 
+	toplevel = imbr->toplevel;
 	core_ptr = EDV_CORE(imbr->core_ptr);
 	if(core_ptr == NULL)
 	    return;
 
 	/* Check and warn if write protect is enabled */
-	if(EDVCheckWriteProtect(core_ptr, TRUE, imbr->toplevel))
+	if(EDVCheckWriteProtect(core_ptr, TRUE, toplevel))
 	    return;
 
 	if(TRUE)
@@ -1895,19 +1867,20 @@ void EDVImbrOPChMod(edv_imbr_struct *imbr)
 {
 	edv_object_struct **sel_object;
 	gint total_sel_objects;
+	GtkWidget *toplevel;
 	edv_core_struct *core_ptr;
 	edv_fopdlg_struct *d;
 
-
 	if(imbr == NULL)
 	    return;
 
+	toplevel = imbr->toplevel;
 	core_ptr = EDV_CORE(imbr->core_ptr);
 	if(core_ptr == NULL)
 	    return;
 
 	/* Check and warn if write protect is enabled */
-	if(EDVCheckWriteProtect(core_ptr, TRUE, imbr->toplevel))
+	if(EDVCheckWriteProtect(core_ptr, TRUE, toplevel))
 	    return;
 
 	/* Get pointer to file operation dialog and create it as needed */
@@ -1932,7 +1905,7 @@ void EDVImbrOPChMod(edv_imbr_struct *imbr)
 	    d, EDV_FOPDLG_OP_CHMOD,
 	    sel_object, total_sel_objects,
 	    EDVImbrCurrentLocation(imbr),
-	    imbr->toplevel
+	    toplevel
 	);
 
 	/* Delete selected objects pointer array but not each object      
@@ -1948,19 +1921,20 @@ void EDVImbrOPChown(edv_imbr_struct *imbr)
 {
 	edv_object_struct **sel_object;
 	gint total_sel_objects;
+	GtkWidget *toplevel;
 	edv_core_struct *core_ptr;
 	edv_fopdlg_struct *d;
 
-
 	if(imbr == NULL)
 	    return;
 
+	toplevel = imbr->toplevel;
 	core_ptr = EDV_CORE(imbr->core_ptr);
 	if(core_ptr == NULL)
 	    return;
 
 	/* Check and warn if write protect is enabled */
-	if(EDVCheckWriteProtect(core_ptr, TRUE, imbr->toplevel))
+	if(EDVCheckWriteProtect(core_ptr, TRUE, toplevel))
 	    return;
 
 	/* Get pointer to file operation dialog and create it as needed */
@@ -1985,7 +1959,7 @@ void EDVImbrOPChown(edv_imbr_struct *imbr)
 	    d, EDV_FOPDLG_OP_CHOWN,
 	    sel_object, total_sel_objects,
 	    EDVImbrCurrentLocation(imbr),
-	    imbr->toplevel
+	    toplevel
 	);
 
 	/* Delete selected objects pointer array but not each object      
@@ -2007,6 +1981,7 @@ void EDVImbrOPDelete(edv_imbr_struct *imbr)
 	guint *index;
 	gint total_indices;
 	const gchar *error_mesg;
+	GtkWidget *toplevel;
 	edv_core_struct *core_ptr;
 
 	if(imbr == NULL)
@@ -2018,6 +1993,7 @@ void EDVImbrOPDelete(edv_imbr_struct *imbr)
  total_object_paths = 0;			\
 }
 
+	toplevel = imbr->toplevel;
 	core_ptr = EDV_CORE(imbr->core_ptr);
 	if(core_ptr == NULL)
 	{
@@ -2026,7 +2002,7 @@ void EDVImbrOPDelete(edv_imbr_struct *imbr)
 	}
 
 	/* Check and warn if write protect is enabled */
-	if(EDVCheckWriteProtect(core_ptr, TRUE, imbr->toplevel))
+	if(EDVCheckWriteProtect(core_ptr, TRUE, toplevel))
 	{
 	    DO_FREE_LOCALS
 	    return;
@@ -2082,7 +2058,7 @@ void EDVImbrOPDelete(edv_imbr_struct *imbr)
 
 	/* Confirm delete */
 	status = EDVConfirmDelete(
-	    core_ptr, imbr->toplevel,
+	    core_ptr, toplevel,
 	    (total_object_paths == 1) ? object_path[0] : NULL,
 	    total_object_paths
 	);
@@ -2118,7 +2094,7 @@ void EDVImbrOPDelete(edv_imbr_struct *imbr)
 	    status = EDVRecBinFOPDelete(
 		core_ptr, path_ptr,
 		&index, &total_indices,
-		imbr->toplevel,
+		toplevel,
 		TRUE, TRUE, &yes_to_all
 	    );
 
@@ -2133,7 +2109,7 @@ void EDVImbrOPDelete(edv_imbr_struct *imbr)
 		    "Operation Error",
 		    error_mesg,
 		    NULL,
-		    imbr->toplevel
+		    toplevel
 		);
 	    }
 
@@ -2365,11 +2341,14 @@ void EDVImbrOPInvertSelection(edv_imbr_struct *imbr)
  */
 void EDVImbrOPProperties(edv_imbr_struct *imbr)
 {
+	GtkWidget *toplevel;
 	edv_object_struct *obj;
 
 	if(imbr == NULL)
 	    return;
 
+	toplevel = imbr->toplevel;
+
 	EDVImbrSyncData(imbr);
 
 	/* Get object from last selected thumb */
@@ -2380,7 +2359,7 @@ void EDVImbrOPProperties(edv_imbr_struct *imbr)
 	    EDVNewPropertiesDialog(
 		EDV_CORE(imbr->core_ptr),
 		obj,
-		imbr->toplevel
+		toplevel
 	    );
 }
 
@@ -2390,12 +2369,15 @@ void EDVImbrOPProperties(edv_imbr_struct *imbr)
  */
 void EDVImbrOPCopyPath(edv_imbr_struct *imbr)
 {
+	gint total_sel_objects;   
+	GtkWidget *toplevel;
 	edv_object_struct **sel_object;
-	gint total_sel_objects;
 
 	if(imbr == NULL)
 	    return;
 
+	toplevel = imbr->toplevel;
+
 	EDVImbrSyncData(imbr);
 
 	/* Create a list of disk objects, each pointer in the array will
@@ -2415,7 +2397,7 @@ void EDVImbrOPCopyPath(edv_imbr_struct *imbr)
 	EDVCopyDiskObjectsToDDEPath(
 	    EDV_CORE(imbr->core_ptr),
 	    sel_object, total_sel_objects,
-	    imbr->toplevel
+	    toplevel
 	);
 
 	g_free(sel_object);
@@ -2426,12 +2408,15 @@ void EDVImbrOPCopyPath(edv_imbr_struct *imbr)
  */
 void EDVImbrOPCopyURL(edv_imbr_struct *imbr)
 {
-	edv_object_struct **sel_object;
 	gint total_sel_objects;
+	GtkWidget *toplevel;
+	edv_object_struct **sel_object;
 
 	if(imbr == NULL)
 	    return;
 
+	toplevel = imbr->toplevel;
+
 	EDVImbrSyncData(imbr);
 
 	/* Create a list of disk objects, each pointer in the array will
@@ -2451,7 +2436,7 @@ void EDVImbrOPCopyURL(edv_imbr_struct *imbr)
 	EDVCopyDiskObjectsToDDEURL(
 	    EDV_CORE(imbr->core_ptr),
 	    sel_object, total_sel_objects,
-	    imbr->toplevel
+	    toplevel
 	);
 
 	g_free(sel_object);
@@ -2629,7 +2614,7 @@ void EDVImbrOPRefresh(edv_imbr_struct *imbr)
 	cur_path = STRDUP(EDVImbrCurrentLocation(imbr));
 
 	/* Refresh toplevel */
-	w = imbr->toplevel;
+	w = toplevel;
 	if(w != NULL)
 	    gtk_widget_queue_resize(w);
 
@@ -2763,14 +2748,18 @@ void EDVImbrOpPresentationMode(edv_imbr_struct *imbr)
  */
 void EDVImbrOPDownload(edv_imbr_struct *imbr)
 {
+	GtkWidget *toplevel;
+
 	if(imbr == NULL)
 	    return;
 
+	toplevel = imbr->toplevel;
+
 	EDVInternetDownloadObject(
 	    EDV_CORE(imbr->core_ptr),
 	    NULL,
 	    EDVImbrCurrentLocation(imbr),
-	    imbr->toplevel
+	    toplevel
 	);
 }
 
