@@ -5,10 +5,13 @@
 #ifndef IMBROPCB_H
 #define IMBROPCB_H
 
-
 #include <gtk/gtk.h>
+#include "toolbar.h"
 #include "edvtypes.h"
 #include "edvdevices.h"
+#include "mountbar.h"
+#include "findbar.h"
+#include "statusbar.h"
 #include "imbr.h"
 
 
@@ -21,32 +24,34 @@ extern gint EDVImbrMenuItemLeaveCB(
 );
 
 extern void EDVImbrOPCB(
-        toolbar_item_struct *item, gint id, gpointer data
+	toolbar_item_struct *item, gint id, gpointer data
 );
 extern void EDVImbrOPEnterCB(
-        toolbar_item_struct *item, gint id, gpointer data
+	toolbar_item_struct *item, gint id, gpointer data
 );
 extern void EDVImbrOPLeaveCB(
-        toolbar_item_struct *item, gint id, gpointer data
+	toolbar_item_struct *item, gint id, gpointer data
 );
 
 extern void EDVImbrMountBarMountCB(
-	gpointer mb, gint dev_num, edv_device_struct *dev_ptr,
+	edv_mountbar_struct *mb, gint dev_num, edv_device_struct *dev,
 	gpointer data
 );
 extern void EDVImbrMountBarEjectCB(
-	gpointer mb, gint dev_num, edv_device_struct *dev_ptr,
+	edv_mountbar_struct *mb, gint dev_num, edv_device_struct *dev,
 	gpointer data
 );
 extern void EDVImbrMountBarGoToCB(
-	gpointer mb, gint dev_num, edv_device_struct *dev_ptr,
+	edv_mountbar_struct *mb, gint dev_num, edv_device_struct *dev,
 	gpointer data
 );
 
-extern gchar *EDVImbrFindBarLocationCB(gpointer fb, gpointer data);
-extern void EDVImbrFindBarStartCB(gpointer fb, gpointer data);
+extern const gchar *EDVImbrFindBarLocationCB(
+	edv_findbar_struct *fb, gpointer data
+);
+extern void EDVImbrFindBarStartCB(edv_findbar_struct *fb, gpointer data);
 extern void EDVImbrFindBarEndCB(
-	gpointer fb, gint total_matches, gpointer data
+	edv_findbar_struct *fb, gint total_matches, gpointer data
 );
 extern void EDVImbrFindBarMatchCB(
 	const gchar *path, const struct stat *lstat_buf,
@@ -54,12 +59,8 @@ extern void EDVImbrFindBarMatchCB(
 	gpointer data
 );
 
-extern void EDVImbrBarStatusMessageCB(
-	gpointer mb, const gchar *message, gpointer data
-);
-extern void EDVImbrBarStatusProgressCB(
-	gpointer bar, gfloat progress, gpointer data
-);
+extern void EDVImbrStatusMessageCB(const gchar *message, gpointer data);
+extern void EDVImbrStatusProgressCB(gfloat progress, gpointer data);
 
 extern void EDVImbrOPSyncDisks(edv_imbr_struct *imbr);
 extern void EDVImbrOPWriteProtect(edv_imbr_struct *imbr);
@@ -67,7 +68,9 @@ extern void EDVImbrOPWriteProtect(edv_imbr_struct *imbr);
 extern void EDVImbrOPClose(edv_imbr_struct *imbr);
 extern void EDVImbrOPExit(edv_imbr_struct *imbr);
 
-extern void EDVImbrOPNewObject(edv_imbr_struct *imbr);
+extern void EDVImbrOPNewObject(
+	edv_imbr_struct *imbr, toolbar_item_struct *item
+);
 extern void EDVImbrOPNewFile(edv_imbr_struct *imbr);
 extern void EDVImbrOPNewDirectory(edv_imbr_struct *imbr);
 extern void EDVImbrOPNewLink(edv_imbr_struct *imbr);
@@ -89,10 +92,11 @@ extern void EDVImbrOPProperties(edv_imbr_struct *imbr);
 extern void EDVImbrOPCopyPath(edv_imbr_struct *imbr);
 extern void EDVImbrOPCopyURL(edv_imbr_struct *imbr);
 
-extern void EDVImbrOPStop(edv_imbr_struct *imbr);
-extern void EDVImbrOpContinue(edv_imbr_struct *imbr);
 extern void EDVImbrOPRefresh(edv_imbr_struct *imbr);
 extern void EDVImbrOPRefreshAll(edv_imbr_struct *imbr);
+extern void EDVImbrOPStop(edv_imbr_struct *imbr);
+extern void EDVImbrOpContinue(edv_imbr_struct *imbr);
+extern void EDVImbrOpPresentationMode(edv_imbr_struct *imbr);
 
 extern void EDVImbrOPDownload(edv_imbr_struct *imbr);
 
