@@ -1,6 +1,9 @@
 #include <stdlib.h>
 #include <string.h>
 #include <sys/stat.h>
+#ifdef HAVE_LIBGIF
+# include "gif.h"
+#endif
 #ifdef HAVE_IMLIB
 # include <Imlib.h>
 #endif
@@ -49,9 +52,10 @@ static guint8 *EDVImbrTListLoadImageRGBATarga(
 	gint *width, gint *height, gint *bpl,
 	GdkWindow *window			/* Reference window */
 );
-guint8 *EDVImbrTListLoadImageRGBA(
+GList *EDVImbrTListLoadImageRGBA(
 	tlist_struct *tlist, const gchar *path,
 	gint *width, gint *height, gint *bpl,
+	gint *nframes, GList **delay_list,
 	gboolean resize_for_thumb,		/* Resize for tlist thumb */
 	gboolean no_enlarge,			/* No enlarge if smaller
 						 * than req size */
@@ -126,7 +130,7 @@ void EDVImbrTListObjectRemovedNotify(
 
 /* Mount Callbacks */
 void EDVImbrTListMountNotify(
-	edv_imbr_struct *imbr, edv_device_struct *dev_ptr,
+	edv_imbr_struct *imbr, edv_device_struct *dev,
 	gboolean is_mounted
 );
 
@@ -275,9 +279,10 @@ static guint8 *EDVImbrTListLoadImageRGBATarga(
  *
  *	Returns the RGBA image data or NULL on error.
  */
-guint8 *EDVImbrTListLoadImageRGBA(
+GList *EDVImbrTListLoadImageRGBA(
 	tlist_struct *tlist, const gchar *path,
 	gint *width, gint *height, gint *bpl,
+	gint *nframes, GList **delay_list,
 	gboolean resize_for_thumb,		/* Resize for tlist thumb */
 	gboolean no_enlarge,			/* No enlarge if smaller
 						 * than req size */
@@ -287,7 +292,7 @@ guint8 *EDVImbrTListLoadImageRGBA(
 #ifdef HAVE_IMLIB
 	const gchar *name;
 	gint swidth, sheight, twidth, theight;
-	guint8 *rgba = NULL;
+	GList *rgba_list = NULL;
 	ImlibImage *imlib_image;
 
 	/* Reset returns */
@@ -297,11 +302,15 @@ guint8 *EDVImbrTListLoadImageRGBA(
 	    *height = 0;
 	if(bpl != NULL)
 	    *bpl = 0;
+	if(nframes != NULL)
+	    *nframes = 0;
+	if(delay_list != NULL)
+	    *delay_list = NULL;
 
 	if(STRISEMPTY(path))
 	    return(NULL);
 
-	name = EDVGetPathName(path);
+	name = g_basename(path);
 
 	/* Begin checking extension to see if we should use a native
 	 * image format loader instead of Imlib, since native loaders
@@ -311,17 +320,73 @@ guint8 *EDVImbrTListLoadImageRGBA(
 	/* Targa */
 	if(EDVIsExtension(name, ".tga .targa"))
 	{
-	    rgba = EDVImbrTListLoadImageRGBATarga(
+	    guint8 *rgba = EDVImbrTListLoadImageRGBATarga(
 		path, width, height, bpl, window
 	    );
+	    rgba_list = g_list_append(rgba_list, rgba);
+	    if(delay_list != NULL)
+	        *delay_list = g_list_append(
+		    *delay_list, (gpointer)0l
+		);
+	    if(nframes != NULL)
+		*nframes = g_list_length(rgba_list);
 	}
+#ifdef HAVE_LIBGIF
+	else if(EDVIsExtension(name, ".gif"))
+	{
+	    gint	bpp = 0,
+			x = 0, y = 0, base_width = 0, base_height = 0,
+			user_aborted = 0;
+	    gchar	*creator = NULL,
+			*title = NULL,
+			*author = NULL,
+			*comments = NULL;
+	    guint8 **rgba = NULL, bg_color[4];
+	    gulong *delay = NULL;
+	    ImgGIFReadRGBA(
+		path,
+		width, height, &bpp, bpl,
+		&rgba, &delay, nframes,
+		bg_color,		/* 4 bytes RGBA */
+		&x, &y, &base_width, &base_height,
+		&creator, &title, &author, &comments,
+		0xff,			/* Default alpha value */
+		NULL, NULL,
+		&user_aborted
+	    );
+	    if(*nframes > 0)
+	    {
+		gint i;
+		for(i = 0; i < *nframes; i++)
+		{
+		    rgba_list = g_list_append(rgba_list, rgba[i]);
+		    rgba[i] = NULL;
+
+		    if((delay_list != NULL) && (delay != NULL))
+		    {
+			const guint d = (guint)delay[i];
+			*delay_list = g_list_append(
+			    *delay_list,
+			    (gpointer)d
+			);
+		    }
+		}
+	    }
+	    g_free(rgba);
+	    g_free(delay);
+	    g_free(creator);
+	    g_free(title);
+	    g_free(author);
+	    g_free(comments);
+	}
+#endif	/* HAVE_LIBGIF */
 /* Add other image types that we should load alternatively (without
  * Imlib) here and make sure they return() the RGBA data pointer and do
  * not continue
  */
 	/* Loaded image with native loaders? */
-	if(rgba != NULL)
-	    return(rgba);
+	if(rgba_list != NULL)
+	    return(rgba_list);
 
 
 	/* Load Imlib image */
@@ -377,6 +442,7 @@ guint8 *EDVImbrTListLoadImageRGBA(
 	{
 	    gint	t_rgb_bpl = twidth * 3,
 			t_alpha_bpl = twidth * 1;
+	    guint8 *rgba;
 
 	    /* Allocate resized image buffers */
 	    guint8	*t_rgb = (imlib_image->rgb_data != NULL) ?
@@ -409,6 +475,7 @@ guint8 *EDVImbrTListLoadImageRGBA(
 		twidth, theight,
 		-1, -1		/* Autocalculate bpl values */
 	    );
+	    rgba_list = g_list_append(rgba_list, rgba);
 
 	    g_free(t_rgb);
 	    g_free(t_alpha);
@@ -420,16 +487,23 @@ guint8 *EDVImbrTListLoadImageRGBA(
 	else
 	{
 	    /* Create RGBA data from the Imlib's RGB and Alpha data */
-	    rgba = EDVImbrTListConvertRGBToRGBA(
+	    guint8 *rgba = EDVImbrTListConvertRGBToRGBA(
 		imlib_image->rgb_data, imlib_image->alpha_data,
 		swidth, sheight,
 		-1, -1		/* Autocalculate bpl values */
 	    );
+	    rgba_list = g_list_append(rgba_list, rgba);
 	}
 
 	/* Destroy Imlib image */
 	Imlib_destroy_image(imlib_handle, imlib_image);
 
+	/* Set delay for only frame as 0 ms */
+	if(delay_list != NULL)
+	    *delay_list = g_list_append(
+		*delay_list, (gpointer)0l
+	    );
+
 	/* Update returns */
 	if(width != NULL)
 	    *width = swidth;
@@ -437,8 +511,10 @@ guint8 *EDVImbrTListLoadImageRGBA(
 	    *height = sheight;
 	if(bpl != NULL)
 	    *bpl = swidth * 4;
+	if(nframes != NULL)
+	    *nframes = g_list_length(rgba_list);
 
-	return(rgba);
+	return(rgba_list);
 #else
 	return(NULL);
 #endif	/* HAVE_IMLIB */
@@ -899,11 +975,31 @@ void EDVImbrTListGetListing(
 		    if(full_path == NULL)
 			FREE_AND_CONTINUE
 
-		    /* Get this object's destination statistics */
-		    if(stat((char *)full_path, &stat_buf))
+		    /* Get this object's destination stats */
+		    if(stat((const char *)full_path, &stat_buf))
+		    {
+#if 0
+/* Do not add anyways on the directory iteration */
+			/* Unable to get stats, add the object anyways
+			 * without stats
+			 */
+			obj = EDVObjectNew();
+			if(obj != NULL)
+			{
+			    EDVObjectSetPath(obj, full_path);
+			    EDVObjectUpdateLinkFlags(obj);
+			    EDVImbrTListAppendObject(
+				core_ptr, imbr, tlist, obj
+			    );
+			    obj = NULL; 
+			    objects_loaded++;
+			}
+#endif
 			FREE_AND_CONTINUE
+		    }
+
 #ifdef S_ISDIR
-		    /* Skip if destination is not a directory */
+		    /* Skip if the destination is not a directory */
 		    if(!S_ISDIR(stat_buf.st_mode))
 			FREE_AND_CONTINUE
 #endif
@@ -917,8 +1013,6 @@ void EDVImbrTListGetListing(
 		    obj = EDVObjectNew();
 		    if(obj != NULL)
 		    {
-			gint thumb_num;
-
 			EDVObjectSetPath(obj, full_path);
 			EDVObjectSetStat(obj, &lstat_buf);
 			EDVObjectUpdateLinkFlags(obj);
@@ -932,19 +1026,17 @@ void EDVImbrTListGetListing(
 			{
 			    EDVObjectDelete(obj);
 			    obj = NULL;
-			    thumb_num = -1;
 			}
 			else
 			{
 			    /* Append thumb using this object, the
 			     * object will be transfered
 			     */
-			    thumb_num = EDVImbrTListAppendObject(
+			    EDVImbrTListAppendObject(
 				core_ptr, imbr, tlist, obj
 			    );
 			    obj = NULL;
-
-			    objects_loaded++;	/* Count this as an object loaded */
+			    objects_loaded++;
 			}
 		    }
 
@@ -1003,12 +1095,29 @@ void EDVImbrTListGetListing(
 		    if(full_path == NULL)
 			FREE_AND_CONTINUE
 
-		    /* Get local stats of this object */
-		    if(lstat((char *)full_path, &lstat_buf))
+		    /* Get this object's local stats */
+		    if(lstat((const char *)full_path, &lstat_buf))
+		    {
+			/* Unable to get stats, add the object anyways
+			 * without stats
+			 */
+			memset(&lstat_buf, 0x00, sizeof(struct stat));
+			obj = EDVObjectNew();
+			if(obj != NULL)
+			{
+			    EDVObjectSetPath(obj, full_path);
+			    EDVObjectUpdateLinkFlags(obj);
+			    EDVImbrTListAppendObject(
+				core_ptr, imbr, tlist, obj
+			    );
+			    obj = NULL;
+			    objects_loaded++;
+			}
 			FREE_AND_CONTINUE
+		    }
 
 		    /* Get destination stats of this object */
-		    stat_result = stat((char *)full_path, &stat_buf);
+		    stat_result = stat((const char *)full_path, &stat_buf);
 		    if(!stat_result)
 		    {
 #ifdef S_ISDIR
@@ -1022,8 +1131,6 @@ void EDVImbrTListGetListing(
 		    obj = EDVObjectNew();
 		    if(obj != NULL)
 		    {
-			gint thumb_num;
-
 			EDVObjectSetPath(obj, full_path);
 			EDVObjectSetStat(obj, &lstat_buf);
 			EDVObjectUpdateLinkFlags(obj);
@@ -1041,19 +1148,17 @@ void EDVImbrTListGetListing(
 			{
 			    EDVObjectDelete(obj);
 			    obj = NULL;
-			    thumb_num = -1;
 			}
 			else
 			{
 			    /* Append thumb using this object, the
 			     * object will be transfered
 			     */
-			    thumb_num = EDVImbrTListAppendObject(
+			    EDVImbrTListAppendObject(
 				core_ptr, imbr, tlist, obj
 			    );
 			    obj = NULL;
-
-			    objects_loaded++;	/* Count this as an object loaded */
+			    objects_loaded++;
 			}
 		    }
 
@@ -1263,10 +1368,10 @@ gint EDVImbrTListLoadIterate(
 	/* Load image for this thumb */
 	if(TRUE)
 	{
-	    gint width, height, bpl;
-	    guint8 *data_rgba;
+	    gint width, height, bpl, nframes;
 	    const gchar	*name = obj->name,
 			*full_path = obj->full_path;
+	    GList *rgba_list, *delay_list;
 	    GdkWindow *window = toplevel->window;
 
 	    if(update_status_bar)
@@ -1295,14 +1400,14 @@ gint EDVImbrTListLoadIterate(
 /* Check if image is cached */
 
 	    /* Load image to RGBA data */
-	    data_rgba = EDVImbrTListLoadImageRGBA(
+	    rgba_list = EDVImbrTListLoadImageRGBA(
 		tlist, full_path,
-		&width, &height, &bpl,
+		&width, &height, &bpl, &nframes, &delay_list,
 		TRUE,			/* Resize for tlist thumb */
 		no_enlarge,		/* Do not enlarge? */
 		window
 	    );
-	    if(data_rgba == NULL)
+	    if(rgba_list == NULL)
 	    {
 		/* Failed to load image for this thumb, mark the thumb's
 		 * load state as failed and set the badimage icon for
@@ -1327,12 +1432,14 @@ gint EDVImbrTListLoadIterate(
 		tlist, thumb_to_load_num,
 		width, height, bpl,
 		GDK_RGB_DITHER_NORMAL,
-		data_rgba,
+		(guint8 *)rgba_list->data,	/* Use first image */
 		no_enlarge
 	    );
 
-	    /* Delete image RGBA data */
-	    g_free(data_rgba);
+	    /* Delete the loaded images */
+	    g_list_foreach(rgba_list, (GFunc)g_free, NULL);
+	    g_list_free(rgba_list);
+	    g_list_free(delay_list);
 
 	    /* Report one thumb loaded */
 	    return(1);
@@ -1588,8 +1695,8 @@ static void EDVImbrTListFPromptRenameApplyCB(
 		if((new_obj != NULL) && (old_full_path != NULL))
 		{
 		    struct stat lstat_buf;
-		    const gchar	*new_child = EDVGetPathName(new_obj),
-				*old_child = EDVGetPathName(old_full_path);
+		    const gchar	*new_child = g_basename(new_obj),
+				*old_child = g_basename(old_full_path);
 
 		    /* Get new local statistics for the renamed object */
 		    if(!lstat(new_obj, &lstat_buf))
@@ -1746,17 +1853,14 @@ void EDVImbrTListDoFPromptRename(
 
 
 /*
- *      This should be called whenever a new object has been added, it
- *      will add a new row as needed to represent the new object.
- *
- *      The given path must be an absolute path to the object.
+ *	Object added callback.
  */
 void EDVImbrTListObjectAddedNotify(
 	edv_imbr_struct *imbr, const gchar *path,
 	const struct stat *lstat_buf
 )
 {
-	gchar *cur_path, *parent_path;
+	gchar *cur_loc, *parent_path;
 	gint thumb_num;
 	tlist_struct *tlist;
 	edv_object_struct *obj;
@@ -1771,15 +1875,15 @@ void EDVImbrTListObjectAddedNotify(
 	    return;
 
 #define DO_FREE_LOCALS	{	\
- g_free(cur_path);		\
- cur_path = NULL;		\
+ g_free(cur_loc);		\
+ cur_loc = NULL;		\
  g_free(parent_path);		\
  parent_path = NULL;		\
 }
 	/* Get parent of the given path and current location */
-	cur_path = STRDUP(EDVImbrCurrentLocation(imbr));
+	cur_loc = STRDUP(EDVImbrCurrentLocation(imbr));
 	parent_path = g_dirname(path);
-	if((cur_path == NULL) || (parent_path == NULL))
+	if((cur_loc == NULL) || (parent_path == NULL))
 	{
 	    DO_FREE_LOCALS
 	    return;
@@ -1788,7 +1892,7 @@ void EDVImbrTListObjectAddedNotify(
 	/* Is location of what contents list is displaying is different
 	 * from the location of the new object to add?
 	 */
-	if(strcmp(cur_path, parent_path))
+	if(strcmp(cur_loc, parent_path))
 	{
 	    DO_FREE_LOCALS
 	    return;
@@ -1847,13 +1951,7 @@ void EDVImbrTListObjectAddedNotify(
 }
 
 /*
- *      This should be called whenever a object has been modified, it will
- *      search for the object and then reupdate the matching thumb.
- *
- *      The given path must be an absolute path to the object and must be
- *      the path of the object's original name. The new_path must be an
- *      absolute path to the object at its new name, the new_path may be
- *      NULL if there was no name change.
+ *	Object modified callback.
  */
 void EDVImbrTListObjectModifiedNotify(
 	edv_imbr_struct *imbr, const gchar *path,
@@ -1861,7 +1959,7 @@ void EDVImbrTListObjectModifiedNotify(
 	const struct stat *lstat_buf
 )
 {
-	gchar *cur_path, *parent_path;
+	gchar *cur_loc, *parent_path;
 	gint thumb_num;
 	tlist_struct *tlist;
 	edv_object_struct *obj;
@@ -1879,15 +1977,15 @@ void EDVImbrTListObjectModifiedNotify(
 	    return;
 
 #define DO_FREE_LOCALS	{	\
- g_free(cur_path);		\
- cur_path = NULL;		\
+ g_free(cur_loc);		\
+ cur_loc = NULL;		\
  g_free(parent_path);		\
  parent_path = NULL;		\
 }
 	/* Get parent of the given path and current location */
-	cur_path = STRDUP(EDVImbrCurrentLocation(imbr));
+	cur_loc = STRDUP(EDVImbrCurrentLocation(imbr));
 	parent_path = g_dirname(new_path);
-	if((cur_path == NULL) || (parent_path == NULL))
+	if((cur_loc == NULL) || (parent_path == NULL))
 	{
 	    DO_FREE_LOCALS
 	    return;
@@ -1897,7 +1995,7 @@ void EDVImbrTListObjectModifiedNotify(
 	/* Is given path that has been modified the same as the
 	 * current location?
 	 */
-	if(!strcmp(new_path, cur_path))
+	if(!strcmp(new_path, cur_loc))
 	{
 	    /* Reget listing */
 	    EDVImbrTListGetListing(imbr, new_path, TRUE);
@@ -1930,16 +2028,13 @@ void EDVImbrTListObjectModifiedNotify(
 }
 
 /*
- *      This should be called whenever a object has been removed, it will
- *      search for the object and then remove the matching thumb.
- *
- *      The given path must be an absolute path to the object.
+ *	Object removed callback.
  */
 void EDVImbrTListObjectRemovedNotify(
 	edv_imbr_struct *imbr, const gchar *path
 )
 {
-	gchar *cur_path, *parent_path;
+	gchar *cur_loc, *parent_path;
 	gint thumb_num;
 	tlist_struct *tlist;
 
@@ -1951,15 +2046,15 @@ void EDVImbrTListObjectRemovedNotify(
 	    return;
 
 #define DO_FREE_LOCALS	{	\
- g_free(cur_path);		\
- cur_path = NULL;		\
+ g_free(cur_loc);		\
+ cur_loc = NULL;		\
  g_free(parent_path);		\
  parent_path = NULL;		\
 }
 	/* Get parent of the given path and current location */
-	cur_path = STRDUP(EDVImbrCurrentLocation(imbr));
+	cur_loc = STRDUP(EDVImbrCurrentLocation(imbr));
 	parent_path = g_dirname(path);
-	if((cur_path == NULL) || (parent_path == NULL))
+	if((cur_loc == NULL) || (parent_path == NULL))
 	{
 	    DO_FREE_LOCALS
 	    return;
@@ -1968,7 +2063,7 @@ void EDVImbrTListObjectRemovedNotify(
 	/* Is given path that has been removed the same as the current
 	 * location?
 	 */
-	if(!strcmp(path, cur_path))
+	if(!strcmp(path, cur_loc))
 	{
 	    /* Clear thumbs list */
 	    TListFreeze(tlist);
@@ -1994,18 +2089,17 @@ void EDVImbrTListObjectRemovedNotify(
 
 
 /*
- *      This should be called whenever a device has been mounted or
- *	unmounted.
+ *	Device mount/unmount callback.
  */
 void EDVImbrTListMountNotify(
-	edv_imbr_struct *imbr, edv_device_struct *dev_ptr,
+	edv_imbr_struct *imbr, edv_device_struct *dev,
 	gboolean is_mounted
 )
 {
-	gchar *cur_path, *mount_path;
+	gchar *cur_loc, *mount_path;
 	tlist_struct *tlist;
 
-	if((imbr == NULL) || (dev_ptr == NULL))
+	if((imbr == NULL) || (dev == NULL))
 	    return;
 
 	tlist = imbr->tlist;
@@ -2013,31 +2107,32 @@ void EDVImbrTListMountNotify(
 	    return;
 
 #define DO_FREE_LOCALS	{	\
- g_free(cur_path);		\
- cur_path = NULL;		\
+ g_free(cur_loc);		\
+ cur_loc = NULL;		\
  g_free(mount_path);		\
  mount_path = NULL;		\
 }
+
 	/* Get coppies of current location and mount paths */
-	cur_path = STRDUP(EDVImbrCurrentLocation(imbr));
-	mount_path = STRDUP(dev_ptr->mount_path);
-	if((cur_path == NULL) || (mount_path == NULL))
+	cur_loc = STRDUP(EDVImbrCurrentLocation(imbr));
+	mount_path = STRDUP(dev->mount_path);
+	if((cur_loc == NULL) || (mount_path == NULL))
 	{
 	    DO_FREE_LOCALS
 	    return;
 	}
 
 	/* Need to simplify coppies of current and mount paths */
-	EDVSimplifyPath(cur_path);
+	EDVSimplifyPath(cur_loc);
 	EDVSimplifyPath(mount_path);
 
-	/* Check if mount path was the current location, if it was then
-	 * the contents clist needs to be updated
+	/* Check if mount path is a parent of the current location,
+	 * if it is then the Thumbs List needs to be updated
 	 */
-	if(!strcmp(cur_path, mount_path))
+	if(strpfx(cur_loc, mount_path))
 	{
 	    /* Reget listing */
-	    EDVImbrTListGetListing(imbr, cur_path, TRUE);
+	    EDVImbrTListGetListing(imbr, cur_loc, TRUE);
 	}
 
 	DO_FREE_LOCALS
