@@ -747,7 +747,7 @@ static void KeymapListDoScanKey(keymap_list_struct *kmlist)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Apriete La Sucesion Clave..."
 #elif defined(PROG_LANGUAGE_FRENCH)
-"La Sequence Clee De Presse..."
+"Raccourcis Clavier..."
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Drucken Sie Reihenfolge Der Tasten..."
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -878,10 +878,7 @@ void KeymapListScanKey(keymap_list_struct *kmlist, gint row)
 	}
 
 	/* Schedual idle call to scan the key sequence */
-	gtk_idle_add(
-	    KeymapListScanIdleCB,
-	    kmlist
-	);
+	gtk_idle_add(KeymapListScanIdleCB, kmlist);
 }
 
 /*
@@ -967,9 +964,9 @@ void KeymapListSetDefaultKeys(keymap_list_struct *kmlist)
 "?Usted esta seguro que usted quiere poner las\n\
 llaves predefinidas?",
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Regler Des Clefs Implicites",
-"Etesvous sur que vous voulez regler les clefs\n\
-implicites?",
+"Charger les raccourcis clavier prdfinis",
+"Etes vous sur de vouloir regler les raccourcis clavier\n\
+prdfinis?",
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Fester Standardwert Gibt Ein",
 "Sind Sie Sicher Sie Wollen Setzen Die\n\
@@ -1125,11 +1122,11 @@ Los conflictos con llave:\n\
 \n\
     %s\n",
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Clef:\n\
+"Squence de touches:\n\
 \n\
     %s\n\
 \n\
-Les conflits avec la clef:\n\
+en conflits avec le raccourci:\n\
 \n\
     %s\n",
 #elif defined(PROG_LANGUAGE_GERMAN)
@@ -1188,7 +1185,7 @@ Conflicts with key sequence for function:\n\
 #if defined(PROG_LANGUAGE_SPANISH)
 "Llaves Opuestas",
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Clefs Contradictoires",
+"Conflit de raccourcis",
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Sich Widersprechende",
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1326,7 +1323,7 @@ keymap_list_struct *KeymapListNew(
 	heading[1] = "Sucesion De Llaves";
 #elif defined(PROG_LANGUAGE_FRENCH)
 	heading[0] = "Fonction";
-	heading[1] = "Sequence De Clefs";
+	heading[1] = "Sequence de touches";
 #elif defined(PROG_LANGUAGE_GERMAN)
 	heading[0] = "Funktion";
 	heading[1] = "Reihenfolge Der Tasten";
@@ -1414,7 +1411,7 @@ keymap_list_struct *KeymapListNew(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Escudrine",
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Balayage",
+"scrute",
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Prufen",
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1442,7 +1439,7 @@ keymap_list_struct *KeymapListNew(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Escudrina la sucesion clave para la llave escogida"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Scrute la sequence clee pour la clef choisie"
+"Scrute le raccourci pour la touche slecte"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Pruft die schlusselreihenfolge fur die ausgewahlte taste"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1465,7 +1462,7 @@ keymap_list_struct *KeymapListNew(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Vacie",
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Eclaircir",
+"Effacer",
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Reinigen",
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1493,7 +1490,7 @@ keymap_list_struct *KeymapListNew(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Vacia la sucesio'n clave para la llave escogida"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Eclaircit la sequence clee pour la clef choisie"
+"Effacer le raccourci pour la touche slecte"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Reinigt die schlusselreihenfolge fur die ausgewahlte taste"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1524,7 +1521,7 @@ keymap_list_struct *KeymapListNew(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Defectos",
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Defauts",
+"prdfinis",
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Standardwerte",
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1552,7 +1549,7 @@ keymap_list_struct *KeymapListNew(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Pone la sucesion clave predefinida para el todo adapta"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Regle la sequence clee implicite pour les toutes clefs"
+"Prdfinir les raccourcis de toutes les touches"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Setzt die standardschlusselreihenfolge fur die alle tasten"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1867,7 +1864,7 @@ void KeymapListSetKey(
 }
 	    if(state & GDK_LOCK_MASK)
 	    {
-		CAT_MODS("Lock+");
+		CAT_MODS("CapsLock+");
 	    }
 	    if(state & GDK_CONTROL_MASK)
 	    {
@@ -1883,7 +1880,7 @@ void KeymapListSetKey(
 	    }
 	    if(state & GDK_MOD2_MASK)
 	    {
-		CAT_MODS("Mod2+");
+		CAT_MODS("NumLock+");
 	    }
 	    if(state & GDK_MOD3_MASK)
 	    {
@@ -1895,7 +1892,7 @@ void KeymapListSetKey(
 	    }
 	    if(state & GDK_MOD5_MASK)
 	    {
-		CAT_MODS("Mod5+");
+		CAT_MODS("ScrollLock+");
 	    }
 
 	    text = g_strconcat(mods_name, key_name, NULL);
