@@ -20,7 +20,11 @@ int main(int argc, char *argv[])
 	     * The Endeavour program must be currently running or else
 	     * this call will have no affect.
 	     */
-	    EDVOpen(ctx, argv[1], NULL);
+	    GList *glist = NULL;
+	    glist = g_list_append(glist, g_strdup(argv[1]));
+	    EDVOpen(ctx, glist, NULL);
+	    g_list_foreach(glist, (GFunc)g_free, NULL);
+	    g_list_free(glist);
 	}
 	else
 	{
