@@ -1,5 +1,10 @@
 #include <string.h>
+#if defined(__FreeBSD__)
+#include <sys/param.h>
+#include <sys/mount.h>
+#else
 #include <sys/vfs.h>
+#endif
 #if defined(__SOLARIS__)
 # include <sys/statvfs.h>
 #endif
@@ -61,16 +66,16 @@ edv_device_struct *EDVDeviceCopy(const edv_device_struct *d);
 void EDVDeviceDelete(edv_device_struct *d);
 
 
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
