@@ -2,7 +2,9 @@
 #include <stdlib.h>
 #include <string.h>
 #include <sys/stat.h>
-#if defined(__SOLARIS__)
+#if defined(__FreeBSD__)
+# include <fstab.h>
+#elif defined(__SOLARIS__)
 # include <sys/mnttab.h>
 # include <sys/vfstab.h>
 #else
@@ -57,10 +59,13 @@ void EDVDevicesListUpdateMountStatesFromSystem(
 )
 {
 	FILE *fp;
-	gint dev_num = -1;
-	edv_device_struct *dev = NULL;
-#if defined(__SOLARIS__)
-	struct mnttab *mt_ptr = NULL;
+	gint dev_num;
+	edv_device_struct *dev;
+#if defined(__FreeBSD__)
+        gint i, mntsize;  
+        struct statfs *mt_buf;
+#elif defined(__SOLARIS__)
+	struct mnttab *mt_ptr;
 	int mtback;
 #else
 	struct mntent *mt_ptr;
@@ -80,7 +85,9 @@ void EDVDevicesListUpdateMountStatesFromSystem(
 	}
 
 	/* Open the system's mounted devices list file */
-#if defined(__SOLARIS__)
+#if defined(__FreeBSD__)
+	fp = (FILE *)1;		/* Mark the mount info file as opened */
+#elif defined(__SOLARIS__)
 	fp = FOpen("/etc/mnttab", "rb");
 #else
 	fp = setmntent("/proc/mounts", "rb");
@@ -89,7 +96,12 @@ void EDVDevicesListUpdateMountStatesFromSystem(
 	    return;
 
 	/* Begin reading the system's mounted devices list file */
-#if defined(__SOLARIS__)
+#if defined(__FreeBSD__)
+        if((mntsize = getmntinfo(&mt_buf, MNT_NOWAIT)) == 0)
+            return;
+        i = mntsize - 1;
+        while(i >= 0)
+#elif defined(__SOLARIS__)
 	mt_ptr = (struct mnttab *)g_malloc(sizeof(struct mnttab));
 	mtback = getmntent(fp, mt_ptr);
 	while(mtback != 0)
@@ -98,28 +110,50 @@ void EDVDevicesListUpdateMountStatesFromSystem(
 	while(mt_ptr != NULL)
 #endif
 	{
-	    /* Check if the mounted device path matches a Device in
-	     * the specified list
+	    /* Check if the this mounted device's devie path matches
+	     * a Device in the specified list
 	     */
 	    dev = EDVDeviceListMatchDevicePath(
 		list, total,
-#if defined(__SOLARIS__)
-		&dev_num, mt_ptr->mnt_special
+		&dev_num,
+#if defined(__FreeBSD__)
+		mt_buf[i].f_mntfromname
+#elif defined(__SOLARIS__)
+		mt_ptr->mnt_special
 #else
-		&dev_num, mt_ptr->mnt_fsname
+		mt_ptr->mnt_fsname
 #endif
 	    );
 	    if(dev != NULL)
 	    {
-		/* Entry from system's list of mounted devices matches
-		 * one of the Devices in the list so mark that Device as
-		 * mounted
-		 */
+		/* Mark this device as mounted */
 		dev->flags |= EDV_DEVICE_MOUNTED;
 	    }
 
-	    /* Read next mount entry */
-#if defined(__SOLARIS__)
+	    /* Also check if this mounted device's mount path matches
+	     * a Device in the specified list
+	     */
+	    dev = EDVDeviceListMatchMountPath(
+		list, total,
+		&dev_num,
+#if defined(__FreeBSD__)
+                mt_buf[i].f_mntonname
+#elif defined(__SOLARIS__)
+		mt_ptr->mnt_mountp
+#else
+		mt_ptr->mnt_dir
+#endif
+	    );
+	    if(dev != NULL)
+	    {
+		/* Mark this device as mounted */
+		dev->flags |= EDV_DEVICE_MOUNTED;
+	    }
+
+	    /* Get the next mount entry */
+#if defined(__FreeBSD__)
+	    i--;
+#elif defined(__SOLARIS__)
 	    mtback = getmntent(fp, mt_ptr);
 #else
 	    mt_ptr = getmntent(fp);
@@ -127,9 +161,12 @@ void EDVDevicesListUpdateMountStatesFromSystem(
 	}
 
 
-	/* Close system mounted devices list file */
-#if defined(__SOLARIS__)
+	/* Close the system's mounted devices list file */
+#if defined(__FreeBSD__)
+	fp = NULL;	/* Mark the mount info file as closed */
+#elif defined(__SOLARIS__)
 	FClose(fp);
+	g_free(mt_ptr);
 #else
 	endmntent(fp);
 #endif
@@ -143,7 +180,7 @@ edv_device_struct **EDVDevicesListLoadFromFile(
 	const gchar *filename, gint *total
 )
 {
-	FILE *fp;   
+	FILE *fp;
 	gchar *parm;
 	gint dev_num = -1;
 	edv_device_struct **list = NULL, *dev = NULL;
