@@ -10,6 +10,7 @@ gchar **EDVGetConfigurationParameters(
 	edv_context_struct *ctx, gint *total
 );
 
+gboolean EDVGetB(edv_context_struct *ctx, const gchar *parm);
 gint EDVGetI(edv_context_struct *ctx, const gchar *parm);
 glong EDVGetL(edv_context_struct *ctx, const gchar *parm);
 gulong EDVGetUL(edv_context_struct *ctx, const gchar *parm);
@@ -23,23 +24,24 @@ gboolean EDVGetVersion(
 );
 
 
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
- *      Returns a list of parameters.
+ *	Returns a dynamically allocated list of configuration
+ *	parameters.
  *
- *      The calling function must deallocate the returned pointer array
- *      and each string.
+ *	The calling function must delete the returned pointer array
+ *	and each string.
  */
 gchar **EDVGetConfigurationParameters(
 	edv_context_struct *ctx, gint *total
@@ -80,9 +82,20 @@ gchar **EDVGetConfigurationParameters(
 }
 
 /*
- *      Gets the integer value of the given parameter.
- *
- *	This function does not distinguish error returns.
+ *	Gets the boolean value of the specified parameter.
+ */
+gboolean EDVGetB(edv_context_struct *ctx, const gchar *parm)
+{
+        if((ctx == NULL) || STRISEMPTY(parm))
+            return(FALSE);
+
+        return((gboolean)CFGItemListGetValueI(
+            ctx->cfg_list, parm
+        ));
+}
+
+/*
+ *	Gets the integer value of the specified parameter.
  */
 gint EDVGetI(edv_context_struct *ctx, const gchar *parm)
 {
@@ -95,9 +108,7 @@ gint EDVGetI(edv_context_struct *ctx, const gchar *parm)
 }
 
 /*
- *      Gets the long integer value of the given parameter.
- *
- *      This function does not distinguish error returns.
+ *	Gets the long integer value of the specified parameter.
  */
 glong EDVGetL(edv_context_struct *ctx, const gchar *parm)
 {
@@ -110,9 +121,7 @@ glong EDVGetL(edv_context_struct *ctx, const gchar *parm)
 }
 
 /*
- *      Gets the unsigned long integer value of the given parameter.
- *
- *      This function does not distinguish error returns.
+ *	Gets the unsigned long integer value of the specified parameter.
  */
 gulong EDVGetUL(edv_context_struct *ctx, const gchar *parm)
 {
@@ -125,9 +134,7 @@ gulong EDVGetUL(edv_context_struct *ctx, const gchar *parm)
 }
 
 /*
- *      Gets the float value of the given parameter.
- *
- *      This function does not distinguish error returns.
+ *	Gets the float value of the specified parameter.
  */
 gfloat EDVGetF(edv_context_struct *ctx, const gchar *parm)
 {
@@ -140,9 +147,7 @@ gfloat EDVGetF(edv_context_struct *ctx, const gchar *parm)
 }
 
 /*
- *      Gets the double value of the given parameter.
- *
- *      This function does not distinguish error returns.
+ *	Gets the double value of the specified parameter.
  */
 gdouble EDVGetD(edv_context_struct *ctx, const gchar *parm)
 {
@@ -155,9 +160,9 @@ gdouble EDVGetD(edv_context_struct *ctx, const gchar *parm)
 }
 
 /*
- *	Gets the string value of the given parameter.
+ *	Gets the string value of the specified parameter.
  *
- *	The returned pointer must not be modified or deallocated.
+ *	The returned pointer must not be modified or deleted.
  *
  *	Can return NULL if the parameter does not exist.
  */
@@ -171,6 +176,7 @@ gchar *EDVGetS(edv_context_struct *ctx, const gchar *parm)
 	));
 }
 
+
 /*
  *	Convience function to return the version of Endeavour found
  *	in the configuration.
