@@ -17,8 +17,7 @@ typedef enum{
 	EDV_MIMETYPE_ICON_STATE_SELECTED,	/* Directories = Expanded
 						 * Other = Selected */
 	EDV_MIMETYPE_ICON_STATE_EXTENDED,	/* Links = Broken
-						 * Other = Active/Opened/Reserved
-						 */
+						 * Other = Active/Opened/Reserved */
 	EDV_MIMETYPE_ICON_STATE_HIDDEN
 } edv_mimetype_icon_state;
 #define EDV_MIMETYPE_TOTAL_ICON_STATES		4
@@ -34,6 +33,7 @@ typedef enum{
  *	the program (not loaded from file) and always of the category
  *	EDV_MIMETYPE_CLASS_SYSTEM
  */
+#define EDV_MIMETYPE_STR_UNKNOWN		"unknown"
 #define EDV_MIMETYPE_STR_FILE			"file/regular"
 #define EDV_MIMETYPE_STR_FILE_EXECUTABLE	"file/executable"
 #define EDV_MIMETYPE_STR_DIRECTORY		"directory/regular"
@@ -49,9 +49,9 @@ typedef enum{
  */
 typedef struct {
 
-	edv_mimetype_class mt_class;	/* One of EDV_MIMETYPE_CLASS_* */
+	edv_mimetype_class	mt_class;
 
-	/* String value, its intent is determined by mt_class:
+	/* Value, its contents is determined by mt_class:
 	 *
 	 * mt_class			value is a
 	 * --------                     ----------
@@ -62,14 +62,12 @@ typedef struct {
 	 */
 	gchar		*value;
 
-
-	/* The MIME Type type, consider this the name of the entry */
+	/* The MIME Type's type (aka the MIME Type's name) */
 	gchar		*type;
 
 	/* A one line verbose description */
 	gchar		*description;
 
-
 	/* Small 20x20 icons */
 	gchar		*small_icon_file[EDV_MIMETYPE_TOTAL_ICON_STATES];
 
@@ -79,21 +77,18 @@ typedef struct {
 	/* Large 48x48 icons */
 	gchar		*large_icon_file[EDV_MIMETYPE_TOTAL_ICON_STATES];
 
-
-	/* Handler, one of EDV_MIMETYPE_HANDLER_*
-	 *
-	 * This is basically to determine if a command should be used
-	 * to open the object associated with this MIME Type (in the
-	 * case of EDV_MIMETYPE_HANDLER_COMMAND) or to use one of
+	/* Handler, determines if a command should be used to open
+	 * objects assicated with this MIME Type (in the case of member
+	 * handler = EDV_MIMETYPE_HANDLER_COMMAND) or to use one of
 	 * Endeavour's windows to open the object
 	 */
 	edv_mimetype_handler	handler;
 
-	/* Command strings and corresponding command name strings
+	/* Commands and corresponding command names
 	 *
-	 * The first index is usually considered the default
+	 * The first command is usually considered the default
 	 *
-	 * Command are only used if the handler is set to
+	 * Commands are only used if member handler =
 	 * EDV_MIMETYPE_HANDLER_COMMAND
 	 *
 	 * The intention of each command is related by the mt_class as
@@ -103,8 +98,12 @@ typedef struct {
 	 * --------			----------
 	 * EDV_MIMETYPE_CLASS_SYSTEM	*Ignored*
 	 * EDV_MIMETYPE_CLASS_FORMAT	Program commands or program aliases
-	 * EDV_MIMETYPE_CLASS_PROGRAM	Program commands (no aliases)
+	 * EDV_MIMETYPE_CLASS_PROGRAM	Program command (no aliases)
 	 * EDV_MIMETYPE_CLASS_UNIQUE	Program commands or program aliases
+	 *
+	 * If the command is not an absolute path then it is considered
+	 * an alias, an alias is the type (the name) of a MIME Type
+	 * who's member mt_class = EDV_MIMETYPE_CLASS_PROGRAM
 	 */
 	gchar		**command;
 	gchar		**command_name;
