@@ -1,9 +1,11 @@
 #include <string.h>
+#include <sys/types.h>
 #include <limits.h>
 #include <time.h>
 #include <sys/stat.h>
-#include <unistd.h>
 #include <glib.h>
+#include <unistd.h>
+
 #include "edvtypes.h"
 #include "../edvobj.h"
 #include "../edvrecbin.h"
@@ -107,54 +109,94 @@ static void EDVCopyRecycledObjectToStatBuf(
 	    /* Object Type */
 	    switch(SRC->type)
 	    {
+	      case EDV_OBJECT_TYPE_UNKNOWN:
+		break;
 	      case EDV_OBJECT_TYPE_FILE:
+#ifdef S_IFREG
 		TAR->st_mode |= S_IFREG;
+#endif
 		break;
 	      case EDV_OBJECT_TYPE_DIRECTORY:
+#ifdef S_IFDIR
 		TAR->st_mode |= S_IFDIR;
+#endif
 		break;
 	      case EDV_OBJECT_TYPE_LINK:
+#ifdef S_IFLNK
 		TAR->st_mode |= S_IFLNK;
+#endif
 		break;
 	      case EDV_OBJECT_TYPE_DEVICE_BLOCK:
+#ifdef S_IFBLK
 		TAR->st_mode |= S_IFBLK;
+#endif
 		break;
 	      case EDV_OBJECT_TYPE_DEVICE_CHARACTER:
+#ifdef S_IFCHR
 		TAR->st_mode |= S_IFCHR;
+#endif
 		break;
 	      case EDV_OBJECT_TYPE_FIFO:
+#ifdef S_IFIFO
 		TAR->st_mode |= S_IFIFO;
+#endif
 		break;
 	      case EDV_OBJECT_TYPE_SOCKET:
+#ifdef S_IFSOCK
 		TAR->st_mode |= S_IFSOCK;
+#endif
 		break;
 	    }
 
 	    /* Permissions */
+#ifdef S_IXUSR
 	    if(SRC->permissions & EDV_PERMISSION_UEXECUTE)
 		TAR->st_mode |= S_IXUSR;
+#endif
+#ifdef S_IRUSR
 	    if(SRC->permissions & EDV_PERMISSION_UREAD)
 		TAR->st_mode |= S_IRUSR;
+#endif
+#ifdef S_IWUSR
 	    if(SRC->permissions & EDV_PERMISSION_UWRITE)
 		TAR->st_mode |= S_IWUSR;
+#endif
+#ifdef S_IXGRP
 	    if(SRC->permissions & EDV_PERMISSION_GEXECUTE)
 		TAR->st_mode |= S_IXGRP;
+#endif
+#ifdef S_IRGRP
 	    if(SRC->permissions & EDV_PERMISSION_GREAD)
 		TAR->st_mode |= S_IRGRP;
+#endif
+#ifdef S_IWGRP
 	    if(SRC->permissions & EDV_PERMISSION_GWRITE)
 		TAR->st_mode |= S_IWGRP;
+#endif
+#ifdef S_IXOTH
 	    if(SRC->permissions & EDV_PERMISSION_AEXECUTE)
 		TAR->st_mode |= S_IXOTH;
+#endif
+#ifdef S_IROTH
 	    if(SRC->permissions & EDV_PERMISSION_AREAD)
 		TAR->st_mode |= S_IROTH;
+#endif
+#ifdef S_IWOTH
 	    if(SRC->permissions & EDV_PERMISSION_AWRITE)
 		TAR->st_mode |= S_IWOTH;
+#endif
+#ifdef S_ISUID
 	    if(SRC->permissions & EDV_PERMISSION_SETUID)
 		TAR->st_mode |= S_ISUID;
+#endif
+#ifdef S_ISGID
 	    if(SRC->permissions & EDV_PERMISSION_SETGID)
 		TAR->st_mode |= S_ISGID;
+#endif
+#ifdef S_ISVTX
 	    if(SRC->permissions & EDV_PERMISSION_STICKY)
 		TAR->st_mode |= S_ISVTX;
+#endif
 
 	    /* Time Stamps */
 	    TAR->st_atime = (time_t)SRC->access_time;
@@ -363,7 +405,7 @@ guint EDVRecycle(
 )
 {
 	const gchar *s;
-	gchar *dpath, cwd[PATH_MAX];
+	gchar *cwd, *dpath;
 	guint index;
 	gulong date_deleted;
 	mode_t m;
@@ -374,9 +416,8 @@ guint EDVRecycle(
 	if(STRISEMPTY(recycled_index_file) || STRISEMPTY(path))
 	    return(0);
 
-	dpath = EDVCopyEvaluateInputPath(
-	    getcwd(cwd, sizeof(cwd)), path
-	);
+	cwd = EDVGetCWD();
+	dpath = EDVEvaluatePath(cwd, path);
 	date_deleted = (gulong)time(NULL);
 
 	/* Check if local object exists and get the object's local
@@ -385,6 +426,7 @@ guint EDVRecycle(
 	if(lstat(dpath, &lstat_buf))
 	{
 	    g_free(dpath);
+	    g_free(cwd);
 	    return(0);
 	}
 
@@ -398,6 +440,7 @@ guint EDVRecycle(
 	if(TAR == NULL)
 	{                           
 	    g_free(dpath);
+	    g_free(cwd);
 	    return(0);
 	}
 
@@ -422,45 +465,83 @@ guint EDVRecycle(
 	/* Type */
 	if(S_ISREG(m))
 	    TAR->type = EDV_OBJECT_TYPE_FILE;
+#ifdef S_ISDIR
 	else if(S_ISDIR(m))
 	    TAR->type = EDV_OBJECT_TYPE_DIRECTORY;
+#endif
+#ifdef S_ISLNK
 	else if(S_ISLNK(m))
 	    TAR->type = EDV_OBJECT_TYPE_LINK;
+#endif
+#ifdef S_ISBLK
 	else if(S_ISBLK(m))
 	    TAR->type = EDV_OBJECT_TYPE_DEVICE_BLOCK;
+#endif
+#ifdef S_ISCHR
 	else if(S_ISCHR(m))
 	    TAR->type = EDV_OBJECT_TYPE_DEVICE_CHARACTER;
+#endif
+#ifdef S_ISFIFO
 	else if(S_ISFIFO(m))
 	    TAR->type = EDV_OBJECT_TYPE_FIFO;
+#endif
+#ifdef S_ISSOCK
 	else if(S_ISSOCK(m))
 	    TAR->type = EDV_OBJECT_TYPE_SOCKET;
+#endif
+	else
+	    TAR->type = EDV_OBJECT_TYPE_FILE;
 
 	/* Permissions */
 	TAR->permissions = 0;
+#ifdef S_IXUSR
 	if(m & S_IXUSR)
 	    TAR->permissions |= EDV_PERMISSION_UEXECUTE;
+#endif
+#ifdef S_IRUSR
 	if(m & S_IRUSR)
 	    TAR->permissions |= EDV_PERMISSION_UREAD;
+#endif
+#ifdef S_IWUSR
 	if(m & S_IWUSR)
 	    TAR->permissions |= EDV_PERMISSION_UWRITE;
+#endif
+#ifdef S_IXGRP
 	if(m & S_IXGRP)
 	    TAR->permissions |= EDV_PERMISSION_GEXECUTE;
+#endif
+#ifdef S_IRGRP
 	if(m & S_IRGRP)
 	    TAR->permissions |= EDV_PERMISSION_GREAD;
+#endif
+#ifdef S_IWGRP
 	if(m & S_IWGRP)
 	    TAR->permissions |= EDV_PERMISSION_GWRITE;
+#endif
+#ifdef S_IXOTH
 	if(m & S_IXOTH)
 	    TAR->permissions |= EDV_PERMISSION_AEXECUTE;
+#endif
+#ifdef S_IROTH
 	if(m & S_IROTH)
 	    TAR->permissions |= EDV_PERMISSION_AREAD;
+#endif
+#ifdef S_IWOTH
 	if(m & S_IWOTH)
 	    TAR->permissions |= EDV_PERMISSION_AWRITE;
+#endif
+#ifdef S_ISUID
 	if(m & S_ISUID)
 	    TAR->permissions |= EDV_PERMISSION_SETUID;
+#endif
+#ifdef permissions
 	if(m & S_ISGID)
 	    TAR->permissions |= EDV_PERMISSION_SETGID;
+#endif
+#ifdef S_ISVTX
 	if(m & S_ISVTX)
 	    TAR->permissions |= EDV_PERMISSION_STICKY;
+#endif
 
 	/* Time Stamps */
 	TAR->access_time = (gulong)lstat_buf.st_atime;
@@ -505,6 +586,7 @@ guint EDVRecycle(
 
 	EDVRecBinObjectDelete(obj);
 	g_free(dpath);
+	g_free(cwd);
 
 	return(index);
 }
@@ -533,15 +615,14 @@ gint EDVRecover(
 )
 {
 	gint status;
-	gchar *dpath, cwd[PATH_MAX];
+	gchar *cwd, *dpath;
 	const gchar *recycled_index_file = (ctx != NULL) ?
 	    ctx->recycled_index_file : NULL;
 	if(STRISEMPTY(recycled_index_file))
 	    return(-1);
 
-	dpath = EDVCopyEvaluateInputPath(
-	    getcwd(cwd, PATH_MAX), path
-	);
+	cwd = EDVGetCWD();
+	dpath = EDVEvaluatePath(cwd, path);
 
 	/* Recover object */
 	status = EDVRecBinDiskObjectRecover(
@@ -572,6 +653,7 @@ gint EDVRecover(
 	}
 
 	g_free(dpath);
+	g_free(cwd);
 
 	return(status);
 }
