@@ -258,7 +258,7 @@ static void EDVMimeTypesEditIconUpdateDisplay(
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Estndar"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Norme"
+"Normal"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Standard"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -451,11 +451,11 @@ static void EDVMimeTypesEditIconChangeCB(
 Verifique por favor que el sendero especificado es correcto y que el\n\
 archivo es un archivo vlido de la imagen de XPM.\n"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Incapable de charger le fichier d'icne:\n\
+"Impossible de charger le fichier d'icne:\n\
 \n\
     %s\n\
 \n\
-S'il vous plat vrifier que le sentier spcifi est exact et que le\n\
+S'il vous plat vrifier que le rpertoire spcifi est exact et que le\n\
 fichier est un fichier d'image de XPM valide.\n"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Unfhig, abbild akte zu beladen:\n\
@@ -507,7 +507,7 @@ is a valid XPM image file.\n"
 #if defined(PROG_LANGUAGE_SPANISH)
 "Cargue Icono Fallado"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Charger L'Icne Echoue"
+"Charger Icne Echou"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Beladen Sie Abbild, Versagt Wird, Das"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -946,8 +946,8 @@ static void EDVMimeTypesEditWinApplyCB(
 "Aplique Fallado",
 "Este MIME Type no ms largo existe, estos valores se tirarn.\n",
 #elif defined(PROG_LANGUAGE_FRENCH)
-"S'appliquer Echou",
-"Ce MIME Type non plus long existe, ces valeurs seront rejetes.\n",
+"Appliquer Echou",
+"Ce MIME Type n'existe plu, les valeurs seront rejetes.\n",
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Verwenden Sie Versagt".
 "Dieser MIME Type werden nicht mehr, diese werte\n\
@@ -983,8 +983,8 @@ worden bestaat.\n",
 "MIME Type \"%s\" no se puede redactar, porque era ni\n\
 creado internamente ni cargado de una configuracin global.\n"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"MIME Type \"%s\" ne peut pas tre dit, parce qu'il\n\
-ou a t intrieurement cr ou a t charg d'une configuration\n\
+"Le Type MIME \"%s\" ne peut pas tre dit, parce qu'il\n\
+ou a t soit cr intrieurement soit charg par la configuration\n\
 globale.\n"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "MIME Type \"%s\" kann nicht redigiert werden, weil es\n\
@@ -1016,7 +1016,7 @@ configuration.\n"
 #if defined(PROG_LANGUAGE_SPANISH)
 "Aplique Fallado"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"S'appliquer Echou"
+"appliquer Echou"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Verwenden Sie Versagt"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1388,7 +1388,7 @@ static gint EDVMimeTypesEditWinCheckMIMEType(
 #if defined(PROG_LANGUAGE_SPANISH)
 "MIME Type con el ndice #%i no est en la lista"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"MIME Type avec #%i d'index n'est pas dans la liste"
+"MIME Type avec l'index %i n'est pas dans la liste"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "MIME Type mit index #%i ist nicht in der liste"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1510,8 +1510,8 @@ identify any file formats"
 "Ordene reffers de \"%s\" a un MIME Type\n\
 inexistente llam \"%s\".\n"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Ordonner reffers  \"%s\"  un MIME Type\n\
-inexistant a appel \"%s\".\n"
+"la commande \"%s\" fait rfrence  un MIME Type\n\
+inexistant nomm \"%s\".\n"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Befehlen Sie \"%s\" reffers zu einem nicht\n\
 vorhandenen MIME Type hat gerufen \"%s\".\n"
@@ -1595,7 +1595,7 @@ identify this MIME Type"
 \n\
     %s\n"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"L'objet nul d'application:\n\
+"Objet d'application invalide:\n\
 \n\
     %s\n"
 #elif defined(PROG_LANGUAGE_GERMAN)
@@ -1633,9 +1633,9 @@ identify this MIME Type"
 executable. Tambin, se cerciora que usted especifica un sendero\n\
 repleto al objeto de la aplicacin.\n"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"L'objet d'application n'est pas dfini, ne pas existe, ou n'est pas\n\
-rgl executable. Aussi, s'assure que vous spcifiez un sentier plein\n\
- l'objet d'application.\n"
+"L'application n'est pas dfini, ou n'existe pas, ou n'est pas\n\
+executable. Aussi, assurez-vous que vous spcifiez le rpertoire complet\n\
+d'accs  l'application.\n"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Das anwendung objekt ist nicht definiert, existiert nicht, oder ist\n\
 nicht ausfhrbar gesetzt. Vergewissern sie auch sich, da Sie einen\n\
@@ -1685,9 +1685,9 @@ ejecutar la aplicacin reffers a."
 			);
 #elif defined(PROG_LANGUAGE_FRENCH)
 			buf = STRDUP(
-"Aucun ordre a t dfini sur ce MIME Type de\n\
-classe d'application, ce MIME Type ne pourra pas\n\
-excuter l'application il reffers ."
+"Aucune commande n'a t dfinie pour cette classe d'application MIME Type\n\
+, le MIME Type ne pourra pas donc\n\
+excuter l'application auquel il se rfre."
 			);
 #else
 			buf = STRDUP(
@@ -1733,7 +1733,7 @@ identify this MIME Type"
 			);
 #elif defined(PROG_LANGUAGE_FRENCH)
 			buf = STRDUP(
-"L'emplacement d'objet unique pas srie"
+"L'emplacement de l'objet spcifique n'est pas dfini"
 			);
 #else
 			buf = STRDUP(
@@ -1747,7 +1747,7 @@ identify this MIME Type"
 \n\
     %s\n"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Incapable de trouver objec:\n\
+"Impossible de trouver l'objet:\n\
 \n\
     %s\n"
 #elif defined(PROG_LANGUAGE_GERMAN)
@@ -1785,9 +1785,9 @@ identify this MIME Type"
 se define y existe, entonces cheque si sus permisos no permiten\n\
 ser conseguido acceso a."
 #elif defined(PROG_LANGUAGE_FRENCH)
-"L'objet unique n'est pas dfini ou n'apparat pas d'exister. S'il\n\
-est dfini et existe, alors le chque si ses permissions ne\n\
-permettent pas il tre accessed."
+"L'objet spcifique n'est pas dfini ou ne semble pas exister. S'il\n\
+est dfini et existe, alors ses permissions ne\n\
+permettent pas d'y accder."
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Das spezifische objekt ist nicht definiert oder nicht erscheint zu\n\
 existieren. Wenn es dann kontrolle definiert und ist existiert ist,\n\
@@ -1829,7 +1829,7 @@ allow it to be accessed."
 #if defined(PROG_LANGUAGE_SPANISH)
 "Cdigo `%i' no apoyado de clase de MIME Type.\n"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Le code `%i' non soutenu de classe de MIME Type.\n"
+"Le code de la classe MIME Type `%i' n'est pas support.\n"
 #else
 "Unsupported MIME Type class code `%i'.\n"
 #endif
@@ -2415,8 +2415,8 @@ glist = g_list_append(glist, "El Formato Del Archivo");
 glist = g_list_append(glist, "La Aplicacin");
 glist = g_list_append(glist, "El Objeto Especfico");
 #elif defined(PROG_LANGUAGE_FRENCH)
-glist = g_list_append(glist, "Le Type D'Objet De Systme");
-glist = g_list_append(glist, "Format De Fichier");
+glist = g_list_append(glist, "Type de l'objet Systme");
+glist = g_list_append(glist, "Format du Fichier");
 glist = g_list_append(glist, "Application");
 glist = g_list_append(glist, "Objet Spcifique");
 #elif defined(PROG_LANGUAGE_GERMAN)
@@ -2652,10 +2652,10 @@ glist = g_list_append(glist, "Endeavour El Fabricante Del Archivo");
 glist = g_list_append(glist, "Endeavour Imagine A Examinador");
 glist = g_list_append(glist, "Endeavour Recicle Cajn");
 #elif defined(PROG_LANGUAGE_FRENCH)
-glist = g_list_append(glist, "Ordre");
-glist = g_list_append(glist, "Endeavour Archiver Fabricant");
-glist = g_list_append(glist, "Endeavour Navigateur D'Image");
-glist = g_list_append(glist, "Endeavour Recycler L'Huche");
+glist = g_list_append(glist, "Commande");
+glist = g_list_append(glist, "Endeavour Archive");
+glist = g_list_append(glist, "Endeavour Navigateur d'Image");
+glist = g_list_append(glist, "Endeavour Corbeille");
 #elif defined(PROG_LANGUAGE_GERMAN)
 glist = g_list_append(glist, "Befehl");
 glist = g_list_append(glist, "Endeavour Archivieren Sie Hersteller");
@@ -2740,7 +2740,7 @@ heading[0] = "El Nombre";
 heading[1] = "La Orden";
 #elif defined(PROG_LANGUAGE_FRENCH)
 heading[0] = "Nom";
-heading[1] = "Ordre";
+heading[1] = "Commande";
 #elif defined(PROG_LANGUAGE_GERMAN)
 heading[0] = "Name";
 heading[1] = "Befehl";
@@ -2798,7 +2798,7 @@ heading[1] = "Command";
 #if defined(PROG_LANGUAGE_SPANISH)
 "Iconos"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Icnes"
+"Icne"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Abbilder"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -2853,7 +2853,7 @@ heading[1] = "Command";
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Medio"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Milieu"
+"Moyen"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Medium"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -2935,7 +2935,7 @@ heading[1] = "Command";
 #if defined(PROG_LANGUAGE_SPANISH)
 "Aplique"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"S'Appliquer"
+"Appliquer"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Verwenden"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -3017,7 +3017,7 @@ heading[1] = "Command";
 #if defined(PROG_LANGUAGE_SPANISH)
 "Cierre"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Fin"
+"Quitter"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Nah"
 #elif defined(PROG_LANGUAGE_ITALIAN)
