@@ -446,7 +446,7 @@ gboolean EDVMimeTypesMailcapImportOptsGetResponse(
 		rcstyle->font_name = STRDUP(
 "-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-1"
 		);
-		w = gtk_label_new(EDVGetPathName(path));
+		w = gtk_label_new(g_basename(path));
 		gtk_label_set_justify(GTK_LABEL(w), GTK_JUSTIFY_LEFT);
 		gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 		gtk_widget_modify_style(w, rcstyle);
@@ -721,7 +721,7 @@ gboolean EDVMimeTypesMediaTypesImportOptsGetResponse(
 		rcstyle->font_name = STRDUP(
 "-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-1"
 		);
-		w = gtk_label_new(EDVGetPathName(path));
+		w = gtk_label_new(g_basename(path));
 		gtk_label_set_justify(GTK_LABEL(w), GTK_JUSTIFY_LEFT);
 		gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 		gtk_widget_modify_style(w, rcstyle);
