@@ -13,7 +13,7 @@
 #include "edvutils.h"
 #include "mountbar.h"
 #include "endeavour.h"
-#include "edvmount.h"  
+#include "edvmount.h"
 #include "edvcb.h"
 #include "edvop.h"
 #include "edvutilsgtk.h"
@@ -114,7 +114,7 @@ static gint EDVMountBarCrossingCB(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Mount/unmount dispositivo"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Mount/unmount appareil"
+"Monter/Dmonter un composant"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Mount/unmount vorrichtung"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -134,7 +134,7 @@ static gint EDVMountBarCrossingCB(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Expulse medios del dispositivo"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Ejecter la presse de l'appareil"
+"Ejecter le support du composant"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Werfen sie medien von vorrichtung aus"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -154,7 +154,7 @@ static gint EDVMountBarCrossingCB(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Refresque toda estadstica de dispositivo"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Rafrachir toute statistique d'appareil"
+"Rafrachir toutes les statistique composant"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Erfrischen sie alle gertestatistik"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -174,7 +174,7 @@ static gint EDVMountBarCrossingCB(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Vaya a montar sendero"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Aller monter le sentier"
+"Aller au rpertoire mont"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Gehen sie, um pfad aufzustellen"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -198,7 +198,7 @@ static gint EDVMountBarCrossingCB(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Verifique el sistema del archivo de dispositivo"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Vrifier le systme de classement de l'appareil"
+"Vrifier le systme de fichier du composan"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Prfen sie das dateisystem der vorrichtung"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -218,7 +218,7 @@ static gint EDVMountBarCrossingCB(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Corra el programa de instrumentos de dispositivo"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Courir le programme d'outils de l'appareil"
+"Lancer le panneau d'outil du composant"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Laufen sie die werkzeuge der vorrichtung programmieren"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -238,7 +238,7 @@ static gint EDVMountBarCrossingCB(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Formatear los medios en el dispositivo"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Met en format la presse dans l'appareil"
+"Formatter le support dans le composant"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Formatieren sie die medien in der vorrichtung"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -484,7 +484,7 @@ static gint EDVMountBarDeviceEventCB(
 			    continue;
 			if(EDV_DEVICE_IS_UNLISTED(dev))
 			    continue;
-			break;          /* This device is selectable */
+			break;		/* This device is selectable */
 		    }
 		    /* Found a selectable device index? */
 		    if(i >= 0)
@@ -792,12 +792,10 @@ static void EDVMountBarFSCKCB(GtkWidget *widget, gpointer data)
 
 	/* Get the selected device */
 	dev_num = mb->selected_dev_num;
-	if((dev_num >= 0) && (dev_num < core_ptr->total_devices))
-	    dev = core_ptr->device[dev_num];
-	else
-	    dev = NULL;
+	dev = ((dev_num >= 0) && (dev_num < core_ptr->total_devices)) ?
+	    core_ptr->device[dev_num] : NULL;
 	if(dev == NULL)
-	    return;   
+	    return;
 
 	/* Run the device check */
 	EDVRunDeviceCheck(
@@ -823,10 +821,8 @@ static void EDVMountBarToolsCB(GtkWidget *widget, gpointer data)
 
 	/* Get the selected device */
 	dev_num = mb->selected_dev_num;
-	if((dev_num >= 0) && (dev_num < core_ptr->total_devices))
-	    dev = core_ptr->device[dev_num];
-	else
-	    dev = NULL;
+        dev = ((dev_num >= 0) && (dev_num < core_ptr->total_devices)) ?
+            core_ptr->device[dev_num] : NULL;
 	if(dev == NULL)  
 	    return;
 
@@ -854,10 +850,8 @@ static void EDVMountBarFormatCB(GtkWidget *widget, gpointer data)
 
 	/* Get the selected device */
 	dev_num = mb->selected_dev_num;
-	if((dev_num >= 0) && (dev_num < core_ptr->total_devices))
-	    dev = core_ptr->device[dev_num];
-	else
-	    dev = NULL;
+        dev = ((dev_num >= 0) && (dev_num < core_ptr->total_devices)) ?
+            core_ptr->device[dev_num] : NULL;
 	if(dev == NULL)
 	    return;
 
@@ -1283,7 +1277,7 @@ Free & Available: %s kb  Free: %s kb";
 #if defined(PROG_LANGUAGE_SPANISH)
 		fmt = "El Artefacto \"%s\" No Mont";
 #elif defined(PROG_LANGUAGE_FRENCH)
-		fmt = "L'Appareil \"%s\" Pas Mont";
+		fmt = "Composant \"%s\" Non Mont";
 #else
 		fmt = "Device \"%s\" Not Mounted";
 #endif
@@ -1465,7 +1459,7 @@ edv_mountbar_struct *EDVMountBarNew(
 #if defined(PROG_LANGUAGE_SPANISH)
 	    "El monte/artefacto de unmount"
 #elif defined(PROG_LANGUAGE_FRENCH)
-	    "Appareil de monte/unmount"
+	    "Monte/dmonte le composant"
 #else
 	    "Mount/unmount the device"
 #endif
@@ -1495,7 +1489,7 @@ edv_mountbar_struct *EDVMountBarNew(
 #if defined(PROG_LANGUAGE_SPANISH)
 	    "Expulse medios del artefacto"
 #elif defined(PROG_LANGUAGE_FRENCH)
-	    "Ejecter le presse de l'appareil"
+	    "Ejecter le support du composant"
 #else
 	    "Eject the media from the device"
 #endif
@@ -1525,7 +1519,7 @@ edv_mountbar_struct *EDVMountBarNew(
 #if defined(PROG_LANGUAGE_SPANISH)
 	    "Refresque toda estadstica de artefacto"
 #elif defined(PROG_LANGUAGE_FRENCH)
-	    "Rafrachir toute statistique d'appareil"
+	    "Rafrachir toute statistique composant"
 #else
 	    "Refresh all device statistics"
 #endif
@@ -1560,7 +1554,7 @@ edv_mountbar_struct *EDVMountBarNew(
 #if defined(PROG_LANGUAGE_SPANISH)
 	    "Vaya a montar sendero"
 #elif defined(PROG_LANGUAGE_FRENCH)
-	    "Aller monter le sentier"
+	    "Aller au point de montage"
 #else
 	    "Go to the mount path"
 #endif
@@ -1619,7 +1613,7 @@ edv_mountbar_struct *EDVMountBarNew(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Verifique el sistema del archivo de dispositivo"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Vrifier le systme de classement de l'appareil"
+"Vrifier le systme de fichier du composant"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Prfen sie das dateisystem der vorrichtung"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1659,7 +1653,7 @@ edv_mountbar_struct *EDVMountBarNew(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Corra el programa de instrumentos de dispositivo"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Courir le programme d'outils de l'appareil"
+"Lancer le panneau de contrle du composant"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Laufen sie die werkzeuge der vorrichtung programmieren"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1699,7 +1693,7 @@ edv_mountbar_struct *EDVMountBarNew(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Formatear los medios en el dispositivo"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Met en format la presse dans l'appareil"
+"Formatte le support dans le composant"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Formatieren sie die medien in der vorrichtung"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1822,7 +1816,7 @@ void EDVMountBarUpdateMenus(edv_mountbar_struct *mb)
 	{
 	    const gchar *s = dev->name;
 	    if((s == NULL) && (dev->device_path != NULL))
-		s = EDVGetPathName(dev->device_path);
+		s = g_basename(dev->device_path);
 	    if(s == NULL)
 		s = "(null)";
 
@@ -1873,10 +1867,10 @@ void EDVMountBarUpdateMenus(edv_mountbar_struct *mb)
 	);
 
 
-	/* Redraw device icon and label */
+	/* Redraw the device icon and label */
 	gtk_widget_queue_draw(mb->dev_da);
 
-	/* Update stats label */
+	/* Update and redraw the stats label */
 	EDVMountBarSetStats(mb);
 }
 
