@@ -699,7 +699,7 @@ optwin_struct *OptWinNew(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Aplique"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"S'Appliquer"
+"Appliquer"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Verwenden"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -738,7 +738,7 @@ optwin_struct *OptWinNew(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Salve"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Epargner"
+"Enregistrer"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Auer"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -818,7 +818,7 @@ optwin_struct *OptWinNew(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Cierre"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Fin"
+"Quitter"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Nah"
 #elif defined(PROG_LANGUAGE_ITALIAN)
