@@ -1,6 +1,10 @@
 #include <stdlib.h>
 #include <string.h>
-#include <sys/time.h>
+#if defined(WIN32)
+# include <windows.h>
+#else
+# include <sys/time.h>
+#endif
 
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
@@ -241,8 +245,10 @@ static gint ProgressDialogAnimationDrawCB(
 	total_frames = MAX(pd->total_icons + 2, 2);
 
 	/* Calculate animation frame index */
-	frame = (gfloat)pd->animation_position / (gfloat)((guint16)-1) *
-	    total_frames;
+	frame = (gint)(
+	    (gfloat)pd->animation_position / (gfloat)((guint16)-1) *
+	    total_frames
+	);
 
 	/* Calculate number of animation units in one frame */
 	if(total_frames > 0)
@@ -393,7 +399,7 @@ static gint ProgressDialogAnimationDrawCB(
 		iframe_coeff = 0.0f;
 
 	    /* Calculate icon index based on inside frame coeff */
-	    i = iframe_coeff * pd->total_icons;
+	    i = (gint)(iframe_coeff * pd->total_icons);
 
 	    /* Check which icon structure to draw based on frame index */
 	    if((i >= 0) && (i < pd->total_icons))
@@ -416,7 +422,7 @@ static gint ProgressDialogAnimationDrawCB(
 		    width - start_icon_width - end_icon_width - icon_width,
 		    0
 		);
-		x = (iframe_coeff * range) + start_icon_width;
+		x = (gint)(iframe_coeff * range) + start_icon_width;
 
 		/* Calculate y position based on iframe_coeff and range */
 		range = MAX(
@@ -425,13 +431,13 @@ static gint ProgressDialogAnimationDrawCB(
 		);
 		if(iframe_coeff > 0.5f)
 		{
-		    gfloat tc = (iframe_coeff - 0.5) / 0.5;
-		    y = (tc * tc) * range;
+		    const gfloat tc = (gfloat)((iframe_coeff - 0.5) / 0.5);
+		    y = (gint)((tc * tc) * range);
 		}
 		else
 		{
-		    gfloat tc = 1.0 - (iframe_coeff / 0.5);
-		    y = (tc * tc) * range;
+		    const gfloat tc = (gfloat)(1.0 - (iframe_coeff / 0.5));
+		    y = (gint)((tc * tc) * range);
 		}
 		y += y_border;	/* Add 5 pixels margin */
 
@@ -481,7 +487,7 @@ static gint ProgressDialogAnimationDrawCB(
  */
 static gulong ProgressDialogCurrentTime(void)
 {
-#if defined(_WIN32)
+#if defined(WIN32)
 	SYSTEMTIME t;   /* Current time of day structure */
 
 	GetSystemTime(&t);
@@ -1262,7 +1268,6 @@ void ProgressDialogUpdate(
 	progress_dialog_struct *pd = &progress_dialog;
 	GtkWidget *w;
 
-
 	if(!pd->initialized || !pd->map_state)
 	    return;
 
@@ -1301,7 +1306,6 @@ void ProgressDialogUpdate(
 	    GtkProgress *pr = GTK_PROGRESS(w);
 	    GtkProgressBar *pb = GTK_PROGRESS_BAR(w);
 
-
 	    if(position > 1.0)
 		position = 1.0;
 	    else if(position < 0.0)
@@ -1325,7 +1329,7 @@ void ProgressDialogUpdate(
 		    pb, GTK_PROGRESS_CONTINUOUS
 		);
 	    }
-	    gtk_progress_bar_update(pb, position);
+	    gtk_progress_bar_update(pb, (gfloat)position);
 	}
 
 	/* Check if animation drawing area widget is mapped */
@@ -1460,7 +1464,7 @@ void ProgressDialogUpdateUnknown(
 	    gtk_progress_bar_set_bar_style(
 		pb, GTK_PROGRESS_CONTINUOUS
 	    );
-	    gtk_progress_set_value(pr, position);
+	    gtk_progress_set_value(pr, (gfloat)position);
 	}
 
 	/* Check if animation drawing area widget is mapped */
