@@ -121,6 +121,10 @@ struct _edv_propdlg_struct {
 
 
 /* Callbacks */
+extern void EDVPropDlgObjectAddedNotifyCB(
+        edv_propdlg_struct *pd, const gchar *path,
+        const struct stat *lstat_buf
+);
 extern void EDVPropDlgObjectModifiedNotifyCB(
 	edv_propdlg_struct *pd,
 	const gchar *path, const gchar *new_path,
