@@ -91,7 +91,7 @@ void EDVRecBinUpdateContentsHeadings(
 	edv_recbin_struct *recbin,
 	const gint *contents_heading, gint total_contents_headings
 );
-void EDVRecBinSetBusy(edv_recbin_struct *recbin, gboolean is_busy);
+void EDVRecBinSetBusy(edv_recbin_struct *recbin, gboolean busy);
 gboolean EDVRecBinIsMapped(edv_recbin_struct *recbin);
 void EDVRecBinMap(edv_recbin_struct *recbin);
 void EDVRecBinUnmap(edv_recbin_struct *recbin);
@@ -147,7 +147,11 @@ edv_recbin_opid_struct *EDVRecBinMatchOPID(
 void EDVRecBinSetTitle(edv_recbin_struct *recbin)
 {
 	gboolean include_user_name;
+#if defined(PROG_LANGUAGE_FRENCH)
+	const gchar *prog_name = "Corbeille";
+#else
 	const gchar *prog_name = "Recycle Bin";
+#endif
 	gchar *title;
 	GtkWidget *w;
 	const cfg_item_struct *cfg_list;
@@ -424,8 +428,8 @@ void EDVRecBinToolBarRegenerate(edv_recbin_struct *recbin)
 	    return;
 
 	/* Delete existing Tool Bar if any */
-	ToolBarDelete(recbin->toolbar);
-	recbin->toolbar = NULL;
+	ToolBarDelete(recbin->tool_bar);
+	recbin->tool_bar = NULL;
 
 	/* Create Tool Bar items list */
 	glist = intlist->list;
@@ -477,7 +481,7 @@ void EDVRecBinToolBarRegenerate(edv_recbin_struct *recbin)
 	}
 
 	/* Create new Tool Bar */
-	recbin->toolbar = toolbar = ToolBarNew(
+	recbin->tool_bar = toolbar = ToolBarNew(
 	    item, total_items, parent,
 	    tb_display, tb_relief, FALSE
 	);
@@ -706,8 +710,8 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	tooltip = "Cierre esta ventana";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	button_name = "Proche";
-	menu_name = "Proche";
+	button_name = "Fermer";
+	menu_name = "Fermer";
 	tooltip = "Fermer cette fentre";
 #endif
 	accel_key = GDK_w;
@@ -730,8 +734,8 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	tooltip = "Cierra todas ventanas en la aplicacin y la";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	button_name = "Sortie";
-	menu_name = "Sortie";
+	button_name = "Quitter";
+	menu_name = "Quitter";
 	tooltip = "Ferme toutes fentres dans l'application et sortie";
 #endif
 	accel_key = GDK_q;
@@ -755,9 +759,9 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	tooltip = "Limpan cualquiera transferencias pendientes de datos al disco";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	button_name = "Disq Syn";
-	menu_name = "Les Disques De Syn";
-	tooltip = "Rincer des transferts de donnes en attente au disque";
+	button_name = "Synchro";
+	menu_name = "Synchroniser Les Disques";
+	tooltip = "Mettre  jour les transferts de donnes en attente au disque";
 #endif
 	accel_key = 0;
 	accel_mods = 0;
@@ -779,9 +783,9 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	tooltip = "La Historia de rdenes procesadas por esta aplicacin";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	button_name = "L'Histoire";
-	menu_name = "L'Histoire...";
-	tooltip = "L'Histoire d'ordres traits par cette application";
+	button_name = "Historique";
+	menu_name = "Historique...";
+	tooltip = "Historique des commandes traites par cette application";
 #endif
 	accel_key = 0;
 	accel_mods = 0;
@@ -803,8 +807,8 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	tooltip = "Corra un programa";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	button_name = "Courir";
-	menu_name = "Courir...";
+	button_name = "Excuter";
+	menu_name = "Excuter...";
 	tooltip = "Excute un programme";
 #endif
 	accel_key = GDK_r;
@@ -827,9 +831,9 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	tooltip = "Corre una terminal";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	button_name = "Le Terminal";
-	menu_name = "Le Terminal";
-	tooltip = "Courir un terminal";
+	button_name = "Terminal";
+	menu_name = "Terminal";
+	tooltip = "Ouvrir un terminal";
 #endif
 	accel_key = 0;
 	accel_mods = 0;
@@ -853,7 +857,7 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 #ifdef PROG_LANGUAGE_FRENCH
 	button_name = "Protge";
 	menu_name = "Protge En criture";
-	tooltip = "Rend capable/rend infirme protge en criture";
+	tooltip = "En-service/Hors-service la protection en criture";
 #endif
 	accel_key = GDK_y;
 	accel_mods = GDK_CONTROL_MASK;
@@ -869,9 +873,9 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	menu_name = "Sync Recycle Bin";
 	tooltip = "Compact recycled objects and fix any errors";
 #elif defined(PROG_LANGUAGE_FRENCH)
-	button_name = "SynRecBin";
-	menu_name = "Sync Recycle Bin";
-	tooltip = "Compact recycled objects and fix any errors";
+	button_name = "SynCorbeille";
+	menu_name = "Compacte la Corbeille";
+	tooltip = "Compacte la Corbeille et corrige toutes les erreurs";
 #elif defined(PROG_LANGUAGE_GERMAN)
 	button_name = "SynRecBin";
 	menu_name = "Sync Recycle Bin";
@@ -910,7 +914,7 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 #ifdef PROG_LANGUAGE_ENGLISH
 	button_name = "Recover";
 	menu_name = "Recover";
-	tooltip = "Recover selected object(s)";
+	tooltip = "Recover the selected object(s)";
 #endif
 #ifdef PROG_LANGUAGE_SPANISH
 	button_name = "Recupere";
@@ -934,7 +938,7 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 #ifdef PROG_LANGUAGE_ENGLISH
 	button_name = "Purge";
 	menu_name = "Purge";
-	tooltip = "Permanently discard selected object(s)";
+	tooltip = "Permanently discard the selected object(s)";
 #endif
 #ifdef PROG_LANGUAGE_SPANISH
 	button_name = "Purga";
@@ -943,7 +947,7 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
 	button_name = "Purge";
-	menu_name = "La Purge";
+	menu_name = "Purge";
 	tooltip = "D'Une faon permanente rejeter l'objet choisi(s)";
 #endif
 	accel_key = GDK_Delete;
@@ -958,7 +962,7 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 #ifdef PROG_LANGUAGE_ENGLISH
 	button_name = "Purge All";
 	menu_name = "Purge All";
-	tooltip = "Permanently discard all recycled objects";
+	tooltip = "Permanently discard all of the recycled objects";
 #endif
 #ifdef PROG_LANGUAGE_SPANISH
 	button_name = "PurgTodo";
@@ -968,7 +972,7 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 #ifdef PROG_LANGUAGE_FRENCH
 	button_name = "PurgTout";
 	menu_name = "Purger Tout";
-	tooltip = "D'Une faon permanente rejeter tous objets recycls";
+	tooltip = "d'une faon permanente rejeter tous objets recycls";
 #endif
 	accel_key = GDK_Delete;
 	accel_mods = GDK_SHIFT_MASK;
@@ -1016,8 +1020,8 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
 	button_name = "UnSelAll";
-	menu_name = "Unchoisir Tout";
-	tooltip = "Unchoisir tous objets";
+	menu_name = "Aucun";
+	tooltip = "Aucun objets slects";
 #endif
 	accel_key = GDK_u;
 	accel_mods = GDK_CONTROL_MASK;
@@ -1043,8 +1047,8 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 #ifdef PROG_LANGUAGE_FRENCH
 	button_name = "InvSel";
 	menu_name = "Inverser Slection";
-	tooltip =
- "Choisir tous objets dslections et deslectionner tous objets choisis";
+	tooltip = "Rejete tous les objets slections et slectionne les autres";
+
 #endif
 	accel_key = GDK_i;
 	accel_mods = GDK_CONTROL_MASK;
@@ -1066,9 +1070,9 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	tooltip = "El Hallazgo se opone (s) por atributos especificados";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	button_name = "Dcouverte";
-	menu_name = "La Dcouverte";
-	tooltip = "L'objet de Dcouverte (s) par les attributs spcifis ";
+	button_name = "Find";
+	menu_name = "Recherche";
+	tooltip = "Recherche le objet(s) suivant les attributs spcifis ";
 #endif
 	accel_key = GDK_f;
 	accel_mods = GDK_CONTROL_MASK;
@@ -1139,9 +1143,9 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	tooltip = "La Exposicin/la barra de herramienta de cuero";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	button_name = "ToolBar";
-	menu_name = "Tool Bar";
-	tooltip = "La barre d'outil de montre/peau";
+	button_name = "Outils";
+	menu_name = "Barre d'outils";
+	tooltip = "Monter/cacher la barre d'outil";
 #endif
 	accel_key = 0;
 	accel_mods = 0;
@@ -1163,9 +1167,9 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	tooltip = "La exposicin/la barra del hallazgo del cuero";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	button_name = "FindBar";
-	menu_name = "Find Bar";
-	tooltip = "La barre de dcouverte de montre/peau";
+	button_name = "Recherche";
+	menu_name = "Barre de Recherche";
+	tooltip = "Montrer/cacher la barre de Recherche";
 #endif
 	accel_key = 0;
 	accel_mods = 0;
@@ -1187,9 +1191,9 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	tooltip = "La exposicin/la barra de la posicin del cuero";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	button_name = "StatusBar";
-	menu_name = "Status Bar";
-	tooltip = "La barre de statut de montre/peau";
+	button_name = "Etat";
+	menu_name = "Barre d'tat";
+	tooltip = "monter/cacher la barre d'tat";
 #endif
 	accel_key = 0;
 	accel_mods = 0;
@@ -1214,7 +1218,7 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 #ifdef PROG_LANGUAGE_FRENCH
 	button_name = "MIMETypes";
 	menu_name = "MIME Types...";
-	tooltip = "Vue/modifie MIME Types";
+	tooltip = "Voir/modifie MIME Types";
 #endif
 	accel_key = GDK_m;
 	accel_mods = GDK_CONTROL_MASK;
@@ -1237,9 +1241,9 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	tooltip = "Crea a un examinador nuevo del archivo";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	button_name = "FBrowser";
-	menu_name = "Nouveau Browser de Fichier";
-	tooltip = "Crer un nouveau browser de fichier";
+	button_name = "Dossier";
+	menu_name = "Nouveau navigateur de Fichier";
+	tooltip = "Crer un nouveau navigateur de fichier";
 #endif
 	accel_key = GDK_1;
 	accel_mods = GDK_CONTROL_MASK;
@@ -1261,9 +1265,9 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	tooltip = "Crea a un examinador nuevo de la imagen";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	button_name = "IBrowser";
-	menu_name = "Nouveau Browser D'Image";
-	tooltip = "Crer un nouveau browser d'image";
+	button_name = "Galerie";
+	menu_name = "Nouveau Navigateur d'Image";
+	tooltip = "Crer un nouveau navigateur d'image";
 #endif
 	accel_key = GDK_2;
 	accel_mods = GDK_CONTROL_MASK;
@@ -1285,9 +1289,9 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	tooltip = "Crea un archiver nuevo";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	button_name = "Archiver";
-	menu_name = "Nouveau Archiver";
-	tooltip = "Crer un nouveau archiver";
+	button_name = "Archive";
+	menu_name = "Nouvelle Archive";
+	tooltip = "Crer un nouvelle archive";
 #endif
 	accel_key = GDK_3;
 	accel_mods = GDK_CONTROL_MASK;
@@ -1310,9 +1314,9 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	tooltip = "Modifican estas opciones de la aplicacin";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	button_name = "Les Options";
-	menu_name = "Les Options";
-	tooltip = "Modifier ces options de l'application";
+	button_name = "Options";
+	menu_name = "Options";
+	tooltip = "Modifier les options de l'application";
 #endif
 	accel_key = GDK_o;
 	accel_mods = GDK_CONTROL_MASK;
@@ -1334,9 +1338,9 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	tooltip = "Personaliza la mirada y se siente de esta aplicacin";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	button_name = "Personnal";
-	menu_name = "Personnalise...";
-	tooltip = "Personnalise le regard et sens de cette application";
+	button_name = "Prfrences";
+	menu_name = "Prfrences...";
+	tooltip = "Rgle les prfrences pour cette application";
 #endif
 	accel_key = GDK_t;
 	accel_mods = GDK_CONTROL_MASK;
@@ -1359,9 +1363,9 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	tooltip = "El Indice de toda ayuda pagina";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	button_name = "L'Aide";
-	menu_name = "Les Contenus";
-	tooltip = "L'Index de toutes pages d'aide";
+	button_name = "Aide";
+	menu_name = "Contenu d'aide";
+	tooltip = "Index de toutes les pages d'aide";
 #endif
 	accel_key = GDK_F1;
 	accel_mods = 0;
@@ -1408,9 +1412,15 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	flags = 0;
 	button_icon_data = (guint8 **)icon_help_20x20_xpm;
 	menu_icon_data = NULL;
+#ifdef PROG_LANGUAGE_FRENCH
+	button_name = "Aide";
+	menu_name = "Corbeille";
+	tooltip = "aide sur l'utilisation de la Corbeille";
+#else
 	button_name = "Help";
 	menu_name = "Recycle Bin";
 	tooltip = "Help on using the recycle bin";
+#endif
 	accel_key = 0;
 	accel_mods = 0;
 	DO_APPEND_OPID
@@ -1431,9 +1441,9 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	tooltip = "La Lista de todo teclado las operaciones claves";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	button_name = "HelpKeys";
-	menu_name = "La Liste De Clefs";
-	tooltip = "La Liste de tout clavier toutes oprations principales";
+	button_name = "Raccourcis";
+	menu_name = "Raccourcis clavier";
+	tooltip = "Liste des raccourcis clavier pour les oprations principales";
 #endif
 	accel_key = 0;
 	accel_mods = 0;
@@ -1455,9 +1465,9 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	tooltip = "La Ayuda en las operaciones ms comunes";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	button_name = "HelpOp";
+	button_name = "Oprations";
 	menu_name = "Les Oprations Communes";
-	tooltip = "L'Aide sur montant des appareils";
+	tooltip = "Aide sur montage des composants";
 #endif
 	accel_key = 0;
 	accel_mods = 0;
@@ -1479,9 +1489,9 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	tooltip = "Acerca de esta aplicacin";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	button_name = "De";
-	menu_name = "De";
-	tooltip = "De cette application";
+	button_name = "A propos";
+	menu_name = "A propos";
+	tooltip = "A propos de cette application";
 #endif
 	accel_key = 0;
 	accel_mods = 0;
@@ -1791,7 +1801,7 @@ static void EDVRecBinCreateMenuBar(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Vista"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Vue"
+"Voir"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Blick"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1832,7 +1842,7 @@ static void EDVRecBinCreateMenuBar(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Escenarios"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Montages"
+"Rglages"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Setzen"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1870,7 +1880,7 @@ static void EDVRecBinCreateMenuBar(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Ventanas"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Windows"
+"Fentres"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Fenster"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -2026,7 +2036,7 @@ edv_recbin_struct *EDVRecBinNew(gpointer core_ptr)
 	recbin->contents_clist_selected_row = -1;
 	recbin->last_recbin_items = -1;
 	recbin->last_write_protect_state = -1;
-	recbin->findbar = NULL;
+	recbin->find_bar = NULL;
 	recbin->status_bar = NULL;
 
 
@@ -2133,7 +2143,7 @@ edv_recbin_struct *EDVRecBinNew(gpointer core_ptr)
 	if(recbin->tool_bar_map_state)
 	    gtk_widget_show(w);
 	/* Build tool bar later */
-	recbin->toolbar = NULL;
+	recbin->tool_bar = NULL;
 
 
 	/* GtkHandleBox for the Find Bar */
@@ -2152,7 +2162,7 @@ edv_recbin_struct *EDVRecBinNew(gpointer core_ptr)
 	parent2 = w;
 
 	/* Create the Find Bar */
-	recbin->findbar = EDVFindBarNew(
+	recbin->find_bar = EDVFindBarNew(
 	    core_ptr, parent2,
 	    EDV_FINDBAR_ROLE_RECYCLED_OBJECT,
 	    NULL,
@@ -2163,7 +2173,7 @@ edv_recbin_struct *EDVRecBinNew(gpointer core_ptr)
 	    EDVRecBinStatusProgressCB,
 	    recbin
 	);
-	EDVFindBarMap(recbin->findbar);
+	EDVFindBarMap(recbin->find_bar);
 
 
 	/* Scrolled window for contents clist */
@@ -2209,11 +2219,11 @@ edv_recbin_struct *EDVRecBinNew(gpointer core_ptr)
 	    GTK_OBJECT(w), "motion_notify_event",
 	    GTK_SIGNAL_FUNC(EDVCListMotionEventCB), core_ptr
 	);
-	gtk_signal_connect(
+	gtk_signal_connect_after(
 	    GTK_OBJECT(w), "key_press_event",
 	    GTK_SIGNAL_FUNC(EDVRecBinKeyEventCB), recbin
 	);
-	gtk_signal_connect(
+	gtk_signal_connect_after(
 	    GTK_OBJECT(w), "key_release_event",
 	    GTK_SIGNAL_FUNC(EDVRecBinKeyEventCB), recbin
 	);
@@ -2250,7 +2260,7 @@ edv_recbin_struct *EDVRecBinNew(gpointer core_ptr)
 	    dnd_src_types,
 	    sizeof(dnd_src_types) / sizeof(GtkTargetEntry),
 	    GDK_ACTION_MOVE,			/* Actions */
-	    GDK_BUTTON1_MASK | GDK_BUTTON2_MASK,/* Buttons */
+	    GDK_BUTTON1_MASK,			/* Buttons */
 	    NULL,
 	    EDVRecBinContentsDragDataGetCB,
 	    EDVRecBinContentsDragDataDeleteCB,
@@ -2361,7 +2371,7 @@ void EDVRecBinUpdateMenus(edv_recbin_struct *recbin)
 
 	cfg_list = core_ptr->cfg_list;
 
-	tb = recbin->toolbar;
+	tb = recbin->tool_bar;
 
 #define DO_SHOW			\
 { if(w != NULL) gtk_widget_show(w); }
@@ -2537,54 +2547,41 @@ void EDVRecBinUpdateMenus(edv_recbin_struct *recbin)
 /*
  *	Sets the Recycle Bin as busy or ready.
  */
-void EDVRecBinSetBusy(edv_recbin_struct *recbin, gboolean is_busy)
+void EDVRecBinSetBusy(edv_recbin_struct *recbin, gboolean busy)
 {
-	GdkCursor *cursor;
+	GdkCursor *cur;
 	GtkWidget *w;
 	edv_core_struct *core_ptr;
 
-
 	if(recbin == NULL)
 	    return;
 
+	w = recbin->toplevel;
 	core_ptr = EDV_CORE(recbin->core_ptr);
-	if(core_ptr == NULL)
+	if((w == NULL) || (core_ptr == NULL))
 	    return;
 
-	w = recbin->toplevel;
-	if(w != NULL)
+	if(busy)
 	{
-	    if(is_busy)
-	    {
-		/* Increase busy count */
-		recbin->busy_count++;
+	    recbin->busy_count++;
+	    if(recbin->busy_count > 1)
+		return;
+	    cur = EDVGetCursor(core_ptr, EDV_CURSOR_CODE_BUSY);
+	}
+	else
+	{
+	    recbin->busy_count--;
+	    if(recbin->busy_count < 0)
+		recbin->busy_count = 0;
+	    if(recbin->busy_count > 0)
+		return;
+	    cur = NULL;
+	}
 
-		/* If already busy then don't change anything */
-		if(recbin->busy_count > 1)
-		    return;
-
-		cursor = EDVGetCursor(core_ptr, EDV_CURSOR_CODE_BUSY);
-	    }
-	    else
-	    {
-		/* Reduce busy count */
-		recbin->busy_count--;
-		if(recbin->busy_count < 0)
-		    recbin->busy_count = 0;
-
-		/* If still busy do not change anything */
-		if(recbin->busy_count > 0)
-		    return;
-
-		cursor = NULL;  /* Use default cursor */
-	    }
-
-	    /* Update toplevel window's cursor */
-	    if(w->window != NULL)
-	    {
-		gdk_window_set_cursor(w->window, cursor);
-		gdk_flush();
-	    }
+	if(w->window != NULL)
+	{
+	    gdk_window_set_cursor(w->window, cur);
+	    gdk_flush();
 	}
 }
 
@@ -2644,12 +2641,12 @@ void EDVRecBinDelete(edv_recbin_struct *recbin)
 	recbin->status_bar = NULL;
 
 	/* Delete the Find Bar */
-	EDVFindBarDelete(recbin->findbar);
-	recbin->findbar = NULL;
+	EDVFindBarDelete(recbin->find_bar);
+	recbin->find_bar = NULL;
 
 	/* Delete the Tool Bar */
-	ToolBarDelete(recbin->toolbar);
-	recbin->toolbar = NULL;
+	ToolBarDelete(recbin->tool_bar);
+	recbin->tool_bar = NULL;
 
 
 	/* Destroy the Menus and the Menu Bar */
