@@ -97,11 +97,11 @@ void EDVRecBinRecycledObjectRemovedNotifyCB(
 void EDVRecBinReconfiguredNotifyCB(edv_recbin_struct *recbin);
 void EDVRecBinMimeTypeAddedCB(
 	edv_recbin_struct *recbin,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 );
 void EDVRecBinMimeTypeModifiedCB(
 	edv_recbin_struct *recbin,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 );
 void EDVRecBinMimeTypeRemovedCB(
 	edv_recbin_struct *recbin, gint mt_num
@@ -364,8 +364,9 @@ gint EDVRecBinKeyEventCB(
 		 * item who's name starts with the letter of the key
 		 * that was pressed
 		 */
-		if(isalnum((char)keyval) && is_press &&
-		   ((state == 0x00000000) || (state == GDK_SHIFT_MASK))
+		if(isalnum((int)keyval) && is_press &&
+                   !(state & GDK_CONTROL_MASK) &&
+                   !(state & GDK_SHIFT_MASK)    
 		)
 		{
 		    /* Get the column that is displaying the object
@@ -760,9 +761,10 @@ void EDVRecBinSelectRowCB(
 	/* Check which clist this signal is for */
 	if(GTK_WIDGET(clist) == recbin->contents_clist)
 	{
+	    edv_core_struct *core_ptr = EDV_CORE(recbin->core_ptr);
+
 	    /* Get total number of objects selected */
-	    gint total_selected = (clist->selection != NULL) ?
-		g_list_length(clist->selection) : 0;
+	    const gint nselected = g_list_length(clist->selection);
 
 	    /* Get object */
 	    edv_recbin_object_struct *obj = EDV_RECBIN_OBJECT(
@@ -826,10 +828,10 @@ void EDVRecBinSelectRowCB(
 		    }
 
 		    /* Set status bar message */
-		    if(total_selected > 1)
+		    if(nselected > 1)
 			buf = g_strdup_printf(
-			    "%i objects selected",
-			    total_selected
+			    "%s objects selected",
+			    EDVGetObjectSizeStr(core_ptr, nselected)
 			);
 		    else if(!strcmp(obj->name, ".."))
 			buf = g_strdup_printf(
@@ -892,18 +894,33 @@ void EDVRecBinUnselectRowCB(
 	/* Check which clist this signal is for */
 	if(GTK_WIDGET(clist) == recbin->contents_clist)
 	{
+	    gchar *buf;
+	    edv_core_struct *core_ptr = EDV_CORE(recbin->core_ptr);
 
+	    /* Get total number of objects selected */
+	    const gint nselected = g_list_length(clist->selection);
+
+	    /* Update status bar message */
+	    if(nselected > 0)
+		buf = g_strdup_printf(
+		    "%s object%s selected",
+		    EDVGetObjectSizeStr(core_ptr, nselected),
+		    (nselected == 1) ? "" : "s"  
+		);
+	    else
+		buf = STRDUP("No objects selected");
+	    EDVStatusBarMessage(
+		recbin->status_bar, buf, FALSE
+	    );
+	    g_free(buf);
 
-/*	    EDVRecBinSetTitle(recbin); */
 	    EDVRecBinUpdateMenus(recbin);
 	}
 }
 
 
 /*
- *      Called whenever the global write protect has changed.
- *
- *      The new state is given as state.
+ *	Write protect changed callback.
  */
 void EDVRecBinWriteProtectChangedCB(
 	edv_recbin_struct *recbin, gboolean state
@@ -919,8 +936,7 @@ void EDVRecBinWriteProtectChangedCB(
 }
 
 /*
- *      Called whenever a recycled object has been added to the recycled
- *	objects directory.
+ *	Recycled object added callback.
  */
 void EDVRecBinRecycledObjectAddedNotifyCB(
 	edv_recbin_struct *recbin, guint index
@@ -928,7 +944,6 @@ void EDVRecBinRecycledObjectAddedNotifyCB(
 {
 	edv_core_struct *core_ptr;
 
-
 	if(recbin == NULL)
 	    return;
 
@@ -939,12 +954,9 @@ void EDVRecBinRecycledObjectAddedNotifyCB(
 	if(core_ptr == NULL)
 	    return;
 
-	/* Notify contents clist about added object */
+	/* Contents List */
 	EDVRecBinContentsObjectAddedNotify(recbin, index);
 
-	/* Update menus and Recycle Bin toplevel window's WM icon */
-	EDVRecBinUpdateMenus(recbin);
-
 	/* Update menus for the purpose of updating the Recycle Bin
 	 * toplevel window's WM icon. Do this only if there is a change
 	 * in the number of recycled objects from 0.
@@ -954,8 +966,7 @@ void EDVRecBinRecycledObjectAddedNotifyCB(
 }
 
 /*
- *      Called whenever a recycled object has been modified in the recycled
- *      objects directory.
+ *	Recycled object modified callback.
  */
 void EDVRecBinRecycledObjectModifiedNotifyCB(
 	edv_recbin_struct *recbin, guint index
@@ -963,7 +974,6 @@ void EDVRecBinRecycledObjectModifiedNotifyCB(
 {
 	edv_core_struct *core_ptr;
 
-
 	if(recbin == NULL)
 	    return;
 
@@ -974,20 +984,19 @@ void EDVRecBinRecycledObjectModifiedNotifyCB(
 	if(core_ptr == NULL)
 	    return;
 
-	/* Notify contents clist about modified object */
+	/* Contents List */
 	EDVRecBinContentsObjectModifiedNotify(recbin, index);
 
 	/* Update menus for the purpose of updating the Recycle Bin
-	 * toplevel window's WM icon. Do this only if there is a change
-	 * in the number of recycled objects from 0.
+	 * toplevel window's WM icon. Do this only if there is a
+	 * change in the number of recycled objects from 0
 	 */
 	if(core_ptr->last_recbin_items != recbin->last_recbin_items)
 	    EDVRecBinUpdateMenus(recbin);
 }
 
 /*
- *      Called whenever a recycled object has been removed from the recycled
- *      objects directory.
+ *	Recycled object removed callback.
  */
 void EDVRecBinRecycledObjectRemovedNotifyCB(
 	edv_recbin_struct *recbin, guint index
@@ -995,7 +1004,6 @@ void EDVRecBinRecycledObjectRemovedNotifyCB(
 {
 	edv_core_struct *core_ptr;
 
-
 	if(recbin == NULL)
 	    return;
 
@@ -1006,12 +1014,12 @@ void EDVRecBinRecycledObjectRemovedNotifyCB(
 	if(core_ptr == NULL)
 	    return;
 
-	/* Notify contents clist and directory ctree about removed object */
+	/* Contents List */
 	EDVRecBinContentsObjectRemovedNotify(recbin, index);
 
 	/* Update menus for the purpose of updating the Recycle Bin
 	 * toplevel window's WM icon. Do this only if there is a change
-	 * in the number of recycled objects from 0.
+	 * in the number of recycled objects from 0
 	 */
 	if(core_ptr->last_recbin_items != recbin->last_recbin_items)
 	    EDVRecBinUpdateMenus(recbin);
@@ -1019,18 +1027,16 @@ void EDVRecBinRecycledObjectRemovedNotifyCB(
 
 
 /*
- *	Reconfigured notify callback.
+ *	Reconfigured callback.
  */
 void EDVRecBinReconfiguredNotifyCB(edv_recbin_struct *recbin)
 {
 	GtkRcStyle *standard_rcstyle, *lists_rcstyle;
 	GtkWidget *w;
-	GtkCList *clist;
 	const cfg_item_struct *cfg_list;
 	edv_statusbar_struct *status_bar;
 	edv_core_struct *core_ptr;
 
-
 	if(recbin == NULL)
 	    return;
 
@@ -1113,24 +1119,13 @@ void EDVRecBinReconfiguredNotifyCB(edv_recbin_struct *recbin)
 	if((w != NULL) && (standard_rcstyle != NULL))
 	    gtk_widget_modify_style_recursive(w, standard_rcstyle);
 
-
-	/* Reget listings */
-
-	/* Reget listing for contents clist */
-	clist = (GtkCList *)recbin->contents_clist;
-	if(clist != NULL)
-	{
-	    gtk_clist_freeze(clist);
-	    EDVRecBinContentsResetRows(recbin);
-	    gtk_clist_thaw(clist);
-	}
-
+	/* Realize listings */
+	EDVRecBinContentsRealizeListing(recbin);
 
 	/* Update menus */
 	EDVRecBinUpdateMenus(recbin);
 
-
-	/* Notify recbin's toplevel widget to resize */
+	/* Notify toplevel to resize */
 	w = recbin->toplevel;
 	if(w != NULL)
 	    gtk_widget_queue_resize(w);
@@ -1138,91 +1133,55 @@ void EDVRecBinReconfiguredNotifyCB(edv_recbin_struct *recbin)
 
 
 /*
- *      Called whenever a MIME Type has been added to the core
- *      structure's list of MIME Types.
+ *	MIME Type added callback.
  */
 void EDVRecBinMimeTypeAddedCB(
 	edv_recbin_struct *recbin,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 )
 {
-	/* Treat a MIME Type added the same as it would be for a MIME Type
-	 * modified, forward signal to the MIME Type modified callback.
+	/* Treat a MIME Type added the same as it would be for a MIME
+	 * Type modified, forward signal to the MIME Type modified
+	 * callback
 	 */
-	EDVRecBinMimeTypeModifiedCB(recbin, mt_num, mt_ptr);
+	EDVRecBinMimeTypeModifiedCB(recbin, mt_num, mt);
 }
 
 /*
- *      Called whenever a MIME Type has been modified on the core
- *      structure's list of MIME Types.
+ *	MIME Type modified callback.
  */
 void EDVRecBinMimeTypeModifiedCB(
 	edv_recbin_struct *recbin,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 )
 {
-	GtkCList *clist;
-	edv_core_struct *core_ptr;
-
-
 	if(recbin == NULL)
 	    return;
 
 	if(recbin->processing)
 	    return;
 
-	core_ptr = EDV_CORE(recbin->core_ptr);
-	if(core_ptr == NULL)
-	    return;
-
-
-	/* Reget listings */
-
-	/* Reset displayed row values of contents clist */
-	clist = (GtkCList *)recbin->contents_clist;
-	if(clist != NULL)
-	{
-	    gtk_clist_freeze(clist);
-	    EDVRecBinContentsResetRows(recbin);
-	    gtk_clist_thaw(clist);
-	}
+	/* Realize listings */
+	EDVRecBinContentsRealizeListing(recbin);
 
 /*      EDVRecBinUpdateMenus(recbin); */
 }
 
 /*
- *      Called whenever a MIME Type has been removed from the core
- *      structure's list of MIME Types.
+ *	MIME Type removed callback.
  */
 void EDVRecBinMimeTypeRemovedCB(
 	edv_recbin_struct *recbin, gint mt_num
 )
 {
-	GtkCList *clist;
-	edv_core_struct *core_ptr;
-
-
 	if(recbin == NULL)
 	    return;
 
 	if(recbin->processing)
 	    return;
 
-	core_ptr = EDV_CORE(recbin->core_ptr);
-	if(core_ptr == NULL)
-	    return;
-
-
-	/* Reget listings */
-
-	/* Reset displayed row values of contents clist */
-	clist = (GtkCList *)recbin->contents_clist;
-	if(clist != NULL)
-	{
-	    gtk_clist_freeze(clist);
-	    EDVRecBinContentsResetRows(recbin);
-	    gtk_clist_thaw(clist);
-	}
+	/* Realize listings */
+	EDVRecBinContentsRealizeListing(recbin);
 
 /*	EDVRecBinUpdateMenus(recbin); */
 }
