@@ -66,11 +66,11 @@ extern void EDVRecBinRecycledObjectRemovedNotifyCB(
 extern void EDVRecBinReconfiguredNotifyCB(edv_recbin_struct *recbin);
 extern void EDVRecBinMimeTypeAddedCB(
 	edv_recbin_struct *recbin,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 );
 extern void EDVRecBinMimeTypeModifiedCB(
 	edv_recbin_struct *recbin,
-	gint mt_num, edv_mimetype_struct *mt_ptr
+	gint mt_num, edv_mimetype_struct *mt
 );
 extern void EDVRecBinMimeTypeRemovedCB(
 	edv_recbin_struct *recbin, gint mt_num
