@@ -116,7 +116,7 @@ static gint EDVRecBinContentsAppendObject(
 	edv_core_struct *core_ptr, edv_recbin_struct *recbin,
 	GtkCList *clist, edv_recbin_object_struct *obj
 );
-static void EDVRecBinContentsGetListing(
+static void EDVRecBinContentsDoGetListing(
 	edv_recbin_struct *recbin, gboolean update_status_bar
 );
 
@@ -124,11 +124,15 @@ gint EDVRecBinContentsFindRowByIndex(
 	edv_recbin_struct *recbin, guint index
 );
 
-void EDVRecBinContentsResetRows(edv_recbin_struct *recbin);
-void EDVRecBinContentsDoUpdate(
+/* Realize Listing */
+void EDVRecBinContentsRealizeListing(edv_recbin_struct *recbin);
+
+/* Get Listing */
+void EDVRecBinContentsGetListing(
 	edv_recbin_struct *recbin, gboolean update_status_bar
 );
 
+/* Callbacks */
 void EDVRecBinContentsObjectAddedNotify(
 	edv_recbin_struct *recbin, guint index
 );
@@ -360,6 +364,7 @@ static void EDVRecBinContentsSetCellName(
 		clist, row, column,
 		(name != NULL) ? name : "(null)"
 	    );
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, 0
 	);
@@ -392,6 +397,7 @@ static void EDVRecBinContentsSetCellSize(
 	gtk_clist_set_text(
 	    clist, row, column, s
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, -border_minor
 	);
@@ -421,6 +427,7 @@ static void EDVRecBinContentsSetCellType(
 	gtk_clist_set_text(
 	    clist, row, column, (type_str != NULL) ? type_str : ""
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, 0
 	);
@@ -467,6 +474,7 @@ static void EDVRecBinContentsSetCellPermissions(
 	gtk_clist_set_text(
 	    clist, row, column, s
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, 0
 	);
@@ -494,6 +502,7 @@ static void EDVRecBinContentsSetCellOwner(
 	gtk_clist_set_text(
 	    clist, row, column, owner_name
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, 0
 	);
@@ -521,6 +530,7 @@ static void EDVRecBinContentsSetCellGroup(
 	gtk_clist_set_text(
 	    clist, row, column, group_name
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, 0
 	);
@@ -552,6 +562,7 @@ static void EDVRecBinContentsSetCellDateAccess(
 	gtk_clist_set_text(
 	    clist, row, column, date_str
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, 0
 	);
@@ -583,6 +594,7 @@ static void EDVRecBinContentsSetCellDateModified(
 	gtk_clist_set_text(
 	    clist, row, column, date_str
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, 0
 	);
@@ -614,6 +626,7 @@ static void EDVRecBinContentsSetCellDateChanged(
 	gtk_clist_set_text(
 	    clist, row, column, date_str
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, 0
 	);
@@ -645,6 +658,7 @@ static void EDVRecBinContentsSetCellDateDeleted(
 	gtk_clist_set_text(
 	    clist, row, column, date_str
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, 0
 	);
@@ -670,6 +684,7 @@ static void EDVRecBinContentsSetCellLinkedTo(
 	gtk_clist_set_text(
 	    clist, row, column, link_dest
 	);
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, 0
 	);
@@ -968,10 +983,10 @@ static gint EDVRecBinContentsAppendObject(
 }
 
 /*
- *	Gets all recycled objects in the recycled objects directory and
- *	appends them to the contents clist.
+ *	Gets all recycled objects in the recycled objects directory
+ *	and appends them to the Contents List.
  */
-static void EDVRecBinContentsGetListing(
+static void EDVRecBinContentsDoGetListing(
 	edv_recbin_struct *recbin, gboolean update_status_bar
 )
 {
@@ -1101,10 +1116,10 @@ gint EDVRecBinContentsFindRowByIndex(
  *      of each row need to be set again from internal data, usually
  *      when a MIME Type has been added/modified/removed. This function
  *      should not be used to `refresh' the list (get new values of
- *      disk object structures), use EDVRecBinContentsDoUpdate()
+ *      disk object structures), use EDVRecBinContentsGetListing()
  *      instead.
  */
-void EDVRecBinContentsResetRows(edv_recbin_struct *recbin)
+void EDVRecBinContentsRealizeListing(edv_recbin_struct *recbin)
 {
 	gint i;
 	GtkWidget *w;
@@ -1122,6 +1137,8 @@ void EDVRecBinContentsResetRows(edv_recbin_struct *recbin)
 
 	clist = GTK_CLIST(w);
 
+	gtk_clist_freeze(clist);
+
 	/* Reset columns */
 	EDVRecBinContentsResetColumns(core_ptr, recbin, clist);
 
@@ -1136,13 +1153,14 @@ void EDVRecBinContentsResetRows(edv_recbin_struct *recbin)
 		core_ptr, recbin, clist, obj, i
 	    );
 	}
+
+	gtk_clist_thaw(clist);
 }
 
 /*
- *	Procedure to clear and reupdate the contents list on the recycle
- *	bin with the contents found in the recycled objects directory.
+ *	Gets listing of recycled objects.
  */
-void EDVRecBinContentsDoUpdate(
+void EDVRecBinContentsGetListing(
 	edv_recbin_struct *recbin, gboolean update_status_bar
 )
 {
@@ -1160,7 +1178,6 @@ void EDVRecBinContentsDoUpdate(
 
 	clist = GTK_CLIST(w);
 
-
 	/* Begin updating the Contents List */
 
 	/* Report initial status */
@@ -1176,7 +1193,9 @@ void EDVRecBinContentsDoUpdate(
 	    );
 	}
 
-	/* Delete all entries */
+	gtk_clist_freeze(clist);
+
+	/* Clear the Contents List */
 	EDVRecBinContentsClear(clist);
 
 	/* Update columns */
@@ -1184,8 +1203,10 @@ void EDVRecBinContentsDoUpdate(
 	    core_ptr, recbin, clist
 	);
 
-	/* Get listing of recycled objects */
-	EDVRecBinContentsGetListing(recbin, update_status_bar);
+	/* Get new listing of recycled objects */
+	EDVRecBinContentsDoGetListing(recbin, update_status_bar);
+
+	gtk_clist_thaw(clist);
 
 	/* Report final status */
 	if(update_status_bar)
