@@ -9,15 +9,20 @@
 #include "recbin.h"
 
 
+/* Finding */
 extern gint EDVRecBinContentsFindRowByIndex(
 	edv_recbin_struct *recbin, guint index
 );
 
-extern void EDVRecBinContentsResetRows(edv_recbin_struct *recbin);
-extern void EDVRecBinContentsDoUpdate(
+/* Realize Listing */
+extern void EDVRecBinContentsRealizeListing(edv_recbin_struct *recbin);
+
+/* Get Listing */
+extern void EDVRecBinContentsGetListing(
 	edv_recbin_struct *recbin, gboolean update_status_bar
 );
 
+/* Callbacks */
 extern void EDVRecBinContentsObjectAddedNotify(
 	edv_recbin_struct *recbin, guint index
 );
