@@ -50,7 +50,7 @@ void EDVRecBinDeskIconDelete(edv_recbin_deskicon_struct *rbdi);
 #if defined(PROG_LANGUAGE_SPANISH)
 # define EDV_RECBIN_DESKICON_LABEL	"Cajn De Recirculacin"
 #elif defined(PROG_LANGUAGE_FRENCH)
-# define EDV_RECBIN_DESKICON_LABEL	"Recycler L'Huche"
+# define EDV_RECBIN_DESKICON_LABEL	"Corbeille"
 #elif defined(PROG_LANGUAGE_GERMAN)
 # define EDV_RECBIN_DESKICON_LABEL	"Verwerten Sie Behlter"
 #elif defined(PROG_LANGUAGE_ITALIAN)
