@@ -139,6 +139,7 @@ void EDVRecBinOPCB(
 	toolbar_item_struct *item, gint id, gpointer data  
 )
 {
+	GtkWidget *toplevel;
 	edv_recbin_struct *recbin;
 	edv_core_struct *core_ptr;
 	edv_recbin_opid_struct *opid = EDV_RECBIN_OPID(data);
@@ -152,6 +153,7 @@ void EDVRecBinOPCB(
 	if(recbin->processing || (recbin->freeze_count > 0))
 	    return;
 
+	toplevel = recbin->toplevel;
 	core_ptr = EDV_CORE(recbin->core_ptr);
 	if(core_ptr == NULL)
 	    return;
@@ -203,7 +205,7 @@ void EDVRecBinOPCB(
 	    break;
 
 	  case EDV_RECBIN_OP_HISTORY:
-	    EDVMapHistoryListWin(core_ptr, recbin->toplevel);
+	    EDVMapHistoryListWin(core_ptr, toplevel);
 	    break;
 
 	  case EDV_RECBIN_OP_SYNC_RECYCLE_BIN:
@@ -223,12 +225,12 @@ void EDVRecBinOPCB(
 		core_ptr,
 		NULL,
 		NULL,
-		recbin->toplevel
+		toplevel
 	    );
 	    break;
 
 	  case EDV_RECBIN_OP_RUN_TERMINAL:
-	    EDVRunTerminal(core_ptr, NULL, recbin->toplevel);
+	    EDVRunTerminal(core_ptr, NULL, NULL, toplevel);
 	    break;
 
 
@@ -284,7 +286,7 @@ void EDVRecBinOPCB(
 
 
 	  case EDV_RECBIN_OP_MIME_TYPES:
-	    EDVMapMIMETypesListWin(core_ptr, recbin->toplevel);
+	    EDVMapMIMETypesListWin(core_ptr, toplevel);
 	    break;
 
 
@@ -302,37 +304,37 @@ void EDVRecBinOPCB(
 
 
 	  case EDV_RECBIN_OP_OPTIONS:
-	    EDVMapOptionsWin(core_ptr, recbin->toplevel);
+	    EDVMapOptionsWin(core_ptr, toplevel);
 	    break;
 
 	  case EDV_RECBIN_OP_CUSTOMIZE:
-	    EDVMapCustomizeWin(core_ptr, recbin->toplevel);
+	    EDVMapCustomizeWin(core_ptr, toplevel);
 	    break;
 
 
 	  case EDV_RECBIN_OP_HELP_ABOUT:
-	    EDVAbout(core_ptr, recbin->toplevel);
+	    EDVAbout(core_ptr, toplevel);
 	    break;
 	  case EDV_RECBIN_OP_HELP_CONTENTS:
-	    EDVHelp(core_ptr, "Contents", recbin->toplevel);
+	    EDVHelp(core_ptr, "Contents", toplevel);
 	    break;
 	  case EDV_RECBIN_OP_HELP_FILE_BROWSER:
-	    EDVHelp(core_ptr, "File Browser", recbin->toplevel);
+	    EDVHelp(core_ptr, "File Browser", toplevel);
 	    break;
 	  case EDV_RECBIN_OP_HELP_IMAGE_BROWSER:
-	    EDVHelp(core_ptr, "Image Browser", recbin->toplevel);
+	    EDVHelp(core_ptr, "Image Browser", toplevel);
 	    break;
 	  case EDV_RECBIN_OP_HELP_ARCHIVER:
-	    EDVHelp(core_ptr, "Archiver", recbin->toplevel);
+	    EDVHelp(core_ptr, "Archiver", toplevel);
 	    break;
 	  case EDV_RECBIN_OP_HELP_RECYCLE_BIN:
-	    EDVHelp(core_ptr, "Recycle Bin", recbin->toplevel);
+	    EDVHelp(core_ptr, "Recycle Bin", toplevel);
 	    break;
 	  case EDV_RECBIN_OP_HELP_KEYS_LIST:
-	    EDVHelp(core_ptr, "Keys List", recbin->toplevel);
+	    EDVHelp(core_ptr, "Keys List", toplevel);
 	    break;
 	  case EDV_RECBIN_OP_HELP_COMMON_OPERATIONS:
-	    EDVHelp(core_ptr, "Common Operations", recbin->toplevel);
+	    EDVHelp(core_ptr, "Common Operations", toplevel);
 	    break;
 	}
 
@@ -1496,7 +1498,7 @@ void EDVRecBinOPRefresh(edv_recbin_struct *recbin)
 	    gtk_clist_freeze(clist);
 
 	    /* Refresh list items */
-	    EDVRecBinContentsDoUpdate(
+	    EDVRecBinContentsGetListing(
 		recbin,
 		EDV_GET_B(EDV_CFG_PARM_LISTS_ANIMATE_UPDATES)
 	    );
