@@ -92,7 +92,7 @@ void EDVRunDlgDelete(edv_run_dlg_struct *d);
 #if defined(PROG_LANGUAGE_SPANISH)
 # define RUNDLG_TITLE		"Corra"
 #elif defined(PROG_LANGUAGE_FRENCH)
-# define RUNDLG_TITLE		"Course"
+# define RUNDLG_TITLE		"Lancer"
 #elif defined(PROG_LANGUAGE_GERMAN)
 # define RUNDLG_TITLE		"Lauf"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -135,7 +135,7 @@ static void EDVRunDlgRunCB(
 )
 {
 	gint euid;
-	gchar *s, *buf, *pwd, *prog, *args, *cmd;
+	gchar *s, *pwd, *prog, *args, *cmd;
 	const gchar *cmd_src, *wd;
 	struct stat stat_buf;
 	const cfg_item_struct *cfg_list;
@@ -167,6 +167,7 @@ static void EDVRunDlgRunCB(
 	);
 	if(STRISEMPTY(cmd_src))
 	{
+	    g_free(pwd);
 	    EDVRunDlgSetBusy(d, FALSE);
 	    return;
 	}
@@ -196,15 +197,17 @@ static void EDVRunDlgRunCB(
 
 	/* Record this command */
 	if(args != NULL)
-	    buf = g_strdup_printf("%s %s", prog, args);
+	    s = g_strdup_printf("%s %s", prog, args);
 	else
-	    buf = g_strdup_printf("%s", prog);
-	GUIComboAddItem(d->run_combo, buf);
-	g_free(buf);
+	    s = g_strdup_printf("%s", prog);
+	GUIComboAddItem(d->run_combo, s);
+	g_free(s);
 
 	/* Get program stats to see if it exists and is executable */
 	if(stat(prog, &stat_buf))
 	{
+	    gchar *buf;
+
 	    s = STRDUP(strerror(errno));
 	    if(s == NULL)
 		s = STRDUP("no such file");
@@ -222,9 +225,10 @@ static void EDVRunDlgRunCB(
 	    g_free(buf);
 	    g_free(s);
 
-	    EDVRunDlgSetBusy(d, FALSE);
+	    g_free(pwd);
 	    g_free(prog);
 	    g_free(args);
+	    EDVRunDlgSetBusy(d, FALSE);
 	    return;
 	}
 	else if(((euid == stat_buf.st_uid) || (euid == 0)) ?
@@ -232,7 +236,7 @@ static void EDVRunDlgRunCB(
 		 !(stat_buf.st_mode & S_IXOTH)
 	       )
 	{
-	    buf = g_strdup_printf(
+	    gchar *buf = g_strdup_printf(
 "Not executable:\n\
 \n\
     %s\n\
@@ -246,9 +250,10 @@ The program must be set executable in order to run it.\n",
 	    );
 	    g_free(buf);
 
-	    EDVRunDlgSetBusy(d, FALSE);
+	    g_free(pwd);
 	    g_free(prog);
 	    g_free(args);
+	    EDVRunDlgSetBusy(d, FALSE);
 	    return;
 	}
 
@@ -272,24 +277,23 @@ The program must be set executable in order to run it.\n",
 			"%s %s",
 			cmd_terminal_run, prog
 		    );
-
-
 	    }
 	    else
 	    {
 		EDVPlaySoundWarning(core_ptr);
 		EDVMessageWarning(   
 		    "Run Failed",
-"The \"Run In Terminal\" command was not set.\n\
+"The \"Run In Terminal\" command is not set.\n\
 \n\
 To set the \"Run In Terminal\" command go to\n\
 Settings->Options...->Programs.",
 		    NULL,
 		    toplevel
 		);
-		EDVRunDlgSetBusy(d, FALSE);
+		g_free(pwd);
 		g_free(prog);
 		g_free(args);
+		EDVRunDlgSetBusy(d, FALSE);
 		return;
 	    }
 	}
@@ -966,7 +970,7 @@ edv_run_dlg_struct *EDVRunDlgNew(gpointer core_ptr)
 #if defined(PROG_LANGUAGE_SPANISH)
 "La Orden:"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Ordre:"
+"Commande:"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Befehl:"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1009,7 +1013,7 @@ edv_run_dlg_struct *EDVRunDlgNew(gpointer core_ptr)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Entre el nombre del programa ms cualquier argumento"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Entrer le nom du programme plus n'importe quels arguments"
+"Entrer le nom du programme avec les arguments"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Tragen Sie den Namen des Programms und irgendeine Argumente ein"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1040,7 +1044,7 @@ edv_run_dlg_struct *EDVRunDlgNew(gpointer core_ptr)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Hojee"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Brouter"
+"Parcourir"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Brausen"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1070,7 +1074,7 @@ edv_run_dlg_struct *EDVRunDlgNew(gpointer core_ptr)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Claro"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Clair"
+"Effacer"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Klar"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1101,7 +1105,7 @@ edv_run_dlg_struct *EDVRunDlgNew(gpointer core_ptr)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Gua Trabajo:"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Annuaire Travaillant:"
+"Rpertoire de travail:"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Arbeitenden Verzeichnis:"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1130,8 +1134,7 @@ edv_run_dlg_struct *EDVRunDlgNew(gpointer core_ptr)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Entre la gua de trabajo que se usar cundo correr el programa"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Entrer l'annuaire qui travaillant qui sera utilis en courant le\
- programme"
+"Entrer le rpertoire de travail utilis par le programme programme"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Tragen Sie das arbeitende Verzeichnis, das benutzt werden wird,\
  beim Laufen des Programms ein"
@@ -1166,7 +1169,7 @@ edv_run_dlg_struct *EDVRunDlgNew(gpointer core_ptr)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Hojee"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Brouter"
+"Parcourir"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Brausen"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1196,7 +1199,7 @@ edv_run_dlg_struct *EDVRunDlgNew(gpointer core_ptr)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Claro"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Clair"
+"Effacer"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Klar"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1226,7 +1229,7 @@ edv_run_dlg_struct *EDVRunDlgNew(gpointer core_ptr)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Obtenga trabajando gua del valor actual de la orden"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Recevoir l'annuaire qui travaillant de la valeur d'ordre actuelle"
+"Recevoir le rpertoire de travail depuis la commande"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Erhalten Sie arbeitenden Verzeichnis vom jetzigen Befehl Wert"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1254,7 +1257,7 @@ edv_run_dlg_struct *EDVRunDlgNew(gpointer core_ptr)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Corra En La Terminal"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Courir Dans Le Terminal"
+"Ouvrir Dans un Terminal"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Laufen Sie In Terminal"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1275,8 +1278,8 @@ edv_run_dlg_struct *EDVRunDlgNew(gpointer core_ptr)
 "Corra el programa especificado en una terminal, esto a\
  menudo se necesita para programas basados de texto"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Courir le programme spcifi dans un terminal, ceci\
- est souvent eu besoin de pour les programmes texte-bass"
+"Ouvrir le programme spcifi dans un terminal, ceci\
+ est souvent nexessaire pour les programmes bas sur du texte"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Laufen Sie das angegebene Programm in ein Terminal, dies ist often,\
  der fr Text basiert Programme gebraucht wird"
@@ -1323,7 +1326,7 @@ edv_run_dlg_struct *EDVRunDlgNew(gpointer core_ptr)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Mantenga este dilogo trazado despus de correr un programa"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Garder ce mapped de dialogue aprs avoir excutant un programme"
+"Garder cette boite de dialogue aprs avoir excuter le programme"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Behalten Sie diesen Dialog, der nach Laufen jedes Programms\
  aufgezeichnet wird"
@@ -1376,7 +1379,7 @@ edv_run_dlg_struct *EDVRunDlgNew(gpointer core_ptr)
 #if defined(PROG_LANGUAGE_SPANISH)
 "El clic para configurar los programas terminales"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Le dclic pour configurer des programmes dlimitants"
+"Configuer le terminal"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Klicken, letzte Programme zu gestalten"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1416,7 +1419,7 @@ edv_run_dlg_struct *EDVRunDlgNew(gpointer core_ptr)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Corra"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Courir"
+"Excuter"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Lauf"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -1459,7 +1462,7 @@ edv_run_dlg_struct *EDVRunDlgNew(gpointer core_ptr)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Cierre"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Fin"
+"Fermer"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Nah"
 #elif defined(PROG_LANGUAGE_ITALIAN)
