@@ -162,7 +162,7 @@ static gint EDVStatusBarCrossingEventCB(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Escriba proteja es permitido, el clic a incapacitarlo"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Protge en criture est rendu capable, le dclic pour le rendre infirme"
+"Protection criture En Service, cliquer pour annuler"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Schreibgeschtzt ist, klicken ermglicht, unwirksam es zu machen"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -197,7 +197,7 @@ static gint EDVStatusBarCrossingEventCB(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Escriba proteja es incapacitado, el clic para permitirlo"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Protge en criture est rendu infirme, le dclic pour le rendre capable"
+"Protection criture est Hors Service, cliquer pour la mettre En Service"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Schreibgeschtzt ist unwirksam, klicken gemacht, es zu ermglichen"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -233,8 +233,7 @@ static gint EDVStatusBarCrossingEventCB(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Borra el mtodo se pone a reciclar, hacer clic para ponerlo purgar"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Effacer la mthode est rgle pour recycler, cliqueter pour rgler\
- le purger"
+"La mthode pour Supprimer est positionne sur mettre  la Corbeille, cliquer pour changer en Dtruire"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Lschen Sie Methode ist gesetzt wiederzuverwerten, zu klicken, es\
  zu setzen, zu reinigen"
@@ -273,8 +272,7 @@ static gint EDVStatusBarCrossingEventCB(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Borre el mtodo se pone a purgar, hacer clic para ponerlo reciclar"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Effacer la mthode est rgle pour purger, cliqueter pour rgler\
- le recycler"
+"La mthode pour Supprimer est positionne sur dtruire, cliquer pour rgler  mettre dans la Corbeille"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Lschen Sie Methode ist gesetzt zu reinigen, zu klicken, es zu\
  setzen, wiederzuverwerten"
@@ -384,7 +382,7 @@ edv_statusbar_struct *EDVStatusBarNew(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Escriba proteja es permitido"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Protge en criture est rendu capable"
+"Protection criture est En-Service"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Schreibgeschtzt ist ermglicht"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -440,7 +438,7 @@ edv_statusbar_struct *EDVStatusBarNew(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Escriba proteja es incapacitado"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Protge en criture est rendu infirme"
+"Protection criture est Hors Service"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Schreibgeschtzt ist unwirksam gemacht"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -498,7 +496,7 @@ edv_statusbar_struct *EDVStatusBarNew(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Borre el mtodo se pone a reciclar"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Effacer la mthode est rgle pour recycler"
+"La mthode pour Supprimer est positionne sur mettre  la Corbeille"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Lschen sie methode ist gesetzt wiederzuverwerten"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -554,7 +552,7 @@ edv_statusbar_struct *EDVStatusBarNew(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Borre el mtodo se pone a purgar"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Effacer la mthode est rgle pour purger"
+"La mthode pour Supprimer est positionne sur dtruire"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Lschen sie methode ist gesetzt zu reinigen"
 #elif defined(PROG_LANGUAGE_ITALIAN)
