@@ -279,9 +279,9 @@ static void StyleEditResetCB(
 "Usted est seguro que usted quiere reponer los valores del\n\
 estilo a los valores del estilo de la rebelda de GTK?\n",
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Confirmer Remet  L'tat Initial",
-"Etes-vous sr que vous voulez remettre  l'tat initial les\n\
-valeurs de style au GTK les valeurs de style implicites?\n",
+"Confirmer Remettre  L'tat Initial",
+"Etes-vous sr de vouloir rtablir les caratristiques des styles\n\
+  celles des valeurs prtablies de GTK ?\n",
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Besttigen Sie Nachstellung",
 "Sind sie sicher sie den stil werte zum GTK standardwert stil\n\
@@ -872,7 +872,7 @@ style_edit_struct *StyleEditNew(
 #if defined(PROG_LANGUAGE_SPANISH)
 "El clic para reponer los valores"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Le dclic pour remettre  l'tat initial des valeurs"
+"cliquer pour remettre les valeurs  l'tat initial"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Klicken, werte nachzustellen"
 #elif defined(PROG_LANGUAGE_ITALIAN)
