@@ -1589,7 +1589,7 @@ sysinfo_win_struct *SysInfoNew(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Cierre"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Fin"
+"Fermer"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Nah"
 #elif defined(PROG_LANGUAGE_ITALIAN)
