@@ -314,560 +314,542 @@ static gint TListKeyEventCB(
  TListQueueDraw(tlist);				\
 }
 
-	/* Check which widget this event is for */
-
-	/* Thumbs List GtkDrawingArea */
-	if(widget == tlist->list_da)
+	/* Handle by key value */
+	switch(keyval)
 	{
-	    /* Handle by key value */
-	    switch(keyval)
+	  case GDK_space:
+	    if(press)
 	    {
-	      case GDK_space:
-		if(press)
+		gint thumb_num = tlist->focus_thumb;
+
+		TListFreeze(tlist);
+
+		switch(tlist->selection_mode)
 		{
-		    gint thumb_num = tlist->focus_thumb;
-
-		    TListFreeze(tlist);
-
-		    switch(tlist->selection_mode)
-		    {
-		      case GTK_SELECTION_EXTENDED:
-		      case GTK_SELECTION_MULTIPLE:
-			if(TListIsThumbSelected(tlist, thumb_num))
-			    TListDoUnselectThumb(
-				tlist, thumb_num, NULL
-			    );
-			else
-			    TListDoSelectThumb(
-				tlist, thumb_num, NULL, TRUE
-			    );
-			break;
-
-		      case GTK_SELECTION_BROWSE:
+		  case GTK_SELECTION_EXTENDED:
+		  case GTK_SELECTION_MULTIPLE:
+		    if(TListIsThumbSelected(tlist, thumb_num))
+			TListDoUnselectThumb(
+			    tlist, thumb_num, NULL
+			);
+		    else
 			TListDoSelectThumb(
-			    tlist, thumb_num, NULL, FALSE
+			    tlist, thumb_num, NULL, TRUE
 			);
-			break;
-
-		      case GTK_SELECTION_SINGLE:
-			if(TListIsThumbSelected(tlist, thumb_num))
-			{
-			    TListDoUnselectAllThumbs(tlist);
-			}
-			else
-			{
-			    TListDoUnselectAllThumbs(tlist);
-			    TListDoSelectThumb(
-				tlist, thumb_num, NULL, TRUE
-			    );
-			}
-			break;
-		    }
-
-		    TListThaw(tlist);
-		}
-		break;
-
-
-	      case GDK_Up:
-	      case GDK_KP_Up:
-		if((state & GDK_CONTROL_MASK) && press)
-		{
-		    /* Get adjustment and scroll up */
-		    GtkAdjustment *adj = tlist->vadj;
-		    if(adj != NULL)
+		    break;
+		  case GTK_SELECTION_BROWSE:
+		    TListDoSelectThumb(
+			tlist, thumb_num, NULL, FALSE
+		    );
+		    break;
+		  case GTK_SELECTION_SINGLE:
+		    if(TListIsThumbSelected(tlist, thumb_num))
 		    {
-			adj->value -= adj->step_increment;
-			DO_ADJ_CLAMP_EMIT
+			TListDoUnselectAllThumbs(tlist);
 		    }
-		}
-		else if((state & GDK_SHIFT_MASK) && press)
-		{
-		    TListFreeze(tlist);
-
-		    /* Move focus thumb up */
-		    tlist->focus_thumb -= (tlist->flags & TLIST_HORIZONTAL) ?
-			1 : tlist->thumbs_per_line;
-		    DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
-
-		    switch(tlist->selection_mode)
+		    else
 		    {
-		      case GTK_SELECTION_EXTENDED:
-		      case GTK_SELECTION_MULTIPLE:
-			TListDoSelectThumbRange(
-			    tlist, tlist->focus_thumb, NULL
-			);
-			break;
-
-		      case GTK_SELECTION_BROWSE:
-		      case GTK_SELECTION_SINGLE:
 			TListDoUnselectAllThumbs(tlist);
 			TListDoSelectThumb(
-			    tlist, tlist->focus_thumb, NULL, TRUE
+			    tlist, thumb_num, NULL, TRUE
 			);
-			break;
 		    }
-
-		    if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
-			GTK_VISIBILITY_FULL
-		    )
-			TListMoveTo(tlist, tlist->focus_thumb, 0.0f);
-
-		    TListThaw(tlist);
+		    break;
 		}
-		else if(press)
-		{
-		    TListFreeze(tlist);
-
-		    /* Move focus thumb up */
-		    tlist->focus_thumb -= (tlist->flags & TLIST_HORIZONTAL) ?
-			1 : tlist->thumbs_per_line;
-		    DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
-
-		    if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
-			GTK_VISIBILITY_FULL
-		    )
-			TListMoveTo(tlist, tlist->focus_thumb, 0.0f);
-
-		    TListThaw(tlist);
-		}
-		DO_STOP_KEY_SIGNAL_EMIT
-		status = TRUE;
-		break;
-
-	      case GDK_Down:
-	      case GDK_KP_Down:
-		if((state & GDK_CONTROL_MASK) && press)
-		{
-		    /* Get adjustment and scroll down */
-		    GtkAdjustment *adj = tlist->vadj;
-		    if(adj != NULL)
-		    {
-			adj->value += adj->step_increment;
-			DO_ADJ_CLAMP_EMIT
-		    }
-		}
-		else if((state & GDK_SHIFT_MASK) && press)
-		{
-		    TListFreeze(tlist);
-
-		    /* Move focus thumb down */
-		    tlist->focus_thumb += (tlist->flags & TLIST_HORIZONTAL) ?
-			1 : tlist->thumbs_per_line;
-		    DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
-
-		    switch(tlist->selection_mode)
-		    {
-		      case GTK_SELECTION_EXTENDED:
-		      case GTK_SELECTION_MULTIPLE:
-			TListDoSelectThumbRange(
-			    tlist, tlist->focus_thumb, NULL
-			);
-			break;
-
-		      case GTK_SELECTION_BROWSE:
-		      case GTK_SELECTION_SINGLE:
-			TListDoUnselectAllThumbs(tlist);
-			TListDoSelectThumb(
-			    tlist, tlist->focus_thumb, NULL, TRUE
-			);
-			break;
-		    }
-
-		    if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
-			GTK_VISIBILITY_FULL
-		    )
-			TListMoveTo(tlist, tlist->focus_thumb, 1.0f);
-
-		    TListThaw(tlist);
-		}
-		else if(press)
-		{
-		    TListFreeze(tlist);
-
-		    /* Move focus thumb down */
-		    tlist->focus_thumb += (tlist->flags & TLIST_HORIZONTAL) ?
-			1 : tlist->thumbs_per_line;
-		    DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
-
-		    if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
-			GTK_VISIBILITY_FULL
-		    )
-			TListMoveTo(tlist, tlist->focus_thumb, 1.0f);
-
-		    TListThaw(tlist);
-		}
-		DO_STOP_KEY_SIGNAL_EMIT
-		status = TRUE;
-		break;
-
-	      case GDK_Left:
-	      case GDK_KP_Left:
-		if((state & GDK_CONTROL_MASK) && press)
-		{
-		    /* Get adjustment and scroll left */
-		    GtkAdjustment *adj = tlist->hadj;
-		    if(adj != NULL)
-		    {
-			adj->value -= adj->step_increment;
-			DO_ADJ_CLAMP_EMIT
-		    }
-		}
-		else if((state & GDK_SHIFT_MASK) && press)
-		{
-		    TListFreeze(tlist);
-
-		    /* Move focus thumb left */
-		    tlist->focus_thumb -= (tlist->flags & TLIST_HORIZONTAL) ?
-			tlist->thumbs_per_line : 1;
-		    DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
-
-		    switch(tlist->selection_mode)
-		    {
-		      case GTK_SELECTION_EXTENDED:
-		      case GTK_SELECTION_MULTIPLE:
-			TListDoSelectThumbRange(
-			    tlist, tlist->focus_thumb, NULL
-			);
-			break;
-
-		      case GTK_SELECTION_BROWSE:
-		      case GTK_SELECTION_SINGLE:
-			TListDoUnselectAllThumbs(tlist);
-			TListDoSelectThumb(
-			    tlist, tlist->focus_thumb, NULL, TRUE
-			);
-			break;
-		    }
-
-		    if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
-			GTK_VISIBILITY_FULL
-		    )
-			TListMoveTo(tlist, tlist->focus_thumb, 0.0f);
-
-		    TListThaw(tlist);
-		}
-		else if(press)
-		{
-		    TListFreeze(tlist);
-
-		    /* Move focus thumb left */
-		    tlist->focus_thumb -= (tlist->flags & TLIST_HORIZONTAL) ?
-			tlist->thumbs_per_line : 1;
-		    DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
-
-		    if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
-			GTK_VISIBILITY_FULL
-		    )
-			TListMoveTo(tlist, tlist->focus_thumb, 0.0f);
-
-		    TListThaw(tlist);
-		}
-		DO_STOP_KEY_SIGNAL_EMIT
-		status = TRUE;
-		break;
-
-	      case GDK_Right:
-	      case GDK_KP_Right:
-		if((state & GDK_CONTROL_MASK) && press)
-		{
-		    /* Get adjustment and scroll right */
-		    GtkAdjustment *adj = tlist->hadj;
-		    if(adj != NULL)
-		    {
-			adj->value += adj->step_increment;
-			DO_ADJ_CLAMP_EMIT
-		    }
-		}
-		else if((state & GDK_SHIFT_MASK) && press)
-		{
-		    TListFreeze(tlist);
-
-		    /* Move focus thumb right */
-		    tlist->focus_thumb += (tlist->flags & TLIST_HORIZONTAL) ?
-			tlist->thumbs_per_line : 1;
-		    DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
-
-		    switch(tlist->selection_mode)
-		    {
-		      case GTK_SELECTION_EXTENDED:
-		      case GTK_SELECTION_MULTIPLE:
-			TListDoSelectThumbRange(
-			    tlist, tlist->focus_thumb, NULL
-			);
-			break;
-
-		      case GTK_SELECTION_BROWSE:
-		      case GTK_SELECTION_SINGLE:
-			TListDoUnselectAllThumbs(tlist);
-			TListDoSelectThumb(
-			    tlist, tlist->focus_thumb, NULL, TRUE
-			);
-			break;
-		    }
-
-		    if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
-			GTK_VISIBILITY_FULL
-		    )
-			TListMoveTo(tlist, tlist->focus_thumb, 1.0f);
-
-		    TListThaw(tlist);
-		}
-		else if(press)
-		{
-		    TListFreeze(tlist);
-
-		    /* Move focus thumb right */
-		    tlist->focus_thumb += (tlist->flags & TLIST_HORIZONTAL) ?
-			tlist->thumbs_per_line : 1;
-		    DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
-
-		    if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
-			GTK_VISIBILITY_FULL
-		    )
-			TListMoveTo(tlist, tlist->focus_thumb, 1.0f);
-
-		    TListThaw(tlist);
-		}
-		DO_STOP_KEY_SIGNAL_EMIT
-		status = TRUE;
-		break;
-
-	      case GDK_Page_Up:
-	      case GDK_KP_Page_Up:
-		if((state & GDK_CONTROL_MASK) && press)
-		{
-		    GtkAdjustment *adj = (tlist->flags & TLIST_HORIZONTAL) ?
-			tlist->hadj : tlist->vadj;
-		    if(adj != NULL)
-		    {
-			adj->value -= adj->page_increment;
-			DO_ADJ_CLAMP_EMIT
-		    }
-		}
-		else if(press)
-		{
-		    gint thumb_len = (tlist->flags & TLIST_HORIZONTAL) ?
-			tlist->thumb_width : tlist->thumb_height;
-		    GtkAdjustment *adj = (tlist->flags & TLIST_HORIZONTAL) ?
-			tlist->hadj : tlist->vadj;
-		    if((adj != NULL) && (thumb_len > 0))
-		    {
-			gint n = (gint)(adj->page_increment / thumb_len) *
-			    tlist->thumbs_per_line;
-
-			TListFreeze(tlist);
-
-			/* Move focus thumb */
-			tlist->focus_thumb -= n;
-			DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
-
-			/* Select thumbs in between */
-			if(state & GDK_SHIFT_MASK)
-			{
-			    switch(tlist->selection_mode)
-			    {
-			      case GTK_SELECTION_EXTENDED:
-			      case GTK_SELECTION_MULTIPLE:
-				TListDoSelectThumbRange(
-				    tlist, tlist->focus_thumb, NULL 
-				);
-				break;
-
-			      case GTK_SELECTION_BROWSE:
-			      case GTK_SELECTION_SINGLE:
-				TListDoUnselectAllThumbs(tlist);
-				TListDoSelectThumb(
-				    tlist, tlist->focus_thumb, NULL, TRUE
-				);
-				break;
-			    }
-			}
-
-			if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
-			    GTK_VISIBILITY_FULL
-			)
-			    TListMoveTo(tlist, tlist->focus_thumb, 0.0f);
-
-			TListThaw(tlist);
-		    }
-		}
-		DO_STOP_KEY_SIGNAL_EMIT
-		status = TRUE;
-		break;
-
-	      case GDK_Page_Down:
-	      case GDK_KP_Page_Down:
-		if((state & GDK_CONTROL_MASK) && press)
-		{
-		    GtkAdjustment *adj = (tlist->flags & TLIST_HORIZONTAL) ?
-			tlist->hadj : tlist->vadj;
-		    if(adj != NULL)
-		    {
-			adj->value += adj->page_increment;
-			DO_ADJ_CLAMP_EMIT
-		    }
-		}
-		else if(press)
-		{
-		    gint thumb_len = (tlist->flags & TLIST_HORIZONTAL) ?
-			tlist->thumb_width : tlist->thumb_height;
-		    GtkAdjustment *adj = (tlist->flags & TLIST_HORIZONTAL) ?
-			tlist->hadj : tlist->vadj;
-		    if((adj != NULL) && (thumb_len > 0))
-		    {
-			gint n = (gint)(adj->page_increment / thumb_len) *
-			    tlist->thumbs_per_line;
-
-			TListFreeze(tlist);
-
-			/* Move focus thumb */
-			tlist->focus_thumb += n;
-			DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
-
-			/* Select thumbs in between */
-			if(state & GDK_SHIFT_MASK)
-			{
-			    switch(tlist->selection_mode)
-			    {
-			      case GTK_SELECTION_EXTENDED:
-			      case GTK_SELECTION_MULTIPLE:
-				TListDoSelectThumbRange(
-				    tlist, tlist->focus_thumb, NULL 
-				);
-				break;
-
-			      case GTK_SELECTION_BROWSE:
-			      case GTK_SELECTION_SINGLE:
-				TListDoUnselectAllThumbs(tlist);
-				TListDoSelectThumb(
-				    tlist, tlist->focus_thumb, NULL, TRUE
-				);
-				break;
-			    }
-			}
-
-			if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
-			    GTK_VISIBILITY_FULL
-			)
-			    TListMoveTo(tlist, tlist->focus_thumb, 1.0f);
-
-			TListThaw(tlist);
-		    }
-		}
-		DO_STOP_KEY_SIGNAL_EMIT
-		status = TRUE;
-		break;
-
-	      case GDK_Home:
-	      case GDK_KP_Home:
-		if((state & GDK_CONTROL_MASK) && press)
-		{
-		    /* Get adjustment and scroll all the way up */
-		    GtkAdjustment *adj = (tlist->flags & TLIST_HORIZONTAL) ?
-			tlist->hadj : tlist->vadj;
-		    if(adj != NULL)
-		    {
-			adj->value = adj->lower;
-			DO_ADJ_CLAMP_EMIT
-		    }
-		}
-		else if(press)
-		{
-		    TListFreeze(tlist);
-
-		    /* Move focus thumb */
-		    tlist->focus_thumb = 0;
-		    DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
-
-		    /* Select thumbs in between */
-		    if(state & GDK_SHIFT_MASK)
-		    {
-			switch(tlist->selection_mode)
-			{
-			  case GTK_SELECTION_EXTENDED:
-			  case GTK_SELECTION_MULTIPLE:
-			    TListDoSelectThumbRange(
-				tlist, tlist->focus_thumb, NULL
-			    );
-			    break; 
-
-			  case GTK_SELECTION_BROWSE:
-			  case GTK_SELECTION_SINGLE:
-			    TListDoUnselectAllThumbs(tlist);
-			    TListDoSelectThumb(
-				tlist, tlist->focus_thumb, NULL, TRUE
-			    );
-			    break;
-			}
-		    }
-
-		    if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
-			GTK_VISIBILITY_FULL
-		    )
-			TListMoveTo(tlist, tlist->focus_thumb, 0.0f);
-
-		    TListThaw(tlist);
-		}
-		DO_STOP_KEY_SIGNAL_EMIT
-		status = TRUE;
-		break;
-
-	      case GDK_End:
-	      case GDK_KP_End:
-		if((state & GDK_CONTROL_MASK) && press)
-		{
-		    /* Get adjustment and scroll all the way down */
-		    GtkAdjustment *adj = (tlist->flags & TLIST_HORIZONTAL) ?
-			tlist->hadj : tlist->vadj;
-		    if(adj != NULL)
-		    {
-			adj->value = adj->upper - adj->page_size;
-			DO_ADJ_CLAMP_EMIT
-		    }
-		}
-		else if(press)
-		{
-		    TListFreeze(tlist);
-
-		    /* Move focus thumb */
-		    tlist->focus_thumb = tlist->total_thumbs - 1;
-		    DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
-
-		    /* Select thumbs in between */
-		    if(state & GDK_SHIFT_MASK)
-		    {
-			switch(tlist->selection_mode)
-			{
-			  case GTK_SELECTION_EXTENDED:
-			  case GTK_SELECTION_MULTIPLE:
-			    TListDoSelectThumbRange(
-				tlist, tlist->focus_thumb, NULL
-			    );
-			    break; 
-
-			  case GTK_SELECTION_BROWSE:
-			  case GTK_SELECTION_SINGLE:
-			    TListDoUnselectAllThumbs(tlist);
-			    TListDoSelectThumb(
-				tlist, tlist->focus_thumb, NULL, TRUE
-			    );
-			    break;
-			}
-		    }
-
-		    if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
-			GTK_VISIBILITY_FULL
-		    )
-			TListMoveTo(tlist, tlist->focus_thumb, 1.0f);
-
-		    TListThaw(tlist);
-		}
-		DO_STOP_KEY_SIGNAL_EMIT
-		status = TRUE;
-		break;
 
+		TListThaw(tlist);
 	    }
+	    break;
+
+	  case GDK_Up:
+	  case GDK_KP_Up:
+	    if((state & GDK_CONTROL_MASK) && press)
+	    {
+		/* Get adjustment and scroll up */
+		GtkAdjustment *adj = tlist->vadj;
+		if(adj != NULL)
+		{
+		    adj->value -= adj->step_increment;
+		    DO_ADJ_CLAMP_EMIT
+		}
+	    }
+	    else if((state & GDK_SHIFT_MASK) && press)
+	    {
+		TListFreeze(tlist);
+
+		/* Move focus thumb up */
+		tlist->focus_thumb -= (tlist->flags & TLIST_HORIZONTAL) ?
+		    1 : tlist->thumbs_per_line;
+		DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
+
+		switch(tlist->selection_mode)
+		{
+		  case GTK_SELECTION_EXTENDED:
+		  case GTK_SELECTION_MULTIPLE:
+		    TListDoSelectThumbRange(
+			tlist, tlist->focus_thumb, NULL
+		    );
+		    break;
+		  case GTK_SELECTION_BROWSE:
+		  case GTK_SELECTION_SINGLE:
+		    TListDoUnselectAllThumbs(tlist);
+		    TListDoSelectThumb(
+			tlist, tlist->focus_thumb, NULL, TRUE
+		    );
+		    break;
+		}
+		if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
+		    GTK_VISIBILITY_FULL
+		)
+		    TListMoveTo(tlist, tlist->focus_thumb, 0.0f);
+
+		TListThaw(tlist);
+	    }
+	    else if(press)
+	    {
+		TListFreeze(tlist);
+
+		/* Move focus thumb up */
+		tlist->focus_thumb -= (tlist->flags & TLIST_HORIZONTAL) ?
+		    1 : tlist->thumbs_per_line;
+		DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
+
+		if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
+		    GTK_VISIBILITY_FULL
+		)
+		    TListMoveTo(tlist, tlist->focus_thumb, 0.0f);
+
+		TListThaw(tlist);
+	    }
+	    DO_STOP_KEY_SIGNAL_EMIT
+	    status = TRUE;
+	    break;
+
+	  case GDK_Down:
+	  case GDK_KP_Down:
+	    if((state & GDK_CONTROL_MASK) && press)
+	    {
+		/* Get adjustment and scroll down */
+		GtkAdjustment *adj = tlist->vadj;
+		if(adj != NULL)
+		{
+		    adj->value += adj->step_increment;
+		    DO_ADJ_CLAMP_EMIT
+		}
+	    }
+	    else if((state & GDK_SHIFT_MASK) && press)
+	    {
+		TListFreeze(tlist);
+
+		/* Move focus thumb down */
+		tlist->focus_thumb += (tlist->flags & TLIST_HORIZONTAL) ?
+		    1 : tlist->thumbs_per_line;
+		DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
+
+		switch(tlist->selection_mode)
+		{
+		  case GTK_SELECTION_EXTENDED:
+		  case GTK_SELECTION_MULTIPLE:
+		    TListDoSelectThumbRange(
+			tlist, tlist->focus_thumb, NULL
+		    );
+		    break;
+		  case GTK_SELECTION_BROWSE:
+		  case GTK_SELECTION_SINGLE:
+		    TListDoUnselectAllThumbs(tlist);
+		    TListDoSelectThumb(
+			tlist, tlist->focus_thumb, NULL, TRUE
+		    );
+		    break;
+		}
+
+		if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
+		    GTK_VISIBILITY_FULL
+		)
+		    TListMoveTo(tlist, tlist->focus_thumb, 1.0f);
+
+		TListThaw(tlist);
+	    }
+	    else if(press)
+	    {
+		TListFreeze(tlist);
+
+		/* Move focus thumb down */
+		tlist->focus_thumb += (tlist->flags & TLIST_HORIZONTAL) ?
+		    1 : tlist->thumbs_per_line;
+		DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
+
+		if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
+		    GTK_VISIBILITY_FULL
+		)
+		    TListMoveTo(tlist, tlist->focus_thumb, 1.0f);
+
+		TListThaw(tlist);
+	    }
+	    DO_STOP_KEY_SIGNAL_EMIT
+	    status = TRUE;
+	    break;
+
+	  case GDK_Left:
+	  case GDK_KP_Left:
+	    if((state & GDK_CONTROL_MASK) && press)
+	    {
+		/* Get adjustment and scroll left */
+		GtkAdjustment *adj = tlist->hadj;
+		if(adj != NULL)
+		{
+		    adj->value -= adj->step_increment;
+		    DO_ADJ_CLAMP_EMIT
+		}
+	    }
+	    else if((state & GDK_SHIFT_MASK) && press)
+	    {
+		TListFreeze(tlist);
+
+		/* Move focus thumb left */
+		tlist->focus_thumb -= (tlist->flags & TLIST_HORIZONTAL) ?
+		    tlist->thumbs_per_line : 1;
+		DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
+
+		switch(tlist->selection_mode)
+		{
+		  case GTK_SELECTION_EXTENDED:
+		  case GTK_SELECTION_MULTIPLE:
+		    TListDoSelectThumbRange(
+			tlist, tlist->focus_thumb, NULL
+		    );
+		    break;
+		  case GTK_SELECTION_BROWSE:
+		  case GTK_SELECTION_SINGLE:
+		    TListDoUnselectAllThumbs(tlist);
+		    TListDoSelectThumb(
+			tlist, tlist->focus_thumb, NULL, TRUE
+		    );
+		    break;
+		}
+
+		if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
+		    GTK_VISIBILITY_FULL
+		)
+		    TListMoveTo(tlist, tlist->focus_thumb, 0.0f);
+
+		TListThaw(tlist);
+	    }
+	    else if(press)
+	    {
+		    TListFreeze(tlist);
+
+		    /* Move focus thumb left */
+		    tlist->focus_thumb -= (tlist->flags & TLIST_HORIZONTAL) ?
+			tlist->thumbs_per_line : 1;
+		    DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
+
+		    if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
+			GTK_VISIBILITY_FULL
+		    )
+			TListMoveTo(tlist, tlist->focus_thumb, 0.0f);
+
+		    TListThaw(tlist);
+		}
+		DO_STOP_KEY_SIGNAL_EMIT
+		status = TRUE;
+		break;
+
+	  case GDK_Right:
+	  case GDK_KP_Right:
+	    if((state & GDK_CONTROL_MASK) && press)
+	    {
+		/* Get adjustment and scroll right */
+		GtkAdjustment *adj = tlist->hadj;
+		if(adj != NULL)
+		{
+		    adj->value += adj->step_increment;
+		    DO_ADJ_CLAMP_EMIT
+		}
+	    }
+	    else if((state & GDK_SHIFT_MASK) && press)
+	    {
+		TListFreeze(tlist);
+
+		/* Move focus thumb right */
+		tlist->focus_thumb += (tlist->flags & TLIST_HORIZONTAL) ?
+		    tlist->thumbs_per_line : 1;
+		DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
+
+		switch(tlist->selection_mode)
+		{
+		  case GTK_SELECTION_EXTENDED:
+		  case GTK_SELECTION_MULTIPLE:
+		    TListDoSelectThumbRange(
+			tlist, tlist->focus_thumb, NULL
+		    );
+		    break;
+		  case GTK_SELECTION_BROWSE:
+		  case GTK_SELECTION_SINGLE:
+		    TListDoUnselectAllThumbs(tlist);
+		    TListDoSelectThumb(
+			tlist, tlist->focus_thumb, NULL, TRUE
+		    );
+		    break;
+		}
+
+		if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
+		    GTK_VISIBILITY_FULL
+		)
+		    TListMoveTo(tlist, tlist->focus_thumb, 1.0f);
+
+		TListThaw(tlist);
+	    }
+	    else if(press)
+	    {
+		TListFreeze(tlist);
+
+		/* Move focus thumb right */
+		tlist->focus_thumb += (tlist->flags & TLIST_HORIZONTAL) ?
+		    tlist->thumbs_per_line : 1;
+		DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
+
+		if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
+		    GTK_VISIBILITY_FULL
+		)
+		    TListMoveTo(tlist, tlist->focus_thumb, 1.0f);
+
+		TListThaw(tlist);
+	    }
+	    DO_STOP_KEY_SIGNAL_EMIT
+	    status = TRUE;
+	    break;
+
+	  case GDK_Page_Up:
+	  case GDK_KP_Page_Up:
+	    if((state & GDK_CONTROL_MASK) && press)
+	    {
+		GtkAdjustment *adj = (tlist->flags & TLIST_HORIZONTAL) ?
+		    tlist->hadj : tlist->vadj;
+		if(adj != NULL)
+		{
+		    adj->value -= adj->page_increment;
+		    DO_ADJ_CLAMP_EMIT
+		}
+	    }
+	    else if(press)
+	    {
+		const gint thumb_len = (tlist->flags & TLIST_HORIZONTAL) ?
+		    tlist->thumb_width : tlist->thumb_height;
+		GtkAdjustment *adj = (tlist->flags & TLIST_HORIZONTAL) ?
+		    tlist->hadj : tlist->vadj;
+		if((adj != NULL) && (thumb_len > 0))
+		{
+		    gint n = (gint)(adj->page_increment / thumb_len) *
+			tlist->thumbs_per_line;
+
+		    TListFreeze(tlist);
+
+		    /* Move focus thumb */
+		    tlist->focus_thumb -= n;
+		    DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
+
+		    /* Select thumbs in between */
+		    if(state & GDK_SHIFT_MASK)
+		    {
+			switch(tlist->selection_mode)
+			{
+			  case GTK_SELECTION_EXTENDED:
+			  case GTK_SELECTION_MULTIPLE:
+			    TListDoSelectThumbRange(
+				tlist, tlist->focus_thumb, NULL 
+			    );
+			    break;
+			  case GTK_SELECTION_BROWSE:
+			  case GTK_SELECTION_SINGLE:
+			    TListDoUnselectAllThumbs(tlist);
+			    TListDoSelectThumb(
+				tlist, tlist->focus_thumb, NULL, TRUE
+			    );
+			    break;
+			}
+		    }
+
+		    if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
+			GTK_VISIBILITY_FULL
+		    )
+			TListMoveTo(tlist, tlist->focus_thumb, 0.0f);
+
+		    TListThaw(tlist);
+		}
+	    }
+	    DO_STOP_KEY_SIGNAL_EMIT
+	    status = TRUE;
+	    break;
+
+	  case GDK_Page_Down:
+	  case GDK_KP_Page_Down:
+	    if((state & GDK_CONTROL_MASK) && press)
+	    {
+		GtkAdjustment *adj = (tlist->flags & TLIST_HORIZONTAL) ?
+		    tlist->hadj : tlist->vadj;
+		if(adj != NULL)
+		{
+		    adj->value += adj->page_increment;
+		    DO_ADJ_CLAMP_EMIT
+		}
+	    }
+	    else if(press)
+	    {
+		const gint thumb_len = (tlist->flags & TLIST_HORIZONTAL) ?
+		    tlist->thumb_width : tlist->thumb_height;
+		GtkAdjustment *adj = (tlist->flags & TLIST_HORIZONTAL) ?
+		    tlist->hadj : tlist->vadj;
+		if((adj != NULL) && (thumb_len > 0))
+		{
+		    gint n = (gint)(adj->page_increment / thumb_len) *
+			tlist->thumbs_per_line;
+
+		    TListFreeze(tlist);
+
+		    /* Move focus thumb */
+		    tlist->focus_thumb += n;
+		    DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
+
+		    /* Select thumbs in between */
+		    if(state & GDK_SHIFT_MASK)
+		    {
+			switch(tlist->selection_mode)
+			{
+			  case GTK_SELECTION_EXTENDED:
+			  case GTK_SELECTION_MULTIPLE:
+			    TListDoSelectThumbRange(
+				tlist, tlist->focus_thumb, NULL 
+			    );
+			    break;
+
+			   case GTK_SELECTION_BROWSE:
+			   case GTK_SELECTION_SINGLE:
+			    TListDoUnselectAllThumbs(tlist);
+			    TListDoSelectThumb(
+				tlist, tlist->focus_thumb, NULL, TRUE
+			    );
+			    break;
+			}
+		    }
+
+		    if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
+			GTK_VISIBILITY_FULL
+		    )
+			TListMoveTo(tlist, tlist->focus_thumb, 1.0f);
+
+		    TListThaw(tlist);
+		}
+	    }
+	    DO_STOP_KEY_SIGNAL_EMIT
+	    status = TRUE;
+	    break;
+
+	  case GDK_Home:
+	  case GDK_KP_Home:
+	    if((state & GDK_CONTROL_MASK) && press)
+	    {
+		/* Get adjustment and scroll all the way up */
+		GtkAdjustment *adj = (tlist->flags & TLIST_HORIZONTAL) ?
+		    tlist->hadj : tlist->vadj;
+		if(adj != NULL)
+		{
+		    adj->value = adj->lower;
+		    DO_ADJ_CLAMP_EMIT
+	        }
+	    }
+	    else if(press)
+	    {
+		TListFreeze(tlist);
+
+		/* Move focus thumb */
+		tlist->focus_thumb = 0;
+		DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
+
+		/* Select thumbs in between */
+		if(state & GDK_SHIFT_MASK)
+		{
+		    switch(tlist->selection_mode)
+		    {
+		      case GTK_SELECTION_EXTENDED:
+		      case GTK_SELECTION_MULTIPLE:
+			TListDoSelectThumbRange(
+			    tlist, tlist->focus_thumb, NULL
+			);
+			break; 
+		      case GTK_SELECTION_BROWSE:
+		      case GTK_SELECTION_SINGLE:
+			TListDoUnselectAllThumbs(tlist);
+			TListDoSelectThumb(
+			    tlist, tlist->focus_thumb, NULL, TRUE
+			);
+			break;
+		    }
+		}
+
+		if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
+		    GTK_VISIBILITY_FULL
+		)
+		    TListMoveTo(tlist, tlist->focus_thumb, 0.0f);
+
+		TListThaw(tlist);
+	    }
+	    DO_STOP_KEY_SIGNAL_EMIT
+	    status = TRUE;
+	    break;
+
+	  case GDK_End:
+	  case GDK_KP_End:
+	    if((state & GDK_CONTROL_MASK) && press)
+	    {
+		/* Get adjustment and scroll all the way down */
+		GtkAdjustment *adj = (tlist->flags & TLIST_HORIZONTAL) ?
+		    tlist->hadj : tlist->vadj;
+		if(adj != NULL)
+		{
+		    adj->value = adj->upper - adj->page_size;
+		    DO_ADJ_CLAMP_EMIT
+		}
+	    }
+	    else if(press)
+	    {
+		TListFreeze(tlist);
+
+		/* Move focus thumb */
+		tlist->focus_thumb = tlist->total_thumbs - 1;
+		DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
+
+		/* Select thumbs in between */
+		if(state & GDK_SHIFT_MASK)
+		{
+		    switch(tlist->selection_mode)
+		    {
+		      case GTK_SELECTION_EXTENDED:
+		      case GTK_SELECTION_MULTIPLE:
+			TListDoSelectThumbRange(
+			    tlist, tlist->focus_thumb, NULL
+			);
+		        break; 
+		      case GTK_SELECTION_BROWSE:
+		      case GTK_SELECTION_SINGLE:
+			TListDoUnselectAllThumbs(tlist);
+			TListDoSelectThumb(
+			    tlist, tlist->focus_thumb, NULL, TRUE
+			);
+			break;
+		    }
+		}
+
+		if(TListIsThumbVisible(tlist, tlist->focus_thumb) !=
+		    GTK_VISIBILITY_FULL
+		)
+		    TListMoveTo(tlist, tlist->focus_thumb, 1.0f);
+
+		TListThaw(tlist);
+	    }
+	    DO_STOP_KEY_SIGNAL_EMIT
+	    status = TRUE;
+	    break;
 	}
 
 #undef DO_TLIST_FOCUS_THUMB_CLAMP_DRAW
@@ -3664,51 +3646,51 @@ tlist_struct *TListNew(
 	    GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
 	    GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK
 	);
-	gtk_signal_connect(
+	gtk_signal_connect_after(
 	    GTK_OBJECT(w), "realize",
 	    GTK_SIGNAL_FUNC(TListRealizeCB), tlist
 	);
-	gtk_signal_connect(
+	gtk_signal_connect_after(
 	    GTK_OBJECT(w), "configure_event",
 	    GTK_SIGNAL_FUNC(TListConfigureEventCB), tlist
 	);
-	gtk_signal_connect(
+	gtk_signal_connect_after(
 	    GTK_OBJECT(w), "expose_event",
 	    GTK_SIGNAL_FUNC(TListExposeEventCB), tlist
 	);                                            
-	gtk_signal_connect(
+	gtk_signal_connect_after(
 	    GTK_OBJECT(w), "key_press_event",
 	    GTK_SIGNAL_FUNC(TListKeyEventCB), tlist
 	);
-	gtk_signal_connect(
+	gtk_signal_connect_after(
 	    GTK_OBJECT(w), "key_release_event",
 	    GTK_SIGNAL_FUNC(TListKeyEventCB), tlist
 	);
-	gtk_signal_connect(
+	gtk_signal_connect_after(
 	    GTK_OBJECT(w), "button_press_event",
 	    GTK_SIGNAL_FUNC(TListButtonEventCB), tlist
 	);
-	gtk_signal_connect(
+	gtk_signal_connect_after(
 	    GTK_OBJECT(w), "button_release_event",
 	    GTK_SIGNAL_FUNC(TListButtonEventCB), tlist
 	);
-	gtk_signal_connect(
+	gtk_signal_connect_after(
 	    GTK_OBJECT(w), "motion_notify_event",
 	    GTK_SIGNAL_FUNC(TListMotionEventCB), tlist
 	);
-	gtk_signal_connect(
+	gtk_signal_connect_after(
 	    GTK_OBJECT(w), "enter_notify_event",
 	    GTK_SIGNAL_FUNC(TListCrossingEventCB), tlist
 	);
-	gtk_signal_connect(
+	gtk_signal_connect_after(
 	    GTK_OBJECT(w), "leave_notify_event",
 	    GTK_SIGNAL_FUNC(TListCrossingEventCB), tlist
 	);
-	gtk_signal_connect(
+	gtk_signal_connect_after(
 	    GTK_OBJECT(w), "focus_in_event",
 	    GTK_SIGNAL_FUNC(TListFocusEventCB), tlist
 	);
-	gtk_signal_connect(
+	gtk_signal_connect_after(
 	    GTK_OBJECT(w), "focus_out_event",
 	    GTK_SIGNAL_FUNC(TListFocusEventCB), tlist
 	);
