@@ -123,7 +123,7 @@ void TViewScrollToLine(
 		    break;
 		}
 
-		if(GTK_TEXT_INDEX(GTK_TEXT(w), i) == '\n')
+		if(GTK_TEXT_INDEX(GTK_TEXT(w), (guint)i) == '\n')
 		    line_count++;
 	    }
 	}
@@ -398,7 +398,7 @@ void TViewCopy(tview_struct *tv)
 	/* Allocate buffer and copy selected data to it */
 	buf = (guint8 *)g_malloc(sel_len * sizeof(guint8));
 	for(i = 0; i < sel_len; i++)
-	    buf[i] = (guint8)GTK_TEXT_INDEX(GTK_TEXT(w), sel_pos + i);
+	    buf[i] = (guint8)GTK_TEXT_INDEX(GTK_TEXT(w), (guint)(sel_pos + i));
 
 	/* Copy to clipboard */
 	GUIDDESetBinary(w, GDK_NONE, GDK_CURRENT_TIME, buf, sel_len);
@@ -729,7 +729,7 @@ tview_struct *TViewNew(GtkWidget *parent)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Corte"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Coupure"
+"Couper"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Schnitt"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -755,7 +755,7 @@ tview_struct *TViewNew(GtkWidget *parent)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Copia"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Copie"
+"Copier"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Kopie"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -781,7 +781,7 @@ tview_struct *TViewNew(GtkWidget *parent)
 #if defined(PROG_LANGUAGE_SPANISH) 
 "Pasta"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Pte"
+"Coller"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Paste"
 #elif defined(PROG_LANGUAGE_ITALIAN)
@@ -807,7 +807,7 @@ tview_struct *TViewNew(GtkWidget *parent)
 #if defined(PROG_LANGUAGE_SPANISH)
 "Borre"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Effacer"
+"Supprimer"
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Lschen"
 #elif defined(PROG_LANGUAGE_ITALIAN)
