@@ -1,5 +1,7 @@
 #include <stdlib.h>
 #include <string.h>
+#include <sys/types.h>
+#include <sys/stat.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
@@ -39,10 +41,10 @@ GList *ZipToolOPIDListNew(zip_tool_struct *zt);
 void ZipToolOPIDListDelete(GList *opid);
 
 void ZipToolSetDevice(
-	zip_tool_struct *zt, edv_device_struct *dev_ptr
+	zip_tool_struct *zt, edv_device_struct *dev
 );
 void ZipToolRefreshDevice(
-	zip_tool_struct *zt, edv_device_struct *dev_ptr
+	zip_tool_struct *zt, edv_device_struct *dev
 );
 
 zip_tool_struct *ZipToolNew(edv_context_struct *ctx);
@@ -220,14 +222,14 @@ void ZipToolOPIDListDelete(GList *opid)
 }
 
 /*
- *	Sets the new device specified by dev_ptr on the zip tools
+ *	Sets the new device specified by dev on the zip tools
  *	window. If a device already exists then it will be deallocated
  *	first.
  *
  *	The given device will be taken by this function and should no
  *	longer be referenced by the calling function.
  */
-void ZipToolSetDevice(zip_tool_struct *zt, edv_device_struct *dev_ptr)
+void ZipToolSetDevice(zip_tool_struct *zt, edv_device_struct *dev)
 {
 	GtkWidget *w;
 
@@ -238,27 +240,27 @@ void ZipToolSetDevice(zip_tool_struct *zt, edv_device_struct *dev_ptr)
 	 * device reference
 	 */
 	EDVDeviceDelete(zt->device);
-	zt->device = dev_ptr;
+	zt->device = dev;
 
 	/* Update title */
 	w = zt->toplevel;
 	if(w != NULL)
 	{
-	    if(dev_ptr != NULL)
+	    if(dev != NULL)
 	    {
 		gchar *buf;
 
-		if((dev_ptr->name != NULL) && (dev_ptr->device_path != NULL))
+		if((dev->name != NULL) && (dev->device_path != NULL))
 		    buf = g_strdup_printf(
 			"%s: %s (%s)",
-			PROG_NAME, dev_ptr->name, dev_ptr->device_path
+			PROG_NAME, dev->name, dev->device_path
 		    );
 		else
 		    buf = g_strdup_printf(
 			"%s: %s",
 			PROG_NAME,
-			(dev_ptr->name != NULL) ? dev_ptr->name :
-			    dev_ptr->device_path
+			(dev->name != NULL) ? dev->name :
+			    dev->device_path
 		    );
 		gtk_window_set_title(GTK_WINDOW(w), buf);
 		g_free(buf);
@@ -272,10 +274,10 @@ void ZipToolSetDevice(zip_tool_struct *zt, edv_device_struct *dev_ptr)
 
 /*
  *	Rescans the specified device (or the current device on the Zip
- *	Tool Window if dev_ptr is NULL) and updates the display widgets.
+ *	Tool Window if dev is NULL) and updates the display widgets.
  */
 void ZipToolRefreshDevice(
-	zip_tool_struct *zt, edv_device_struct *dev_ptr
+	zip_tool_struct *zt, edv_device_struct *dev
 )
 {
 	const gint	border_major = 5,
@@ -285,17 +287,17 @@ void ZipToolRefreshDevice(
 	if(zt == NULL)
 	    return;
 
-	if(dev_ptr == NULL)
-	    dev_ptr = zt->device;
-	if(dev_ptr == NULL)
+	if(dev == NULL)
+	    dev = zt->device;
+	if(dev == NULL)
 	    return;
 
 	/* Update the Device's mount state and stats */
-	EDVDeviceUpdateMountState(dev_ptr);
-	EDVDeviceUpdateStats(dev_ptr);
+	EDVDeviceUpdateMountState(dev);
+	EDVDeviceUpdateStats(dev);
 
 	/* Get lock state */
-	zt->lock_state = ZipToolDeviceIsProtected(dev_ptr);
+	zt->lock_state = ZipToolDeviceIsProtected(dev);
 
 
 	/* Destroy existing display widgets */
@@ -380,8 +382,8 @@ void ZipToolRefreshDevice(
 } }
 
 	    /* Get stats of the mount path */
-	    stat_status = !STRISEMPTY(dev_ptr->mount_path) ?
-		stat(dev_ptr->mount_path, &stat_buf) : -1;
+	    stat_status = !STRISEMPTY(dev->mount_path) ?
+		stat(dev->mount_path, &stat_buf) : -1;
 
 
 	    /* Hbox for multiple columns */
@@ -404,49 +406,49 @@ void ZipToolRefreshDevice(
 	    parent3 = w;
  
 	    /* Get pixmap and mask to display device icon */
-	    if(dev_ptr->is_mounted &&
+	    if(EDV_DEVICE_IS_MOUNTED(dev) &&
 	       (EDV_DEVICE_TOTAL_ICON_STATES > EDV_DEVICE_ICON_STATE_STANDARD)
 	    )
 	    {
 		edv_device_icon_state i = EDV_DEVICE_ICON_STATE_STANDARD;
 		pixmap = GDK_PIXMAP_NEW_FROM_XPM_FILE(
-		    &mask, dev_ptr->large_icon_file[i]
+		    &mask, dev->large_icon_file[i]
 		);
 		if(pixmap == NULL)
 		    pixmap = GDK_PIXMAP_NEW_FROM_XPM_FILE(
-			&mask, dev_ptr->medium_icon_file[i]
+			&mask, dev->medium_icon_file[i]
 		    );
 		if(pixmap == NULL)
 		    pixmap = GDK_PIXMAP_NEW_FROM_XPM_FILE(
-			&mask, dev_ptr->small_icon_file[i]
+			&mask, dev->small_icon_file[i]
 		    );
 	    }
 	    else if(EDV_DEVICE_TOTAL_ICON_STATES > EDV_DEVICE_ICON_STATE_UNMOUNTED)
 	    {
 		edv_device_icon_state i = EDV_DEVICE_ICON_STATE_UNMOUNTED;
 		pixmap = GDK_PIXMAP_NEW_FROM_XPM_FILE(
-		    &mask, dev_ptr->large_icon_file[i]
+		    &mask, dev->large_icon_file[i]
 		);
 		if(pixmap == NULL)
 		    pixmap = GDK_PIXMAP_NEW_FROM_XPM_FILE(
-			&mask, dev_ptr->medium_icon_file[i]
+			&mask, dev->medium_icon_file[i]
 		    );
 		if(pixmap == NULL)
 		    pixmap = GDK_PIXMAP_NEW_FROM_XPM_FILE(
-			&mask, dev_ptr->small_icon_file[i]
+			&mask, dev->small_icon_file[i]
 		    );
 		i = EDV_DEVICE_ICON_STATE_STANDARD;
 		if(pixmap == NULL)
 		    pixmap = GDK_PIXMAP_NEW_FROM_XPM_FILE(
-			&mask, dev_ptr->large_icon_file[i]
+			&mask, dev->large_icon_file[i]
 		    );
 		if(pixmap == NULL)
 		    pixmap = GDK_PIXMAP_NEW_FROM_XPM_FILE(
-			&mask, dev_ptr->medium_icon_file[i]
+			&mask, dev->medium_icon_file[i]
 		    );
 		if(pixmap == NULL)
 		    pixmap = GDK_PIXMAP_NEW_FROM_XPM_FILE(
-			&mask, dev_ptr->small_icon_file[i]
+			&mask, dev->small_icon_file[i]
 		    );
 	    }
 	    if(pixmap != NULL)
@@ -465,8 +467,8 @@ void ZipToolRefreshDevice(
 	    rcstyle->font_name = STRDUP( 
 "-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-1"
 	    );
-	    if(!STRISEMPTY(dev_ptr->name))
-		buf = STRDUP(dev_ptr->name);
+	    if(!STRISEMPTY(dev->name))
+		buf = STRDUP(dev->name);
 	    else
 		buf = STRDUP("Untitled");
 	    w = gtk_label_new(buf);
@@ -477,8 +479,8 @@ void ZipToolRefreshDevice(
 	    GTK_RC_STYLE_UNREF(rcstyle)
 
 	    /* Device Path Label */
-	    if(!STRISEMPTY(dev_ptr->device_path))
-		buf = EDVCopyShortenPath(dev_ptr->device_path, 35);
+	    if(!STRISEMPTY(dev->device_path))
+		buf = EDVShortenPath(dev->device_path, 35);
 	    else
 		buf = STRDUP("*path not set*");
 	    w = gtk_label_new(buf);
@@ -487,7 +489,7 @@ void ZipToolRefreshDevice(
 	    gtk_widget_show(w);
 
 	    /* Mount Path Button */
-	    if(!STRISEMPTY(dev_ptr->mount_path))
+	    if(!STRISEMPTY(dev->mount_path))
 	    {
 		/* Hbox */
 		w = gtk_hbox_new(TRUE, 0); 
@@ -495,7 +497,7 @@ void ZipToolRefreshDevice(
 		gtk_widget_show(w);
 		parent3 = w;
 		/* Button */
-		buf2 = EDVCopyShortenPath(dev_ptr->mount_path, 35);
+		buf2 = EDVShortenPath(dev->mount_path, 35);
 		buf = g_strdup_printf(
 "Mount Path: %s",
 		    buf2
@@ -512,21 +514,21 @@ void ZipToolRefreshDevice(
 	    }
 
 	    /* Usage Pie Chart */
-	    if(dev_ptr->is_mounted)
+	    if(EDV_DEVICE_IS_MOUNTED(dev))
 	    {
 		gchar *ss_kb, *ss_mb;
 
 		adj = (GtkAdjustment *)gtk_adjustment_new(
 		    0.0f, 0.0f,
-		    (gfloat)(dev_ptr->blocks_total / adj_division),
+		    (gfloat)(dev->blocks_total / adj_division),
 		    0.0f, 0.0f, 0.0f
 		);
 		GDK_COLOR_SET_COEFF(&c, 0.0f, 0.0f, 1.0f)
 		ss_kb = STRDUP(
-		    EDVSizeStrDelim(dev_ptr->blocks_total)
+		    EDVSizeStrDelim(dev->blocks_total)
 		);
 		ss_mb = STRDUP(
-		    EDVSizeStrDelim(dev_ptr->blocks_total / 1000)
+		    EDVSizeStrDelim(dev->blocks_total / 1000)
 		);
 		buf = g_strdup_printf(
 		    "%s: %s kb (%s mb)",
@@ -545,10 +547,10 @@ void ZipToolRefreshDevice(
 		g_free(ss_mb);
 
 		ss_kb = STRDUP(
-		    EDVSizeStrDelim(dev_ptr->blocks_free)
+		    EDVSizeStrDelim(dev->blocks_free)
 		);
 		ss_mb = STRDUP(
-		    EDVSizeStrDelim(dev_ptr->blocks_free / 1000)
+		    EDVSizeStrDelim(dev->blocks_free / 1000)
 		);
 		buf2 = g_strdup_printf(
 		    "%s kb (%s mb)",
@@ -581,14 +583,14 @@ void ZipToolRefreshDevice(
 		GDK_COLOR_SET_COEFF(&c, 0.0f, 1.0f, 1.0f)
 		adj = (GtkAdjustment *)gtk_adjustment_new(
 		    0.0f, 0.0f,
-		    (gfloat)(dev_ptr->blocks_available / adj_division),
+		    (gfloat)(dev->blocks_available / adj_division),
 		    0.0f, 0.0f, 0.0f
 		);
 		ss_kb = STRDUP(
-		    EDVSizeStrDelim(dev_ptr->blocks_available)
+		    EDVSizeStrDelim(dev->blocks_available)
 		);
 		ss_mb = STRDUP(
-		    EDVSizeStrDelim(dev_ptr->blocks_available / 1000)
+		    EDVSizeStrDelim(dev->blocks_available / 1000)
 		);
 		buf = g_strdup_printf(
 		    "%s kb (%s mb)",
@@ -616,19 +618,19 @@ void ZipToolRefreshDevice(
 		adj = (GtkAdjustment *)gtk_adjustment_new(
 		    0.0, 0.0,
 		    (gfloat)(
-			(dev_ptr->blocks_total - dev_ptr->blocks_free) /
+			(dev->blocks_total - dev->blocks_free) /
 			    adj_division
 		    ),
 		    0.0f, 0.0f, 0.0f
 		);
 		ss_kb = STRDUP(
 		    EDVSizeStrDelim(
-			dev_ptr->blocks_total - dev_ptr->blocks_free
+			dev->blocks_total - dev->blocks_free
 		    )
 		);
 		ss_mb = STRDUP(
 		    EDVSizeStrDelim(
-			(dev_ptr->blocks_total - dev_ptr->blocks_free) / 1000
+			(dev->blocks_total - dev->blocks_free) / 1000
 		    )
 		);
 		buf = g_strdup_printf(
@@ -697,11 +699,11 @@ void ZipToolRefreshDevice(
 	    gtk_widget_show(w);
 	    parent3 = w;
 	    /* Button */
-	    if(dev_ptr->is_mounted)
+	    if(EDV_DEVICE_IS_MOUNTED(dev))
 	    {
 		buf = g_strdup_printf(
 		    "Mounted (%s)",
-		    dev_ptr->read_only ? "Read Only" : "Read/Write"
+		    EDV_DEVICE_IS_READ_ONLY(dev) ? "Read Only" : "Read/Write"
 		);
 		zt->display_mount_btn = w = GUIButtonPixmapLabelH(
 		    (guint8 **)icon_mounted_20x20_xpm,
@@ -753,7 +755,7 @@ void ZipToolRefreshDevice(
 	    gtk_widget_show(w);
 
 	    /* Ownership widgets (only if mounted) */
-	    if(dev_ptr->is_mounted)
+	    if(EDV_DEVICE_IS_MOUNTED(dev))
 	    {
 		prefix_label_width = 70;
 
@@ -798,8 +800,9 @@ void ZipToolRefreshDevice(
 		    buf = STRDUP("");
 		}
 		else
-		{   
-		    mode_t m = stat_buf.st_mode;
+		{
+		    const mode_t m = stat_buf.st_mode;
+#if defined(S_IRUSR) && defined(S_IWUSR) && defined(S_IXUSR) && defined(S_IRGRP) && defined(S_IWGRP) && defined(S_IXGRP) && defined(S_IROTH) && defined(S_IWOTH) && defined(S_IXOTH) && defined(S_ISUID) && defined(S_ISGID) && defined(S_ISVTX)
 		    buf = g_strdup_printf(
 			"%c%c%c%c%c%c%c%c%c",
 			(m & S_IRUSR) ? 'r' : '-',
@@ -815,13 +818,16 @@ void ZipToolRefreshDevice(
 			(m & S_ISVTX) ? 'S' :
 			    ((m & S_IXOTH) ? 'x' : '-')
 		    );
+#else
+		    buf = STRDUP("");
+#endif
 		}
 		ADD_LABEL("Permissions:", buf)
 		g_free(buf);
 	    }
 
 	    /* Details widgets (only if mounted) */
-	    if(dev_ptr->is_mounted)
+	    if(EDV_DEVICE_IS_MOUNTED(dev))
 	    {
 		prefix_label_width = 90;
 
@@ -851,7 +857,7 @@ void ZipToolRefreshDevice(
 
 		/* Filesystem Label */
 		buf = STRDUP(
-		    EDVDeviceGetFSStringFromNumber(dev_ptr->fs_type)
+		    EDVDeviceGetFSNameFromType(dev->fs_type)
 		);
 		ADD_LABEL("Filesystem:", buf)   
 		g_free(buf);
@@ -1184,37 +1190,37 @@ void ZipToolUpdate(zip_tool_struct *zt)
 	gboolean sensitive;
 	GtkWidget *w;
 	toolbar_struct *tb;
-	edv_device_struct *dev_ptr;
+	edv_device_struct *dev;
 
 	if(zt == NULL)
 	    return;
 
 	tb = zt->tool_bar;
-	dev_ptr = zt->device;
+	dev = zt->device;
 
 	/* Mount */
-	sensitive = (dev_ptr != NULL) ? !dev_ptr->is_mounted : TRUE;
+	sensitive = (dev != NULL) ? !EDV_DEVICE_IS_MOUNTED(dev) : TRUE;
 	ToolBarItemSetSensitiveID(
 	    tb, ZIP_TOOL_OPID_MOUNT, sensitive
 	);
 	GTK_WIDGET_SET_SENSITIVE(zt->mount_mi, sensitive)
 
 	/* Unmount */
-	sensitive = (dev_ptr != NULL) ? dev_ptr->is_mounted : FALSE;
+	sensitive = (dev != NULL) ? EDV_DEVICE_IS_MOUNTED(dev) : FALSE;
 	ToolBarItemSetSensitiveID(
 	    tb, ZIP_TOOL_OPID_UNMOUNT, sensitive
 	);
 	GTK_WIDGET_SET_SENSITIVE(zt->unmount_mi, sensitive)
 
 	/* Eject */
-	sensitive = (dev_ptr != NULL) ? !dev_ptr->is_mounted : TRUE;
+	sensitive = (dev != NULL) ? !EDV_DEVICE_IS_MOUNTED(dev) : TRUE;
 	ToolBarItemSetSensitiveID(
 	    tb, ZIP_TOOL_OPID_EJECT, sensitive
 	);
 	GTK_WIDGET_SET_SENSITIVE(zt->eject_mi, sensitive)
 
 	/* Lock/unlock */
-	sensitive = (dev_ptr != NULL) ? !dev_ptr->is_mounted : TRUE;
+	sensitive = (dev != NULL) ? !EDV_DEVICE_IS_MOUNTED(dev) : TRUE;
 	ToolBarItemUpdateByID(
 	    tb,
 	    ZIP_TOOL_OPID_PASSWORD,
@@ -1235,7 +1241,7 @@ void ZipToolUpdate(zip_tool_struct *zt)
 	GTK_WIDGET_SET_SENSITIVE(w, sensitive)
 
 	/* FSCK */
-	sensitive = (dev_ptr != NULL) ? !dev_ptr->is_mounted : TRUE;
+	sensitive = (dev != NULL) ? !EDV_DEVICE_IS_MOUNTED(dev) : TRUE;
 	ToolBarItemSetSensitiveID(
 	    tb, ZIP_TOOL_OPID_FSCK, sensitive
 	);
