@@ -9,6 +9,7 @@
 #include "../../include/prochandle.h"
 
 #include "../lib/endeavour2.h"
+#include "../edvutils.h"
 
 #include "ziptoolio.h"
 #include "config.h"
@@ -17,6 +18,7 @@
 static void ZipToolLoadFileToString(
 	const gchar *path, gchar *buf, gint buf_len
 );
+static gchar *ZipToolGetZipToolProg(void);
 
 gchar *ZipToolLastError(void);
 
@@ -24,6 +26,7 @@ gint ZipToolMount(edv_device_struct *dev_ptr);
 gint ZipToolUnmount(edv_device_struct *dev_ptr);
 
 zip_tool_lock_state ZipToolDeviceIsProtected(edv_device_struct *dev_ptr);
+
 gint ZipToolLock(
 	edv_device_struct *dev_ptr, const gchar *password
 );
@@ -49,7 +52,6 @@ gint ZipToolEject(edv_device_struct *dev_ptr);
 #define UNLINK(p)	(STRISEMPTY(p) ? -1 : unlink(p))
 
 #define DEV_NULL_PATH		"/dev/null"
-#define ZIP_TOOL_PROG_PATH	"/usr/bin/ziptool"
 
 
 static gchar last_error[1024];
@@ -72,8 +74,10 @@ static void ZipToolLoadFileToString(
 
 	if(buf != NULL)
 	{
-	    gint bytes_read = fread(buf, sizeof(gchar), buf_len, fp);
-	    if(bytes_read >= buf_len)
+	    gint bytes_read = (gint)fread(
+		(void *)buf, (size_t)sizeof(gchar), (size_t)buf_len, fp
+	    );
+ 	    if(bytes_read >= buf_len)
 		bytes_read = buf_len - 1;
 	    if(bytes_read >= 0)
 		buf[bytes_read] = '\0';
@@ -84,6 +88,26 @@ static void ZipToolLoadFileToString(
 	FClose(fp);
 }
 
+/*
+ *	Returns the full path to the ZipTool program or NULL on error.
+ *
+ *	The last_error will be updated if the ZipTool program is not
+ *	found.
+ *
+ *	The calling function must deleted the returned string.
+ */
+static gchar *ZipToolGetZipToolProg(void)
+{
+	gchar *prog = EDVWhich(ZIPTOOL_PROG);
+	if(prog == NULL)
+	    g_snprintf(
+		last_error, sizeof(last_error),
+"Unable to find the program \"%s\".",
+		ZIPTOOL_PROG
+	    );
+	return(prog);
+}
+
 /*
  *	Returns a statically allocated string describing the last
  *	error or NULL if there was no error.
@@ -107,18 +131,22 @@ gint ZipToolMount(edv_device_struct *dev_ptr)
 {
 	pid_t p;
 	const gchar *tmp_dir;
-	gchar *cmd, *stderr_path;
+	gchar *cmd, *prog, *stderr_path;
 
 	*last_error = '\0';		/* Reset last error message */
 
 	if(dev_ptr == NULL)
 	    return(-2);
-
 	if(STRISEMPTY(dev_ptr->device_path))
 	    return(-2);
 	if(STRISEMPTY(dev_ptr->mount_path))
 	    return(-2);
 
+	/* Get the ZipTool program */
+	prog = ZipToolGetZipToolProg();
+	if(prog == NULL)
+	    return(-1);
+
 	/* Get temp dir */
 	tmp_dir = g_getenv("TMPDIR");
 	if(STRISEMPTY(tmp_dir))      
@@ -132,10 +160,10 @@ gint ZipToolMount(edv_device_struct *dev_ptr)
 	stderr_path = STRDUP(PrefixPaths(tmp_dir, "ziptoolXXXXXX"));
 	mkstemp(stderr_path);                                       
 
-	/* Format and execute eject command */
+	/* Format and execute mount command */
 	cmd = g_strdup_printf(
 	    "%s -m %s %s",
-	    ZIP_TOOL_PROG_PATH,
+	    prog,
 	    dev_ptr->device_path, dev_ptr->mount_path
 	);
 	p = ExecBOE(cmd, DEV_NULL_PATH, stderr_path);
@@ -150,6 +178,8 @@ gint ZipToolMount(edv_device_struct *dev_ptr)
 	UNLINK(stderr_path);
 	g_free(stderr_path);
 
+	g_free(prog);
+
 	return((p == 0) ? -3 : 0);
 }
 
@@ -167,16 +197,20 @@ gint ZipToolUnmount(edv_device_struct *dev_ptr)
 {
 	pid_t p;
 	const gchar *tmp_dir;
-	gchar *cmd, *stderr_path;
+	gchar *cmd, *prog, *stderr_path;
 
 	*last_error = '\0';		/* Reset last error message */
 
 	if(dev_ptr == NULL)
 	    return(-2);
-
 	if(STRISEMPTY(dev_ptr->device_path))
 	    return(-2);
 
+	/* Get the ZipTool program */
+	prog = ZipToolGetZipToolProg();
+	if(prog == NULL)
+	    return(-1);
+
 	/* Get temp dir */
 	tmp_dir = g_getenv("TMPDIR");
 	if(STRISEMPTY(tmp_dir))      
@@ -190,10 +224,10 @@ gint ZipToolUnmount(edv_device_struct *dev_ptr)
 	stderr_path = STRDUP(PrefixPaths(tmp_dir, "ziptoolXXXXXX"));
 	mkstemp(stderr_path);                                       
 
-	/* Format and execute eject command */
+	/* Format and execute unmount command */
 	cmd = g_strdup_printf(
 	    "%s -u %s",
-	    ZIP_TOOL_PROG_PATH,
+	    prog,
 	    dev_ptr->device_path
 	);
 	p = ExecBOE(cmd, DEV_NULL_PATH, stderr_path);
@@ -208,6 +242,8 @@ gint ZipToolUnmount(edv_device_struct *dev_ptr)
 	UNLINK(stderr_path);
 	g_free(stderr_path);
 
+	g_free(prog);
+
 	return((p == 0) ? -3 : 0);
 }
 
@@ -217,19 +253,23 @@ gint ZipToolUnmount(edv_device_struct *dev_ptr)
  */
 zip_tool_lock_state ZipToolDeviceIsProtected(edv_device_struct *dev_ptr)
 {
-	gint status = 0;
+	zip_tool_lock_state status = ZIP_TOOL_LOCK_STATE_UNLOCKED;
 	pid_t p;
 	const gchar *tmp_dir;
-	gchar *cmd, *stdout_path, *stderr_path;
+	gchar *cmd, *prog, *stdout_path, *stderr_path;
 
 	*last_error = '\0';             /* Reset last error message */
 
 	if(dev_ptr == NULL)
 	    return(status);
-
 	if(STRISEMPTY(dev_ptr->device_path))
 	    return(status);
 
+	/* Get the ZipTool program */
+	prog = ZipToolGetZipToolProg();
+	if(prog == NULL)
+	    return(status);
+
 	/* Get temp dir */
 	tmp_dir = g_getenv("TMPDIR");
 	if(STRISEMPTY(tmp_dir))      
@@ -248,7 +288,7 @@ zip_tool_lock_state ZipToolDeviceIsProtected(edv_device_struct *dev_ptr)
 	/* Format and execute device status command */
 	cmd = g_strdup_printf(
 	    "%s -s %s",
-	    ZIP_TOOL_PROG_PATH,
+	    prog,
 	    dev_ptr->device_path
 	);
 	p = ExecBOE(cmd, stdout_path, stderr_path);
@@ -260,6 +300,7 @@ zip_tool_lock_state ZipToolDeviceIsProtected(edv_device_struct *dev_ptr)
 	    g_free(stdout_path);
 	    UNLINK(stderr_path);
 	    g_free(stderr_path);
+	    g_free(prog);
 	    return(status);
 	}
 	else
@@ -276,17 +317,17 @@ zip_tool_lock_state ZipToolDeviceIsProtected(edv_device_struct *dev_ptr)
 		    buf,
 		    "password write-protected"
 		) != NULL)
-		    status = 2;
+		    status = ZIP_TOOL_LOCK_STATE_LOCKED_PASSWORD;
 		else if(strstr(
 		    buf,
 		    "write-protected"
 		) != NULL)
-		    status = 1;
+		    status = ZIP_TOOL_LOCK_STATE_LOCKED;
 		else if(strstr(
 		    buf,
 		    "not protected"
 		) != NULL)
-		    status = 0;
+		    status = ZIP_TOOL_LOCK_STATE_UNLOCKED;
 
 		/* All else assume not protected */
 
@@ -305,6 +346,8 @@ zip_tool_lock_state ZipToolDeviceIsProtected(edv_device_struct *dev_ptr)
 	UNLINK(stderr_path);
 	g_free(stderr_path);
 
+	g_free(prog);
+
 	return(status);
 }
 
@@ -327,17 +370,26 @@ gint ZipToolLock(
 	edv_device_struct *dev_ptr, const gchar *password
 )
 {
+	gchar *prog;
+
 	*last_error = '\0';             /* Reset last error message */
 
 	if(dev_ptr == NULL)
 	    return(-2);
-
 	if(STRISEMPTY(dev_ptr->device_path))
 	    return(-2);
 
+	/* Get the ZipTool program */
+	prog = ZipToolGetZipToolProg();
+	if(prog == NULL)
+	    return(-1);
+
 	/* Device is already locked? */
 	if(ZipToolDeviceIsProtected(dev_ptr) != ZIP_TOOL_LOCK_STATE_UNLOCKED)
+	{
+	    g_free(prog);
 	    return(-5);
+	}
 
 	/* Lock with password? */
 	if(!STRISEMPTY(password))
@@ -345,13 +397,16 @@ gint ZipToolLock(
 	    /* Format and execute lock device with password command */
 	    gchar *cmd = g_strdup_printf(
 		"%s -rp %s",
-		ZIP_TOOL_PROG_PATH,
+		prog,
 		dev_ptr->device_path
 	    );
 	    FILE *fp = popen(cmd, "w");
 	    g_free(cmd);
 	    if(fp == NULL)
+	    {
+		g_free(prog);
 		return(-3);
+	    }
 
 	    /* Send password */
 	    fprintf(fp, "%s\n", password);
@@ -363,19 +418,24 @@ gint ZipToolLock(
 	    /* Format and execute lock device command */
 	    gchar *cmd = g_strdup_printf(
 		"%s -ro %s",
-		ZIP_TOOL_PROG_PATH,
+		prog,
 		dev_ptr->device_path
 	    );
 	    FILE *fp = popen(cmd, "w");
 	    g_free(cmd);
 	    if(fp == NULL)
+	    {
+		g_free(prog);
 		return(-3);
+	    }
 
 	    /* Do not send any password */
 
 	    pclose(fp);
 	}
 
+	g_free(prog);
+
 #if 0
 	/* Device was not successfully locked? */
 /* This does not work quite well, because the device is ejected after
@@ -406,20 +466,27 @@ gint ZipToolUnlock(
 	edv_device_struct *dev_ptr, const gchar *password
 )
 {
-	gchar *cmd;
+	gchar *cmd, *prog;
 	FILE *fp;
 
 	*last_error = '\0';             /* Reset last error message */
 
 	if(dev_ptr == NULL)
 	    return(-2);
-
 	if(STRISEMPTY(dev_ptr->device_path))
 	    return(-2);
 
+	/* Get the ZipTool program */
+	prog = ZipToolGetZipToolProg();
+	if(prog == NULL)
+	    return(-1);
+
 	/* Device is not locked? */
 	if(ZipToolDeviceIsProtected(dev_ptr) == ZIP_TOOL_LOCK_STATE_UNLOCKED)
+	{
+	    g_free(prog);
 	    return(0);
+	}
 
 	if(password == NULL)
 	    password = "";
@@ -427,24 +494,28 @@ gint ZipToolUnlock(
 	/* Format and execute unlock device command */
 	cmd = g_strdup_printf(
 	    "%s -rw %s",
-	    ZIP_TOOL_PROG_PATH,
+	    prog,
 	    dev_ptr->device_path
 	);
 	fp = popen(cmd, "w");
 	g_free(cmd);
 	if(fp == NULL)
+	{
+	    g_free(prog);
 	    return(-3);
+	}
 
 	/* Send password */
 	fprintf(fp, "%s\n", password);
 
 	pclose(fp);
 
+	g_free(prog);
+
 	/* Device was not successfully unlocked? */
-	if(ZipToolDeviceIsProtected(dev_ptr) != ZIP_TOOL_LOCK_STATE_UNLOCKED)
-	    return(-4);
-	else
-	    return(0);
+	return((ZipToolDeviceIsProtected(dev_ptr) != ZIP_TOOL_LOCK_STATE_UNLOCKED) ?
+	    -4 : 0
+	);
 }
 
 /*
@@ -461,16 +532,20 @@ gint ZipToolSpinDown(edv_device_struct *dev_ptr)
 {
 	pid_t p;
 	const gchar *tmp_dir;
-	gchar *cmd, *stderr_path;
+	gchar *cmd, *prog, *stderr_path;
 
 	*last_error = '\0';             /* Reset last error message */
 
 	if(dev_ptr == NULL)
 	    return(-2);
-
 	if(STRISEMPTY(dev_ptr->device_path))
 	    return(-2);
 
+	/* Get the ZipTool program */
+	prog = ZipToolGetZipToolProg();
+	if(prog == NULL)
+	    return(-1);
+
 	/* Get temp dir */
 	tmp_dir = g_getenv("TMPDIR");
 	if(STRISEMPTY(tmp_dir))
@@ -487,7 +562,7 @@ gint ZipToolSpinDown(edv_device_struct *dev_ptr)
 	/* Format and execute spin down command */
 	cmd = g_strdup_printf(
 	    "%s -p %s",
-	    ZIP_TOOL_PROG_PATH,
+	    prog,
 	    dev_ptr->device_path
 	);
 	p = ExecBOE(cmd, DEV_NULL_PATH, stderr_path);
@@ -502,6 +577,8 @@ gint ZipToolSpinDown(edv_device_struct *dev_ptr)
 	UNLINK(stderr_path);
 	g_free(stderr_path);
 
+	g_free(prog);
+
 	return((p == 0) ? -3 : 0);
 }
 
@@ -520,16 +597,20 @@ gint ZipToolEject(edv_device_struct *dev_ptr)
 {
 	pid_t p;
 	const gchar *tmp_dir;
-	gchar *cmd, *stderr_path;
+	gchar *cmd, *prog,  *stderr_path;
 
 	*last_error = '\0';             /* Reset last error message */
 
 	if(dev_ptr == NULL)
 	    return(-2);
-
 	if(STRISEMPTY(dev_ptr->device_path))
 	    return(-2);
 
+	/* Get the ZipTool program */
+	prog = ZipToolGetZipToolProg();
+	if(prog == NULL)
+	    return(-1);
+
 	/* Get temp dir */
 	tmp_dir = g_getenv("TMPDIR");
 	if(STRISEMPTY(tmp_dir))
@@ -546,7 +627,7 @@ gint ZipToolEject(edv_device_struct *dev_ptr)
 	/* Format and execute eject command */
 	cmd = g_strdup_printf(
 	    "%s -e %s",
-	    ZIP_TOOL_PROG_PATH,
+	    prog,
 	    dev_ptr->device_path
 	);
 	p = ExecBOE(cmd, DEV_NULL_PATH, stderr_path);
@@ -561,6 +642,7 @@ gint ZipToolEject(edv_device_struct *dev_ptr)
 	UNLINK(stderr_path);
 	g_free(stderr_path);
 
+	g_free(prog);
+
 	return((p == 0) ? -3 : 0);
 }
-
